@@ -10,10 +10,7 @@ int main(int argc, char **argv)
 
   // Import resources from libCGALQt4.
   // See http://doc.trolltech.com/4.4/qdir.html#Q_INIT_RESOURCE
-  Q_INIT_RESOURCE(File);
-  Q_INIT_RESOURCE(Triangulation_2); 
-  Q_INIT_RESOURCE(Input);
-  Q_INIT_RESOURCE(CGAL);
+  CGAL_QT4_INIT_RESOURCES
 
   MainWindow mainWindow;
   mainWindow.show();
@@ -25,11 +22,26 @@ int main(int argc, char **argv)
     mainWindow.setAddKeyFrameKeyboardModifiers(::Qt::MetaModifier);
     args.removeAt(0);
   }
-
+#ifdef QT_SCRIPT_LIB
+  if(!args.empty() && args[0] == "--debug-scripts")
+  {
+    mainWindow.enableScriptDebugger();
+    args.removeAt(0);
+  }
+  mainWindow.open("autostart.js", true);
+#endif
   Q_FOREACH(QString filename, args) {
     mainWindow.open(filename);
   }
-  return app.exec();
+
+  // A Qt Script may have closed the main window
+  // The following loop launch app.exec() only if there is a visible
+  // window.
+  Q_FOREACH (QWidget *widget, QApplication::topLevelWidgets()) {
+    if(widget->isVisible())
+      return app.exec();
+  }
+  return 0;
 }
 
 #ifndef USE_FORWARD_DECL
