@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Filtered_kernel/examples/Filtered_kernel/Cartesian_I.h $
-// $Id: Cartesian_I.h 51161 2009-08-10 15:57:03Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Filtered_kernel/examples/Filtered_kernel/Cartesian_I.h $
+// $Id: Cartesian_I.h 56667 2010-06-09 07:37:13Z sloriot $
 //
 //
 // Author(s)     : Herve Bronnimann, Sylvain Pion
@@ -28,7 +28,7 @@
 #include <CGAL/Handle_for.h>
 #include <CGAL/Kernel/Type_equality_wrapper.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 namespace CartesianKernelFunctors {
 
@@ -103,6 +103,6 @@ struct Cartesian_I
                 Cartesian_I<FT_> >
 {};
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_CARTESIAN_I_H
