@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: $
-// $Id: $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Mesh_3/examples/Mesh_3/mesh_implicit_domains.cpp $
+// $Id: mesh_implicit_domains.cpp 58703 2010-09-20 12:12:46Z lrineau $
 //
 //
 // Author(s)     : Stéphane Tayeb
@@ -44,7 +44,7 @@
 using namespace CGAL::parameters;
 
 // Domain
-struct K: public CGAL::Exact_predicates_inexact_constructions_kernel {};
+typedef CGAL::Exact_predicates_inexact_constructions_kernel K;
 typedef FT_to_point_function_wrapper<K::FT, K::Point_3> Function;
 typedef CGAL::Mesh_3::Implicit_vector_to_labeled_function_wrapper<Function, K>
                                                         Function_wrapper;
