@@ -17,8 +17,8 @@
 // and a STREP (FET Open) Project under Contract No  IST-006413 
 // (ACS -- Algorithms for Complex Shapes)
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Algebraic_kernel_for_spheres/include/CGAL/Algebraic_kernel_for_spheres_2_3.h $
-// $Id: Algebraic_kernel_for_spheres_2_3.h 46224 2008-10-13 11:22:46Z pmachado $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Algebraic_kernel_for_spheres/include/CGAL/Algebraic_kernel_for_spheres_2_3.h $
+// $Id: Algebraic_kernel_for_spheres_2_3.h 63778 2011-05-31 13:03:27Z sloriot $
 //
 // Author(s) : Monique Teillaud <Monique.Teillaud@sophia.inria.fr>
 //             Sylvain Pion
@@ -29,7 +29,7 @@
 #ifndef CGAL_ALGEBRAIC_KERNEL_FOR_SPHERES_2_3_H
 #define CGAL_ALGEBRAIC_KERNEL_FOR_SPHERES_2_3_H
 
-#include <CGAL/Root_of_2.h>
+#include <CGAL/Root_of_traits.h>
 #include <CGAL/Polynomials_2_3.h>
 #include <CGAL/Polynomials_1_3.h>
 #include <CGAL/Polynomials_for_line_3.h>
@@ -40,7 +40,7 @@
 #include <CGAL/global_functions_on_roots_and_polynomials_2_3.h>
 #include <CGAL/global_functions_on_root_for_sphere_2_3.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
   template< class RT_ >
   struct Algebraic_kernel_for_spheres_2_3
@@ -120,6 +120,6 @@ CGAL_BEGIN_NAMESPACE
 
   };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_ALGEBRAIC_KERNEL_FOR_SPHERES_2_3_H
