@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Alpha_shapes_2/include/CGAL/Alpha_shape_euclidean_traits_2.h $
-// $Id: Alpha_shape_euclidean_traits_2.h 28567 2006-02-16 14:30:13Z lsaboret $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Alpha_shapes_2/include/CGAL/Alpha_shape_euclidean_traits_2.h $
+// $Id: Alpha_shape_euclidean_traits_2.h 56667 2010-06-09 07:37:13Z sloriot $
 // 
 //
 // Author(s)     : Tran Kai Frank DA <Frank.Da@sophia.inria.fr>
@@ -22,12 +22,12 @@
 #define CGAL_ALPHA_SHAPE_EUCLIDEAN_TRAITS_H
 
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template < class R >
 class Alpha_shape_euclidean_traits_2 : public R
 {};
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
