@@ -11,11 +11,11 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Apollonius_graph_2/include/CGAL/Apollonius_graph_2.h $
-// $Id: Apollonius_graph_2.h 51456 2009-08-24 17:10:04Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Apollonius_graph_2/include/CGAL/Apollonius_graph_2.h $
+// $Id: Apollonius_graph_2.h 63970 2011-06-08 06:31:19Z mkaravel $
 // 
 //
-// Author(s)     : Menelaos Karavelas <mkaravel@cse.nd.edu>
+// Author(s)     : Menelaos Karavelas <mkaravel@iacm.forth.gr>
 
 
 
@@ -47,7 +47,7 @@
 #include <CGAL/Concatenate_iterator.h>
 
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 
 namespace internal {
@@ -320,7 +320,7 @@ public:
   size_type number_of_hidden_sites() const {
     //    if ( !Vertex::StoreHidden ) { return 0; }
 
-    int n_hidden(0);
+    size_type n_hidden(0);
     for (Finite_vertices_iterator vit = finite_vertices_begin();
 	 vit != finite_vertices_end(); ++vit) {
       n_hidden += vit->number_of_hidden_sites();
@@ -475,7 +475,7 @@ public:
   // INSERTION
   //----------
   template< class Input_iterator >
-  unsigned int insert(Input_iterator first, Input_iterator beyond) {
+  size_type insert(Input_iterator first, Input_iterator beyond) {
     // copy to a local container
     Site_list wp_list;
     for (Input_iterator it = first; it != beyond; ++it) {
@@ -493,7 +493,7 @@ public:
     }
 
     // store how many sites where in the range
-    unsigned int num = wp_list.size();
+    size_type num = wp_list.size();
 
     // clear the local container
     wp_list.clear();
@@ -599,12 +599,12 @@ public:
       CGAL::Hyperbola_2<Gt>            h;
       CGAL::Hyperbola_segment_2<Gt>    hs;
       CGAL::Hyperbola_ray_2<Gt>        hr;
-      if (assign(hs, o))  hs.draw(str);
-      if (assign(s, o))   str << s; 
-      if (assign(hr, o))  hr.draw(str);
-      if (assign(r, o))   str << r;
-      if (assign(h, o))   h.draw(str);
-      if (assign(l, o))   str << l;
+      if (assign(hs, o)) hs.draw(str);
+      else if (assign(s, o))  str << s; 
+      else if (assign(hr, o))  hr.draw(str);
+      else if (assign(r, o))   str << r;
+      else if (assign(h, o))  h.draw(str);
+      else if (assign(l, o)) str << l;
     }
     return str;
   }
@@ -1328,7 +1328,7 @@ std::istream& operator>>(std::istream& is,
   return is;
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #include <CGAL/Apollonius_graph_2/Apollonius_graph_2_impl.h>
 
