@@ -11,11 +11,11 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Apollonius_graph_2/include/CGAL/Apollonius_graph_2/basic.h $
-// $Id: basic.h 48840 2009-04-21 18:17:32Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Apollonius_graph_2/include/CGAL/Apollonius_graph_2/basic.h $
+// $Id: basic.h 63970 2011-06-08 06:31:19Z mkaravel $
 // 
 //
-// Author(s)     : Menelaos Karavelas <mkaravel@cse.nd.edu>
+// Author(s)     : Menelaos Karavelas <mkaravel@iacm.forth.gr>
 
 #ifndef CGAL_APOLLONIUS_GRAPH_2_BASIC_H
 #define CGAL_APOLLONIUS_GRAPH_2_BASIC_H 1
@@ -25,10 +25,5 @@
 
 #define CGAL_APOLLONIUS_GRAPH_2_NS CGAL::ApolloniusGraph_2
 
-#define CGAL_APOLLONIUS_GRAPH_2_BEGIN_NAMESPACE \
-  namespace ApolloniusGraph_2 {
-
-#define CGAL_APOLLONIUS_GRAPH_2_END_NAMESPACE }
-
 
 #endif // CGAL_APOLLONIUS_GRAPH_2_BASIC_H
