@@ -11,11 +11,11 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Apollonius_graph_2/include/CGAL/Apollonius_graph_2/compare_quadratic.h $
-// $Id: compare_quadratic.h 32776 2006-07-30 13:02:57Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Apollonius_graph_2/include/CGAL/Apollonius_graph_2/compare_quadratic.h $
+// $Id: compare_quadratic.h 63970 2011-06-08 06:31:19Z mkaravel $
 // 
 //
-// Author(s)     : Menelaos Karavelas <mkaravel@cse.nd.edu>
+// Author(s)     : Menelaos Karavelas <mkaravel@iacm.forth.gr>
 
 
 
@@ -25,9 +25,9 @@
 #include <CGAL/Apollonius_graph_2/basic.h>
 #include <CGAL/functions_on_signs.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
-CGAL_APOLLONIUS_GRAPH_2_BEGIN_NAMESPACE
+namespace ApolloniusGraph_2 {
 
 #ifdef COMPARATOR_PROFILER
 #include <CGAL/Apollonius_graph_2/comparator_profiler.h>
@@ -983,8 +983,8 @@ ke_compare_r1_r2_filtered(const CT& a1, const CT& b1, const CT& c1,
 //--------------------------------------------------------------------
 //--------------------------------------------------------------------
 
-CGAL_APOLLONIUS_GRAPH_2_END_NAMESPACE
+} //namespace ApolloniusGraph_2
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_APOLLONIUS_GRAPH_2_COMPARE_QUADRATIC_H
