@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.3-branch/Approximate_min_ellipsoid_d/include/CGAL/Approximate_min_ellipsoid_d/Approximate_min_ellipsoid_d_debug.h $
-// $Id: Approximate_min_ellipsoid_d_debug.h 37176 2007-03-17 08:35:57Z afabri $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Approximate_min_ellipsoid_d/include/CGAL/Approximate_min_ellipsoid_d/Approximate_min_ellipsoid_d_debug.h $
+// $Id: Approximate_min_ellipsoid_d_debug.h 58436 2010-09-02 09:54:58Z afabri $
 // 
 //
 // Author(s)     : Kaspar Fischer <fischerk@inf.ethz.ch>
@@ -24,6 +24,8 @@
 #include <map>
 #include <iostream>
 #include <fstream>
+#include <sstream>
+#include <boost/random/linear_congruential.hpp>
 
 namespace CGAL {
 
@@ -214,7 +216,7 @@ namespace CGAL {
         // fetch current usage:
         rusage now;
         int status = getrusage(RUSAGE_SELF,&now);
-        assert(status == 0);
+        CGAL_assertion(status == 0);
         
         // save it:
         timers[std::string(timer_name)] = now.ru_utime;
@@ -223,12 +225,12 @@ namespace CGAL {
       float lapse(const char *name)
       {
         // assert that start(name) has been called before:
-        assert(timers.find(std::string(name)) != timers.end());
+        CGAL_assertion(timers.find(std::string(name)) != timers.end());
         
         // get current usage:
         rusage now;
         int status = getrusage(RUSAGE_SELF,&now);
-        assert(status == 0);
+        CGAL_assertion(status == 0);
         
         // compute elapsed usage:
         now.ru_utime -= (*timers.find(std::string(name))).second;
@@ -273,7 +275,8 @@ namespace CGAL {
       bool adjust_bb;
       double zoom;
       std::string filename;
-      
+      boost::rand48 rng;  
+
     public: // construction and destruction:
       
       // Begins exporting to file filename.  Sets the current stroke mode
@@ -575,7 +578,7 @@ namespace CGAL {
 
 	// generate next angle (if needed):
 	if (lm == Random_angle)
-	  next_angle = static_cast<double>(std::rand());
+	  next_angle = static_cast<double>(rng());
 	
 	// update counter and label:
 	next_label = default_label(++count);
@@ -621,7 +624,7 @@ namespace CGAL {
 	
 	// generate next angle (if needed):
 	if (lm == Random_angle)
-	  next_angle = static_cast<double>(std::rand());
+	  next_angle = static_cast<double>(rng());
 	
 	// update counter and label:
 	next_label = default_label(++count);
@@ -686,7 +689,7 @@ namespace CGAL {
 
 	// generate next angle (if needed):
 	if (lm == Random_angle)
-	  next_angle = static_cast<double>(std::rand());
+	  next_angle = static_cast<double>(rng());
 	
 	// update counter and label:
 	next_label = default_label(++count);
