@@ -1,4 +1,4 @@
-// Copyright (c) 2006  Tel-Aviv University (Israel).
+// Copyright (c) 2006,2007,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Arr_Bezier_curve_traits_2.h $
-// $Id: Arr_Bezier_curve_traits_2.h 51984 2009-09-20 16:18:10Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arr_Bezier_curve_traits_2.h $
+// $Id: Arr_Bezier_curve_traits_2.h 64639 2011-07-06 11:41:06Z lrineau $
 // 
 // 
 // Author(s)     : Ron Wein     <wein@post.tau.ac.il>
@@ -33,7 +33,7 @@
 #include <CGAL/Arr_geometry_traits/Bezier_cache.h>
 #include <CGAL/Arr_geometry_traits/Bezier_bounding_rational_traits.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 /*! \class
  * A traits class for maintaining an arrangement of Bezier curves with
@@ -76,11 +76,12 @@ public:
   // Category tags:
   typedef Tag_true                               Has_left_category;
   typedef Tag_true                               Has_merge_category;
+  typedef Tag_false                              Has_do_intersect_category;
 
-  typedef Arr_oblivious_side_tag                 Arr_left_side_category;
-  typedef Arr_oblivious_side_tag                 Arr_bottom_side_category;
-  typedef Arr_oblivious_side_tag                 Arr_top_side_category;
-  typedef Arr_oblivious_side_tag                 Arr_right_side_category;
+  typedef Arr_oblivious_side_tag                 Left_side_category;
+  typedef Arr_oblivious_side_tag                 Bottom_side_category;
+  typedef Arr_oblivious_side_tag                 Top_side_category;
+  typedef Arr_oblivious_side_tag                 Right_side_category;
 
   // Traits-class types:
   typedef _Bezier_curve_2<Rat_kernel,
@@ -98,6 +99,9 @@ public:
                           Nt_traits,
                           Bounding_traits>             Point_2;
 
+  typedef typename X_monotone_curve_2::Multiplicity    Multiplicity;
+
+
   // Type definition for the vertical-tangnecy and intersection point cache.
   typedef _Bezier_cache<Nt_traits>                     Bezier_cache;
 
@@ -563,21 +567,18 @@ public:
 
         for (pit = vpts.begin(); pit != vpts.end(); ++pit)
         {
-          *oi = CGAL::make_object (X_monotone_curve_2 (B, xid,
-                                                       p0, *pit,
-                                                       *p_cache));
-          ++oi;
-
+          *oi++ = CGAL::make_object (X_monotone_curve_2 (B, xid,
+                                                         p0, *pit,
+                                                         *p_cache));
           xid++;
           p0 = *pit;
         }
 
         Point_2    p1(B, Rational(1)); // A rational end point.
 
-        *oi = CGAL::make_object (X_monotone_curve_2 (B, xid,
-                                                     p0, p1,
-                                                     *p_cache));
-
+        *oi++ = CGAL::make_object (X_monotone_curve_2 (B, xid,
+                                                       p0, p1,
+                                                       *p_cache));
         return (oi);
       }
 
@@ -598,21 +599,18 @@ public:
       for (it = vt_list.begin(); it != vt_list.end(); ++it)
       {
         p1 = Point_2 (B, *it);
-        *oi = CGAL::make_object (X_monotone_curve_2 (B, xid,
-                                                     p0, p1,
-                                                     *p_cache));
-        ++oi;
-
+        *oi++ = CGAL::make_object (X_monotone_curve_2 (B, xid,
+                                                       p0, p1,
+                                                       *p_cache));
         xid++;
         p0 = p1;
       }
 
       // Create the final subcurve.
       p1 = Point_2 (B, Rational(1));
-      *oi = CGAL::make_object (X_monotone_curve_2 (B, xid,
-                                                   p0, p1,
-                                                   *p_cache));
-
+      *oi++ = CGAL::make_object (X_monotone_curve_2 (B, xid,
+                                                     p0, p1,
+                                                     *p_cache));
       return (oi);
     }
   };
@@ -807,6 +805,6 @@ public:
   //@}
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
