@@ -1,4 +1,4 @@
-// Copyright (c) 2006  Tel-Aviv University (Israel).
+// Copyright (c) 2006,2007,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Arr_bounded_planar_topology_traits_2.h $
-// $Id: Arr_bounded_planar_topology_traits_2.h 51984 2009-09-20 16:18:10Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arr_bounded_planar_topology_traits_2.h $
+// $Id: Arr_bounded_planar_topology_traits_2.h 64639 2011-07-06 11:41:06Z lrineau $
 // 
 //
 // Author(s) : Ron Wein        <wein@post.tau.ac.il>
@@ -35,7 +35,7 @@
 #include <CGAL/Arr_topology_traits/Arr_bounded_planar_vert_decomp_helper.h>
 #include <CGAL/Arr_topology_traits/Arr_inc_insertion_zone_visitor.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 // Forward declaration:
 template <class GeomTraits_, class TopTraits_> 
@@ -75,28 +75,27 @@ public:
   typedef typename Base::Isolated_vertex                  Isolated_vertex;
   //@}
 
-  // TODO remove adaptor as top-traits might be instantiated by Aos_2 itself
+  //! \name Arrangement types
+  //!@{
+  typedef Arr_bounded_planar_topology_traits_2<Geometry_traits_2, Dcel> Self;
   typedef Arr_traits_basic_adaptor_2<Geometry_traits_2>   Traits_adaptor_2;
-  
-  typedef Arr_bounded_planar_topology_traits_2<Geometry_traits_2, Dcel>
-                                                          Self;
+  //!@}
   
   ///! \name The side tags
   //@{
-  // are inherited from the geometry traits
-  typedef typename Traits_adaptor_2::Arr_left_side_category   Arr_left_side_category;
-  typedef typename Traits_adaptor_2::Arr_bottom_side_category Arr_bottom_side_category;
-  typedef typename Traits_adaptor_2::Arr_top_side_category    Arr_top_side_category;
-  typedef typename Traits_adaptor_2::Arr_right_side_category  Arr_right_side_category;
+  typedef typename Traits_adaptor_2::Left_side_category   Left_side_category;
+  typedef typename Traits_adaptor_2::Bottom_side_category Bottom_side_category;
+  typedef typename Traits_adaptor_2::Top_side_category    Top_side_category;
+  typedef typename Traits_adaptor_2::Right_side_category  Right_side_category;
   
   BOOST_MPL_ASSERT
-  ((boost::is_same< Arr_left_side_category, Arr_oblivious_side_tag >));
+  ((boost::is_same< Left_side_category, Arr_oblivious_side_tag >));
   BOOST_MPL_ASSERT
-  ((boost::is_same< Arr_bottom_side_category, Arr_oblivious_side_tag >));
+  ((boost::is_same< Bottom_side_category, Arr_oblivious_side_tag >));
   BOOST_MPL_ASSERT
-  ((boost::is_same< Arr_top_side_category, Arr_oblivious_side_tag >));
+  ((boost::is_same< Top_side_category, Arr_oblivious_side_tag >));
   BOOST_MPL_ASSERT
-  ((boost::is_same< Arr_right_side_category, Arr_oblivious_side_tag >));
+  ((boost::is_same< Right_side_category, Arr_oblivious_side_tag >));
   //@}
 
   /*! \struct
@@ -207,7 +206,7 @@ private:
 
   /// \name Auxiliary type definitions.
   //@{
-  typedef Arrangement_on_surface_2<Geometry_traits_2, Self>    Arr;
+  typedef Arrangement_on_surface_2<Geometry_traits_2, Self>             Arr;
 
   // Type definition for the constuction sweep-line visitor.
   typedef Arr_construction_subcurve<Geometry_traits_2>         CSubcurve; 
@@ -630,7 +629,7 @@ public:
   //@}
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #include <CGAL/Arr_topology_traits/Arr_bounded_planar_topology_traits_2_impl.h>
 
