@@ -1,4 +1,4 @@
-// Copyright (c) 2005  Tel-Aviv University (Israel).
+// Copyright (c) 2005,2006,2007,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Arr_circle_segment_traits_2.h $
-// $Id: Arr_circle_segment_traits_2.h 51984 2009-09-20 16:18:10Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arr_circle_segment_traits_2.h $
+// $Id: Arr_circle_segment_traits_2.h 64639 2011-07-06 11:41:06Z lrineau $
 // 
 //
 // Author(s)     : Ron Wein          <wein@post.tau.ac.il>
@@ -31,7 +31,7 @@
 
 #include <fstream>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 /*! \class
  * A traits class for maintaining an arrangement of circles.
@@ -43,6 +43,9 @@ public:
 
   typedef Kernel_                                        Kernel;
   typedef typename Kernel::FT                            NT;
+  typedef typename Kernel::Point_2                       Rational_point_2;
+  typedef typename Kernel::Segment_2                     Rational_segment_2;
+  typedef typename Kernel::Circle_2                      Rational_circle_2;
   typedef _One_root_point_2<NT, Filter_>                 Point_2;
   typedef typename Point_2::CoordNT                      CoordNT;
   typedef _Circle_segment_2<Kernel, Filter_>             Curve_2;
@@ -51,13 +54,14 @@ public:
   typedef Arr_circle_segment_traits_2<Kernel, Filter_>   Self;
 
   // Category tags:
-  typedef Tag_true                                       Has_left_category;
-  typedef Tag_true                                       Has_merge_category;
+  typedef Tag_true                                     Has_left_category;
+  typedef Tag_true                                     Has_merge_category;
+  typedef Tag_false                                    Has_do_intersect_category;
 
-  typedef Arr_oblivious_side_tag                         Arr_left_side_category;
-  typedef Arr_oblivious_side_tag                         Arr_bottom_side_category;
-  typedef Arr_oblivious_side_tag                         Arr_top_side_category;
-  typedef Arr_oblivious_side_tag                         Arr_right_side_category;
+  typedef Arr_oblivious_side_tag                       Left_side_category;
+  typedef Arr_oblivious_side_tag                       Bottom_side_category;
+  typedef Arr_oblivious_side_tag                       Top_side_category;
+  typedef Arr_oblivious_side_tag                       Right_side_category;
     
 protected:
 
@@ -677,6 +681,6 @@ public:
 
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
