@@ -1,4 +1,4 @@
-// Copyright (c) 2003-2006  INRIA Sophia-Antipolis (France).
+// Copyright (c) 2003,2004,2005,2006,2007,2008,2009,2010,2011 INRIA Sophia-Antipolis (France).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Arrangement_on_surface_2/include/CGAL/Arr_circular_line_arc_traits_2.h $
-// $Id: Arr_circular_line_arc_traits_2.h 59736 2010-11-16 19:54:03Z sloriot $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arr_circular_line_arc_traits_2.h $
+// $Id: Arr_circular_line_arc_traits_2.h 64639 2011-07-06 11:41:06Z lrineau $
 //
 // Author(s)     : Monique Teillaud, Sylvain Pion, Julien Hazebrouck
 
@@ -533,10 +533,10 @@ namespace CGAL {
     typedef CGAL::Tag_false 			   Has_merge_category;
     typedef CGAL::Tag_false                        Has_do_intersect_category;
 
-    typedef Arr_oblivious_side_tag                 Arr_left_side_category;
-    typedef Arr_oblivious_side_tag                 Arr_bottom_side_category;
-    typedef Arr_oblivious_side_tag                 Arr_top_side_category;
-    typedef Arr_oblivious_side_tag                 Arr_right_side_category;
+    typedef Arr_oblivious_side_tag                 Left_side_category;
+    typedef Arr_oblivious_side_tag                 Bottom_side_category;
+    typedef Arr_oblivious_side_tag                 Top_side_category;
+    typedef Arr_oblivious_side_tag                 Right_side_category;
     
     typedef internal_Argt_traits::Not_X_Monotone                Not_X_Monotone;
   
