@@ -1,4 +1,4 @@
-// Copyright (c) 2005, 2009  Tel-Aviv University (Israel).
+// Copyright (c) 2006,2007,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Arr_consolidated_curve_data_traits_2.h $
-// $Id: Arr_consolidated_curve_data_traits_2.h 51984 2009-09-20 16:18:10Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arr_consolidated_curve_data_traits_2.h $
+// $Id: Arr_consolidated_curve_data_traits_2.h 64639 2011-07-06 11:41:06Z lrineau $
 // 
 //
 // Author(s)     : Ron Wein          <wein@post.tau.ac.il>
@@ -28,7 +28,7 @@
 #include<CGAL/Arr_curve_data_traits_2.h>
 #include<CGAL/Arr_geometry_traits/Consolidated_curve_data_aux.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 /*! \class
  * A generic traits class for maintaining an arrangement of curves that have
@@ -77,16 +77,21 @@ public:
   
   typedef typename Base_traits_2::Has_merge_category  Base_has_merge_category;
   typedef Tag_true                                    Has_merge_category;
+  typedef typename Base_traits_2::Has_do_intersect_category
+                                                      Has_do_intersect_category;
 
   // Base_traits_2 is Arr_curve_data_traits that already completes
   // incomplete tags
-  typedef typename Base_traits_2::Arr_left_side_category   Arr_left_side_category;
-  typedef typename Base_traits_2::Arr_bottom_side_category Arr_bottom_side_category;
-  typedef typename Base_traits_2::Arr_top_side_category    Arr_top_side_category;
-  typedef typename Base_traits_2::Arr_right_side_category  Arr_right_side_category;
+  typedef typename Base_traits_2::Left_side_category
+                                                      Left_side_category;
+  typedef typename Base_traits_2::Bottom_side_category
+                                                      Bottom_side_category;
+  typedef typename Base_traits_2::Top_side_category
+                                                      Top_side_category;
+  typedef typename Base_traits_2::Right_side_category
+                                                      Right_side_category;
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
-
