@@ -1,4 +1,4 @@
-// Copyright (c) 2005  Tel-Aviv University (Israel).
+// Copyright (c) 2005,2007,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,10 +11,11 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Arr_counting_traits_2.h $
-// $Id: Arr_counting_traits_2.h 51984 2009-09-20 16:18:10Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arr_counting_traits_2.h $
+// $Id: Arr_counting_traits_2.h 64718 2011-07-11 10:15:31Z efif $
 //
-// Author(s)     : Efi Fogel    <efif@post.tau.ac.il>
+// Author(s): Efi Fogel      <efif@post.tau.ac.il>
+//            Eric Berberich <ericb@post.tau.ac.il>
 
 #ifndef CGAL_ARR_COUNTING_TRAITS_H
 #define CGAL_ARR_COUNTING_TRAITS_H
@@ -31,8 +32,9 @@
 
 #include <CGAL/basic.h>
 #include <CGAL/Arr_enums.h>
+#include <CGAL/Arr_tags.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 /*! \class 
  * A model of the ArrangementTraits_2 concept that counts the methods invoked.
@@ -62,19 +64,23 @@ public:
     PARAMETER_SPACE_IN_X_CURVE_END_OP,
     PARAMETER_SPACE_IN_X_POINT_OP,
     PARAMETER_SPACE_IN_X_CURVE_OP,
-    COMPARE_Y_NEAR_BOUNDARY_OP,
-    COMPARE_Y_ON_BOUNDARY_OP,
     IS_ON_X_IDENTIFICATION_POINT_OP,
     IS_ON_X_IDENTIFICATION_CURVE_OP,
+    COMPARE_Y_ON_BOUNDARY_OP,
+    COMPARE_Y_NEAR_BOUNDARY_OP,
 
     PARAMETER_SPACE_IN_Y_CURVE_END_OP,
     PARAMETER_SPACE_IN_Y_POINT_OP,
     PARAMETER_SPACE_IN_Y_CURVE_OP,
-    COMPARE_X_NEAR_BOUNDARY_POINT_CURVE_END_OP,
-    COMPARE_X_NEAR_BOUNDARY_CURVE_ENDS_OP,
-    COMPARE_X_ON_BOUNDARY_OP,
     IS_ON_Y_IDENTIFICATION_POINT_OP,
     IS_ON_Y_IDENTIFICATION_CURVE_OP,
+    COMPARE_X_AT_LIMIT_POINT_CURVE_END_OP,
+    COMPARE_X_AT_LIMIT_CURVE_ENDS_OP,
+    COMPARE_X_NEAR_LIMIT_OP,
+    COMPARE_X_ON_BOUNDARY_POINTS_OP,
+    COMPARE_X_ON_BOUNDARY_POINT_CURVE_END_OP,
+    COMPARE_X_ON_BOUNDARY_CURVE_ENDS_OP,
+    COMPARE_X_NEAR_BOUNDARY_OP,
     
     NUMBER_OF_OPERATIONS
   };
@@ -90,7 +96,7 @@ public:
   }
 
   /*! Construct copy */
-  Arr_counting_traits_2(Arr_counting_traits_2 & other) : Base(other)
+  Arr_counting_traits_2(Arr_counting_traits_2& other) : Base(other)
   {
     clear_counters();
     increment();
@@ -162,11 +168,18 @@ public:
   unsigned int count_parameter_space_in_x_point() const
   { return m_counters[PARAMETER_SPACE_IN_X_POINT_OP]; }
   
+  unsigned int count_is_on_x_identification_point() const
+  { return m_counters[IS_ON_X_IDENTIFICATION_POINT_OP]; }
+
+  unsigned int count_is_on_x_identification_curve() const
+  { return m_counters[IS_ON_X_IDENTIFICATION_CURVE_OP]; }
+
+  unsigned int count_compare_y_on_boundary() const
+  { return m_counters[COMPARE_Y_ON_BOUNDARY_OP]; }
+
   unsigned int count_compare_y_near_boundary() const
   { return m_counters[COMPARE_Y_NEAR_BOUNDARY_OP]; }
 
-    unsigned int count_compare_y_on_boundary() const
-  { return m_counters[COMPARE_Y_ON_BOUNDARY_OP]; }
 
   // bottom-top
 
@@ -179,48 +192,67 @@ public:
   unsigned int count_parameter_space_in_y_point() const
   { return m_counters[PARAMETER_SPACE_IN_Y_POINT_OP]; }
 
-  unsigned int count_compare_x_near_boundary_point_curve_end() const
-  { return m_counters[COMPARE_X_NEAR_BOUNDARY_POINT_CURVE_END_OP]; }
+  unsigned int count_is_on_y_identification_point() const
+  { return m_counters[IS_ON_Y_IDENTIFICATION_POINT_OP]; }
 
-  unsigned int count_compare_x_near_boundary_curve_ends() const
-  { return m_counters[COMPARE_X_NEAR_BOUNDARY_CURVE_ENDS_OP]; }
-  
-  unsigned int count_compare_x_on_boundary() const
-  { return m_counters[COMPARE_X_ON_BOUNDARY_OP]; }
+  unsigned int count_is_on_y_identification_curve() const
+  { return m_counters[IS_ON_Y_IDENTIFICATION_CURVE_OP]; }
+
+  unsigned int count_compare_x_at_limit_point_curve_end() const
+  { return m_counters[COMPARE_X_AT_LIMIT_POINT_CURVE_END_OP]; }
+
+  unsigned int count_compare_x_at_limit_curve_ends() const
+  { return m_counters[COMPARE_X_AT_LIMIT_CURVE_ENDS_OP]; }
+
+  unsigned int count_compare_x_near_limit() const
+  { return m_counters[COMPARE_X_NEAR_LIMIT_OP]; }
+
+  unsigned int count_compare_x_on_boundary_points() const
+  { return m_counters[COMPARE_X_ON_BOUNDARY_POINTS_OP]; }
+
+  unsigned int count_compare_x_on_boundary_point_curve_end() const
+  { return m_counters[COMPARE_X_ON_BOUNDARY_POINT_CURVE_END_OP]; }
+
+  unsigned int count_compare_x_on_boundary_curve_ends() const
+  { return m_counters[COMPARE_X_ON_BOUNDARY_CURVE_ENDS_OP]; }
+
+  unsigned int count_compare_x_near_boundary() const
+  { return m_counters[COMPARE_X_NEAR_BOUNDARY_OP]; }
 
   /// \name Types and functors inherited from the base
   //@{
 
   // Traits types:
-  typedef typename Base::Has_left_category      Has_left_category;
-  typedef typename Base::Has_merge_category     Has_merge_category;
+  typedef typename Base::Has_left_category          Has_left_category;
+  typedef typename Base::Has_merge_category         Has_merge_category;
+  typedef typename Base::Has_do_intersect_category  Has_do_intersect_category;
 
-  typedef typename internal::Arr_complete_left_side_tag< Base >::Tag
-                                                Arr_left_side_category;
-  typedef typename internal::Arr_complete_bottom_side_tag< Base >::Tag
-                                                Arr_bottom_side_category;
-  typedef typename internal::Arr_complete_top_side_tag< Base >::Tag
-                                                Arr_top_side_category;
-  typedef typename internal::Arr_complete_right_side_tag< Base >::Tag
-                                                Arr_right_side_category;
+  typedef typename internal::Arr_complete_left_side_category< Base >::Category
+                                                    Left_side_category;
+  typedef typename internal::Arr_complete_bottom_side_category< Base >::Category
+                                                    Bottom_side_category;
+  typedef typename internal::Arr_complete_top_side_category< Base >::Category
+                                                    Top_side_category;
+  typedef typename internal::Arr_complete_right_side_category< Base >::Category
+                                                    Right_side_category;
   
-  typedef typename Base::Point_2                Point_2;
-  typedef typename Base::X_monotone_curve_2     X_monotone_curve_2;
-  typedef typename Base::Curve_2                Curve_2;
+  typedef typename Base::Point_2                    Point_2;
+  typedef typename Base::X_monotone_curve_2         X_monotone_curve_2;
+  typedef typename Base::Curve_2                    Curve_2;
 
   /*! A functor that compares the x-coordinates of two points */
   class Compare_x_2 {
   private:
     typename Base::Compare_x_2 m_object;
-    unsigned int & m_counter;
+    unsigned int& m_counter;
 
   public:
     /*! Construct */
-    Compare_x_2(const Base * base, unsigned int & counter) :
+    Compare_x_2(const Base* base, unsigned int& counter) :
       m_object(base->compare_x_2_object()), m_counter(counter) {}
 
     /*! Operate */
-    Comparison_result operator()(const Point_2 & p1, const Point_2 & p2) const
+    Comparison_result operator()(const Point_2& p1, const Point_2& p2) const
     { ++m_counter; return m_object(p1, p2); }
   };
 
@@ -228,15 +260,15 @@ public:
   class Compare_xy_2 {
   private:
     typename Base::Compare_xy_2 m_object;
-    mutable unsigned int & m_counter;
+    unsigned int& m_counter;
 
   public:
     /*! Construct */
-    Compare_xy_2(const Base * base, unsigned int & counter) :
+    Compare_xy_2(const Base* base, unsigned int& counter) :
       m_object(base->compare_xy_2_object()), m_counter(counter) {}
 
     /*! Operate */
-    Comparison_result operator()(const Point_2 & p1, const Point_2 & p2) const
+    Comparison_result operator()(const Point_2& p1, const Point_2& p2) const
     { ++m_counter; return m_object(p1, p2); }
   };
 
@@ -244,15 +276,15 @@ public:
   class Construct_min_vertex_2 {
   private:
     typename Base::Construct_min_vertex_2 m_object;
-    unsigned int & m_counter;
+    unsigned int& m_counter;
 
   public:
     /*! Construct */
-    Construct_min_vertex_2(const Base * base, unsigned int & counter) :
+    Construct_min_vertex_2(const Base* base, unsigned int& counter) :
       m_object(base->construct_min_vertex_2_object()), m_counter(counter) {}
 
     /*! Operate */
-    const Point_2 operator()(const X_monotone_curve_2 & xc) const
+    const Point_2 operator()(const X_monotone_curve_2& xc) const
     { ++m_counter; return m_object(xc); }
   };
 
@@ -260,15 +292,15 @@ public:
   class Construct_max_vertex_2 {
   private:
     typename Base::Construct_max_vertex_2 m_object;
-    unsigned int & m_counter;
+    unsigned int& m_counter;
 
   public:
     /*! Construct */
-    Construct_max_vertex_2(const Base * base, unsigned int & counter) :
+    Construct_max_vertex_2(const Base* base, unsigned int& counter) :
       m_object(base->construct_max_vertex_2_object()), m_counter(counter) {}
 
     /*! Operate */
-    const Point_2 operator()(const X_monotone_curve_2 & xc) const
+    const Point_2 operator()(const X_monotone_curve_2& xc) const
     { ++m_counter; return m_object(xc); }
   };
   
@@ -276,15 +308,15 @@ public:
   class Is_vertical_2 {
   private:
     typename Base::Is_vertical_2 m_object;
-    unsigned int & m_counter;
+    unsigned int& m_counter;
 
   public:
     /*! Construct */
-    Is_vertical_2(const Base * base, unsigned int & counter) :
+    Is_vertical_2(const Base* base, unsigned int& counter) :
       m_object(base->is_vertical_2_object()), m_counter(counter) {}
 
     /*! Operate */
-    bool operator()(const X_monotone_curve_2 & xc) const
+    bool operator()(const X_monotone_curve_2& xc) const
     { ++m_counter; return m_object(xc); }
   };
   
@@ -294,16 +326,16 @@ public:
   class Compare_y_at_x_2 {
   private:
     typename Base::Compare_y_at_x_2 m_object;
-    unsigned int & m_counter;
+    unsigned int& m_counter;
 
   public:
     /*! Construct */
-    Compare_y_at_x_2(const Base * base, unsigned int & counter) :
+    Compare_y_at_x_2(const Base* base, unsigned int& counter) :
       m_object(base->compare_y_at_x_2_object()), m_counter(counter) {}
 
     /*! Operate */
-    Comparison_result operator()(const Point_2 & p,
-                                 const X_monotone_curve_2 & xc) const
+    Comparison_result operator()(const Point_2& p,
+                                 const X_monotone_curve_2& xc) const
     { ++m_counter; return m_object(p, xc); }
   };
   
@@ -313,24 +345,23 @@ public:
   class Equal_2 {
   private:
     typename Base::Equal_2 m_object;
-    unsigned int & m_counter1;
-    unsigned int & m_counter2;
+    unsigned int& m_counter1;
+    unsigned int& m_counter2;
 
   public:
     /*! Construct */
-    Equal_2(const Base * base,
-            unsigned int & counter1, unsigned int & counter2) :
+    Equal_2(const Base* base, unsigned int& counter1, unsigned int& counter2) :
       m_object(base->equal_2_object()),
       m_counter1(counter1), m_counter2(counter2)
     {}
 
     /*! Operate */
-    bool operator()(const X_monotone_curve_2 & xc1,
-                    const X_monotone_curve_2 & xc2) const
+    bool operator()(const X_monotone_curve_2& xc1,
+                    const X_monotone_curve_2& xc2) const
     { ++m_counter1; return m_object(xc1, xc2); }
 
     /*! Operate */
-    bool operator()(const Point_2 & p1, const Point_2 & p2) const
+    bool operator()(const Point_2& p1, const Point_2& p2) const
     { ++m_counter2; return m_object(p1, p2); }    
   };
 
@@ -340,17 +371,17 @@ public:
   class Compare_y_at_x_left_2 {
   private:
     typename Base::Compare_y_at_x_left_2 m_object;
-    unsigned int & m_counter;
+    unsigned int& m_counter;
 
   public:
     /*! Construct */
-    Compare_y_at_x_left_2(const Base * base, unsigned int & counter) :
+    Compare_y_at_x_left_2(const Base* base, unsigned int& counter) :
       m_object(base->compare_y_at_x_left_2_object()), m_counter(counter) {}
 
     /*! Operate */
-    Comparison_result operator()(const X_monotone_curve_2 & xc1,
-                                 const X_monotone_curve_2 & xc2,
-                                 const Point_2 & p) const
+    Comparison_result operator()(const X_monotone_curve_2& xc1,
+                                 const X_monotone_curve_2& xc2,
+                                 const Point_2& p) const
     { ++m_counter; return m_object(xc1, xc2, p); }
   };
 
@@ -360,17 +391,17 @@ public:
   class Compare_y_at_x_right_2 {
   private:
     typename Base::Compare_y_at_x_right_2 m_object;
-    unsigned int & m_counter;
+    unsigned int& m_counter;
 
   public:
     /*! Construct */
-    Compare_y_at_x_right_2(const Base * base, unsigned int & counter) :
+    Compare_y_at_x_right_2(const Base* base, unsigned int& counter) :
       m_object(base->compare_y_at_x_right_2_object()), m_counter(counter) {}
 
     /*! Operate */
-    Comparison_result operator()(const X_monotone_curve_2 & xc1,
-                                 const X_monotone_curve_2 & xc2,
-                                 const Point_2 & p) const
+    Comparison_result operator()(const X_monotone_curve_2& xc1,
+                                 const X_monotone_curve_2& xc2,
+                                 const Point_2& p) const
     { ++m_counter; return m_object(xc1, xc2, p); }
   };
   
@@ -378,16 +409,16 @@ public:
   class Make_x_monotone_2 {
   private:
     typename Base::Make_x_monotone_2 m_object;
-    unsigned int & m_counter;
+    unsigned int& m_counter;
 
   public:
     /*! Construct */
-    Make_x_monotone_2(const Base * base, unsigned int & counter) :
+    Make_x_monotone_2(const Base* base, unsigned int& counter) :
       m_object(base->make_x_monotone_2_object()), m_counter(counter) {}
 
     /*! Operate */
     template<class OutputIterator>
-    OutputIterator operator()(const Curve_2 & cv, OutputIterator oi) const
+    OutputIterator operator()(const Curve_2& cv, OutputIterator oi) const
     { ++m_counter; return m_object(cv, oi); }
   };
 
@@ -395,16 +426,16 @@ public:
   class Split_2 {
   private:
     typename Base::Split_2 m_object;
-    unsigned int & m_counter;
+    unsigned int& m_counter;
 
   public:
     /*! Construct */
-    Split_2(const Base * base, unsigned int & counter) :
+    Split_2(const Base* base, unsigned int& counter) :
       m_object(base->split_2_object()), m_counter(counter) {}
 
     /*! Operate */
-    void operator()(const X_monotone_curve_2 & xc, const Point_2 & p,
-                    X_monotone_curve_2 & xc1, X_monotone_curve_2 & xc2) const
+    void operator()(const X_monotone_curve_2& xc, const Point_2& p,
+                    X_monotone_curve_2& xc1, X_monotone_curve_2& xc2) const
     { ++m_counter; m_object(xc, p, xc1, xc2); }
   };
 
@@ -412,17 +443,17 @@ public:
   class Intersect_2 {
   private:
     typename Base::Intersect_2 m_object;
-    unsigned int & m_counter;
+    unsigned int& m_counter;
 
   public:
     /*! Construct */
-    Intersect_2(const Base * base, unsigned int & counter) :
+    Intersect_2(const Base* base, unsigned int& counter) :
       m_object(base->intersect_2_object()), m_counter(counter) {}
 
     /*! Operate */
     template<class OutputIterator>
-    OutputIterator operator()(const X_monotone_curve_2 & xc1,
-                              const X_monotone_curve_2 & xc2,
+    OutputIterator operator()(const X_monotone_curve_2& xc1,
+                              const X_monotone_curve_2& xc2,
                               OutputIterator oi) const
     { ++m_counter; return m_object(xc1, xc2, oi); }
   };
@@ -431,16 +462,16 @@ public:
   class Are_mergeable_2 {
   private:
     typename Base::Are_mergeable_2 m_object;
-    unsigned int & m_counter;
+    unsigned int& m_counter;
 
   public:
     /*! Construct */
-    Are_mergeable_2(const Base * base, unsigned int & counter) :
+    Are_mergeable_2(const Base* base, unsigned int& counter) :
       m_object(base->are_mergeable_2_object()), m_counter(counter) {}
 
     /*! Operate */
-    bool operator()(const X_monotone_curve_2 & xc1,
-                    const X_monotone_curve_2 & xc2) const
+    bool operator()(const X_monotone_curve_2& xc1,
+                    const X_monotone_curve_2& xc2) const
     { ++m_counter; return m_object(xc1, xc2); }
   };
 
@@ -448,17 +479,17 @@ public:
   class Merge_2 {
   private:
     typename Base::Merge_2 m_object;
-    unsigned int & m_counter;
+    unsigned int& m_counter;
 
   public:
     /*! Construct */
-    Merge_2(const Base * base, unsigned int & counter) :
+    Merge_2(const Base* base, unsigned int& counter) :
       m_object(base->merge_2_object()), m_counter(counter) {}
 
     /*! Operate */
-    void operator()(const X_monotone_curve_2 & xc1,
-                    const X_monotone_curve_2 & xc2,
-                    X_monotone_curve_2 & xc) const
+    void operator()(const X_monotone_curve_2& xc1,
+                    const X_monotone_curve_2& xc2,
+                    X_monotone_curve_2& xc) const
     { ++m_counter; m_object(xc1, xc2, xc); }
   };
 
@@ -466,15 +497,15 @@ public:
   class Construct_opposite_2 {
   private:
     typename Base::Construct_opposite_2 m_object;
-    unsigned int & m_counter;
+    unsigned int& m_counter;
 
   public:
     /*! Construct */
-    Construct_opposite_2(const Base * base, unsigned int & counter) :
+    Construct_opposite_2(const Base* base, unsigned int& counter) :
       m_object(base->construct_opposite_2_object()), m_counter(counter) {}
 
     /*! Operate */
-    X_monotone_curve_2 operator()(const X_monotone_curve_2 & xc)
+    X_monotone_curve_2 operator()(const X_monotone_curve_2& xc)
     { ++m_counter; return m_object(xc); }
   };
 
@@ -484,15 +515,15 @@ public:
   class Compare_endpoints_xy_2 {
   private:
     typename Base::Compare_endpoints_xy_2 m_object;
-    unsigned int & m_counter;
+    unsigned int& m_counter;
 
   public:
     /*! Construct */
-    Compare_endpoints_xy_2(const Base * base, unsigned int & counter) :
+    Compare_endpoints_xy_2(const Base* base, unsigned int& counter) :
       m_object(base->compare_endpoints_xy_2_object()), m_counter(counter) {}
 
     /*! Operate */
-    Comparison_result operator()(const X_monotone_curve_2 & xc)
+    Comparison_result operator()(const X_monotone_curve_2& xc)
     { ++m_counter; return m_object(xc); }
   };
 
@@ -504,56 +535,62 @@ public:
   class Parameter_space_in_x_2 {
   private:
     typename Base::Parameter_space_in_x_2 m_object;
-    mutable unsigned int & m_counter1;
-    mutable unsigned int & m_counter2;
-    mutable unsigned int & m_counter3;
+    unsigned int& m_counter1;
+    unsigned int& m_counter2;
+    unsigned int& m_counter3;
 
   public:
     /*! Construct */
-    Parameter_space_in_x_2(const Base * base, 
-                           unsigned int & counter1,
-                           unsigned int & counter2,
-                           unsigned int & counter3) :
+    Parameter_space_in_x_2(const Base* base, unsigned int& counter1,
+                           unsigned int& counter2, unsigned int& counter3) :
       m_object(base->parameter_space_in_x_2_object()), 
       m_counter1(counter1),
       m_counter2(counter2),
       m_counter3(counter3) {}
 
     /*! Operate */
-    Arr_parameter_space operator()(const X_monotone_curve_2 & xc,
+    Arr_parameter_space operator()(const X_monotone_curve_2& xc,
                              Arr_curve_end ce) const
     { ++m_counter1; return m_object(xc, ce); }
 
 
     /*! Operate */
-    Arr_parameter_space operator()(const Point_2 & p) const
+    Arr_parameter_space operator()(const Point_2& p) const
     { ++m_counter2; return m_object(p); }
 
 
     /*! Operate */
-    Arr_parameter_space operator()(const X_monotone_curve_2 & xc) const
+    Arr_parameter_space operator()(const X_monotone_curve_2& xc) const
     { ++m_counter3; return m_object(xc); }
 
   };
 
-    /*! A functor that compares the y-coordinates of curve ends near the
-   * boundary of the parameter space.
+  /*! A functor that determines whether a point or a curve lies on an
+   * identification in x.
    */
-  class Compare_y_near_boundary_2 {
+  class Is_on_x_identification_2 {
   private:
-    typename Base::Compare_y_near_boundary_2 m_object;
-    unsigned int & m_counter;
+    typename Base::Is_on_x_identificiation_2 m_object;
+    unsigned int& m_counter1;
+    unsigned int& m_counter2;
 
   public:
     /*! Construct */
-    Compare_y_near_boundary_2(const Base * base, unsigned int & counter) :
-      m_object(base->compare_y_near_boundary_2_object()), m_counter(counter) {}
+    Is_on_x_identification_2(const Base* base, 
+                             unsigned int& counter1, unsigned int& counter2) :
+      m_object(base->is_on_x_identificiation_2_object()), 
+      m_counter1(counter1),
+      m_counter2(counter2) {}
 
     /*! Operate */
-    Comparison_result operator()(const X_monotone_curve_2 & xc1,
-                                 const X_monotone_curve_2 & xc2, 
-                                 Arr_curve_end ce) const
-    { ++m_counter; return m_object(xc1, xc2, ce); }
+    Arr_parameter_space operator()(const Point_2& p) const
+    { ++m_counter1; return m_object(p); }
+
+
+    /*! Operate */
+    Arr_parameter_space operator()(const X_monotone_curve_2& xc) const
+    { ++m_counter2; return m_object(xc); }
+
   };
 
   /*! A functor that compares the y-coordinate of two given points
@@ -562,25 +599,41 @@ public:
   class Compare_y_on_boundary_2 {
   private:
     typename Base::Compare_y_on_boundary_2 m_object;
-    unsigned int & m_counter;
+    unsigned int& m_counter;
 
   public:
     /*! Construct */
-    Compare_y_on_boundary_2(const Base * base, unsigned int & counter) :
+    Compare_y_on_boundary_2(const Base* base, unsigned int& counter) :
       m_object(base->compare_y_on_boundary_2_object()),
       m_counter(counter)
     {}
 
     /*! Operate */
-    Comparison_result operator()(const Point_2 & p1,
-                                 const Point_2 & p2) const
+    Comparison_result operator()(const Point_2& p1, const Point_2& p2) const
     { ++m_counter; return m_object(p1, p2); }
   };
   
-  // TODO Is_on_x_identification_2
-  
-  // bottom-top
+  /*! A functor that compares the y-coordinates of curve ends near the
+   * boundary of the parameter space.
+   */
+  class Compare_y_near_boundary_2 {
+  private:
+    typename Base::Compare_y_near_boundary_2 m_object;
+    unsigned int& m_counter;
 
+  public:
+    /*! Construct */
+    Compare_y_near_boundary_2(const Base* base, unsigned int& counter) :
+      m_object(base->compare_y_near_boundary_2_object()), m_counter(counter) {}
+
+    /*! Operate */
+    Comparison_result operator()(const X_monotone_curve_2& xc1,
+                                 const X_monotone_curve_2& xc2, 
+                                 Arr_curve_end ce) const
+    { ++m_counter; return m_object(xc1, xc2, ce); }
+  };
+
+  // bottom-top
 
   /*! A functor that determines whether an endpoint of an x-monotone arc lies
    * on a boundary of the parameter space along the y axis.
@@ -588,92 +641,177 @@ public:
   class Parameter_space_in_y_2 {
   private:
     typename Base::Parameter_space_in_y_2 m_object;
-    mutable unsigned int & m_counter1;
-    mutable unsigned int & m_counter2;
-    mutable unsigned int & m_counter3;
+    unsigned int& m_counter1;
+    unsigned int& m_counter2;
+    unsigned int& m_counter3;
 
   public:
     /*! Construct */
-    Parameter_space_in_y_2(const Base * base, 
-                           unsigned int & counter1,
-                           unsigned int & counter2,
-                           unsigned int & counter3) :
+    Parameter_space_in_y_2(const Base* base, unsigned int& counter1,
+                           unsigned int& counter2, unsigned int& counter3) :
       m_object(base->parameter_space_in_y_2_object()), 
       m_counter1(counter1),
       m_counter2(counter2),
       m_counter3(counter3) {}
 
     /*! Operate */
-    Arr_parameter_space operator()(const X_monotone_curve_2 & xc,
+    Arr_parameter_space operator()(const X_monotone_curve_2& xc,
                                    Arr_curve_end ce) const
     { ++m_counter1; return m_object(xc, ce); }
 
     /*! Operate */
-    Arr_parameter_space operator()(const Point_2 & p) const
+    Arr_parameter_space operator()(const Point_2& p) const
     { ++m_counter2; return m_object(p); }
 
     /*! Operate */
-    Arr_parameter_space operator()(const X_monotone_curve_2 & xc) const
+    Arr_parameter_space operator()(const X_monotone_curve_2& xc) const
     { ++m_counter3; return m_object(xc); }
     
   };
 
+  /*! A functor that determines whether a point or a curve lies on an
+   * identification in x.
+   */
+  class Is_on_y_identification_2 {
+  private:
+    typename Base::Is_on_y_identificiation_2 m_object;
+    unsigned int& m_counter1;
+    unsigned int& m_counter2;
+
+  public:
+    /*! Construct */
+    Is_on_y_identification_2(const Base* base, 
+                             unsigned int& counter1, unsigned int& counter2) :
+      m_object(base->is_on_y_identificiation_2_object()), 
+      m_counter1(counter1),
+      m_counter2(counter2) {}
+
+    /*! Operate */
+    Arr_parameter_space operator()(const Point_2& p) const
+    { ++m_counter1; return m_object(p); }
+
+
+    /*! Operate */
+    Arr_parameter_space operator()(const X_monotone_curve_2& xc) const
+    { ++m_counter2; return m_object(xc); }
+
+  };
+
+  /*! A functor that compares the x-limits of curve ends on the
+   * boundary of the parameter space.
+   */
+  class Compare_x_at_limit_2 {
+  private:
+    typename Base::Compare_x_at_limit_2 m_object;
+    unsigned int& m_counter1;
+    unsigned int& m_counter2;
+
+  public:
+    /*! Construct */
+    Compare_x_at_limit_2(const Base* base, 
+                         unsigned int& counter1, unsigned int& counter2) :
+      m_object(base->compare_x_at_limit_2_object()), 
+      m_counter1(counter1),
+      m_counter2(counter2) {}
+
+    /*! Operate */
+    Comparison_result operator()(const Point_2& p,
+                                 const X_monotone_curve_2& xc,
+                                 Arr_curve_end ce) const
+    { ++m_counter1; return m_object(p, xc, ce); }
+
+    /*! Operate */
+    Comparison_result operator()(const X_monotone_curve_2& xc1,
+                                 Arr_curve_end ce1,
+                                 const X_monotone_curve_2& xc2,
+                                 Arr_curve_end ce2) const
+    { ++m_counter2; return m_object(xc1, ce1, xc2, ce2); }
+  };
+
+
+  /*! A functor that compares the x-coordinates of curve ends near the
+   * boundary of the parameter space.
+   */
+  class Compare_x_near_limit_2 {
+  private:
+    typename Base::Compare_x_near_limit_2 m_object;
+    unsigned int& m_counter;
+  
+  public:
+    /*! Construct */
+    Compare_x_near_limit_2(const Base* base, unsigned int& counter) :
+      m_object(base->compare_x_near_limit_2_object()), 
+      m_counter(counter) {}
+
+
+    /*! Operate */
+    Comparison_result operator()(const X_monotone_curve_2& xc1,
+                                 const X_monotone_curve_2& xc2,
+                                 Arr_curve_end ce) const
+    { ++m_counter; return m_object(xc1, xc2, ce); }
+  };
+
+  /*! A functor that compares the x-coordinate of two given points
+   * that lie on horizontal boundaries.
+   */
+  class Compare_x_on_boundary_2 {
+  private:
+    typename Base::Compare_x_on_boundary_2 m_object;
+    unsigned int& m_counter1;
+    unsigned int& m_counter2;
+    unsigned int& m_counter3;
+
+  public:
+    /*! Construct */
+  Compare_x_on_boundary_2(const Base* base,  unsigned int& counter1,
+                          unsigned int& counter2, unsigned int& counter3 ) :
+      m_object(base->compare_x_on_boundary_2_object()),
+      m_counter1(counter1),
+      m_counter2(counter2),
+      m_counter3(counter3)
+    {}
+
+    /*! Operate */
+    Comparison_result operator()(const Point_2& p1, const Point_2& p2) const
+    { ++m_counter1; return m_object(p1, p2); }
+
+    /*! Operate */
+    Comparison_result operator()(const Point_2& pt,
+                                 const X_monotone_curve_2& xcv,
+                                 Arr_curve_end ce) const
+    { ++m_counter2; return m_object(pt, xcv, ce); }
+
+    /*! Operate */
+    Comparison_result operator()(const X_monotone_curve_2& xcv1,
+                                 Arr_curve_end ce1,
+                                 const X_monotone_curve_2& xcv2,
+                                 Arr_curve_end ce2) const
+    { ++m_counter3; return m_object(xcv1, ce1, xcv2, ce2); }
+
+  };
+
   /*! A functor that compares the x-coordinates of curve ends near the
    * boundary of the parameter space.
    */
   class Compare_x_near_boundary_2 {
   private:
     typename Base::Compare_x_near_boundary_2 m_object;
-    unsigned int & m_counter1;
-    unsigned int & m_counter2;
-
-  public:
-    /*! Construct */
-    Compare_x_near_boundary_2(const Base * base, 
-                              unsigned int & counter1,
-                              unsigned int & counter2) :
-      m_object(base->compare_x_near_boundary_2_object()), 
-      m_counter1(counter1),
-      m_counter2(counter2) {}
-
-    /*! Operate */
-    Comparison_result operator()(const Point_2 & p,
-                                 const X_monotone_curve_2 & xc,
-                                 Arr_curve_end ce) const
-    { ++m_counter1; return m_object(p, xc, ce); }
-
-    /*! Operate */
-    Comparison_result operator()(const X_monotone_curve_2 & xc1,
-                                 Arr_curve_end ce1,
-                                 const X_monotone_curve_2 & xc2,
-                                 Arr_curve_end ce2) const
-    { ++m_counter2; return m_object(xc1, ce1, xc2, ce2); }
-  };
-
-
-  /*! A functor that compares the x-coordinate of two given points
-   * that lie on horizontal boundaries.
-   */
-  class Compare_x_on_boundary_2 {
-  private:
-    typename Base::Compare_x_on_boundary_2 m_object;
-    unsigned int & m_counter;
-
-  public:
-    /*! Construct */
-    Compare_x_on_boundary_2(const Base * base, unsigned int & counter) :
-      m_object(base->compare_x_on_boundary_2_object()),
-      m_counter(counter)
-    {}
-
-    /*! Operate */
-    Comparison_result operator()(const Point_2 & p1,
-                                 const Point_2 & p2) const
-    { ++m_counter; return m_object(p1, p2); }
-  };
-
+    unsigned int& m_counter;
   
-  // TODO Is_on_y_identification_2
+  public:
+    /*! Construct */
+    Compare_x_near_boundary_2(const Base* base, 
+                              unsigned int& counter) :
+      m_object(base->compare_x_near_boundary_2_object()), 
+      m_counter(counter) {}
+
+
+    /*! Operate */
+    Comparison_result operator()(const X_monotone_curve_2& xc1,
+                                 const X_monotone_curve_2& xc2,
+                                 Arr_curve_end ce) const
+    { ++m_counter; return m_object(xc1, xc2, ce); }
+  };
 
   //@}
 
@@ -743,6 +881,22 @@ public:
     ); 
   }
   
+  Is_on_x_identification_2 is_on_x_identification_2_object() const
+  {
+    return Is_on_x_identification_2(this, 
+                                    m_counters[IS_ON_X_IDENTIFICATION_POINT_OP],
+                                    m_counters[IS_ON_X_IDENTIFICATION_CURVE_OP]);
+  }
+
+  Compare_y_on_boundary_2 compare_on_boundary_2_object() const
+  { return Compare_y_on_boundary_2(this, m_counters[COMPARE_Y_ON_BOUNDARY_OP]); }
+
+  Compare_y_near_boundary_2 compare_near_boundary_2_object() const
+  {
+    return Compare_y_near_boundary_2(this,
+                                     m_counters[COMPARE_Y_NEAR_BOUNDARY_OP]);
+  }
+
   // bottom-top
   Parameter_space_in_y_2 parameter_space_in_y_2_object() const
   { return Parameter_space_in_y_2(
@@ -753,6 +907,39 @@ public:
     ); 
   }
 
+  Is_on_y_identification_2 is_on_y_identification_2_object() const
+  { return Is_on_y_identification_2(
+        this, 
+        m_counters[IS_ON_Y_IDENTIFICATION_POINT_OP],
+        m_counters[IS_ON_Y_IDENTIFICATION_CURVE_OP]
+    ); 
+  }
+
+  Compare_x_at_limit_2 compare_x_at_limit_2_object() const
+  {
+    return
+      Compare_x_at_limit_2(this, 
+                           m_counters[COMPARE_X_AT_LIMIT_POINT_CURVE_END_OP],
+                           m_counters[COMPARE_X_AT_LIMIT_CURVE_ENDS_OP]);
+  }
+
+  Compare_x_near_limit_2 compare_x_near_limit_2_object() const
+  { return Compare_x_near_limit_2(this, m_counters[COMPARE_X_NEAR_LIMIT_OP]); }
+
+  Compare_x_on_boundary_2 compare_x_on_boundary_2_object() const
+  {
+    return
+      Compare_x_on_boundary_2(this, 
+                              m_counters[COMPARE_X_ON_BOUNDARY_POINTS_OP],
+                              m_counters[COMPARE_X_ON_BOUNDARY_POINT_CURVE_END_OP],
+                              m_counters[COMPARE_X_ON_BOUNDARY_CURVE_ENDS_OP]);
+  }
+ 
+  Compare_x_near_boundary_2 compare_x_near_boundary_2_object() const
+  {
+    return Compare_x_near_boundary_2(this,
+                                     m_counters[COMPARE_X_NEAR_BOUNDARY_OP]);
+  }
 
   //@}
 
@@ -778,8 +965,8 @@ private:
 
 template <class Out_stream, class Base_traits>
 inline
-Out_stream & operator<<(Out_stream & os,
-                        const Arr_counting_traits_2<Base_traits> & traits)
+Out_stream& operator<<(Out_stream& os,
+                       const Arr_counting_traits_2<Base_traits>& traits)
 {
   typedef Arr_counting_traits_2<Base_traits>            Traits;
   unsigned int sum = 0;
@@ -827,10 +1014,14 @@ Out_stream & operator<<(Out_stream & os,
      << traits.count_parameter_space_in_x_point() << std::endl
      << "# of PARAMETER_SPACE_IN_X curve operation = "
      << traits.count_parameter_space_in_x_curve() << std::endl
-     << "# of COMPARE_Y_NEAR_BOUNDARY operation = "
-     << traits.count_compare_y_near_boundary() << std::endl
+     << "# of IS_ON_X_IDENTIFICIATION point operation = "
+     << traits.count_is_on_x_identification_point() << std::endl
+     << "# of IS_ON_X_IDENTIFICATION curve operation = "
+     << traits.count_is_on_x_identification_curve() << std::endl
      << "# of COMPARE_Y_ON_BOUNDARY operation = "
      << traits.count_compare_y_on_boundary() << std::endl
+     << "# of COMPARE_Y_NEAR_BOUNDARY operation = "
+     << traits.count_compare_y_near_boundary() << std::endl
     // bottom-top
      << "# of PARAMETER_SPACE_IN_Y curve-end operation = "
      << traits.count_parameter_space_in_y_curve_end() << std::endl
@@ -838,12 +1029,24 @@ Out_stream & operator<<(Out_stream & os,
      << traits.count_parameter_space_in_y_point() << std::endl
      << "# of PARAMETER_SPACE_IN_Y curve operation = "
      << traits.count_parameter_space_in_y_curve() << std::endl
-     << "# of COMPARE_X_NEAR_BOUNDARY point/curve-end operation = "
-     << traits.count_compare_x_near_boundary_point_curve_end() << std::endl
-     << "# of COMPARE_X_NEAR_BOUNDARY curve-ends operation = "
-     << traits.count_compare_x_near_boundary_curve_ends() << std::endl
-     << "# of COMPARE_X_ON_BOUNDARY operation = "
-     << traits.count_compare_x_on_boundary() << std::endl
+     << "# of IS_ON_Y_IDENTIFICIATION point operation = "
+     << traits.count_is_on_y_identification_point() << std::endl
+     << "# of IS_ON_Y_IDENTIFICATION curve operation = "
+     << traits.count_is_on_y_identification_curve() << std::endl
+     << "# of COMPARE_X_AT_LIMIT point/curve-end operation = "
+     << traits.count_compare_x_at_limit_point_curve_end() << std::endl
+     << "# of COMPARE_X_AT_LIMIT curve-ends operation = "
+     << traits.count_compare_x_at_limit_curve_ends() << std::endl
+     << "# of COMPARE_X_NEAR_LIMIT operation = "
+     << traits.count_compare_x_near_limit() << std::endl
+     << "# of COMPARE_X_ON_BOUNDARY points operation = "
+     << traits.count_compare_x_on_boundary_points() << std::endl
+     << "# of COMPARE_X_ON_BOUNDARY point/curve-end operation = "
+     << traits.count_compare_x_on_boundary_point_curve_end() << std::endl
+     << "# of COMPARE_X_ON_BOUNDARY curve-ends operation = "
+     << traits.count_compare_x_on_boundary_curve_ends() << std::endl
+     << "# of COMPARE_X_NEAR_BOUNDARY operation = "
+     << traits.count_compare_x_near_boundary() << std::endl
 
      << "total # = " << sum << std::endl
      << "# of traits constructed = " << Traits::increment(false)
@@ -851,6 +1054,6 @@ Out_stream & operator<<(Out_stream & os,
   return os;
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
