@@ -1,4 +1,4 @@
-// Copyright (c) 2005  Tel-Aviv University (Israel).
+// Copyright (c) 2006,2007,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Arr_curve_data_traits_2.h $
-// $Id: Arr_curve_data_traits_2.h 51984 2009-09-20 16:18:10Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arr_curve_data_traits_2.h $
+// $Id: Arr_curve_data_traits_2.h 64639 2011-07-06 11:41:06Z lrineau $
 // 
 //
 // Author(s)     : Ron Wein          <wein@post.tau.ac.il>
@@ -29,7 +29,7 @@
 #include<CGAL/Arr_geometry_traits/Curve_data_aux.h>
 #include<list>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 /*! \class
  * A generic traits class for maintaining an arrangement of curves that have
@@ -63,18 +63,19 @@ public:
   typedef typename Base_traits_2::Point_2             Point_2;
 
   typedef typename Base_traits_2::Has_left_category   Has_left_category;
-
   typedef typename Base_traits_2::Has_merge_category  Base_has_merge_category;
   typedef Tag_true                                    Has_merge_category;
+  typedef typename Base_traits_2::Has_do_intersect_category
+                                                      Has_do_intersect_category;
 
-  typedef typename internal::Arr_complete_left_side_tag< Base_traits_2 >::Tag
-                                                      Arr_left_side_category;
-  typedef typename internal::Arr_complete_bottom_side_tag< Base_traits_2 >::Tag
-                                                      Arr_bottom_side_category;
-  typedef typename internal::Arr_complete_top_side_tag< Base_traits_2 >::Tag
-                                                      Arr_top_side_category;
-  typedef typename internal::Arr_complete_right_side_tag< Base_traits_2 >::Tag
-                                                      Arr_right_side_category;
+  typedef typename internal::Arr_complete_left_side_category< Base_traits_2 >::Category
+                                                      Left_side_category;
+  typedef typename internal::Arr_complete_bottom_side_category< Base_traits_2 >::Category
+                                                      Bottom_side_category;
+  typedef typename internal::Arr_complete_top_side_category< Base_traits_2 >::Category
+                                                      Top_side_category;
+  typedef typename internal::Arr_complete_right_side_category< Base_traits_2 >::Category
+                                                      Right_side_category;
 
   // Representation of a curve with an addtional data field:
   typedef _Curve_data_ex<Base_curve_2, Curve_data>    Curve_2;
@@ -442,7 +443,6 @@ public:
 
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
-
