@@ -1,4 +1,4 @@
-// Copyright (c) 2006  Tel-Aviv University (Israel).
+// Copyright (c) 2006,2007,2008,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Arrangement_on_surface_2/include/CGAL/Arr_geometry_traits/Bezier_bounding_rational_traits.h $
-// $Id: Bezier_bounding_rational_traits.h 44415 2008-07-25 09:08:23Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arr_geometry_traits/Bezier_bounding_rational_traits.h $
+// $Id: Bezier_bounding_rational_traits.h 64639 2011-07-06 11:41:06Z lrineau $
 // 
 //
 // Author(s)     : Iddo Hanniel <iddoh@cs.technion.ac.il>
@@ -33,7 +33,7 @@
 #include <list>
 #include <math.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 /*! \struct _Bez_point_bound
  * Representation of a bounding interval for a point on a Bezier curve.
@@ -948,10 +948,17 @@ private:
     const Direction_2     dir_r1 = f_construct_direction (v_max1);
     const Direction_2     dir_l2 = f_construct_direction (v_min2);
     const Direction_2     dir_r2 = f_construct_direction (v_max2);
+    
+    //use the directions to test equality of spans
+    if ( f_equal (dir_l1, dir_l2) && f_equal (dir_r1, dir_r2)) //spans are identical
+      return (true);   
 
+    if ( f_equal (dir_l1, dir_r1) && f_equal (dir_r2, dir_l2) && f_equal (dir_l1, -dir_l2)) //spans are identical but opposite
+      return (true);    
+    
     // Check whether any of the vectors of the second span (or their
     // opposite vectors) is between the vectors of the first span.
-    if (! f_equal (v_min1, v_max1) &&
+    if (! f_equal (dir_l1, dir_r1) &&
         (f_ccw_in_between (dir_l2, dir_l1, dir_r1) ||
          f_ccw_in_between (f_opposite_direction (dir_l2), dir_l1, dir_r1) ||
          f_ccw_in_between (dir_r2, dir_l1, dir_r1) ||
@@ -964,7 +971,7 @@ private:
     // vector) is between the vectors of the second span. Note that at this
     // point, the only possibility is that the first span is totally contained
     // within the second, so we do not need to check both vectors.
-    if (! f_equal (v_min2, v_max2) &&
+    if (! f_equal (dir_l2, dir_r2) &&
         (f_ccw_in_between (dir_l1, dir_l2, dir_r2) ||
          f_ccw_in_between (f_opposite_direction (dir_l1), dir_l2, dir_r2)))
     {
@@ -1238,7 +1245,9 @@ private:
 
       const bool           s1_t1_are_opposite = 
           ((or_2a_s1 == CGAL::opposite (or_2a_t1)) &&
-           (or_2b_s1 == CGAL:: opposite (or_2b_t1)));
+           (or_2b_s1 == CGAL:: opposite (or_2b_t1))
+          ) || 
+          ( skew2a==skew2b && or_2a_s1!=or_2a_t1 );
 
       const Oriented_side  or_1a_s2 = f_oriented_side (skew1a, s2);
       const Oriented_side  or_1a_t2 = f_oriented_side (skew1a, t2);
@@ -1248,7 +1257,8 @@ private:
 
       const bool           s2_t2_are_opposite =
           ((or_1a_s2 == CGAL::opposite (or_1a_t2)) &&
-           (or_1b_s2 == CGAL::opposite (or_1b_t2)));
+           (or_1b_s2 == CGAL::opposite (or_1b_t2)))|| 
+          ( skew1a==skew1b && or_1a_s2!=or_1a_t2 );
 
       if (s1_t1_are_opposite && s2_t2_are_opposite) 
       {
@@ -1509,6 +1519,6 @@ private:
   }
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif //CGAL_BEZIER_BOUNDING_RATIONAL_TRAITS_H
