@@ -1,4 +1,4 @@
-// Copyright (c) 2005  Tel-Aviv University (Israel).
+// Copyright (c) 2006,2007,2008,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Arrangement_on_surface_2/include/CGAL/Arr_geometry_traits/Polyline_2.h $
-// $Id: Polyline_2.h 50598 2009-07-14 08:27:52Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arr_geometry_traits/Polyline_2.h $
+// $Id: Polyline_2.h 64639 2011-07-06 11:41:06Z lrineau $
 // 
 //
 // Author(s)     : Ron Wein  <wein@post.tau.ac.il>
@@ -33,7 +33,7 @@
 
 #include <CGAL/Bbox_2.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 
 /*! \class
@@ -468,6 +468,6 @@ std::istream& operator>> (std::istream& is,
 }
 
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
