@@ -1,4 +1,4 @@
-// Copyright (c) 2005  Tel-Aviv University (Israel).
+// Copyright (c) 2006,2007,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Arrangement_on_surface_2/include/CGAL/Arr_geometry_traits/Rational_arc_2.h $
-// $Id: Rational_arc_2.h 49078 2009-05-03 10:45:23Z ophirset $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arr_geometry_traits/Rational_arc_2.h $
+// $Id: Rational_arc_2.h 64639 2011-07-06 11:41:06Z lrineau $
 // 
 //
 // Author(s)     : Ron Wein <wein@post.tau.ac.il>
@@ -29,7 +29,7 @@
 #include <ostream>
 #include <CGAL/Arr_enums.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 /*! \class _Base_rational_arc_2
  * Representation of an segment of a rational function, given as:
@@ -2159,7 +2159,7 @@ public:
 
     for (x_iter = xs.begin(); x_iter != xs.end(); ++x_iter)
     {
-      if (_is_in_true_x_range (*x_iter) &&
+      if (this->_is_in_true_x_range (*x_iter) &&
           arc._is_in_true_x_range (*x_iter))
       {
         // Compute the intersection point and obtain its multiplicity.
@@ -2507,7 +2507,7 @@ public:
 protected:
 
   /*! Check whether the arc is continuous. */
-  bool _check_continuity ()
+  void _check_continuity ()
   {
     if (this->_is_continuous())
     {
@@ -2520,6 +2520,6 @@ protected:
   }
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
