@@ -1,4 +1,4 @@
-// Copyright (c) 2003-2006  INRIA Sophia-Antipolis (France).
+// Copyright (c) 2003,2004,2005,2006,2007,2008,2009,2010,2011 INRIA Sophia-Antipolis (France).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Arr_line_arc_traits_2.h $
-// $Id: Arr_line_arc_traits_2.h 51984 2009-09-20 16:18:10Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arr_line_arc_traits_2.h $
+// $Id: Arr_line_arc_traits_2.h 64639 2011-07-06 11:41:06Z lrineau $
 //
 // Author(s)     : Monique Teillaud, Sylvain Pion, Julien Hazebrouck
 
@@ -60,11 +60,12 @@ public:
 
   typedef CGAL::Tag_false                        Has_left_category;
   typedef CGAL::Tag_false 			 Has_merge_category;
+  typedef CGAL::Tag_false                        Has_do_intersect_category;
 
-  typedef Arr_oblivious_side_tag                 Arr_left_side_category;
-  typedef Arr_oblivious_side_tag                 Arr_bottom_side_category;
-  typedef Arr_oblivious_side_tag                 Arr_top_side_category;
-  typedef Arr_oblivious_side_tag                 Arr_right_side_category;
+  typedef Arr_oblivious_side_tag                 Left_side_category;
+  typedef Arr_oblivious_side_tag                 Bottom_side_category;
+  typedef Arr_oblivious_side_tag                 Top_side_category;
+  typedef Arr_oblivious_side_tag                 Right_side_category;
 
   Arr_line_arc_traits_2(const CircularKernel &k = CircularKernel())
     : ck(k) {}
