@@ -1,4 +1,4 @@
-// Copyright (c) 2006  Tel-Aviv University (Israel).
+// Copyright (c) 2006,2007,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Arr_linear_traits_2.h $
-// $Id: Arr_linear_traits_2.h 51984 2009-09-20 16:18:10Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arr_linear_traits_2.h $
+// $Id: Arr_linear_traits_2.h 64639 2011-07-06 11:41:06Z lrineau $
 // 
 //
 // Author(s)     : Ron Wein          <wein@post.tau.ac.il>
@@ -32,7 +32,7 @@
 #include <CGAL/Arr_geometry_traits/Segment_assertions.h>
 #include <fstream>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template <class Kernel_> class Arr_linear_object_2;
 
@@ -55,11 +55,12 @@ public:
   // Category tags:
   typedef Tag_true                        Has_left_category;
   typedef Tag_true                        Has_merge_category;
+  typedef Tag_false                       Has_do_intersect_category;
 
-  typedef Arr_open_side_tag               Arr_left_side_category;
-  typedef Arr_open_side_tag               Arr_bottom_side_category;
-  typedef Arr_open_side_tag               Arr_top_side_category;
-  typedef Arr_open_side_tag               Arr_right_side_category;
+  typedef Arr_open_side_tag               Left_side_category;
+  typedef Arr_open_side_tag               Bottom_side_category;
+  typedef Arr_open_side_tag               Top_side_category;
+  typedef Arr_open_side_tag               Right_side_category;
   
   typedef typename Kernel::Line_2         Line_2;
   typedef typename Kernel::Ray_2          Ray_2;
@@ -746,7 +747,7 @@ public:
     typedef Arr_linear_traits_2<Kernel> Traits;
 
     /*! The traits (in case it has state) */
-    const Traits * m_traits;
+    const Traits* m_traits;
 
     /*! Constructor
      * \param traits the traits (in case it has state)
@@ -816,7 +817,7 @@ public:
      */
     Comparison_result operator() (const X_monotone_curve_2& cv1,
                                   const X_monotone_curve_2& cv2,
-                                  const Point_2& CGAL_precondition_code(p) ) const
+                                  const Point_2& CGAL_precondition_code(p)) const
     {
       CGAL_precondition (! cv1.is_degenerate());
       CGAL_precondition (! cv2.is_degenerate());
@@ -826,8 +827,7 @@ public:
       // Make sure that p lies on both curves, and that both are defined to its
       // left (so their left endpoint is lexicographically smaller than p).
       CGAL_precondition_code (
-        typename Kernel::Compare_xy_2 compare_xy = 
-                                                  kernel.compare_xy_2_object();
+        typename Kernel::Compare_xy_2 compare_xy = kernel.compare_xy_2_object();
       );
 
       CGAL_precondition 
@@ -846,8 +846,7 @@ public:
       // Notice we use the supporting lines in order to compare the slopes,
       // and that we swap the order of the curves in order to obtain the
       // correct result to the left of p.
-      return (kernel.compare_slope_2_object()(cv2.supp_line(),
-                                              cv1.supp_line()));
+      return (kernel.compare_slope_2_object()(cv2.supp_line(), cv1.supp_line()));
     }
   };
 
@@ -876,7 +875,7 @@ public:
      */
     Comparison_result operator() (const X_monotone_curve_2& cv1,
                                   const X_monotone_curve_2& cv2,
-                                  const Point_2& CGAL_precondition_code(p) ) const
+                                  const Point_2& CGAL_precondition_code(p)) const
     {
       CGAL_precondition (! cv1.is_degenerate());
       CGAL_precondition (! cv2.is_degenerate());
@@ -886,8 +885,7 @@ public:
       // Make sure that p lies on both curves, and that both are defined to its
       // right (so their right endpoint is lexicographically larger than p).
       CGAL_precondition_code (
-        typename Kernel::Compare_xy_2 compare_xy = 
-                                                 kernel.compare_xy_2_object();
+        typename Kernel::Compare_xy_2 compare_xy = kernel.compare_xy_2_object();
       );
 
       CGAL_precondition
@@ -922,7 +920,8 @@ public:
   {
   public:
     /*!
-     * Check whether the two x-monotone curves are the same (have the same graph).
+     * Check whether the two x-monotone curves are the same (have the same
+     * graph).
      * \param cv1 The first curve.
      * \param cv2 The second curve.
      * \return (true) if the two curves are the same; (false) otherwise.
@@ -937,8 +936,7 @@ public:
       typename Kernel::Equal_2  equal = kernel.equal_2_object();
 
       // Check that the two supporting lines are the same.
-      if (! equal (cv1.supp_line(),
-                   cv2.supp_line()) &&
+      if (! equal (cv1.supp_line(), cv2.supp_line()) &&
           ! equal (cv1.supp_line(), 
                    kernel.construct_opposite_line_2_object()(cv2.supp_line())))
       {
@@ -1066,13 +1064,30 @@ public:
   Parameter_space_in_y_2 parameter_space_in_y_2_object() const
   { return Parameter_space_in_y_2(); }
 
-  /*! A function object that compares the x-coordinates of arc ends near the
+  /*! A function object that compares the x-limits of arc ends on the
    * boundary of the parameter space
    */
-  class Compare_x_near_boundary_2 {
+  class Compare_x_at_limit_2 {
+  protected:
+    typedef Arr_linear_traits_2<Kernel> Traits;
+
+    /*! The traits (in case it has state) */
+    const Traits* m_traits;
+
+    /*! Constructor
+     * \param traits the traits (in case it has state)
+     * The constructor is declared private to allow only the functor
+     * obtaining function, which is a member of the nesting class,
+     * constructing it.
+     */
+    Compare_x_at_limit_2(const Traits* traits) : m_traits(traits) {}
+
+    //! Allow its functor obtaining function calling the private constructor.
+    friend class Arr_linear_traits_2<Kernel>;
+
   public:
-    /*! Compare the x-coordinate of a point with the x-coordinate of
-     * a line end near the boundary at y = +/- oo.
+    /*! Compare the x-limit of a vertical line at a point with the x-limit of
+     * a line end on the boundary at y = +/- oo.
      * \param p the point direction.
      * \param xcv the line, the endpoint of which is compared.
      * \param ce the line-end indicator -
@@ -1083,19 +1098,66 @@ public:
      *         EQUAL   - x(p) = x(xc, ce);
      *         LARGER  - x(p) > x(xc, ce).     
      * \pre p lies in the interior of the parameter space.
-     * \pre the ce end of the line xcv lies on a boundary.
+     * \pre the ce end of the line xcv lies on a boundary, implying
+     *      that xcv1 is vertical.
      */
     Comparison_result operator()(const Point_2 & p,
                                  const X_monotone_curve_2 & xcv,
                                  Arr_curve_end ) const
     {
-      CGAL_precondition (! xcv.is_degenerate());
-      CGAL_precondition (xcv.is_vertical());
+      CGAL_precondition(! xcv.is_degenerate());
+      CGAL_precondition(xcv.is_vertical());
 
-      Kernel                    kernel;
-      return (kernel.compare_x_at_y_2_object() (p, xcv.supp_line()));
+      const Kernel* kernel = m_traits;
+      return (kernel->compare_x_at_y_2_object()(p, xcv.supp_line()));
     }
 
+    /*! Compare the x-limits of 2 arcs ends on the boundary of the
+     * parameter space at y = +/- oo.
+     * \param xcv1 the first arc.
+     * \param ce1 the first arc end indicator -
+     *            ARR_MIN_END - the minimal end of xcv1 or
+     *            ARR_MAX_END - the maximal end of xcv1.
+     * \param xcv2 the second arc.
+     * \param ce2 the second arc end indicator -
+     *            ARR_MIN_END - the minimal end of xcv2 or
+     *            ARR_MAX_END - the maximal end of xcv2.
+     * \return the second comparison result:
+     *         SMALLER - x(xcv1, ce1) < x(xcv2, ce2);
+     *         EQUAL   - x(xcv1, ce1) = x(xcv2, ce2);
+     *         LARGER  - x(xcv1, ce1) > x(xcv2, ce2).
+     * \pre the ce1 end of the line xcv1 lies on a boundary, implying
+     *      that xcv1 is vertical.
+     * \pre the ce2 end of the line xcv2 lies on a boundary, implying
+     *      that xcv2 is vertical.
+     */
+    Comparison_result operator()(const X_monotone_curve_2 & xcv1,
+                                 Arr_curve_end /* ce1 */,
+                                 const X_monotone_curve_2 & xcv2,
+                                 Arr_curve_end /*! ce2 */) const
+    {
+      CGAL_precondition(! xcv1.is_degenerate());
+      CGAL_precondition(! xcv2.is_degenerate());
+      CGAL_precondition(xcv1.is_vertical());
+      CGAL_precondition(xcv2.is_vertical());
+
+      const Kernel* kernel = m_traits;
+      const Point_2 p = kernel->construct_point_2_object()(ORIGIN);
+      return (kernel->compare_x_at_y_2_object()(p, xcv1.supp_line(),
+                                                xcv2.supp_line()));
+    }
+  };
+
+  /*! Obtain a Compare_x_at_limit_2 function object */
+  Compare_x_at_limit_2 compare_x_at_limit_2_object() const
+  { return Compare_x_at_limit_2(this); }
+
+  /*! A function object that compares the x-coordinates of arc ends near the
+   * boundary of the parameter space
+   */
+  class Compare_x_near_limit_2 {
+  public:
+
     /*! Compare the x-coordinates of 2 arcs ends near the boundary of the
      * parameter space at y = +/- oo.
      * \param xcv1 the first arc.
@@ -1110,38 +1172,54 @@ public:
      *         SMALLER - x(xcv1, ce1) < x(xcv2, ce2);
      *         EQUAL   - x(xcv1, ce1) = x(xcv2, ce2);
      *         LARGER  - x(xcv1, ce1) > x(xcv2, ce2).
-     * \pre the ce1 end of the line xcv1 lies on a boundary.
-     * \pre the ce2 end of the line xcv2 lies on a boundary.
+     * \pre the ce end of the line xcv1 lies on a boundary, implying
+     *      that xcv1 is vertical.
+     * \pre the ce end of the line xcv2 lies on a boundary, implying
+     *      that xcv2 is vertical.
+     * \pre the the $x$-coordinates of xcv1 and xcv2 at their ce ends are
+     *      equal, implying that the curves overlap!
      */
-    Comparison_result operator()(const X_monotone_curve_2 & xcv1,
-                                 Arr_curve_end /* ce1 */,
-                                 const X_monotone_curve_2 & xcv2,
-                                 Arr_curve_end /*! ce2 */) const
+    Comparison_result
+    operator()(const X_monotone_curve_2& CGAL_precondition_code(xcv1),
+               const X_monotone_curve_2& CGAL_precondition_code(xcv2),
+               Arr_curve_end /*! ce2 */) const
     {
-      CGAL_precondition (! xcv1.is_degenerate());
-      CGAL_precondition (! xcv2.is_degenerate());
-      CGAL_precondition (xcv1.is_vertical());
-      CGAL_precondition (xcv2.is_vertical());
-
-      Kernel                    kernel;
-      typename Kernel::Point_2 p = kernel.construct_point_2_object() (ORIGIN);
-      return (kernel.compare_x_at_y_2_object() (p,
-                                                xcv1.supp_line(),
-                                                xcv2.supp_line()));
+      CGAL_precondition(! xcv1.is_degenerate());
+      CGAL_precondition(! xcv2.is_degenerate());
+      CGAL_precondition(xcv1.is_vertical());
+      CGAL_precondition(xcv2.is_vertical());
+      return EQUAL;
     }
   };
 
-  /*! Obtain a Compare_x_near_boundary_2 function object */
-  Compare_x_near_boundary_2 compare_x_near_boundary_2_object() const
-  { return Compare_x_near_boundary_2(); }
+  /*! Obtain a Compare_x_near_limit_2 function object */
+  Compare_x_near_limit_2 compare_x_near_limit_2_object() const
+  { return Compare_x_near_limit_2(); }
     
 
-  /*! A function object that compares the y-coordinates of arc ends near the
+  /*! A function object that compares the y-limits of arc ends on the
    * boundary of the parameter space.
    */
   class Compare_y_near_boundary_2 {
+  protected:
+    typedef Arr_linear_traits_2<Kernel> Traits;
+
+    /*! The traits (in case it has state) */
+    const Traits* m_traits;
+
+    /*! Constructor
+     * \param traits the traits (in case it has state)
+     * The constructor is declared private to allow only the functor
+     * obtaining function, which is a member of the nesting class,
+     * constructing it.
+     */
+    Compare_y_near_boundary_2(const Traits* traits) : m_traits(traits) {}
+
+    //! Allow its functor obtaining function calling the private constructor.
+    friend class Arr_linear_traits_2<Kernel>;
+    
   public:
-    /*! Compare the y-coordinates of 2 lines at their ends near the boundary
+    /*! Compare the y-limits of 2 lines at their ends on the boundary
      * of the parameter space at x = +/- oo.
      * \param xcv1 the first arc.
      * \param xcv2 the second arc.
@@ -1155,42 +1233,38 @@ public:
                                  Arr_curve_end ce) const
     {
       // Make sure both curves are defined at x = -oo (or at x = +oo).
-      CGAL_precondition (! xcv1.is_degenerate());
-      CGAL_precondition (! xcv2.is_degenerate());
-      CGAL_precondition ((ce == ARR_MIN_END &&
-                          xcv1.left_infinite_in_x() == ARR_LEFT_BOUNDARY &&
-                          xcv2.left_infinite_in_x() == ARR_LEFT_BOUNDARY) ||
-                         (ce == ARR_MAX_END &&
-                          xcv1.right_infinite_in_x() == ARR_RIGHT_BOUNDARY &&
-                          xcv2.right_infinite_in_x() == ARR_RIGHT_BOUNDARY));
+      CGAL_precondition(! xcv1.is_degenerate());
+      CGAL_precondition(! xcv2.is_degenerate());
+      CGAL_precondition((ce == ARR_MIN_END &&
+                         xcv1.left_infinite_in_x() == ARR_LEFT_BOUNDARY &&
+                         xcv2.left_infinite_in_x() == ARR_LEFT_BOUNDARY) ||
+                        (ce == ARR_MAX_END &&
+                         xcv1.right_infinite_in_x() == ARR_RIGHT_BOUNDARY &&
+                         xcv2.right_infinite_in_x() == ARR_RIGHT_BOUNDARY));
 
       // Compare the slopes of the two supporting lines.
-      Kernel                    kernel;
-      const Comparison_result   res_slopes =
-        kernel.compare_slope_2_object() (xcv1.supp_line(), xcv2.supp_line());
+      const Kernel* kernel = m_traits;
+      const Comparison_result res_slopes =
+        kernel->compare_slope_2_object()(xcv1.supp_line(), xcv2.supp_line());
 
       if (res_slopes == EQUAL) {
         // In case the two supporting line are parallel, compare their
         // relative position at x = 0, which is the same as their position
         // at infinity.
-        typename Kernel::Point_2 p = kernel.construct_point_2_object() (ORIGIN);
-        return (kernel.compare_y_at_x_2_object() (p,
-                                                  xcv1.supp_line(),
+        const Point_2 p = kernel->construct_point_2_object()(ORIGIN);
+        return (kernel->compare_y_at_x_2_object()(p, xcv1.supp_line(),
                                                   xcv2.supp_line()));
       }
 
-      if (ce == ARR_MIN_END)
-        // Flip the slope result if we compare at x = -oo:
-        return ((res_slopes == LARGER) ? SMALLER : LARGER);
-
-      // If we compare at x = +oo, the slope result is what we need:
-      return (res_slopes);
+      // Flip the slope result if we compare at x = -oo:
+      return (ce == ARR_MIN_END) ? CGAL::opposite(res_slopes) : res_slopes;
     }
   };
 
-  /*! Obtain a Compare_y_near_boundary_2 function object */
+
+  /*! Obtain a Compare_y_limit_on_boundary_2 function object */
   Compare_y_near_boundary_2 compare_y_near_boundary_2_object() const
-  { return Compare_y_near_boundary_2(); }
+  { return Compare_y_near_boundary_2(this); }
   
   //@}
   
@@ -1246,8 +1320,7 @@ public:
       // Make sure that p lies on the interior of the curve.
       CGAL_precondition_code (
         Kernel                        kernel;
-        typename Kernel::Compare_xy_2 compare_xy = 
-                                                 kernel.compare_xy_2_object();
+        typename Kernel::Compare_xy_2 compare_xy = kernel.compare_xy_2_object();
       );
 
       CGAL_precondition
@@ -1650,7 +1723,7 @@ public:
 
     Kernel     kernel;
     Segment_2  seg = kernel.construct_segment_2_object() (this->ps, this->pt);
-    return (seg);
+    return seg;
   }
 
   /*!
@@ -1658,8 +1731,7 @@ public:
    */
   bool is_ray () const
   {
-    return (! this->is_degen && 
-            (this->has_source != this->has_target));
+    return (! this->is_degen && (this->has_source != this->has_target));
   }
 
   /*!
@@ -1671,16 +1743,11 @@ public:
     CGAL_precondition (is_ray());
 
     Kernel     kernel;
-    Ray_2      ray;
-
-    if (this->has_source)
-      ray = kernel.construct_ray_2_object() (this->ps, this->l);
-    else
-      ray = kernel.construct_ray_2_object()
-        (this->pt, 
-         kernel.construct_opposite_line_2_object()(this->l));
-
-    return (ray);
+    Ray_2      ray = (this->has_source) ?
+      kernel.construct_ray_2_object() (this->ps, this->l) :
+      kernel.construct_ray_2_object()
+        (this->pt, kernel.construct_opposite_line_2_object()(this->l));
+    return ray;
   }
 
   /*!
@@ -1749,6 +1816,13 @@ public:
     Segment_2  seg = kernel.construct_segment_2_object() (this->ps, this->pt);
     return (kernel.construct_bbox_2_object() (seg));
   }
+
+  // Introducing casting operators instead from a curve to
+  // Kernel::Segment_2, Kernel::Ray_2, and Kernel::Line_2 creates an
+  // umbiguity. The compiler will barf on the last one, because there are
+  // 2 constructors of Kernel::Line_2: one from Kernel::Segment_2 and one
+  // from Kernel::Ray_2. Together with the cast to Kernel::Line_2, the
+  // compiler will have 3 equivalent options to choose from.
 };
 
 /*!
@@ -1808,6 +1882,6 @@ InputStream& operator>> (InputStream& is, Arr_linear_object_2<Kernel>& lobj)
   return (is);
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
