@@ -1,4 +1,4 @@
-// Copyright (c) 2005  Tel-Aviv University (Israel).
+// Copyright (c) 2006,2007,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Arrangement_on_surface_2/include/CGAL/Arr_non_caching_segment_traits_2.h $
-// $Id: Arr_non_caching_segment_traits_2.h 56667 2010-06-09 07:37:13Z sloriot $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arr_non_caching_segment_traits_2.h $
+// $Id: Arr_non_caching_segment_traits_2.h 64639 2011-07-06 11:41:06Z lrineau $
 //
 // Author(s)     : Efi Fogel    <efif@post.tau.ac.il>
 //                 Ron Wein     <wein@post.tau.ac.il>
@@ -62,10 +62,10 @@ public:
   typedef typename Base::Has_left_category           Has_left_category;
   typedef typename Base::Has_do_intersect_category   Has_do_intersect_category;
 
-  typedef typename Base::Arr_left_side_category      Arr_left_side_category;
-  typedef typename Base::Arr_bottom_side_category    Arr_bottom_side_category;
-  typedef typename Base::Arr_top_side_category       Arr_top_side_category;
-  typedef typename Base::Arr_right_side_category     Arr_right_side_category;
+  typedef typename Base::Left_side_category      Left_side_category;
+  typedef typename Base::Bottom_side_category    Bottom_side_category;
+  typedef typename Base::Top_side_category       Top_side_category;
+  typedef typename Base::Right_side_category     Right_side_category;
 
   typedef typename Base::Point_2                     Point_2;
   typedef typename Base::X_monotone_curve_2          X_monotone_curve_2;
@@ -168,7 +168,6 @@ public:
       // Make sure that p lies on the interior of the curve.
       CGAL_precondition_code (
         Compare_xy_2 compare_xy = base.compare_xy_2_object();
-        Compare_y_at_x_2 compare_y_at_x = base.compare_y_at_x_2_object();
       );
 
       Construct_min_vertex_2 min_vertex = base.construct_min_vertex_2_object();
