@@ -1,4 +1,4 @@
-// Copyright (c) 2005  Tel-Aviv University (Israel).
+// Copyright (c) 2007,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Arrangement_on_surface_2/include/CGAL/Arr_point_location/Arr_lm_nearest_neighbor.h $
-// $Id: Arr_lm_nearest_neighbor.h 40429 2007-09-24 15:01:00Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arr_point_location/Arr_lm_nearest_neighbor.h $
+// $Id: Arr_lm_nearest_neighbor.h 64639 2011-07-06 11:41:06Z lrineau $
 // 
 // Author(s)     : Idit Haran   <haranidi@post.tau.ac.il>
 //                 Ron Wein     <wein@post.tau.ac.il>
@@ -27,7 +27,7 @@
 #include <CGAL/Orthogonal_k_neighbor_search.h>
 #include <CGAL/Arrangement_2/Arr_traits_adaptor_2.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 /*! \class
 * A class that answers nearest neighbor queries.
@@ -131,6 +131,8 @@ public:
    */
   struct Construct_coord_iterator
   {
+    typedef const ANT*                                        result_type;
+    
     /*! Get an iterator for the approximate coordinates. */
     const ANT* operator() (const NN_Point_2& nnp) const
     {
@@ -156,6 +158,9 @@ protected:
   Tree            *m_tree;        // The search tree.
   bool             m_is_empty;    // Is the search tree empty.
 
+public: 
+  bool is_empty() const{ return m_is_empty; }
+  
 private:
 
   /*! Copy constructor - not supported. */
@@ -240,6 +245,6 @@ public:
   }
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
