@@ -1,4 +1,4 @@
-// Copyright (c) 2005  Tel-Aviv University (Israel).
+// Copyright (c) 2006,2007,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Arr_rational_arc_traits_2.h $
-// $Id: Arr_rational_arc_traits_2.h 51984 2009-09-20 16:18:10Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arr_rational_arc_traits_2.h $
+// $Id: Arr_rational_arc_traits_2.h 64657 2011-07-06 15:57:54Z lrineau $
 // 
 //
 // Author(s)     : Ron Wein          <wein@post.tau.ac.il>
@@ -20,6 +20,10 @@
 #ifndef CGAL_ARR_RATIONAL_ARC_TRAITS_2_H
 #define CGAL_ARR_RATIONAL_ARC_TRAITS_2_H
 
+#define CGAL_DEPRECATED_HEADER "<CGAL/Arr_rational_arc_traits_2.h>"
+#define CGAL_REPLACEMENT_HEADER "<CGAL/Arr_rational_function_traits_2.h>"
+#include <CGAL/internal/deprecation_warning.h>
+
 /*! \file
  * Definition of the Arr_rational_arc_traits_2 class. 
  */
@@ -28,7 +32,7 @@
 #include <CGAL/Arr_tags.h>
 #include <CGAL/Arr_geometry_traits/Rational_arc_2.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 /*! \class
  * A traits class for maintaining an arrangement of bounded arcs (segments) of
@@ -46,30 +50,31 @@ class Arr_rational_arc_traits_2
 {
 public:
 
-  typedef Alg_kernel_                                   Alg_kernel;
-  typedef Nt_traits_                                    Nt_traits;
+  typedef Alg_kernel_                             Alg_kernel;
+  typedef Nt_traits_                              Nt_traits;
 
-  typedef typename Alg_kernel::FT                       Algebraic;
+  typedef typename Alg_kernel::FT                 Algebraic;
 
-  typedef typename Nt_traits::Integer                   Integer;
+  typedef typename Nt_traits::Integer             Integer;
 
   // Category tags:
-  typedef Tag_true                                      Has_left_category;
-  typedef Tag_true                                      Has_merge_category;
+  typedef Tag_true                                Has_left_category;
+  typedef Tag_true                                Has_merge_category;
+  typedef Tag_false                               Has_do_intersect_category;
 
-  typedef Arr_open_side_tag                             Arr_left_side_category;
-  typedef Arr_open_side_tag                             Arr_bottom_side_category;
-  typedef Arr_open_side_tag                             Arr_top_side_category;
-  typedef Arr_open_side_tag                             Arr_right_side_category;
+  typedef Arr_open_side_tag                       Left_side_category;
+  typedef Arr_open_side_tag                       Bottom_side_category;
+  typedef Arr_open_side_tag                       Top_side_category;
+  typedef Arr_open_side_tag                       Right_side_category;
 
   // Traits objects:
-  typedef _Rational_arc_2<Alg_kernel, Nt_traits>        Curve_2;
+  typedef _Rational_arc_2<Alg_kernel, Nt_traits>  Curve_2;
   typedef _Continuous_rational_arc_2<Alg_kernel, Nt_traits>
-                                                        X_monotone_curve_2;
-  typedef typename Alg_kernel::Point_2                  Point_2;
-  typedef unsigned int                                  Multiplicity;
+                                                  X_monotone_curve_2;
+  typedef typename Alg_kernel::Point_2            Point_2;
+  typedef unsigned int                            Multiplicity;
 
-  typedef typename Curve_2::Rat_vector                  Rat_vector;
+  typedef typename Curve_2::Rat_vector            Rat_vector;
 
 public:
 
@@ -615,16 +620,17 @@ public:
   Parameter_space_in_y_2 parameter_space_in_y_2_object() const
   { return Parameter_space_in_y_2(); }
 
-  /*! A function object that compares the x-coordinates of arc ends near the
+
+ /*! A function object that compares the x-limits of arc ends on the
    * boundary of the parameter space
    */
-  class Compare_x_near_boundary_2 {
+  class Compare_x_at_limit_2 {
   public:
-    /*! Compare the x-coordinate of a point with the x-coordinate of
-     * a line end near the boundary at y = +/- oo.
-     * \param p the point direction.
-     * \param xcv the line, the endpoint of which is compared.
-     * \param ce the line-end indicator -
+    /*! Compare the x-coordinate of a point and the x-coordinate of the limit
+     * of a rational arc at its specificed end at y = +/- oo.
+     * \param p the point.
+     * \param xcv the parametric curve, the endpoint of which is compared.
+     * \param ce identifies an open end of xcv -
      *            ARR_MIN_END - the minimal end of xc or
      *            ARR_MAX_END - the maximal end of xc.
      * \return the comparison result:
@@ -632,44 +638,82 @@ public:
      *         EQUAL   - x(p) = x(xc, ce);
      *         LARGER  - x(p) > x(xc, ce).     
      * \pre p lies in the interior of the parameter space.
-     * \pre the ce end of the line xcv lies on a boundary.
+     * \pre the ce end of the curve xcv lies on a boundary, implying that xcv
+     *      is either a vertical line or a curve with a vertical asymptote.
      */
     Comparison_result operator()(const Point_2 & p,
                                  const X_monotone_curve_2 & xcv,
                                  Arr_curve_end ce) const
     {
+      // TODO implement (simplify)
       return (xcv.compare_end (p, ce));
     }
 
-    /*! Compare the x-coordinates of 2 arcs ends near the boundary of the
-     * parameter space at y = +/- oo.
+    /*! Compare the x-coordinates of the limits of 2 parameteric curves at
+     * their specificed ends at y = +/- oo.
      * \param xcv1 the first arc.
-     * \param ce1 the first arc end indicator -
+     * \param ce1 identifies an open end of ce1 -
      *            ARR_MIN_END - the minimal end of xcv1 or
      *            ARR_MAX_END - the maximal end of xcv1.
      * \param xcv2 the second arc.
-     * \param ce2 the second arc end indicator -
+     * \param ce2 identifies an open end of ce2 -
      *            ARR_MIN_END - the minimal end of xcv2 or
      *            ARR_MAX_END - the maximal end of xcv2.
      * \return the second comparison result:
      *         SMALLER - x(xcv1, ce1) < x(xcv2, ce2);
      *         EQUAL   - x(xcv1, ce1) = x(xcv2, ce2);
      *         LARGER  - x(xcv1, ce1) > x(xcv2, ce2).
-     * \pre the ce1 end of the line xcv1 lies on a boundary.
-     * \pre the ce2 end of the line xcv2 lies on a boundary.
+     * \pre the ce1 end of the line xcv1 lies on a boundary, implying that xcv1
+     *      is either a vertical line or a curve with a vertical asymptote.
+     * \pre the ce2 end of the line xcv2 lies on a boundary, implying that xcv2
+     *      is either a vertical line or a curve with a vertical asymptote.
      */
     Comparison_result operator()(const X_monotone_curve_2 & xcv1,
                                  Arr_curve_end ce1,
                                  const X_monotone_curve_2 & xcv2,
                                  Arr_curve_end ce2) const
     {
+      // TODO implement (simplify)
       return xcv1.compare_ends (ce1, xcv2, ce2);
     }
   };
 
-  /*! Obtain a Compare_x_near_boundary_2 function object */
-  Compare_x_near_boundary_2 compare_x_near_boundary_2_object() const
-  { return Compare_x_near_boundary_2(); }
+  /*! Obtain a Compare_x_at_limit_2 function object */
+  Compare_x_at_limit_2 compare_x_at_limit_2_object() const
+  { return Compare_x_at_limit_2(); }
+    
+  /*! A function object that compares the x-coordinates of arc ends near the
+   * boundary of the parameter space
+   */
+  class Compare_x_near_limit_2 {
+  public:
+    
+    /*! Compare the x-coordinates of 2 arcs ends near the boundary of the
+     * parameter space at y = +/- oo.
+     * \param xcv1 the first arc.
+     * \param xcv2 the second arc.
+     * \param ce the curve end indicator -
+     *            ARR_MIN_END - the minimal end of curves or
+     *            ARR_MAX_END - the maximal end of curves.
+     * \return the second comparison result:
+     *         SMALLER - x(xcv1, ce) < x(xcv2, ce);
+     *         EQUAL   - x(xcv1, ce) = x(xcv2, ce);
+     *         LARGER  - x(xcv1, ce) > x(xcv2, ce).
+     * \pre the ce end of the line xcv1 lies on a boundary.
+     * \pre the ce end of the line xcv2 lies on a boundary.
+     */
+    Comparison_result operator()(const X_monotone_curve_2 & xcv1,
+                                 const X_monotone_curve_2 & xcv2,
+                                 Arr_curve_end ce) const
+    {
+      // TODO implement (simplify)
+      return xcv1.compare_ends (ce, xcv2, ce);
+    }
+  };
+
+  /*! Obtain a Compare_x_near_limit_2 function object */
+  Compare_x_near_limit_2 compare_x_near_limit_2_object() const
+  { return Compare_x_near_limit_2(); }
     
 
   /*! A function object that compares the y-coordinates of arc ends near the
@@ -755,6 +799,6 @@ public:
   //@}
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
