@@ -1,4 +1,4 @@
-// Copyright (c) 2005  Tel-Aviv University (Israel).
+// Copyright (c) 2006,2007,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Arrangement_on_surface_2/include/CGAL/Arr_segment_traits_2.h $
-// $Id: Arr_segment_traits_2.h 56667 2010-06-09 07:37:13Z sloriot $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arr_segment_traits_2.h $
+// $Id: Arr_segment_traits_2.h 64639 2011-07-06 11:41:06Z lrineau $
 // 
 //
 // Author(s)     : Ron Wein          <wein@post.tau.ac.il>
@@ -63,10 +63,10 @@ public:
   typedef Tag_true                        Has_merge_category;
   typedef Tag_false                       Has_do_intersect_category;
   
-  typedef Arr_oblivious_side_tag          Arr_left_side_category;
-  typedef Arr_oblivious_side_tag          Arr_bottom_side_category;
-  typedef Arr_oblivious_side_tag          Arr_top_side_category;
-  typedef Arr_oblivious_side_tag          Arr_right_side_category;
+  typedef Arr_oblivious_side_tag          Left_side_category;
+  typedef Arr_oblivious_side_tag          Bottom_side_category;
+  typedef Arr_oblivious_side_tag          Top_side_category;
+  typedef Arr_oblivious_side_tag          Right_side_category;
  
   typedef typename Kernel::Line_2         Line_2;
   typedef CGAL::Segment_assertions<Arr_segment_traits_2<Kernel> >
