@@ -1,4 +1,4 @@
-// Copyright (c) 2009 Tel-Aviv University (Israel).
+// Copyright (c) 2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,15 +11,15 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Arr_spherical_gaussian_map_3/Arr_on_sphere_transformation.h $
-// $Id: Arr_on_sphere_transformation.h 52628 2009-10-20 08:59:26Z lrineau $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arr_spherical_gaussian_map_3/Arr_on_sphere_transformation.h $
+// $Id: Arr_on_sphere_transformation.h 64639 2011-07-06 11:41:06Z lrineau $
 // 
 // Author(s)     : Naama mayer         <naamamay@post.tau.ac.il>
 
 #ifndef CGAL_ARR_ON_SPHERE_TRANSFORMATION_H
 #define CGAL_ARR_ON_SPHERE_TRANSFORMATION_H
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 /* This function rotates the face when the arrangement is sgm */
 
@@ -32,6 +32,6 @@ class Arr_on_sphere_transformation
 	}
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
-#endif
\ No newline at end of file
+#endif
