@@ -1,4 +1,4 @@
-// Copyright (c) 2007, 2009 Tel-Aviv University (Israel).
+// Copyright (c) 2007,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Arr_tags.h $
-// $Id: Arr_tags.h 53356 2009-12-09 09:53:05Z lrineau $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arr_tags.h $
+// $Id: Arr_tags.h 64639 2011-07-06 11:41:06Z lrineau $
 // 
 //
 // Author(s): Efi Fogel         <efif@post.tau.ac.il>
@@ -34,195 +34,195 @@
  * Definition of the tags for the arrangement package.
  */
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 struct Arr_boundary_side_tag {};
 struct Arr_oblivious_side_tag : public virtual Arr_boundary_side_tag {};
-struct Arr_open_side_tag : public virtual Arr_boundary_side_tag {};
-struct Arr_closed_side_tag : public virtual Arr_boundary_side_tag {};
-struct Arr_contracted_side_tag : public virtual Arr_boundary_side_tag {};
-struct Arr_identified_side_tag : public virtual Arr_boundary_side_tag {};
+struct Arr_open_side_tag : public virtual Arr_oblivious_side_tag {};
+struct Arr_closed_side_tag : public virtual Arr_oblivious_side_tag {};
+struct Arr_contracted_side_tag : public virtual Arr_oblivious_side_tag {};
+struct Arr_identified_side_tag : public virtual Arr_oblivious_side_tag {};
 
-BOOST_MPL_HAS_XXX_TRAIT_DEF(Arr_left_side_category)
-BOOST_MPL_HAS_XXX_TRAIT_DEF(Arr_bottom_side_category)
-BOOST_MPL_HAS_XXX_TRAIT_DEF(Arr_top_side_category)
-BOOST_MPL_HAS_XXX_TRAIT_DEF(Arr_right_side_category)
+BOOST_MPL_HAS_XXX_TRAIT_DEF(Left_side_category)
+BOOST_MPL_HAS_XXX_TRAIT_DEF(Bottom_side_category)
+BOOST_MPL_HAS_XXX_TRAIT_DEF(Top_side_category)
+BOOST_MPL_HAS_XXX_TRAIT_DEF(Right_side_category)
 
 namespace internal {
 
 //! type to provide left side tag (is oblivious if not existing)
 template < class Traits_, bool B >
-struct Get_left_side_tag { 
+struct Get_left_side_category { 
 };
 
 template < class Traits_ >
-struct Get_left_side_tag< Traits_, true > {
-  typedef typename Traits_::Arr_left_side_category Tag;
+struct Get_left_side_category< Traits_, true > {
+  typedef typename Traits_::Left_side_category Category;
 };
 
 template < class Traits_ >
-struct Get_left_side_tag< Traits_, false > {
-  typedef Arr_oblivious_side_tag Tag;
+struct Get_left_side_category< Traits_, false > {
+  typedef Arr_oblivious_side_tag Category;
 };
 
 template < class Traits_ >
-struct Arr_complete_left_side_tag {
+struct Arr_complete_left_side_category {
 
 public:
 
   typedef Traits_ Traits;
 
   typedef typename
-  Get_left_side_tag< Traits, has_Arr_left_side_category< Traits >::value >::Tag Tag;
+  Get_left_side_category< Traits, has_Left_side_category< Traits >::value >::Category Category;
 };
 
 template < class GeometryTraits_2, bool b > 
-struct Validate_left_side_tag {};
+struct Validate_left_side_category {};
 
 template < class GeometryTraits_2 >
-struct Validate_left_side_tag< GeometryTraits_2, true > {
-  void missing__Arr_left_side_category() {}
+struct Validate_left_side_category< GeometryTraits_2, true > {
+  void missing__Left_side_category() {}
 };
 
 template < class GeometryTraits_2 >
-struct Validate_left_side_tag< GeometryTraits_2, false > {
-  void missing__Arr_left_side_category()
+struct Validate_left_side_category< GeometryTraits_2, false > {
+  void missing__Left_side_category()
   { 
     bool 
-      missing__Arr_left_side_category__assuming__Arr_oblivious_side_tag__instead; 
+      missing__Left_side_category__assuming__Arr_oblivious_side_tag__instead; 
   }
 };
 
 
 //! type to provide bottom side tag (is oblivious if not existing)
 template < class Traits_, bool B >
-struct Get_bottom_side_tag { 
+struct Get_bottom_side_category { 
 };
 
 template < class Traits_ >
-struct Get_bottom_side_tag< Traits_, true > {
-  typedef typename Traits_::Arr_bottom_side_category Tag;
+struct Get_bottom_side_category< Traits_, true > {
+  typedef typename Traits_::Bottom_side_category Category;
 };
 
 template < class Traits_ >
-struct Get_bottom_side_tag< Traits_, false > {
-  typedef Arr_oblivious_side_tag Tag;
+struct Get_bottom_side_category< Traits_, false > {
+  typedef Arr_oblivious_side_tag Category;
 };
 
 template < class Traits_ >
-struct Arr_complete_bottom_side_tag {
+struct Arr_complete_bottom_side_category {
 
 public:
 
   typedef Traits_ Traits;
 
   typedef typename
-  Get_bottom_side_tag< Traits, has_Arr_bottom_side_category< Traits >::value >::Tag 
-  Tag;
+  Get_bottom_side_category< Traits, has_Bottom_side_category< Traits >::value >::Category 
+  Category;
 };
 
 template < class GeometryTraits_2, bool b > 
-struct Validate_bottom_side_tag {};
+struct Validate_bottom_side_category {};
 
 template < class GeometryTraits_2 >
-struct Validate_bottom_side_tag< GeometryTraits_2, true > {
-  void missing__Arr_bottom_side_category() {}
+struct Validate_bottom_side_category< GeometryTraits_2, true > {
+  void missing__Bottom_side_category() {}
 };
 
 template < class GeometryTraits_2 >
-struct Validate_bottom_side_tag< GeometryTraits_2, false > {
-  void missing__Arr_bottom_side_category()
+struct Validate_bottom_side_category< GeometryTraits_2, false > {
+  void missing__Bottom_side_category()
   { 
     bool 
-      missing__Arr_bottom_side_category__assuming__Arr_oblivious_side_tag__instead; 
+      missing__Bottom_side_category__assuming__Arr_oblivious_side_tag__instead; 
   }
 };
 
 
 //! type to provide top side tag (is oblivious if not existing)
 template < class Traits_, bool B >
-struct Get_top_side_tag { 
+struct Get_top_side_category { 
 };
 
 template < class Traits_ >
-struct Get_top_side_tag< Traits_, true > {
-  typedef typename Traits_::Arr_top_side_category Tag;
+struct Get_top_side_category< Traits_, true > {
+  typedef typename Traits_::Top_side_category Category;
 };
 
 template < class Traits_ >
-struct Get_top_side_tag< Traits_, false > {
-  typedef Arr_oblivious_side_tag Tag;
+struct Get_top_side_category< Traits_, false > {
+  typedef Arr_oblivious_side_tag Category;
 };
 
 template < class Traits_ >
-struct Arr_complete_top_side_tag {
+struct Arr_complete_top_side_category {
 
 public:
 
   typedef Traits_ Traits;
 
   typedef typename
-  Get_top_side_tag< Traits, has_Arr_top_side_category< Traits >::value >::Tag Tag;
+  Get_top_side_category< Traits, has_Top_side_category< Traits >::value >::Category Category;
 };
 
 template < class GeometryTraits_2, bool b > 
-struct Validate_top_side_tag {};
+struct Validate_top_side_category {};
 
 template < class GeometryTraits_2 >
-struct Validate_top_side_tag< GeometryTraits_2, true > {
-  void missing__Arr_top_side_category() {}
+struct Validate_top_side_category< GeometryTraits_2, true > {
+  void missing__Top_side_category() {}
 };
 
 template < class GeometryTraits_2 >
-struct Validate_top_side_tag< GeometryTraits_2, false > {
-  void missing__Arr_top_side_category()
+struct Validate_top_side_category< GeometryTraits_2, false > {
+  void missing__Top_side_category()
   { 
-    bool missing__Arr_top_side_category__assuming__Arr_oblivious_side_tag__instead; 
+    bool missing__Top_side_category__assuming__Arr_oblivious_side_tag__instead; 
   }
 };
 
 
 //! type to provide right side tag (is oblivious if not existing)
 template < class Traits_, bool B >
-struct Get_right_side_tag { 
+struct Get_right_side_category { 
 };
 
 template < class Traits_ >
-struct Get_right_side_tag< Traits_, true > {
-  typedef typename Traits_::Arr_right_side_category Tag;
+struct Get_right_side_category< Traits_, true > {
+  typedef typename Traits_::Right_side_category Category;
 };
 
 template < class Traits_ >
-struct Get_right_side_tag< Traits_, false > {
-  typedef Arr_oblivious_side_tag Tag;
+struct Get_right_side_category< Traits_, false > {
+  typedef Arr_oblivious_side_tag Category;
 };
 
 template < class Traits_ >
-struct Arr_complete_right_side_tag {
+struct Arr_complete_right_side_category {
 
 public:
 
   typedef Traits_ Traits;
 
   typedef typename
-  Get_right_side_tag< Traits, has_Arr_right_side_category< Traits >::value >::Tag 
-  Tag;
+  Get_right_side_category< Traits, has_Right_side_category< Traits >::value >::Category 
+  Category;
 };
 
 template < class GeometryTraits_2, bool b > 
-struct Validate_right_side_tag {};
+struct Validate_right_side_category {};
 
 template < class GeometryTraits_2 >
-struct Validate_right_side_tag< GeometryTraits_2, true > {
-  void missing__Arr_right_side_category() {}
+struct Validate_right_side_category< GeometryTraits_2, true > {
+  void missing__Right_side_category() {}
 };
 
 template < class GeometryTraits_2 >
-struct Validate_right_side_tag< GeometryTraits_2, false > {
-  void missing__Arr_right_side_category()
+struct Validate_right_side_category< GeometryTraits_2, false > {
+  void missing__Right_side_category()
   { 
     bool 
-      missing__Arr_right_side_category__assuming__Arr_oblivious_side_tag__instead; 
+      missing__Right_side_category__assuming__Arr_oblivious_side_tag__instead; 
   }
 };
 
@@ -242,23 +242,23 @@ struct Arr_not_all_sides_non_open_tag {};
 
 /*!\brief Struct to determine whether all side tags are "oblivious"
  */
-template < class ArrLeftSideTag, class ArrBottomSideTag, 
-           class ArrTopSideTag, class ArrRightSideTag >
+template < class ArrLeftSideCategory, class ArrBottomSideCategory, 
+           class ArrTopSideCategory, class ArrRightSideCategory >
 struct Arr_are_all_sides_oblivious_tag {
 
 public:
 
   //! This instance's first template parameter
-  typedef ArrLeftSideTag   Arr_left_side_category;
+  typedef ArrLeftSideCategory   Left_side_category;
   
   //! This instance's second template parameter
-  typedef ArrBottomSideTag Arr_bottom_side_category;
+  typedef ArrBottomSideCategory Bottom_side_category;
   
   //! This instance's third template parameter
-  typedef ArrTopSideTag    Arr_top_side_category;
+  typedef ArrTopSideCategory    Top_side_category;
   
   //! This instance's fourth template parameter
-  typedef ArrRightSideTag  Arr_right_side_category;
+  typedef ArrRightSideCategory  Right_side_category;
   
 private:
   
@@ -266,22 +266,22 @@ private:
   typedef boost::mpl::bool_< false > false_;
   
   typedef boost::mpl::if_< 
-       boost::is_same< Arr_left_side_category, Arr_oblivious_side_tag >,
+       boost::is_same< Left_side_category, Arr_oblivious_side_tag >,
        true_, false_ > 
   Left_oblivious;
 
   typedef boost::mpl::if_< 
-       boost::is_same< Arr_bottom_side_category, Arr_oblivious_side_tag >,
+       boost::is_same< Bottom_side_category, Arr_oblivious_side_tag >,
        true_, false_ > 
   Bottom_oblivious;
 
   typedef boost::mpl::if_< 
-       boost::is_same< Arr_top_side_category, Arr_oblivious_side_tag >,
+       boost::is_same< Top_side_category, Arr_oblivious_side_tag >,
        true_, false_ > 
   Top_oblivious;
 
   typedef boost::mpl::if_< 
-       boost::is_same< Arr_right_side_category, Arr_oblivious_side_tag >,
+       boost::is_same< Right_side_category, Arr_oblivious_side_tag >,
        true_, false_ > 
   Right_oblivious;
   
@@ -301,23 +301,23 @@ public:
 
 /*!\brief Struct to determine whether all side tags are "non-open"
  */
-template < class ArrLeftSideTag, class ArrBottomSideTag, 
-           class ArrTopSideTag, class ArrRightSideTag >
+template < class ArrLeftSideCategory, class ArrBottomSideCategory, 
+           class ArrTopSideCategory, class ArrRightSideCategory >
 struct Arr_are_all_sides_non_open_tag {
 
 public:
 
   //! This instance's first template parameter
-  typedef ArrLeftSideTag   Arr_left_side_category;
+  typedef ArrLeftSideCategory   Left_side_category;
   
   //! This instance's second template parameter
-  typedef ArrBottomSideTag Arr_bottom_side_category;
+  typedef ArrBottomSideCategory Bottom_side_category;
   
   //! This instance's third template parameter
-  typedef ArrTopSideTag    Arr_top_side_category;
+  typedef ArrTopSideCategory    Top_side_category;
   
   //! This instance's fourth template parameter
-  typedef ArrRightSideTag  Arr_right_side_category;
+  typedef ArrRightSideCategory  Right_side_category;
   
 private:
   
@@ -325,22 +325,22 @@ private:
   typedef boost::mpl::bool_< false > false_;
   
   typedef boost::mpl::if_< 
-       boost::is_same< Arr_left_side_category, Arr_open_side_tag >,
+       boost::is_same< Left_side_category, Arr_open_side_tag >,
        true_, false_ > 
   Left_open;
 
   typedef boost::mpl::if_< 
-       boost::is_same< Arr_bottom_side_category, Arr_open_side_tag >,
+       boost::is_same< Bottom_side_category, Arr_open_side_tag >,
        true_, false_ > 
   Bottom_open;
 
   typedef boost::mpl::if_< 
-       boost::is_same< Arr_top_side_category, Arr_open_side_tag >,
+       boost::is_same< Top_side_category, Arr_open_side_tag >,
        true_, false_ > 
   Top_open;
 
   typedef boost::mpl::if_< 
-       boost::is_same< Arr_right_side_category, Arr_open_side_tag >,
+       boost::is_same< Right_side_category, Arr_open_side_tag >,
        true_, false_ > 
   Right_open;
   
@@ -362,23 +362,23 @@ public:
 
 /*!\brief Struct to check consistent tagging of identifications
  */
-template < class ArrLeftSideTag, class ArrBottomSideTag, 
-           class ArrTopSideTag, class ArrRightSideTag >
+template < class ArrLeftSideCategory, class ArrBottomSideCategory, 
+           class ArrTopSideCategory, class ArrRightSideCategory >
 struct Arr_sane_identified_tagging {
 
 public:
   
   //! This instance's first template parameter
-  typedef ArrLeftSideTag   Arr_left_side_category;
+  typedef ArrLeftSideCategory   Left_side_category;
   
   //! This instance's second template parameter
-  typedef ArrBottomSideTag Arr_bottom_side_category;
+  typedef ArrBottomSideCategory Bottom_side_category;
   
   //! This instance's third template parameter
-  typedef ArrTopSideTag    Arr_top_side_category;
+  typedef ArrTopSideCategory    Top_side_category;
   
   //! This instance's fourth template parameter
-  typedef ArrRightSideTag  Arr_right_side_category;
+  typedef ArrRightSideCategory  Right_side_category;
   
 private:
   
@@ -386,22 +386,22 @@ private:
   typedef boost::mpl::bool_< false > false_;
   
   typedef boost::mpl::if_< 
-       boost::is_same< Arr_left_side_category, Arr_identified_side_tag >,
+       boost::is_same< Left_side_category, Arr_identified_side_tag >,
        true_, false_ > 
   Left_identified;
 
   typedef boost::mpl::if_<
-       boost::is_same< Arr_bottom_side_category, Arr_identified_side_tag >,
+       boost::is_same< Bottom_side_category, Arr_identified_side_tag >,
        true_, false_ > 
   Bottom_identified;
 
   typedef boost::mpl::if_< 
-       boost::is_same< Arr_top_side_category, Arr_identified_side_tag >,
+       boost::is_same< Top_side_category, Arr_identified_side_tag >,
        true_, false_ > 
   Top_identified;
   
   typedef boost::mpl::if_< 
-       boost::is_same< Arr_right_side_category, Arr_identified_side_tag >,
+       boost::is_same< Right_side_category, Arr_identified_side_tag >,
        true_, false_ > 
   Right_identified;
 
@@ -431,7 +431,6 @@ public:
 
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
-
