@@ -1,4 +1,4 @@
-// Copyright (c) 2006  Tel-Aviv University (Israel).
+// Copyright (c) 2006,2007,2008,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Arrangement_on_surface_2/include/CGAL/Arr_topology_traits/Arr_planar_topology_traits_base_2.h $
-// $Id: Arr_planar_topology_traits_base_2.h 50366 2009-07-05 12:56:48Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arr_topology_traits/Arr_planar_topology_traits_base_2.h $
+// $Id: Arr_planar_topology_traits_base_2.h 65392 2011-09-14 12:33:57Z lrineau $
 // 
 //
 // Author(s)     : Ron Wein <wein@post.tau.ac.il>
@@ -43,7 +43,7 @@
 #include <CGAL/Sweep_line_2/Arr_vert_decomp_sl_visitor.h>
 #include <CGAL/Arr_point_location/Arr_batched_point_location_traits_2.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 /*! \class Arr_planar_topology_traits_base_2
  * A base topology-traits class that encapsulates the embedding of 2D
@@ -422,6 +422,20 @@ is_in_face(const Face *f, const Point_2& p, const Vertex *v) const
   // Note that if p coincides with this vertex, p is obviously not in the
   // interior of the component.
   const Halfedge    *first = *(f->outer_ccbs_begin());
+
+  
+  // Some left ends of curves may not yet have the curve assigned, 
+  // In case they are at TOP/BOTTOM they are not comparable to p 
+  // We advance first until we find a comparable vertex to start with.
+  // We always find such a vertex since on the ccb there is at least one 
+  // interior vertex or a vertex at LEFT/RIGHT which are comparable. 
+  while( first->vertex()->parameter_space_in_x()==ARR_INTERIOR 
+      && first->has_null_curve() 
+      && first->next()->has_null_curve()){ 
+    first = first->next(); 
+  }
+
+  
   const Halfedge    *curr = first;
   Comparison_result  res_source;
   Comparison_result  res_target;
@@ -440,7 +454,15 @@ is_in_face(const Face *f, const Point_2& p, const Vertex *v) const
     // the component.
     if (curr->vertex() == v)
       return (false);
-
+    
+    // We jump over vertices at TOP/BOTTOM that do not yet have a curve 
+    if(    curr->vertex()->parameter_space_in_x()==ARR_INTERIOR 
+        && curr->has_null_curve() 
+        && curr->next()->has_null_curve()){ 
+      curr = curr->next(); 
+      continue;
+    }
+    
     res_target = compare_xy (p, curr->vertex());
 
     // In case the current halfedge belongs to an "antenna", namely its
@@ -486,6 +508,6 @@ is_in_face(const Face *f, const Point_2& p, const Vertex *v) const
   return ((n_ray_intersections % 2) != 0);
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
