@@ -1,4 +1,4 @@
-// Copyright (c) 2005  Tel-Aviv University (Israel).
+// Copyright (c) 2007,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Arr_tracing_traits_2.h $
-// $Id: Arr_tracing_traits_2.h 51984 2009-09-20 16:18:10Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arr_tracing_traits_2.h $
+// $Id: Arr_tracing_traits_2.h 64639 2011-07-06 11:41:06Z lrineau $
 //
 // Author(s)     : Efi Fogel    <efif@post.tau.ac.il>
 
@@ -32,7 +32,7 @@
 #include <CGAL/basic.h>
 #include <CGAL/Arr_enums.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 /*! \class 
  * A model of the ArrangementTraits_2 concept that counts the methods invoked.
@@ -63,14 +63,16 @@ public:
     COMPARE_ENDPOINTS_XY_OP,
 
     PARAMETER_SPACE_IN_X_OP,
-    COMPARE_Y_NEAR_BOUNDARY_OP,
-    COMPARE_Y_ON_BOUNDARY_OP,
     IS_ON_X_IDENTIFICATION_OP,    
+    COMPARE_Y_ON_BOUNDARY_OP,
+    COMPARE_Y_NEAR_BOUNDARY_OP,
     
     PARAMETER_SPACE_IN_Y_OP,
-    COMPARE_X_NEAR_BOUNDARY_OP,
-    COMPARE_X_ON_BOUNDARY_OP,
     IS_ON_Y_IDENTIFICATION_OP,
+    COMPARE_X_AT_LIMIT_OP,
+    COMPARE_X_NEAR_LIMIT_OP,
+    COMPARE_X_ON_BOUNDARY_OP,
+    COMPARE_X_NEAR_BOUNDARY_OP,
     
     NUMBER_OF_OPERATIONS
   };
@@ -83,79 +85,89 @@ private:
   unsigned int m_flags;
   
   bool compare_x_op() const
-  { return m_flags & (0x1 << COMPARE_X_OP); }
+  { return (0 != (m_flags & (0x1 << COMPARE_X_OP))); }
 
   bool compare_xy_op() const
-  { return m_flags & (0x1 << COMPARE_XY_OP); }
+  { return (0 != (m_flags & (0x1 << COMPARE_XY_OP))); }
   
   bool construct_min_vertex_op() const
-  { return m_flags & (0x1 << CONSTRUCT_MIN_VERTEX_OP); }
+  { return (0 != (m_flags & (0x1 << CONSTRUCT_MIN_VERTEX_OP))); }
   
   bool construct_max_vertex_op() const
-  { return m_flags & (0x1 << CONSTRUCT_MAX_VERTEX_OP); }
+  { return (0 != (m_flags & (0x1 << CONSTRUCT_MAX_VERTEX_OP))); }
   
   bool is_vertical_op() const
-  { return m_flags & (0x1 << IS_VERTICAL_OP); }
+  { return (0 != (m_flags & (0x1 << IS_VERTICAL_OP))); }
   
   bool compare_y_at_x_op() const
-  { return m_flags & (0x1 << COMPARE_Y_AT_X_OP); }
+  { return (0 != (m_flags & (0x1 << COMPARE_Y_AT_X_OP))); }
   
   bool equal_points_op() const
-  { return m_flags & (0x1 << EQUAL_POINTS_OP); }
+  { return (0 != (m_flags & (0x1 << EQUAL_POINTS_OP))); }
   
   bool equal_curves_op() const
-  { return m_flags & (0x1 << EQUAL_CURVES_OP); }
+  { return (0 != (m_flags & (0x1 << EQUAL_CURVES_OP))); }
   
   bool compare_y_at_x_left_op() const
-  { return m_flags & (0x1 << COMPARE_Y_AT_X_LEFT_OP); }
+  { return (0 != (m_flags & (0x1 << COMPARE_Y_AT_X_LEFT_OP))); }
   
   bool compare_y_at_x_right_op() const
-  { return m_flags & (0x1 << COMPARE_Y_AT_X_RIGHT_OP); }
+  { return (0 != (m_flags & (0x1 << COMPARE_Y_AT_X_RIGHT_OP))); }
   
   bool make_x_monotone_op() const
-  { return m_flags & (0x1 << MAKE_X_MONOTONE_OP); }
+  { return (0 != (m_flags & (0x1 << MAKE_X_MONOTONE_OP))); }
   
   bool split_op() const
-  { return m_flags & (0x1 << SPLIT_OP); }
+  { return (0 != (m_flags & (0x1 << SPLIT_OP))); }
   
   bool intersect_op() const
-  { return m_flags & (0x1 << INTERSECT_OP); }
+  { return (0 != (m_flags & (0x1 << INTERSECT_OP))); }
   
   bool are_mergeable_op() const
-  { return m_flags & (0x1 << ARE_MERGEABLE_OP); }
+  { return (0 != (m_flags & (0x1 << ARE_MERGEABLE_OP))); }
   
   bool merge_op() const
-  { return m_flags & (0x1 << MERGE_OP); }
+  { return (0 != (m_flags & (0x1 << MERGE_OP))); }
   
   bool construct_opposite_op() const
-  { return m_flags & (0x1 << CONSTRUCT_OPPOSITE_OP); }
+  { return (0 != (m_flags & (0x1 << CONSTRUCT_OPPOSITE_OP))); }
   
   bool compare_endpoints_xy_op() const
-  { return m_flags & (0x1 << COMPARE_ENDPOINTS_XY_OP); }
+  { return (0 != (m_flags & (0x1 << COMPARE_ENDPOINTS_XY_OP))); }
+
+  // left-right
 
   bool parameter_space_in_x_op() const
-  { return m_flags & (0x1 << PARAMETER_SPACE_IN_X_OP); }
+  { return (0 != (m_flags & (0x1 << PARAMETER_SPACE_IN_X_OP))); }
   
+  bool is_on_x_identification_op() const 
+  { return m_flags & (0x1 << IS_ON_X_IDENTIFICATION_OP); }  
+
+  bool compare_y_on_boundary_op() const
+  { return (0 != (m_flags & (0x1 << COMPARE_Y_ON_BOUNDARY_OP))); }  
+
   bool compare_y_near_boundary_op() const
   { return m_flags & (0x1 << COMPARE_Y_NEAR_BOUNDARY_OP); }
 
-  bool compare_y_on_boundary_op() const
-  { return m_flags & (0x1 << COMPARE_Y_ON_BOUNDARY_OP); }  
+  // bottom-top
 
-  bool is_on_x_identification_op() const 
-  { return m_flags & (0x1 << IS_ON_X_IDENTIFICATION_OP); }  
-  
   bool parameter_space_in_y_op() const
-  { return m_flags & (0x1 << PARAMETER_SPACE_IN_Y_OP); }
-
-  bool compare_x_near_boundary_op() const
-  { return m_flags & (0x1 << COMPARE_X_NEAR_BOUNDARY_OP); }
-
-  bool compare_x_on_boundary_op() const
-  { return m_flags & (0x1 << COMPARE_X_ON_BOUNDARY_OP); }  
+  { return (0 != (m_flags & (0x1 << PARAMETER_SPACE_IN_Y_OP))); }
 
   bool is_on_y_identification_op() const 
   { return m_flags & (0x1 << IS_ON_Y_IDENTIFICATION_OP); }  
+
+  bool compare_x_at_limit_op() const
+  { return m_flags & (0x1 << COMPARE_X_AT_LIMIT_OP); }
+
+  bool compare_x_near_limit_op() const
+  { return m_flags & (0x1 << COMPARE_X_NEAR_LIMIT_OP); }
+
+  bool compare_x_on_boundary_op() const
+  { return (0 != (m_flags & (0x1 << COMPARE_X_ON_BOUNDARY_OP))); }  
+
+  bool compare_x_near_boundary_op() const
+  { return m_flags & (0x1 << COMPARE_X_NEAR_BOUNDARY_OP); }
   
 public:
   /*! Default constructor */
@@ -189,17 +201,18 @@ public:
   //@{
 
   // Traits types:
-  typedef typename Base::Has_left_category      Has_left_category;
-  typedef typename Base::Has_merge_category     Has_merge_category;
+  typedef typename Base::Has_left_category          Has_left_category;
+  typedef typename Base::Has_merge_category         Has_merge_category;
+  typedef typename Base::Has_do_intersect_category  Has_do_intersect_category;
 
-  typedef typename internal::Arr_complete_left_side_tag< Base >::Tag
-                                                Arr_left_side_category;
-  typedef typename internal::Arr_complete_bottom_side_tag< Base >::Tag
-                                                Arr_bottom_side_category;
-  typedef typename internal::Arr_complete_top_side_tag< Base >::Tag
-                                                Arr_top_side_category;
-  typedef typename internal::Arr_complete_right_side_tag< Base >::Tag
-                                                Arr_right_side_category;
+  typedef typename internal::Arr_complete_left_side_category< Base >::Category
+                                                Left_side_category;
+  typedef typename internal::Arr_complete_bottom_side_category< Base >::Category
+                                                Bottom_side_category;
+  typedef typename internal::Arr_complete_top_side_category< Base >::Category
+                                                Top_side_category;
+  typedef typename internal::Arr_complete_right_side_category< Base >::Category
+                                                Right_side_category;
   
   typedef typename Base::Point_2                Point_2;
   typedef typename Base::X_monotone_curve_2     X_monotone_curve_2;
@@ -741,6 +754,8 @@ public:
     }
   };
 
+  // left-right
+
   /*! A functor that determines whether an endpoint of an x-monotone curve lies
    * on a boundary of the parameter space along the x axis.
    */
@@ -772,6 +787,112 @@ public:
     }
   };
 
+  /*! A functor that determines whether a point or curve is on 
+   * x-identification.
+   */
+  class Is_on_x_identification_2 {
+  private:
+    typename Base::Is_on_x_identification_2 m_object;
+    bool m_enabled;
+    
+  public:
+    /*! Construct */
+    Is_on_x_identification_2(const Base * base, bool enabled = true) :
+      m_object(base->is_on_x_identification_2_object()), m_enabled(enabled) {}
+    /*! Operate
+     * \param p1 the point.
+     */
+    Comparison_result operator()(const Point_2 & p) const
+    {
+      if (!m_enabled) return m_object(p);
+      std::cout << "is_on_x_identification" << std::endl
+                << "  p: " << p << std::endl;
+      Comparison_result cr = m_object(p);
+      std::cout << "  result: " << cr << std::endl;
+      return cr;
+    }
+
+    /*! Operate
+     * \param xcv1 the curve
+     */
+    Comparison_result operator()(const X_monotone_curve_2 & xcv) const
+    {
+      if (!m_enabled) return m_object(xcv);
+      std::cout << "is_on_x_identification" << std::endl
+                << "  xcv: " << xcv << std::endl;
+      Comparison_result cr = m_object(xcv);
+      std::cout << "  result: " << cr << std::endl;
+      return cr;
+    }
+  };
+
+  /*! A functor that compares the y-coordinate of two given points
+   * that lie on vertical boundaries.
+   */
+  class Compare_y_on_boundary_2 {
+  private:
+    typename Base::Compare_y_on_boundary_2 m_object;
+    bool m_enabled;
+    
+  public:
+    /*! Construct */
+    Compare_y_on_boundary_2(const Base * base, bool enabled = true) :
+      m_object(base->compare_y_on_boundary_2_object()),
+      m_enabled(enabled)
+    {}
+
+    /*! Operate
+     * \param p1 the first point.
+     * \param p2 the second point.
+     */
+    Comparison_result operator()(const Point_2 & p1, const Point_2 & p2) const
+    {
+      if (!m_enabled) return m_object(p1, p2);
+      std::cout << "compare_y_on_boundary" << std::endl
+                << "  p1: " << p1 << std::endl
+                << "  p2: " << p2 << std::endl;
+      Comparison_result cr = m_object(p1, p2);
+      std::cout << "  result: " << cr << std::endl;
+      return cr;
+    }
+  };
+
+  /*! A functor that compares the y-coordinates of curve ends near the
+   * boundary of the parameter space.
+   */
+  class Compare_y_near_boundary_2 {
+  private:
+    typename Base::Compare_y_near_boundary_2 m_object;
+    bool m_enabled;
+    
+  public:
+    /*! Construct */
+    Compare_y_near_boundary_2(const Base * base, bool enabled = true) :
+      m_object(base->compare_y_near_boundary_2_object()), m_enabled(enabled) {}
+
+    /*! Operate
+     * \param xcv1 the first curve the end point of which is tested
+     * \param xcv2 the second curve the end point of which is tested
+     * \param ce the curve-end identifier
+     * \return the comparison result
+     */
+    Comparison_result operator()(const X_monotone_curve_2 & xcv1,
+                                 const X_monotone_curve_2 & xcv2, 
+                                 Arr_curve_end ce) const
+    {
+      if (!m_enabled) return m_object(xcv1, xcv2, ce);
+      std::cout << "compare_y_near_boundary" << std::endl
+                << "  ce: " << ce << std::endl
+                << "  xcv1: " << xcv1 << std::endl
+                << "  xcv2: " << xcv2 << std::endl;
+      Comparison_result cr = m_object(xcv1, xcv2, ce);
+      std::cout << "  result: " << cr << std::endl;
+      return cr;
+    }
+  };
+
+  // bottom-top
+
   /*! A functor that determines whether an endpoint of an x-monotone arc lies
    * on a boundary of the parameter space along the y axis.
    */
@@ -816,192 +937,6 @@ public:
     }
   };
 
-  /*! A functor that compares the x-coordinates of curve ends near the
-   * boundary of the parameter space.
-   */
-  class Compare_x_near_boundary_2 {
-  private:
-    typename Base::Compare_x_near_boundary_2 m_object;
-    bool m_enabled;
-    
-  public:
-    /*! Construct */
-    Compare_x_near_boundary_2(const Base * base, bool enabled = true) :
-      m_object(base->compare_x_near_boundary_2_object()), m_enabled(enabled) {}
-
-    /*! Operate
-     * \param p the first point 
-     * \param xcv the curve the end of which is to be compared
-     * \param ce the curve-end identifier
-     * \return the comparison result
-     */
-    Comparison_result operator()(const Point_2 & p,
-                                 const X_monotone_curve_2 & xcv,
-                                 Arr_curve_end ce) const
-    {
-      if (!m_enabled) return m_object(p, xcv, ce);
-      std::cout << "compare_x_near_boundary 1" << std::endl
-                << "  p: " << p << std::endl
-                << "  ce: " << ce << ", xcv: " << xcv << std::endl;
-      Comparison_result cr = m_object(p, xcv, ce);
-      std::cout << "  result: " << std::endl;
-      return cr;
-    }
-
-    /*! Operate
-     * \param xcv1 the first curve the end of which is to be compared
-     * \param ce1 the identifier of the end of the first curve
-     * \param xcv2 the second curve the end of which is to be compared
-     * \param ce2 the identifier of the end of the second curve
-     * \return the comparison result
-     */
-    Comparison_result operator()(const X_monotone_curve_2 & xcv1,
-                                 Arr_curve_end ce1,
-                                 const X_monotone_curve_2 & xcv2,
-                                 Arr_curve_end ce2) const
-    {
-      if (!m_enabled) return m_object(xcv1, ce1, xcv2, ce2);
-      std::cout << "compare_x_near_boundary 2" << std::endl
-                << "  ce1: " << ce1 << ", xcv1: " << xcv1 << std::endl
-                << "  ce2: " << ce2 << ", xcv2: " << xcv2 << std::endl;
-      Comparison_result cr = m_object(xcv1, ce1, xcv2, ce2);
-      std::cout << "  result: " << cr << std::endl;
-      return cr;
-    }
-  };
-
-  /*! A functor that compares the y-coordinates of curve ends near the
-   * boundary of the parameter space.
-   */
-  class Compare_y_near_boundary_2 {
-  private:
-    typename Base::Compare_y_near_boundary_2 m_object;
-    bool m_enabled;
-    
-  public:
-    /*! Construct */
-    Compare_y_near_boundary_2(const Base * base, bool enabled = true) :
-      m_object(base->compare_y_near_boundary_2_object()), m_enabled(enabled) {}
-
-    /*! Operate
-     * \param xcv1 the first curve the end point of which is tested
-     * \param xcv2 the second curve the end point of which is tested
-     * \param ce the curve-end identifier
-     * \return the comparison result
-     */
-    Comparison_result operator()(const X_monotone_curve_2 & xcv1,
-                                 const X_monotone_curve_2 & xcv2, 
-                                 Arr_curve_end ce) const
-    {
-      if (!m_enabled) return m_object(xcv1, xcv2, ce);
-      std::cout << "compare_y_near_boundary" << std::endl
-                << "  ce: " << ce << std::endl
-                << "  xcv1: " << xcv1 << std::endl
-                << "  xcv2: " << xcv2 << std::endl;
-      Comparison_result cr = m_object(xcv1, xcv2, ce);
-      std::cout << "  result: " << cr << std::endl;
-      return cr;
-    }
-  };
-
-  /*! A functor that compares the x-coordinate of two given points
-   * that lie on horizontal boundaries.
-   */
-  class Compare_x_on_boundary_2 {
-  private:
-    typename Base::Compare_x_on_boundary_2 m_object;
-    bool m_enabled;
-    
-  public:
-    /*! Construct */
-    Compare_x_on_boundary_2(const Base * base, bool enabled = true) :
-      m_object(base->compare_x_on_boundary_2_object()), m_enabled(enabled) {}
-    /*! Operate
-     * \param p1 the first point.
-     * \param p2 the second point.
-     */
-    Comparison_result operator()(const Point_2 & p1, const Point_2 & p2) const
-    {
-      if (!m_enabled) return m_object(p1, p2);
-      std::cout << "compare_x_on_boundary" << std::endl
-                << "  p1: " << p1 << std::endl
-                << "  p2: " << p2 << std::endl;
-      Comparison_result cr = m_object(p1, p2);
-      std::cout << "  result: " << cr << std::endl;
-      return cr;
-    }
-  };
-  
-  /*! A functor that compares the y-coordinate of two given points
-   * that lie on vertical boundaries.
-   */
-  class Compare_y_on_boundary_2 {
-  private:
-    typename Base::Compare_y_on_boundary_2 m_object;
-    bool m_enabled;
-    
-  public:
-    /*! Construct */
-    Compare_y_on_boundary_2(const Base * base, bool enabled = true) :
-      m_object(base->compare_y_on_boundary_2_object()),
-      m_enabled(enabled)
-    {}
-
-    /*! Operate
-     * \param p1 the first point.
-     * \param p2 the second point.
-     */
-    Comparison_result operator()(const Point_2 & p1, const Point_2 & p2) const
-    {
-      if (!m_enabled) return m_object(p1, p2);
-      std::cout << "compare_y_on_boundary" << std::endl
-                << "  p1: " << p1 << std::endl
-                << "  p2: " << p2 << std::endl;
-      Comparison_result cr = m_object(p1, p2);
-      std::cout << "  result: " << cr << std::endl;
-      return cr;
-    }
-  };
-
-  /*! A functor that determines whether a point or curve is on 
-   * x-identification.
-   */
-  class Is_on_x_identification_2 {
-  private:
-    typename Base::Is_on_x_identification_2 m_object;
-    bool m_enabled;
-    
-  public:
-    /*! Construct */
-    Is_on_x_identification_2(const Base * base, bool enabled = true) :
-      m_object(base->is_on_x_identification_2_object()), m_enabled(enabled) {}
-    /*! Operate
-     * \param p1 the point.
-     */
-    Comparison_result operator()(const Point_2 & p) const
-    {
-      if (!m_enabled) return m_object(p);
-      std::cout << "is_on_x_identification" << std::endl
-                << "  p: " << p << std::endl;
-      Comparison_result cr = m_object(p);
-      std::cout << "  result: " << cr << std::endl;
-      return cr;
-    }
-
-    /*! Operate
-     * \param xcv1 the curve
-     */
-    Comparison_result operator()(const X_monotone_curve_2 & xcv) const
-    {
-      if (!m_enabled) return m_object(xcv);
-      std::cout << "is_on_x_identification" << std::endl
-                << "  xcv: " << xcv << std::endl;
-      Comparison_result cr = m_object(xcv);
-      std::cout << "  result: " << cr << std::endl;
-      return cr;
-    }
-  };
-
   /*! A functor that determines whether a point or curve is on 
    * y-identification.
    */
@@ -1040,11 +975,204 @@ public:
       return cr;
     }
   };
+
+  /*! A functor that compares the x-limits of curve ends on the
+   * boundary of the parameter space.
+   */
+  class Compare_x_at_limit_2 {
+  private:
+    typename Base::Compare_x_at_limit_2 m_object;
+    bool m_enabled;
+    
+  public:
+    /*! Construct */
+    Compare_x_at_limit_2(const Base * base, bool enabled = true) :
+      m_object(base->compare_x_at_limit_2_object()), m_enabled(enabled) {}
+
+    /*! Operate
+     * \param p the first point 
+     * \param xcv the curve the end of which is to be compared
+     * \param ce the curve-end identifier
+     * \return the comparison result
+     */
+    Comparison_result operator()(const Point_2 & p,
+                                 const X_monotone_curve_2 & xcv,
+                                 Arr_curve_end ce) const
+    {
+      if (!m_enabled) return m_object(p, xcv, ce);
+      std::cout << "compare_x_at_limit 1" << std::endl
+                << "  p: " << p << std::endl
+                << "  ce: " << ce << ", xcv: " << xcv << std::endl;
+      Comparison_result cr = m_object(p, xcv, ce);
+      std::cout << "  result: " << std::endl;
+      return cr;
+    }
+
+    /*! Operate
+     * \param xcv1 the first curve the end of which is to be compared
+     * \param ce1 the identifier of the end of the first curve
+     * \param xcv2 the second curve the end of which is to be compared
+     * \param ce2 the identifier of the end of the second curve
+     * \return the comparison result
+     */
+    Comparison_result operator()(const X_monotone_curve_2 & xcv1,
+                                 Arr_curve_end ce1,
+                                 const X_monotone_curve_2 & xcv2,
+                                 Arr_curve_end ce2) const
+    {
+      if (!m_enabled) return m_object(xcv1, ce1, xcv2, ce2);
+      std::cout << "compare_x_at_limit 2" << std::endl
+                << "  ce1: " << ce1 << ", xcv1: " << xcv1 << std::endl
+                << "  ce2: " << ce2 << ", xcv2: " << xcv2 << std::endl;
+      Comparison_result cr = m_object(xcv1, ce1, xcv2, ce2);
+      std::cout << "  result: " << cr << std::endl;
+      return cr;
+    }
+  };
+
+
+  /*! A functor that compares the x-coordinates of curve ends near the
+   * boundary of the parameter space.
+   */
+  class Compare_x_near_limit_2 {
+  private:
+    typename Base::Compare_x_near_limit_2 m_object;
+    bool m_enabled;
+    
+  public:
+    /*! Construct */
+    Compare_x_near_limit_2(const Base * base, bool enabled = true) :
+      m_object(base->compare_x_near_limit_2_object()), m_enabled(enabled) {}
+
+    /*! Operate
+     * \param xcv1 the first curve the end of which is to be compared
+     * \param ce1 the identifier of the end of the first curve
+     * \param xcv2 the second curve the end of which is to be compared
+     * \param ce2 the identifier of the end of the second curve
+     * \return the comparison result
+     */
+    Comparison_result operator()(const X_monotone_curve_2 & xcv1,
+                                 const X_monotone_curve_2 & xcv2,
+                                 Arr_curve_end ce) const
+    {
+      if (!m_enabled) return m_object(xcv1, xcv2, ce);
+      std::cout << "compare_x_near_limit 2" << std::endl
+                << "  xcv1: " << xcv1 << std::endl
+                << "  xcv2: " << xcv2 << std::endl
+		<< "    ce: " << ce << std::endl; 
+      Comparison_result cr = m_object(xcv1, xcv2, ce);
+      std::cout << "  result: " << cr << std::endl;
+      return cr;
+    }
+  };
+
+  /*! A functor that compares the x-coordinate of two given points
+   * that lie on horizontal boundaries.
+   */
+  class Compare_x_on_boundary_2 {
+  private:
+    typename Base::Compare_x_on_boundary_2 m_object;
+    bool m_enabled;
+    
+  public:
+    /*! Construct */
+    Compare_x_on_boundary_2(const Base * base, bool enabled = true) :
+      m_object(base->compare_x_on_boundary_2_object()), m_enabled(enabled) {}
+    /*! Operate
+     * \param p1 the first point.
+     * \param p2 the second point.
+     */
+    Comparison_result operator()(const Point_2 & p1, const Point_2 & p2) const
+    {
+      if (!m_enabled) return m_object(p1, p2);
+      std::cout << "compare_x_on_boundary" << std::endl
+                << "  p1: " << p1 << std::endl
+                << "  p2: " << p2 << std::endl;
+      Comparison_result cr = m_object(p1, p2);
+      std::cout << "  result: " << cr << std::endl;
+      return cr;
+    }
+
+    /*! Operate
+     * \param pt the point.
+     * \param xcv the curve.
+     * \param ce the curve-end
+     */
+    Comparison_result operator()(const Point_2 & pt, 
+                                 const X_monotone_curve_2 & xcv, Arr_curve_end ce) const
+    {
+      if (!m_enabled) return m_object(pt, xcv, ce);
+      std::cout << "compare_x_on_boundary" << std::endl
+                << "  pt: " << pt << std::endl
+                << " xcv: " << xcv << std::endl
+                << "  ce: " << ce << std::endl;
+      Comparison_result cr = m_object(pt, xcv, ce);
+      std::cout << "  result: " << cr << std::endl;
+      return cr;
+    }
+
+    /*! Operate
+     * \param xcv1 the first curve.
+     * \param ce1 the first curve-end
+     * \param xcv2 the second curve.
+     * \param ce2 the second curve-end
+     */
+    Comparison_result operator()(const X_monotone_curve_2 & xcv1, Arr_curve_end ce1,
+                                 const X_monotone_curve_2 & xcv2, Arr_curve_end ce2) const
+    {
+      if (!m_enabled) return m_object(xcv2, ce1, xcv2, ce2);
+      std::cout << "compare_x_on_boundary" << std::endl
+                << "xcv1: " << xcv1 << std::endl
+                << " ce1: " << ce1 << std::endl
+                << "xcv2: " << xcv2 << std::endl
+                << " ce2: " << ce2 << std::endl;
+      Comparison_result cr = m_object(xcv1, ce1, xcv2, ce2);
+      std::cout << "  result: " << cr << std::endl;
+      return cr;
+    }
+
+  };
   
+  /*! A functor that compares the x-coordinates of curve ends near the
+   * boundary of the parameter space.
+   */
+  class Compare_x_near_boundary_2 {
+  private:
+    typename Base::Compare_x_near_boundary_2 m_object;
+    bool m_enabled;
+    
+  public:
+    /*! Construct */
+    Compare_x_near_boundary_2(const Base * base, bool enabled = true) :
+      m_object(base->compare_x_near_boundary_2_object()), m_enabled(enabled) {}
+
+    /*! Operate
+     * \param xcv1 the first curve the end of which is to be compared
+     * \param ce1 the identifier of the end of the first curve
+     * \param xcv2 the second curve the end of which is to be compared
+     * \param ce2 the identifier of the end of the second curve
+     * \return the comparison result
+     */
+    Comparison_result operator()(const X_monotone_curve_2 & xcv1,
+                                 const X_monotone_curve_2 & xcv2,
+                                 Arr_curve_end ce) const
+    {
+      if (!m_enabled) return m_object(xcv1, xcv2, ce);
+      std::cout << "compare_x_near_boundary 2" << std::endl
+                << "  xcv1: " << xcv1 << std::endl
+                << "  xcv2: " << xcv2 << std::endl
+		<< "    ce: " << ce << std::endl; 
+      Comparison_result cr = m_object(xcv1, xcv2, ce);
+      std::cout << "  result: " << cr << std::endl;
+      return cr;
+    }
+  };
+
   //@}
 
   /// \name Obtain the appropriate functor
   //@{
+
   Compare_x_2 compare_x_2_object() const
   { return Compare_x_2(this, compare_x_op()); }
   
@@ -1093,34 +1221,40 @@ public:
   Compare_endpoints_xy_2 compare_endpoints_xy_2_object() const
   { return Compare_endpoints_xy_2(this, compare_endpoints_xy_op()); }
 
+  // left-right
+
   Parameter_space_in_x_2 parameter_space_in_x_2_object() const
   { return Parameter_space_in_x_2(this, parameter_space_in_x_op()); }
 
+  Is_on_x_identification_2 is_on_x_identification_2_object() const 
+  { return Is_on_x_identification_2(this, is_on_x_identification_op()); }
+  
+  Compare_y_on_boundary_2 compare_y_on_boundary_2_object() const
+  { return Compare_y_on_boundary_2(this, compare_y_on_boundary_op()); }
+
   Compare_y_near_boundary_2 compare_y_near_boundary_2_object() const
   { return Compare_y_near_boundary_2(this, compare_y_near_boundary_op()); }
 
-  Compare_y_on_boundary_2 compare_y_on_boundary_2_object() const
-  {
-    return Compare_y_on_boundary_2(this, compare_y_on_boundary_op());
-  }
-  
-  Is_on_x_identification_2 is_on_x_identification_2_object() const 
-  { return Is_on_x_identification_2(this, is_on_x_identification_op()); }
+  // bottom-top
   
   Parameter_space_in_y_2 parameter_space_in_y_2_object() const
   { return Parameter_space_in_y_2(this, parameter_space_in_y_op()); }
   
-  Compare_x_near_boundary_2 compare_x_near_boundary_2_object() const
-  { return Compare_x_near_boundary_2(this, compare_x_near_boundary_op()); }
-
-  Compare_x_on_boundary_2 compare_x_on_boundary_2_object() const
-  {
-    return Compare_x_on_boundary_2(this, compare_x_on_boundary_op());
-  }
-  
   Is_on_y_identification_2 is_on_y_identification_2_object() const 
   { return Is_on_y_identification_2(this, is_on_y_identification_op()); }
 
+  Compare_x_at_limit_2 compare_x_at_limit_2_object() const
+  { return Compare_x_at_limit_2(this, compare_x_at_limit_op()); }
+
+  Compare_x_near_limit_2 compare_x_near_limit_2_object() const
+  { return Compare_x_near_limit_2(this, compare_x_near_limit_op()); }
+
+  Compare_x_on_boundary_2 compare_x_on_boundary_2_object() const
+  { return Compare_x_on_boundary_2(this, compare_x_on_boundary_op()); }
+
+  Compare_x_near_boundary_2 compare_x_near_boundary_2_object() const
+  { return Compare_x_near_boundary_2(this, compare_x_near_boundary_op()); }
+
   //@}
 };
 
@@ -1131,6 +1265,6 @@ OutputStream & operator<<(OutputStream & os, Comparison_result cr)
   return os;
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
