@@ -1,4 +1,4 @@
-// Copyright (c) 2006, 2009 Tel-Aviv University (Israel).
+// Copyright (c) 2006,2007,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Arrangement_2/Arr_default_planar_topology.h $
-// $Id: Arr_default_planar_topology.h 51456 2009-08-24 17:10:04Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arrangement_2/Arr_default_planar_topology.h $
+// $Id: Arr_default_planar_topology.h 64639 2011-07-06 11:41:06Z lrineau $
 // 
 //
 // Author(s): Ron Wein          <wein@post.tau.ac.il>
@@ -32,7 +32,7 @@
 #include <CGAL/Arr_bounded_planar_topology_traits_2.h>
 #include <CGAL/Arr_unb_planar_topology_traits_2.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 namespace internal {
 
@@ -64,14 +64,13 @@ struct Default_planar_topology :
   public internal::Default_planar_topology_impl < 
     GeomTraits, Dcel, 
     typename Arr_are_all_sides_oblivious_tag< 
-      typename internal::Arr_complete_left_side_tag< GeomTraits >::Tag,
-      typename internal::Arr_complete_bottom_side_tag< GeomTraits> ::Tag,
-      typename internal::Arr_complete_top_side_tag< GeomTraits >::Tag,
-      typename internal::Arr_complete_right_side_tag< GeomTraits >::Tag >::result 
+      typename internal::Arr_complete_left_side_category< GeomTraits >::Category,
+      typename internal::Arr_complete_bottom_side_category< GeomTraits> ::Category,
+      typename internal::Arr_complete_top_side_category< GeomTraits >::Category,
+      typename internal::Arr_complete_right_side_category< GeomTraits >::Category >::result 
 >
 {};
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
-
