@@ -1,4 +1,4 @@
-// Copyright (c) 2007, 2009 Tel-Aviv University (Israel).
+// Copyright (c) 2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,11 +11,11 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Arrangement_2/Arr_traits_adaptor_2_dispatching.h $
-// $Id: Arr_traits_adaptor_2_dispatching.h 51984 2009-09-20 16:18:10Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arrangement_2/Arr_traits_adaptor_2_dispatching.h $
+// $Id: Arr_traits_adaptor_2_dispatching.h 64639 2011-07-06 11:41:06Z lrineau $
 // 
 //
-// Author(s): Eric Berberich    <ericb@post.tau.ac.il>
+// Author(s): Eric Berberich    <eric@mpi-inf.mpg.de>
 
 #ifndef CGAL_ARR_TRAITS_ADAPTOR_2_DISPATCHING_H
 #define CGAL_ARR_TRAITS_ADAPTOR_2_DISPATCHING_H
@@ -34,7 +34,7 @@
  * Definition of the dispatching tags and classes for the traits adaptor
  */
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 //! tag to specify to use a dummy implementation
 struct Arr_use_dummy_tag {};
@@ -44,527 +44,9 @@ struct Arr_use_traits_tag {};
 
 namespace internal {
 
-////////////////
-// left-right //
-////////////////
-
-namespace Parameter_space_in_x_2 {
-
-  // Curve-end
-
-  template < class ArrSideTag >
-  struct Curve_end {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve_end< Arr_oblivious_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve_end< Arr_open_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Curve_end< Arr_contracted_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Curve_end< Arr_closed_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Curve_end< Arr_identified_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-
-  // Curve
-
-  template < class ArrSideTag >
-  struct Curve {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve< Arr_oblivious_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve< Arr_open_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve< Arr_contracted_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve< Arr_closed_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Curve< Arr_identified_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-
-  // Point
-
-  template < class ArrSideTag >
-  struct Point {
-    typedef Arr_use_dummy_tag type;
-  };
-
-  template <>
-  struct Point< Arr_oblivious_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Point< Arr_open_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Point< Arr_contracted_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Point< Arr_closed_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Point< Arr_identified_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-} // namespace Parameter_space_in_x_2
-
-
-namespace Compare_y_near_boundary_2 {
-
-// Curve-ends
-
-  template < class ArrSideTag >
-  struct Curve_ends {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve_ends< Arr_oblivious_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve_ends< Arr_open_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Curve_ends< Arr_contracted_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Curve_ends< Arr_closed_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Curve_ends< Arr_identified_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-
-} // Compare_y_near_boundary_2
-
-namespace Compare_y_on_boundary_2 {
-
- // Poitns
- template < class ArrSideTag >
-  struct Points {
-    typedef Arr_use_dummy_tag type;
-  };
-
-  template <>
-  struct Points< Arr_oblivious_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Points< Arr_open_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Points< Arr_contracted_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Points< Arr_closed_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Points< Arr_identified_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-
-} // namespace Compare_y_on_boundary_2
-
-namespace Is_on_y_identification_2 {
-
-  // Curve
-
-  template < class ArrSideTag >
-  struct Curve {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve< Arr_oblivious_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve< Arr_open_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve< Arr_contracted_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve< Arr_closed_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve< Arr_identified_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-
-  // Point
-
-  template < class ArrSideTag >
-  struct Point {
-    typedef Arr_use_dummy_tag type;
-  };
-
-  template <>
-  struct Point< Arr_oblivious_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Point< Arr_open_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Point< Arr_contracted_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Point< Arr_closed_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Point< Arr_identified_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-} // namespace Is_on_y_identification_2
-
-
-
-////////////////
-// bottom-top //
-////////////////
-
-namespace Parameter_space_in_y_2 {
-
-  // Curve-end
-
-  template < class ArrSideTag >
-  struct Curve_end {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve_end< Arr_oblivious_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve_end< Arr_open_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Curve_end< Arr_contracted_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Curve_end< Arr_closed_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Curve_end< Arr_identified_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-
-  // Curve
-
-  template < class ArrSideTag >
-  struct Curve {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve< Arr_oblivious_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve< Arr_open_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve< Arr_contracted_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve< Arr_closed_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Curve< Arr_identified_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-
-  // Point
-
-  template < class ArrSideTag >
-  struct Point {
-    typedef Arr_use_dummy_tag type;
-  };
-
-  template <>
-  struct Point< Arr_oblivious_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Point< Arr_open_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Point< Arr_contracted_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Point< Arr_closed_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Point< Arr_identified_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-} // namespace Parameter_space_in_y_2
-
-namespace Compare_x_near_boundary_2 {
-
-  // Point_curve-end
-
-  template < class ArrSideTag >
-  struct Point_curve_end {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Point_curve_end< Arr_oblivious_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Point_curve_end< Arr_open_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Point_curve_end< Arr_contracted_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Point_curve_end< Arr_closed_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Point_curve_end< Arr_identified_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-
-  // Curve-ends
-
-  template < class ArrSideTag >
-  struct Curve_ends {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve_ends< Arr_oblivious_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve_ends< Arr_open_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Curve_ends< Arr_contracted_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Curve_ends< Arr_closed_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Curve_ends< Arr_identified_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-
-} // Compare_y_near_boundary_2
-
-namespace Compare_x_on_boundary_2 {
-
- // Poitns
- template < class ArrSideTag >
-  struct Points {
-    typedef Arr_use_dummy_tag type;
-  };
-
-  template <>
-  struct Points< Arr_oblivious_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Points< Arr_open_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Points< Arr_contracted_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Points< Arr_closed_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-  template <>
-  struct Points< Arr_identified_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-
-} // namespace Compare_x_on_boundary_2
-
-namespace Is_on_x_identification_2 {
-
-  // Curve
-
-  template < class ArrSideTag >
-  struct Curve {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve< Arr_oblivious_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve< Arr_open_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve< Arr_contracted_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve< Arr_closed_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Curve< Arr_identified_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-
-  // Point
-
-  template < class ArrSideTag >
-  struct Point {
-    typedef Arr_use_dummy_tag type;
-  };
-
-  template <>
-  struct Point< Arr_oblivious_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Point< Arr_open_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Point< Arr_contracted_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Point< Arr_closed_side_tag > {
-    typedef Arr_use_dummy_tag type;
-  };
-  
-  template <>
-  struct Point< Arr_identified_side_tag > {
-    typedef Arr_use_traits_tag type;
-  };
-  
-} // namespace Is_on_x_identification_2
-
+///////////////
+// combining //
+///////////////
 
 //! struct to combine results in "or"-fashion
 template < class ArrSmallerImplementationTag, class ArrLargerImplementationTag >
@@ -603,178 +85,876 @@ public:
 
 };
 
+
+////////////////
+// left-right //
+////////////////
+
+namespace Parameter_space_in_x_2 {
+
+  // Curve-end
+
+  template < class ArrSideTag >
+  struct Curve_end {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve_end< Arr_oblivious_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve_end< Arr_open_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Curve_end< Arr_closed_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Curve_end< Arr_contracted_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Curve_end< Arr_identified_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+
+  // Curve
+
+  template < class ArrSideTag >
+  struct Curve {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve< Arr_oblivious_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve< Arr_open_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve< Arr_closed_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Curve< Arr_contracted_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve< Arr_identified_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+
+  // Point
+
+  template < class ArrSideTag >
+  struct Point {
+    typedef Arr_use_dummy_tag type;
+  };
+
+  template <>
+  struct Point< Arr_oblivious_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Point< Arr_open_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Point< Arr_closed_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Point< Arr_contracted_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Point< Arr_identified_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+} // namespace Parameter_space_in_x_2
+
+
+namespace Is_on_y_identification_2 {
+
+  // Curve
+
+  template < class ArrSideTag >
+  struct Curve {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve< Arr_oblivious_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve< Arr_open_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve< Arr_closed_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve< Arr_contracted_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve< Arr_identified_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+
+  // Point
+
+  template < class ArrSideTag >
+  struct Point {
+    typedef Arr_use_dummy_tag type;
+  };
+
+  template <>
+  struct Point< Arr_oblivious_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Point< Arr_open_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Point< Arr_closed_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Point< Arr_contracted_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Point< Arr_identified_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+} // namespace Is_on_y_identification_2
+
+
+namespace Compare_y_on_boundary_2 {
+
+ // Poitns
+ template < class ArrSideTag >
+  struct Points {
+    typedef Arr_use_dummy_tag type;
+  };
+
+  template <>
+  struct Points< Arr_oblivious_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Points< Arr_open_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Points< Arr_closed_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Points< Arr_contracted_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Points< Arr_identified_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+
+} // namespace Compare_y_on_boundary_2
+
+
+namespace Compare_y_near_boundary_2 {
+
+// Curve-ends
+
+  template < class ArrSideTag >
+  struct Curve_ends {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_oblivious_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_open_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_closed_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_contracted_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_identified_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+
+} // Compare_y_near_boundary_2
+
+
+
 template < class ArrLeftSideTag, class ArrRightSideTag >
 struct Arr_left_right_implementation_dispatch {
 
 public:
   
   //! This instance's first template parameter
-  typedef ArrLeftSideTag   Arr_left_side_category;
+  typedef ArrLeftSideTag   Left_side_category;
   
   //! This instance's second template parameter
-  typedef ArrRightSideTag  Arr_right_side_category;
+  typedef ArrRightSideTag  Right_side_category;
   
 public:
   
   //! tag type for Parameter_space_in_x_2 (curve-end signature)
   typedef typename internal::Or_traits<
     typename 
-    internal::Parameter_space_in_x_2::Curve_end< Arr_left_side_category >::type,
+    internal::Parameter_space_in_x_2::Curve_end< Left_side_category >::type,
     typename 
-    internal::Parameter_space_in_x_2::Curve_end< Arr_right_side_category >::type 
+    internal::Parameter_space_in_x_2::Curve_end< Right_side_category >::type 
   >::type
   Parameter_space_in_x_2_curve_end_tag;
 
   //! tag type for Parameter_space_in_x_2 (curve signature)
   typedef typename internal::Or_traits<
     typename 
-    internal::Parameter_space_in_x_2::Curve< Arr_left_side_category >::type,
+    internal::Parameter_space_in_x_2::Curve< Left_side_category >::type,
     typename 
-    internal::Parameter_space_in_x_2::Curve< Arr_right_side_category >::type 
+    internal::Parameter_space_in_x_2::Curve< Right_side_category >::type 
   >::type
   Parameter_space_in_x_2_curve_tag;
   
   //! tag type for Parameter_space_in_x_2 (point signature)
   typedef typename internal::Or_traits<
     typename
-    internal::Parameter_space_in_x_2::Point< Arr_left_side_category >::type,
+    internal::Parameter_space_in_x_2::Point< Left_side_category >::type,
     typename
-    internal::Parameter_space_in_x_2::Point< Arr_right_side_category >::type >::type
+    internal::Parameter_space_in_x_2::Point< Right_side_category >::type >::type
   Parameter_space_in_x_2_point_tag;
 
-  
-  //! tag type for Compare_y_near_boundary_2 (curve-ends signature)
-  typedef typename internal::Or_traits<
-    typename 
-    internal::Compare_y_near_boundary_2::Curve_ends< Arr_left_side_category >::type,
-    typename 
-    internal::Compare_y_near_boundary_2::Curve_ends< Arr_right_side_category >::type 
-  >::type
-  Compare_y_near_boundary_2_curve_ends_tag;
-
-  // TODO Compare_y_right_of_2 ???
-
-  //! tag type for Compare_y_on_boundary_2 (points signature)
-  typedef typename internal::Or_traits<
-    typename 
-    internal::Compare_y_on_boundary_2::Points< Arr_left_side_category >::type,
-    typename 
-    internal::Compare_y_on_boundary_2::Points< Arr_right_side_category >::type 
-  >::type
-  Compare_y_on_boundary_2_points_tag;
-
-  //! tag type for Is_on_y_identification_2 (point signature)
-  typedef typename internal::Or_traits<
-    typename 
-    internal::Is_on_y_identification_2::Point< Arr_left_side_category >::type,
-    typename 
-    internal::Is_on_y_identification_2::Point< Arr_right_side_category >::type 
-  >::type
-  Is_on_y_identification_2_point_tag;
-
   //! tag type for Is_on_y_identification_2 (curve signature)
   typedef typename internal::Or_traits<
     typename 
-    internal::Is_on_y_identification_2::Curve< Arr_left_side_category >::type,
+    internal::Is_on_y_identification_2::Curve< Left_side_category >::type,
     typename 
-    internal::Is_on_y_identification_2::Curve< Arr_right_side_category >::type 
+    internal::Is_on_y_identification_2::Curve< Right_side_category >::type 
   >::type
   Is_on_y_identification_2_curve_tag;
 
+  //! tag type for Is_on_y_identification_2 (point signature)
+  typedef typename internal::Or_traits<
+    typename 
+    internal::Is_on_y_identification_2::Point< Left_side_category >::type,
+    typename 
+    internal::Is_on_y_identification_2::Point< Right_side_category >::type 
+  >::type
+  Is_on_y_identification_2_point_tag;
+
+  //! tag type for Compare_y_on_boundary_2 (points signature)
+  typedef typename internal::Or_traits<
+    typename 
+    internal::Compare_y_on_boundary_2::Points< Left_side_category >::type,
+    typename 
+    internal::Compare_y_on_boundary_2::Points< Right_side_category >::type 
+  >::type
+  Compare_y_on_boundary_2_points_tag;
+
+  //! tag type for Compare_y_near_boundary_2 (curve-ends signature)
+  typedef typename internal::Or_traits<
+    typename 
+    internal::Compare_y_near_boundary_2::Curve_ends< Left_side_category >::type,
+    typename 
+    internal::Compare_y_near_boundary_2::Curve_ends< Right_side_category >::type 
+  >::type
+  Compare_y_near_boundary_2_curve_ends_tag;
+
 }; // left-right-dispatch
 
 
+////////////////
+// bottom-top //
+////////////////
+
+namespace Parameter_space_in_y_2 {
+
+  // Curve-end
+
+  template < class ArrSideTag >
+  struct Curve_end {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve_end< Arr_oblivious_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve_end< Arr_open_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Curve_end< Arr_closed_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Curve_end< Arr_contracted_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Curve_end< Arr_identified_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+
+  // Curve
+
+  template < class ArrSideTag >
+  struct Curve {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve< Arr_oblivious_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve< Arr_open_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve< Arr_closed_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Curve< Arr_contracted_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve< Arr_identified_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+
+  // Point
+
+  template < class ArrSideTag >
+  struct Point {
+    typedef Arr_use_dummy_tag type;
+  };
+
+  template <>
+  struct Point< Arr_oblivious_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Point< Arr_open_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Point< Arr_closed_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Point< Arr_contracted_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Point< Arr_identified_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+} // namespace Parameter_space_in_y_2
+
+
+namespace Is_on_x_identification_2 {
+
+  // Curve
+
+  template < class ArrSideTag >
+  struct Curve {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve< Arr_oblivious_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve< Arr_open_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve< Arr_closed_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve< Arr_contracted_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve< Arr_identified_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+
+  // Point
+
+  template < class ArrSideTag >
+  struct Point {
+    typedef Arr_use_dummy_tag type;
+  };
+
+  template <>
+  struct Point< Arr_oblivious_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Point< Arr_open_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Point< Arr_closed_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Point< Arr_contracted_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Point< Arr_identified_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+} // namespace Is_on_x_identification_2
+
+
+namespace Compare_x_at_limit_2 {
+
+  // Point_curve-end
+
+  template < class ArrSideTag >
+  struct Point_curve_end {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Point_curve_end< Arr_oblivious_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Point_curve_end< Arr_open_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Point_curve_end< Arr_closed_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Point_curve_end< Arr_contracted_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Point_curve_end< Arr_identified_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+
+  // Curve-ends
+
+  template < class ArrSideTag >
+  struct Curve_ends {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_oblivious_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+
+  template <>
+  struct Curve_ends< Arr_open_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_closed_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_contracted_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_identified_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+
+} // Compare_x_at_limit_2
+
+namespace Compare_x_near_limit_2 {
+
+  // Curve-ends
+
+  template < class ArrSideTag >
+  struct Curve_ends {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_oblivious_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_open_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_closed_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_contracted_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_identified_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+
+} // Compare_x_near_limit_2
+
+
+namespace Compare_x_on_boundary_2 {
+
+ // Points
+ template < class ArrSideTag >
+  struct Points {
+    typedef Arr_use_dummy_tag type;
+  };
+
+  template <>
+  struct Points< Arr_oblivious_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Points< Arr_open_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Points< Arr_closed_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Points< Arr_contracted_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Points< Arr_identified_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+
+  // Point_curve-end
+
+  template < class ArrSideTag >
+  struct Point_curve_end {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Point_curve_end< Arr_oblivious_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Point_curve_end< Arr_open_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Point_curve_end< Arr_closed_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Point_curve_end< Arr_contracted_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Point_curve_end< Arr_identified_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+
+  // Curve-ends
+
+  template < class ArrSideTag >
+  struct Curve_ends {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_oblivious_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+
+  template <>
+  struct Curve_ends< Arr_open_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_closed_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_contracted_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_identified_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+} // namespace Compare_x_on_boundary_2
+
+
+namespace Compare_x_near_boundary_2 {
+
+  // Curve-ends
+
+  template < class ArrSideTag >
+  struct Curve_ends {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_oblivious_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_open_side_tag > {
+    typedef Arr_use_dummy_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_closed_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_contracted_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+  
+  template <>
+  struct Curve_ends< Arr_identified_side_tag > {
+    typedef Arr_use_traits_tag type;
+  };
+
+} // Compare_y_near_boundary_2
+
+
+
 template < class ArrBottomSideTag, class ArrTopSideTag >
 struct Arr_bottom_top_implementation_dispatch {
 
 public:
   
   //! This instance's first template parameter
-  typedef ArrBottomSideTag   Arr_bottom_side_category;
+  typedef ArrBottomSideTag   Bottom_side_category;
   
   //! This instance's second template parameter
-  typedef ArrTopSideTag  Arr_top_side_category;
+  typedef ArrTopSideTag  Top_side_category;
   
 public:
 
   //! tag type for Parameter_space_in_y_2 (curve-end signature)
   typedef typename internal::Or_traits<
     typename 
-    internal::Parameter_space_in_y_2::Curve_end< Arr_bottom_side_category >::type,
+    internal::Parameter_space_in_y_2::Curve_end< Bottom_side_category >::type,
     typename 
-    internal::Parameter_space_in_y_2::Curve_end< Arr_top_side_category >::type 
+    internal::Parameter_space_in_y_2::Curve_end< Top_side_category >::type 
   >::type
   Parameter_space_in_y_2_curve_end_tag;
 
   //! tag type for Parameter_space_in_y_2 (curve signature)
   typedef typename internal::Or_traits<
     typename 
-    internal::Parameter_space_in_y_2::Curve< Arr_bottom_side_category >::type,
+    internal::Parameter_space_in_y_2::Curve< Bottom_side_category >::type,
     typename 
-    internal::Parameter_space_in_y_2::Curve< Arr_top_side_category >::type 
+    internal::Parameter_space_in_y_2::Curve< Top_side_category >::type 
   >::type
   Parameter_space_in_y_2_curve_tag;
   
   //! tag type for Parameter_space_in_y_2 (point signature)
   typedef typename internal::Or_traits<
     typename
-    internal::Parameter_space_in_y_2::Point< Arr_bottom_side_category >::type,
+    internal::Parameter_space_in_y_2::Point< Bottom_side_category >::type,
     typename
-    internal::Parameter_space_in_y_2::Point< Arr_top_side_category >::type >::type
+    internal::Parameter_space_in_y_2::Point< Top_side_category >::type >::type
   Parameter_space_in_y_2_point_tag;
   
-  //! tag type for Compare_x_near_boundary_2 (point-curve-end signature)
+  //! tag type for Is_on_x_identification_2 (curve signature)
   typedef typename internal::Or_traits<
     typename 
-    internal::Compare_x_near_boundary_2::Point_curve_end< Arr_bottom_side_category >
-    ::type,
+    internal::Is_on_x_identification_2::Curve< Bottom_side_category >::type,
     typename 
-    internal::Compare_x_near_boundary_2::Point_curve_end< Arr_top_side_category >::type 
+    internal::Is_on_x_identification_2::Curve< Top_side_category >::type 
   >::type
-  Compare_x_near_boundary_2_point_curve_end_tag;
-
-  //! tag type for Compare_x_near_boundary_2 (curve-ends signature)
-  typedef typename internal::Or_traits<
-    typename 
-    internal::Compare_x_near_boundary_2::Curve_ends< Arr_bottom_side_category >::type,
-    typename 
-    internal::Compare_x_near_boundary_2::Curve_ends< Arr_top_side_category >::type 
-  >::type
-  Compare_x_near_boundary_2_curve_ends_tag;
-
-  //! tag type for Compare_y_on_boundary_2 (points signature)
-  typedef typename internal::Or_traits<
-    typename 
-    internal::Compare_x_on_boundary_2::Points< Arr_bottom_side_category >::type,
-    typename 
-    internal::Compare_x_on_boundary_2::Points< Arr_top_side_category >::type 
-  >::type
-  Compare_x_on_boundary_2_points_tag;
+  Is_on_x_identification_2_curve_tag;
 
   //! tag type for Is_on_x_identification_2 (point signature)
   typedef typename internal::Or_traits<
     typename 
-    internal::Is_on_x_identification_2::Point< Arr_bottom_side_category >::type,
+    internal::Is_on_x_identification_2::Point< Bottom_side_category >::type,
     typename 
-    internal::Is_on_x_identification_2::Point< Arr_top_side_category >::type 
+    internal::Is_on_x_identification_2::Point< Top_side_category >::type 
   >::type
   Is_on_x_identification_2_point_tag;
 
-  //! tag type for Is_on_x_identification_2 (curve signature)
+  //! tag type for Compare_x_at_limit_2 (point-curve-end signature)
   typedef typename internal::Or_traits<
     typename 
-    internal::Is_on_x_identification_2::Curve< Arr_bottom_side_category >::type,
+    internal::Compare_x_at_limit_2::Point_curve_end< Bottom_side_category >
+    ::type,
     typename 
-    internal::Is_on_x_identification_2::Curve< Arr_top_side_category >::type 
+    internal::Compare_x_at_limit_2::Point_curve_end< Top_side_category >::type 
   >::type
-  Is_on_x_identification_2_curve_tag;
+  Compare_x_at_limit_2_point_curve_end_tag;
+
+  //! tag type for Compare_x_at_limit_2 (curve-ends signature)
+  typedef typename internal::Or_traits<
+    typename 
+    internal::Compare_x_at_limit_2::Curve_ends< Bottom_side_category >::type,
+    typename 
+    internal::Compare_x_at_limit_2::Curve_ends< Top_side_category >::type 
+  >::type
+  Compare_x_at_limit_2_curve_ends_tag;
+
+  //! tag type for Compare_x_near_limit_boundary_2 (curve-ends signature)
+  typedef typename internal::Or_traits<
+    typename 
+    internal::Compare_x_near_limit_2::Curve_ends< Bottom_side_category >
+    ::type,
+    typename 
+    internal::Compare_x_near_limit_2::Curve_ends< Top_side_category >::type 
+  >::type
+  Compare_x_near_limit_2_curve_ends_tag;
+
+  //! tag type for Compare_x_on_boundary_2 (points signature)
+  typedef typename internal::Or_traits<
+    typename 
+    internal::Compare_x_on_boundary_2::Points< Bottom_side_category >::type,
+    typename 
+    internal::Compare_x_on_boundary_2::Points< Top_side_category >::type 
+  >::type
+  Compare_x_on_boundary_2_points_tag;
+
+  //! tag type for Compare_x_on_boundary_2 (point_curve-end signature)
+  typedef typename internal::Or_traits<
+    typename 
+    internal::Compare_x_on_boundary_2::Point_curve_end< Bottom_side_category >::type,
+    typename 
+    internal::Compare_x_on_boundary_2::Point_curve_end< Top_side_category >::type 
+  >::type
+  Compare_x_on_boundary_2_point_curve_end_tag;
+
+  //! tag type for Compare_x_on_boundary_2 (curve-ends signature)
+  typedef typename internal::Or_traits<
+    typename 
+    internal::Compare_x_on_boundary_2::Curve_ends< Bottom_side_category >::type,
+    typename 
+    internal::Compare_x_on_boundary_2::Curve_ends< Top_side_category >::type 
+  >::type
+  Compare_x_on_boundary_2_curve_ends_tag;
   
-}; // bottom-top-dispatch
+  //! tag type for Compare_x_near_boundary_2 (curve-ends signature)
+  typedef typename internal::Or_traits<
+    typename 
+    internal::Compare_x_near_boundary_2::Curve_ends< Bottom_side_category >::type,
+    typename 
+    internal::Compare_x_near_boundary_2::Curve_ends< Top_side_category >::type 
+  >::type
+  Compare_x_near_boundary_2_curve_ends_tag;
+
+  }; // bottom-top-dispatch
 
 } // namespace internal
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_ARR_TRAITS_ADAPTOR_2_DISPATCHING_H
-
-
