@@ -1,4 +1,4 @@
-// Copyright (c) 2005, 2009  Tel-Aviv University (Israel).
+// Copyright (c) 2005,2006,2007,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Arrangement_on_surface_2/include/CGAL/Arrangement_2/Arrangement_zone_2_impl.h $
-// $Id: Arrangement_zone_2_impl.h 50366 2009-07-05 12:56:48Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Arrangement_2/Arrangement_zone_2_impl.h $
+// $Id: Arrangement_zone_2_impl.h 64639 2011-07-06 11:41:06Z lrineau $
 // 
 //
 // Author(s)     : Ron Wein          <wein@post.tau.ac.il>
@@ -26,7 +26,7 @@
  * Member-function definitions for the Arrangement_zone_2 class.
  */
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 //-----------------------------------------------------------------------------
 // Initialize the zone-computation process with a given curve and an object
@@ -718,8 +718,8 @@ _is_to_left_impl(const Point_2& p, Halfedge_handle he,
   if (ps_y != ARR_INTERIOR) {
     // Check if p is to the left of the minimal curve-end:
     const Comparison_result   res =
-      m_geom_traits->compare_x_near_boundary_2_object() (p, he->curve(),
-                                                         ARR_MIN_END);
+      m_geom_traits->compare_x_point_curve_end_2_object() (p, he->curve(),
+                                                           ARR_MIN_END);
 
     return ((res == SMALLER) || (res == EQUAL && ps_y == ARR_TOP_BOUNDARY));
   }
@@ -755,8 +755,8 @@ _is_to_right_impl(const Point_2& p, Halfedge_handle he,
   if (ps_y != ARR_INTERIOR) {
     // Check if p is to the right of the maximal curve-end:
     const Comparison_result   res =
-      m_geom_traits->compare_x_near_boundary_2_object() (p, he->curve(),
-                                                         ARR_MAX_END);
+      m_geom_traits->compare_x_point_curve_end_2_object() (p, he->curve(),
+                                                           ARR_MAX_END);
 
     return ((res == LARGER) || (res == EQUAL && ps_y == ARR_BOTTOM_BOUNDARY));
   }
@@ -790,8 +790,6 @@ void Arrangement_zone_2<Arrangement,ZoneVisitor>::
     m_geom_traits->is_in_x_range_2_object();
   typename Traits_adaptor_2::Construct_min_vertex_2  min_vertex =
     m_geom_traits->construct_min_vertex_2_object();
-  typename Traits_adaptor_2::Construct_max_vertex_2  max_vertex =
-    m_geom_traits->construct_max_vertex_2_object();
   typename Traits_adaptor_2::Compare_y_at_x_2        compare_y_at_x =
     m_geom_traits->compare_y_at_x_2_object();
 
@@ -1533,6 +1531,6 @@ bool Arrangement_zone_2<Arrangement,ZoneVisitor>::_zone_in_overlap ()
   return (false);
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
