@@ -1,4 +1,4 @@
-// Copyright (c) 2005, 2009  Tel-Aviv University (Israel).
+// Copyright (c) 2006,2007,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Basic_sweep_line_2.h $
-// $Id: Basic_sweep_line_2.h 51984 2009-09-20 16:18:10Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/Basic_sweep_line_2.h $
+// $Id: Basic_sweep_line_2.h 64639 2011-07-06 11:41:06Z lrineau $
 // 
 //
 // Author(s)     : Baruch Zukerman <baruchzu@post.tau.ac.il>
@@ -68,7 +68,7 @@
 
 
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 /*! \class Basic_Sweep_line_2 
  * A class that implements the sweep line algorithm for general x-monotone
@@ -96,22 +96,22 @@ public:
   typedef typename Traits_adaptor_2::Point_2            Point_2;
   typedef typename Traits_adaptor_2::X_monotone_curve_2 X_monotone_curve_2;
 
-  typedef typename Traits_adaptor_2::Arr_left_side_category   Arr_left_side_category;
-  typedef typename Traits_adaptor_2::Arr_bottom_side_category Arr_bottom_side_category;
-  typedef typename Traits_adaptor_2::Arr_top_side_category    Arr_top_side_category;
-  typedef typename Traits_adaptor_2::Arr_right_side_category  Arr_right_side_category;
+  typedef typename Traits_adaptor_2::Left_side_category   Left_side_category;
+  typedef typename Traits_adaptor_2::Bottom_side_category Bottom_side_category;
+  typedef typename Traits_adaptor_2::Top_side_category    Top_side_category;
+  typedef typename Traits_adaptor_2::Right_side_category  Right_side_category;
 
   BOOST_MPL_ASSERT(
       (typename 
-       Arr_sane_identified_tagging< Arr_left_side_category, Arr_bottom_side_category, 
-       Arr_top_side_category, Arr_right_side_category >::result)
+       Arr_sane_identified_tagging< Left_side_category, Bottom_side_category, 
+       Top_side_category, Right_side_category >::result)
   );
   
 protected:
 
   typedef typename Arr_are_all_sides_oblivious_tag< 
-                     Arr_left_side_category, Arr_bottom_side_category, 
-                     Arr_top_side_category, Arr_right_side_category >::result
+                     Left_side_category, Bottom_side_category, 
+                     Top_side_category, Right_side_category >::result
   Are_all_sides_oblivious_tag;
   
 public:
@@ -328,25 +328,25 @@ public:
   /*! Get an iterator for the first event in event queue. */
   Event_queue_iterator event_queue_begin()
   {
-    return (m_queue.begin());
+    return (m_queue->begin());
   }
 
   /*! Get a past-the-end iterator for the events in the in event queue. */
   Event_queue_iterator event_queue_end()
   {
-    return (m_queue.end());
+    return (m_queue->end());
   }
 
    /*! Get the event queue size. */
   unsigned int event_queue_size() const
   {
-    return (m_queue.size());
+    return (m_queue->size());
   }
 
   /*! Check if the event queue is empty. */
   bool is_event_queue_empty() const
   {
-    return (m_queue.empty());
+    return (m_queue->empty());
   }
 
   /*! 
@@ -588,7 +588,7 @@ protected:
   #include <CGAL/Sweep_line_2/Sweep_line_2_debug.h>
 #endif
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #include <CGAL/Sweep_line_2/Basic_sweep_line_2_impl.h>
 
