@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Cartesian_kernel/include/CGAL/Cartesian/predicates_on_directions_2.h $
-// $Id: predicates_on_directions_2.h 45156 2008-08-26 13:40:26Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Cartesian_kernel/include/CGAL/Cartesian/predicates_on_directions_2.h $
+// $Id: predicates_on_directions_2.h 56667 2010-06-09 07:37:13Z sloriot $
 // 
 //
 // Author(s)     : Herve Bronnimann
@@ -24,7 +24,7 @@
 #ifndef CGAL_CARTESIAN_PREDICATES_ON_DIRECTIONS_2_H
 #define CGAL_CARTESIAN_PREDICATES_ON_DIRECTIONS_2_H
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template < class K >
 inline
@@ -44,6 +44,6 @@ compare_angle_with_x_axis(const DirectionC2<K> &d1,
   return K().compare_angle_with_x_axis_2_object()(d1, d2);
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_CARTESIAN_PREDICATES_ON_DIRECTIONS_2_H
