@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Kernel_d/include/CGAL/Cartesian_d.h $
-// $Id: Cartesian_d.h 51456 2009-08-24 17:10:04Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Kernel_d/include/CGAL/Cartesian_d.h $
+// $Id: Cartesian_d.h 63930 2011-06-07 08:20:54Z sloriot $
 // 
 //
 // Author(s)     : Michael Seel
@@ -46,7 +46,7 @@
 #include <CGAL/Kernel_d/simple_objects.h>
 #include <CGAL/Dimension.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template <class pFT, class pLA = Linear_algebraCd<pFT> >
 class Cartesian_d
@@ -234,6 +234,7 @@ public:
   { return Construct_aff_transformation_d(); }
 
   // function objects:
+  typedef Compute_coordinateCd<Self> Compute_coordinate_d;
   typedef Lift_to_paraboloidCd<Self> Lift_to_paraboloid_d;
   typedef Project_along_d_axisCd<Self> Project_along_d_axis_d;
   typedef MidpointCd<Self> Midpoint_d;
@@ -250,6 +251,8 @@ public:
   typedef Compare_lexicographicallyCd<Self> Compare_lexicographically_d; 
   typedef Lt_from_compare<Self> Less_lexicographically_d;
   typedef Le_from_compare<Self> Less_or_equal_lexicographically_d;
+  typedef Less_coordinateCd<Self> Less_coordinate_d;
+  typedef Point_dimensionCd<Self> Point_dimension_d;
   typedef Eq_from_method<Self> Equal_d;
   typedef Center_of_sphereCd<Self> Center_of_sphere_d;
   typedef Contained_in_linear_hullCd<Self> Contained_in_linear_hull_d;  
@@ -257,6 +260,12 @@ public:
   typedef Linearly_independentCd<Self> Linearly_independent_d;
   typedef Linear_baseCd<Self> Linear_base_d;
 
+  Compute_coordinate_d compute_coordinate_d_object() const
+  { return Compute_coordinate_d(); }
+  Point_dimension_d point_dimension_d_object() const
+  { return Point_dimension_d(); }
+  Less_coordinate_d less_coordinate_d_object() const
+  { return Less_coordinate_d(); }
   Lift_to_paraboloid_d lift_to_paraboloid_d_object() const
   { return Lift_to_paraboloid_d(); }
   Project_along_d_axis_d project_along_d_axis_d_object() const
@@ -394,7 +403,7 @@ public:
 }; // Cartesian_d<R>
  
  
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #include <CGAL/Kernel_d/Point_d.h>
 #include <CGAL/Kernel_d/Vector_d.h>
