@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Mesh_2/include/CGAL/Delaunay_mesh_size_criteria_2.h $
-// $Id: Delaunay_mesh_size_criteria_2.h 45810 2008-09-26 13:46:54Z lrineau $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Mesh_2/include/CGAL/Delaunay_mesh_size_criteria_2.h $
+// $Id: Delaunay_mesh_size_criteria_2.h 61939 2011-03-23 17:45:59Z lrineau $
 // 
 //
 // Author(s)     : Laurent RINEAU
@@ -32,20 +32,22 @@ class Delaunay_mesh_size_criteria_2 :
     public virtual Delaunay_mesh_criteria_2<CDT>
 {
 protected:
+  typedef typename CDT::Geom_traits Geom_traits;
   double sizebound;
 
 public:
   typedef Delaunay_mesh_criteria_2<CDT> Base;
 
   Delaunay_mesh_size_criteria_2(const double aspect_bound = 0.125, 
-                                const double size_bound = 0)
-    : Base(aspect_bound), sizebound(size_bound) {};
+                                const double size_bound = 0,
+                                const Geom_traits& traits = Geom_traits())
+    : Base(aspect_bound, traits), sizebound(size_bound) {}
 
   inline
-  double size_bound() const { return sizebound; };
+  double size_bound() const { return sizebound; }
 
   inline
-  void set_size_bound(const double sb) { sizebound = sb; };
+  void set_size_bound(const double sb) { sizebound = sb; }
 
   // first: squared_minimum_sine
   // second: size
@@ -54,7 +56,7 @@ public:
     typedef std::pair<double, double> Base;
 
     Quality() : Base() {};
-    Quality(double _sine, double _size) : Base(_sine, _size) {};
+    Quality(double _sine, double _size) : Base(_sine, _size) {}
 
     const double& size() const { return second; }
     const double& sine() const { return first; }
@@ -89,8 +91,10 @@ public:
     typedef typename Base::Is_bad::Point_2 Point_2;
 
     Is_bad(const double aspect_bound,
-	   const double size_bound)
-      : Base::Is_bad(aspect_bound), squared_size_bound(size_bound * size_bound) {};
+	   const double size_bound,
+           const Geom_traits& traits)
+      : Base::Is_bad(aspect_bound, traits),
+        squared_size_bound(size_bound * size_bound) {}
 
     Mesh_2::Face_badness operator()(const Quality q) const
     {
@@ -181,7 +185,8 @@ public:
   };
 
   Is_bad is_bad_object() const
-  { return Is_bad(this->bound(), size_bound()); }
+  { return Is_bad(this->bound(), size_bound(), 
+                  this->traits /* from the bad class */); }
 };
 
 } // end namespace CGAL
