@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Triangulation_3/include/CGAL/Delaunay_triangulation_3.h $
-// $Id: Delaunay_triangulation_3.h 53827 2010-01-27 14:35:38Z lrineau $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Triangulation_3/include/CGAL/Delaunay_triangulation_3.h $
+// $Id: Delaunay_triangulation_3.h 63930 2011-06-07 08:20:54Z sloriot $
 //
 //
 // Author(s)     : Monique Teillaud <Monique.Teillaud@sophia.inria.fr>
@@ -31,11 +31,20 @@
 #include <CGAL/iterator.h>
 #include <CGAL/Location_policy.h>
 
+#ifndef CGAL_TRIANGULATION_3_DONT_INSERT_RANGE_OF_POINTS_WITH_INFO
+#include <CGAL/Spatial_sort_traits_adapter_3.h>
+#include <CGAL/internal/info_check.h>
+
+#include <boost/tuple/tuple.hpp>
+#include <boost/iterator/zip_iterator.hpp>
+#include <boost/mpl/and.hpp>
+#endif //CGAL_TRIANGULATION_3_DONT_INSERT_RANGE_OF_POINTS_WITH_INFO
+
 #ifdef CGAL_DELAUNAY_3_OLD_REMOVE
 #  error "The old remove() code has been removed.  Please report any issue you may have with the current one."
 #endif
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template < class Gt,
            class Tds_ = Default,
@@ -90,6 +99,7 @@ public:
 
   typedef typename Tr_Base::All_cells_iterator       All_cells_iterator;
 
+  typedef typename Tr_Base::size_type size_type;
   typedef typename Tr_Base::Locate_type Locate_type;
 
 
@@ -115,6 +125,16 @@ public:
   using Tr_Base::coplanar;
   using Tr_Base::coplanar_orientation;
   using Tr_Base::orientation;
+  using Tr_Base::adjacent_vertices;
+  using Tr_Base::construct_segment;
+  using Tr_Base::incident_facets;
+  using Tr_Base::insert_in_conflict;
+  using Tr_Base::is_infinite;
+  using Tr_Base::is_valid_finite;
+  using Tr_Base::locate;
+  using Tr_Base::side_of_edge;
+  using Tr_Base::side_of_segment;
+  using Tr_Base::find_conflicts;
 #endif
 
 protected:
@@ -192,12 +212,24 @@ public:
       insert(first, last);
   }
 
+#ifndef CGAL_TRIANGULATION_3_DONT_INSERT_RANGE_OF_POINTS_WITH_INFO
   template < class InputIterator >
-  int
-  insert(InputIterator first, InputIterator last)
+  std::ptrdiff_t
+  insert( InputIterator first, InputIterator last,
+          typename boost::enable_if<
+            boost::is_base_of<
+                Point,
+                typename std::iterator_traits<InputIterator>::value_type
+            >
+          >::type* = NULL
+  )
+#else
+  template < class InputIterator >
+  std::ptrdiff_t
+  insert( InputIterator first, InputIterator last)
+#endif //CGAL_TRIANGULATION_3_DONT_INSERT_RANGE_OF_POINTS_WITH_INFO
   {
-    int n = number_of_vertices();
-
+    size_type n = number_of_vertices();
     std::vector<Point> points (first, last);
     spatial_sort (points.begin(), points.end(), geom_traits());
 
@@ -208,7 +240,82 @@ public:
 
     return number_of_vertices() - n;
   }
+  
+  
+#ifndef CGAL_TRIANGULATION_3_DONT_INSERT_RANGE_OF_POINTS_WITH_INFO
+private:  
+  //top stands for tuple-or-pair
+  template <class Info>
+  const Point& top_get_first(const std::pair<Point,Info>& pair) const { return pair.first; }
+  template <class Info>
+  const Info& top_get_second(const std::pair<Point,Info>& pair) const { return pair.second; }
+  template <class Info>
+  const Point& top_get_first(const boost::tuple<Point,Info>& tuple) const { return boost::get<0>(tuple); }
+  template <class Info>
+  const Info& top_get_second(const boost::tuple<Point,Info>& tuple) const { return boost::get<1>(tuple); }
 
+  template <class Tuple_or_pair,class InputIterator>
+  std::ptrdiff_t insert_with_info(InputIterator first,InputIterator last)
+  {
+    size_type n = number_of_vertices();
+    std::vector<std::ptrdiff_t> indices;
+    std::vector<Point> points;
+    std::vector<typename Triangulation_data_structure::Vertex::Info> infos;
+    std::ptrdiff_t index=0;
+    for (InputIterator it=first;it!=last;++it){
+      Tuple_or_pair value=*it;
+      points.push_back( top_get_first(value)  );
+      infos.push_back ( top_get_second(value) );
+      indices.push_back(index++);
+    }
+
+    typedef Spatial_sort_traits_adapter_3<Geom_traits,Point*> Search_traits;
+    
+    spatial_sort(indices.begin(),indices.end(),Search_traits(&(points[0]),geom_traits()));
+
+    Vertex_handle hint;
+    for (typename std::vector<std::ptrdiff_t>::const_iterator
+      it = indices.begin(), end = indices.end();
+      it != end; ++it){
+      hint = insert(points[*it], hint);
+      if (hint!=Vertex_handle()) hint->info()=infos[*it];
+    }
+
+    return number_of_vertices() - n;
+  }
+  
+public:
+
+  template < class InputIterator >
+  std::ptrdiff_t
+  insert( InputIterator first,
+          InputIterator last,
+          typename boost::enable_if<
+            boost::is_same<
+              typename std::iterator_traits<InputIterator>::value_type,
+              std::pair<Point,typename internal::Info_check<typename Triangulation_data_structure::Vertex>::type>
+            > >::type* =NULL
+  )
+  {
+    return insert_with_info< std::pair<Point,typename internal::Info_check<typename Triangulation_data_structure::Vertex>::type> >(first,last);
+  }
+
+  template <class  InputIterator_1,class InputIterator_2>
+  std::ptrdiff_t
+  insert( boost::zip_iterator< boost::tuple<InputIterator_1,InputIterator_2> > first,
+          boost::zip_iterator< boost::tuple<InputIterator_1,InputIterator_2> > last,
+          typename boost::enable_if<
+            boost::mpl::and_<
+              boost::is_same< typename std::iterator_traits<InputIterator_1>::value_type, Point >,
+              boost::is_same< typename std::iterator_traits<InputIterator_2>::value_type, typename internal::Info_check<typename Triangulation_data_structure::Vertex>::type >
+            >
+          >::type* =NULL
+  )
+  {
+    return insert_with_info< boost::tuple<Point,typename internal::Info_check<typename Triangulation_data_structure::Vertex>::type> >(first,last);
+  }
+#endif //CGAL_TRIANGULATION_3_DONT_INSERT_RANGE_OF_POINTS_WITH_INFO
+  
   Vertex_handle insert(const Point & p, Vertex_handle hint)
   {
     return insert(p, hint == Vertex_handle() ? this->infinite_cell() : hint->cell());
@@ -218,8 +325,30 @@ public:
 
   Vertex_handle insert(const Point & p, Locate_type lt,
 	               Cell_handle c, int li, int);
+	
+public: // internal methods
+	
+  template <class OutputItCells>
+  Vertex_handle insert_and_give_new_cells(const Point  &p, 
+                                          OutputItCells fit,
+                                          Cell_handle start = Cell_handle() );
+		
+  template <class OutputItCells>
+  Vertex_handle insert_and_give_new_cells(const Point& p,
+                                          OutputItCells fit,
+                                          Vertex_handle hint);
 
-  Vertex_handle move_point(Vertex_handle v, const Point & p);
+  template <class OutputItCells>
+  Vertex_handle insert_and_give_new_cells(const Point& p,
+                                          Locate_type lt,
+                                          Cell_handle c, int li, int lj, 
+                                          OutputItCells fit); 
+
+public:	
+	
+#ifndef CGAL_NO_DEPRECATED_CODE
+  CGAL_DEPRECATED Vertex_handle move_point(Vertex_handle v, const Point & p);
+#endif  
 
   template <class OutputIteratorBoundaryFacets,
             class OutputIteratorCells,
@@ -285,10 +414,21 @@ public:
       return std::make_pair(t.first, t.second);
   }
 
+#ifndef CGAL_NO_DEPRECATED_CODE
   // Returns the vertices on the boundary of the conflict hole.
   template <class OutputIterator>
   OutputIterator
   vertices_in_conflict(const Point&p, Cell_handle c, OutputIterator res) const
+  {
+    return vertices_on_conflict_zone_boundary(p, c, res);
+  }
+#endif // CGAL_NO_DEPRECATED_CODE
+
+  // Returns the vertices on the boundary of the conflict hole.
+  template <class OutputIterator>
+  OutputIterator
+  vertices_on_conflict_zone_boundary(const Point&p, Cell_handle c,
+                                     OutputIterator res) const
   {
       CGAL_triangulation_precondition(dimension() >= 2);
 
@@ -317,18 +457,44 @@ public:
       return std::copy(vertices.begin(), vertices.end(), res);
   }
 
+  // REMOVE
   void remove(Vertex_handle v);
 
+  // return new cells (internal)
+  template <class OutputItCells>
+  void remove_and_give_new_cells(Vertex_handle v, 
+                                 OutputItCells fit);
+
   template < typename InputIterator >
-  int remove(InputIterator first, InputIterator beyond)
+  size_type remove(InputIterator first, InputIterator beyond)
   {
-    int n = number_of_vertices();
+    CGAL_triangulation_precondition(!this->does_repeat_in_range(first, beyond));
+    size_type n = number_of_vertices();
     while (first != beyond) {
       remove(*first);
       ++first;
     }
     return n - number_of_vertices();
   }
+	
+  template < typename InputIterator >
+  size_type remove_cluster(InputIterator first, InputIterator beyond)
+  {
+    Self tmp;
+    Vertex_remover<Self> remover (tmp);
+    return Tr_Base::remove(first, beyond, remover);
+  }
+
+  // MOVE
+  Vertex_handle move_if_no_collision(Vertex_handle v, const Point &p);
+
+  Vertex_handle move(Vertex_handle v, const Point &p);
+
+  // return new cells (internal)
+  template <class OutputItCells>
+  Vertex_handle move_if_no_collision_and_give_new_cells(Vertex_handle v, 
+                                                        const Point &p, 
+                                                        OutputItCells fit);
 
 private:
 
@@ -368,6 +534,9 @@ public:
   bool is_Gabriel(const Facet& f)const ;
   bool is_Gabriel(const Edge& e) const;
 
+  bool is_delaunay_after_displacement(Vertex_handle v, 
+                                      const Point &p) const;
+
 // Dual functions
   Point dual(Cell_handle c) const;
 
@@ -396,7 +565,7 @@ public:
       return os;
     }
 
-private:
+protected:
 
   Vertex_handle
   nearest_vertex(const Point &p, Vertex_handle v, Vertex_handle w) const
@@ -489,6 +658,9 @@ private:
   template < class DelaunayTriangulation_3 >
   class Vertex_remover;
 
+  template < class DelaunayTriangulation_3 >
+  class Vertex_inserter;
+
   friend class Perturbation_order;
   friend class Conflict_tester_3;
   friend class Conflict_tester_2;
@@ -533,6 +705,98 @@ insert(const Point & p, Locate_type lt, Cell_handle c, int li, int lj)
   }
 }
 
+template < class Gt, class Tds >
+template <class OutputItCells>
+typename Delaunay_triangulation_3<Gt,Tds>::Vertex_handle 
+Delaunay_triangulation_3<Gt,Tds>::
+insert_and_give_new_cells(const Point  &p, 
+                          OutputItCells fit,
+                          Cell_handle start)
+{
+  Vertex_handle v = insert(p, start);
+  int dimension = this->dimension();
+  if(dimension == 3) this->incident_cells(v, fit);
+  else if(dimension == 2)
+  {
+    Cell_handle c = v->cell(), end = c;
+    do {
+      *fit++ = c;
+      int i = c->index(v);
+      c = c->neighbor((i+1)%3);
+    } while(c != end);			
+  } 
+  else if(dimension == 1)
+  {
+    Cell_handle c = v->cell();
+    *fit++ = c;
+    *fit++ = c->neighbor((~(c->index(v)))&1);
+  }
+  else *fit++ = v->cell(); // dimension = 0
+  return v;		
+}
+
+template < class Gt, class Tds >	
+template <class OutputItCells>
+typename Delaunay_triangulation_3<Gt,Tds>::Vertex_handle 
+Delaunay_triangulation_3<Gt,Tds>::
+insert_and_give_new_cells(const Point& p,
+                          OutputItCells fit,
+                          Vertex_handle hint)
+{
+  Vertex_handle v = insert(p, hint);
+  int dimension = this->dimension();
+  if(dimension == 3) this->incident_cells(v, fit);
+  else if(dimension == 2)
+  {
+    Cell_handle c = v->cell(), end = c;
+    do {
+      *fit++ = c;
+      int i = c->index(v);
+      c = c->neighbor((i+1)%3);
+    } while(c != end);			
+  } 
+  else if(dimension == 1)
+  {
+    Cell_handle c = v->cell();
+    *fit++ = c;
+    *fit++ = c->neighbor((~(c->index(v)))&1);
+  }
+  else *fit++ = v->cell(); // dimension = 0
+  return v;
+}
+
+template < class Gt, class Tds >
+template <class OutputItCells>
+typename Delaunay_triangulation_3<Gt,Tds>::Vertex_handle 
+Delaunay_triangulation_3<Gt,Tds>::
+insert_and_give_new_cells(const Point& p,
+                          Locate_type lt,
+                          Cell_handle c, int li, int lj, 
+                          OutputItCells fit)
+{
+  Vertex_handle v = insert(p, lt, c, li, lj);
+  int dimension = this->dimension();
+  if(dimension == 3) this->incident_cells(v, fit);
+  else if(dimension == 2)
+  {
+    Cell_handle c = v->cell(), end = c;
+    do {
+      *fit++ = c;
+      int i = c->index(v);
+      c = c->neighbor((i+1)%3);
+    } while(c != end);			
+  } 
+  else if(dimension == 1)
+  {
+    Cell_handle c = v->cell();
+    *fit++ = c;
+    *fit++ = c->neighbor((~(c->index(v)))&1);
+  }
+  else *fit++ = v->cell(); // dimension = 0		 
+  return v;
+}
+
+#ifndef CGAL_NO_DEPRECATED_CODE
 template < class Gt, class Tds >
 typename Delaunay_triangulation_3<Gt,Tds>::Vertex_handle
 Delaunay_triangulation_3<Gt,Tds>::
@@ -555,6 +819,7 @@ move_point(Vertex_handle v, const Point & p)
 	return insert(p);
     return insert(p, old_neighbor->cell());
 }
+#endif
 
 template <class Gt, class Tds >
 template <class DelaunayTriangulation_3>
@@ -577,6 +842,35 @@ public:
   }
 };
 
+template <class Gt, class Tds >
+template <class DelaunayTriangulation_3>
+class Delaunay_triangulation_3<Gt, Tds>::Vertex_inserter {
+  typedef DelaunayTriangulation_3 Delaunay;
+public:
+  typedef Nullptr_t Hidden_points_iterator;
+
+  Vertex_inserter(Delaunay &tmp_) : tmp(tmp_) {}
+
+  Delaunay &tmp;
+
+  void add_hidden_points(Cell_handle) {}
+  Hidden_points_iterator hidden_points_begin() { return NULL; }
+  Hidden_points_iterator hidden_points_end() { return NULL; }
+
+  Vertex_handle insert(const Point& p,
+		       Locate_type lt, Cell_handle c, int li, int lj) {
+    return tmp.insert(p, lt, c, li, lj);
+  }
+
+  Vertex_handle insert(const Point& p, Cell_handle c) {
+    return tmp.insert(p, c);
+  }
+
+  Vertex_handle insert(const Point& p) {
+    return tmp.insert(p);
+  }
+};
+
 template < class Gt, class Tds >
 void
 Delaunay_triangulation_3<Gt,Tds>::
@@ -589,6 +883,63 @@ remove(Vertex_handle v)
   CGAL_triangulation_expensive_postcondition(is_valid());
 }
 
+template < class Gt, class Tds >
+typename Delaunay_triangulation_3<Gt,Tds>::Vertex_handle
+Delaunay_triangulation_3<Gt,Tds>::
+move_if_no_collision(Vertex_handle v, const Point &p)
+{
+  Self tmp;
+  Vertex_remover<Self> remover (tmp);
+  Vertex_inserter<Self> inserter (*this);
+  Vertex_handle res = Tr_Base::move_if_no_collision(v,p,remover,inserter);
+
+  CGAL_triangulation_expensive_postcondition(is_valid());	
+	return res;
+}
+
+template <class Gt, class Tds >
+typename Delaunay_triangulation_3<Gt,Tds>::Vertex_handle
+Delaunay_triangulation_3<Gt,Tds>::
+move(Vertex_handle v, const Point &p) {
+  CGAL_triangulation_precondition(!is_infinite(v));
+  if(v->point() == p) return v;
+  Self tmp;
+  Vertex_remover<Self> remover (tmp);
+  Vertex_inserter<Self> inserter (*this);
+	return Tr_Base::move(v,p,remover,inserter);
+}
+
+template < class Gt, class Tds >
+template <class OutputItCells>
+void
+Delaunay_triangulation_3<Gt,Tds>::
+remove_and_give_new_cells(Vertex_handle v, OutputItCells fit)
+{
+  Self tmp;
+  Vertex_remover<Self> remover (tmp);
+  Tr_Base::remove_and_give_new_cells(v,remover,fit);
+
+  CGAL_triangulation_expensive_postcondition(is_valid());
+}
+
+template < class Gt, class Tds >
+template <class OutputItCells>
+typename Delaunay_triangulation_3<Gt,Tds>::Vertex_handle
+Delaunay_triangulation_3<Gt,Tds>::
+move_if_no_collision_and_give_new_cells(Vertex_handle v, const Point &p,
+  OutputItCells fit)
+{
+  Self tmp;
+  Vertex_remover<Self> remover (tmp);
+  Vertex_inserter<Self> inserter (*this);
+  Vertex_handle res = 
+    Tr_Base::move_if_no_collision_and_give_new_cells(v,p,
+      remover,inserter,fit);
+
+  CGAL_triangulation_expensive_postcondition(is_valid());	
+	return res;
+}
+
 template < class Gt, class Tds >
 Oriented_side
 Delaunay_triangulation_3<Gt,Tds>::
@@ -822,7 +1173,7 @@ Delaunay_triangulation_3<Gt,Tds>::
 nearest_vertex_in_cell(const Point& p, Cell_handle c) const
 // Returns the finite vertex of the cell c which is the closest to p.
 {
-    CGAL_triangulation_precondition(dimension() >= 1);
+    CGAL_triangulation_precondition(dimension() >= 0);
 
     Vertex_handle nearest = nearest_vertex(p, c->vertex(0), c->vertex(1));
     if (dimension() >= 2) {
@@ -878,6 +1229,75 @@ nearest_vertex(const Point& p, Cell_handle start) const
     return nearest;
 }
 
+// This is not a fast version.
+// The optimized version needs an int for book-keeping in 
+// tds() so as to avoiding the need to clear
+// the tds marker in each cell (which is an unsigned char)
+// Also the visitor in TDS could be more clever.
+// The Delaunay triangulation which filters displacements
+// will do these optimizations. 
+template <class Gt, class Tds >
+bool 
+Delaunay_triangulation_3<Gt,Tds>::
+is_delaunay_after_displacement(Vertex_handle v, const Point &p) const
+{
+  CGAL_triangulation_precondition(!this->is_infinite(v));	
+  CGAL_triangulation_precondition(this->dimension() == 2);	
+  CGAL_triangulation_precondition(!this->test_dim_down(v));
+	if(v->point() == p) return true;
+  Point ant = v->point();
+  v->set_point(p);
+
+  std::size_t size;
+
+  // are incident cells well-oriented
+  std::vector<Cell_handle> cells;
+  cells.reserve(64);
+  this->incident_cells(v, std::back_inserter(cells));
+  size = cells.size();
+  for(std::size_t i=0; i<size; i++)
+  {
+    Cell_handle c = cells[i];
+    if(this->is_infinite(c)) continue;
+    if(this->orientation(c->vertex(0)->point(), c->vertex(1)->point(), 
+                         c->vertex(2)->point(), c->vertex(3)->point()) 
+       != POSITIVE)
+    {
+      v->set_point(ant);
+      return false;
+    } 
+  }
+
+  // are incident bi-cells Delaunay?	
+  std::vector<Facet> facets;
+  facets.reserve(128);	
+  this->incident_facets(v, std::back_inserter(facets));
+  size = facets.size();
+  for(std::size_t i=0; i<size; i++)
+  {
+    const Facet &f = facets[i];
+    Cell_handle c = f.first;
+    int j = f.second;
+    Cell_handle cj = c->neighbor(j);
+    int mj = this->mirror_index(c, j);
+    Vertex_handle h1 = c->vertex(j);
+    if(this->is_infinite(h1)) {
+      if(this->side_of_sphere(c, cj->vertex(mj)->point(), true) 
+         != ON_UNBOUNDED_SIDE) {
+        v->set_point(ant);
+        return false;
+      }
+    } else {
+      if(this->side_of_sphere(cj, h1->point(), true) != ON_UNBOUNDED_SIDE) {
+        v->set_point(ant);
+        return false;
+      }
+    }
+  }
+		
+  v->set_point(ant);
+  return true;
+}
 
 template < class Gt, class Tds >
 bool
@@ -992,9 +1412,13 @@ dual(Cell_handle c, int i) const
     in = i;
   }
   // n now denotes a finite cell, either c or c->neighbor(i)
-  unsigned char ind[3] = {(in+1)&3,(in+2)&3,(in+3)&3};
+  int ind[3] = {(in+1)&3,(in+2)&3,(in+3)&3};
   if ( (in&1) == 1 )
       std::swap(ind[0], ind[1]);
+  // in=0: 1 2 3
+  // in=1: 3 2 0
+  // in=2: 3 0 1
+  // in=3: 1 0 2
   const Point& p = n->vertex(ind[0])->point();
   const Point& q = n->vertex(ind[1])->point();
   const Point& r = n->vertex(ind[2])->point();
@@ -1155,7 +1579,7 @@ is_valid(Cell_handle c, bool verbose, int level) const
   return true;
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #include <CGAL/internal/Delaunay_triangulation_hierarchy_3.h>
 
