@@ -1,4 +1,4 @@
-// Copyright (c) 2002 Utrecht University (The Netherlands).
+// Copyright (c) 2002,2011 Utrecht University (The Netherlands).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Spatial_searching/include/CGAL/Euclidean_distance.h $
-// $Id: Euclidean_distance.h 59325 2010-10-22 11:03:44Z sloriot $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Spatial_searching/include/CGAL/Euclidean_distance.h $
+// $Id: Euclidean_distance.h 64637 2011-07-06 11:11:58Z lrineau $
 // 
 //
 // Author(s)     : Hans Tangelder (<hanst@cs.uu.nl>)
@@ -24,26 +24,34 @@
 
 namespace CGAL {
 
-
+  template <class SearchTraits>
+  class Euclidean_distance;
+  
+  namespace internal{
+    template <class SearchTraits>
+    struct Spatial_searching_default_distance{
+      typedef ::CGAL::Euclidean_distance<SearchTraits> type;
+    };
+  } //namespace internal
 
   template <class SearchTraits>
   class Euclidean_distance {
-
+    
+    SearchTraits traits;
+    
     public:
 
     typedef typename SearchTraits::FT    FT;
     typedef typename SearchTraits::Point_d Point_d;
     typedef Point_d Query_item;
-    
-    public:
 
     	// default constructor
-    	Euclidean_distance() {}
+    	Euclidean_distance(const SearchTraits& traits_=SearchTraits()):traits(traits_) {}
 
 
 	inline FT transformed_distance(const Query_item& q, const Point_d& p) const {
 	        FT distance = FT(0);
-		typename SearchTraits::Construct_cartesian_const_iterator_d construct_it;
+		typename SearchTraits::Construct_cartesian_const_iterator_d construct_it=traits.construct_cartesian_const_iterator_d_object();
                 typename SearchTraits::Cartesian_const_iterator_d qit = construct_it(q),
 		  qe = construct_it(q,1), pit = construct_it(p);
 		for(; qit != qe; qit++, pit++){
@@ -54,9 +62,9 @@ namespace CGAL {
 
 
 	inline FT min_distance_to_rectangle(const Query_item& q,
-					    const Kd_tree_rectangle<SearchTraits>& r) const {
+					    const Kd_tree_rectangle<FT>& r) const {
 		FT distance = FT(0);
-		typename SearchTraits::Construct_cartesian_const_iterator_d construct_it;
+		typename SearchTraits::Construct_cartesian_const_iterator_d construct_it=traits.construct_cartesian_const_iterator_d_object();
                 typename SearchTraits::Cartesian_const_iterator_d qit = construct_it(q),
 		  qe = construct_it(q,1);
 		for(unsigned int i = 0;qit != qe; i++, qit++){
@@ -72,9 +80,9 @@ namespace CGAL {
 	}
 
 	inline FT max_distance_to_rectangle(const Query_item& q,
-					     const Kd_tree_rectangle<SearchTraits>& r) const {
+					     const Kd_tree_rectangle<FT>& r) const {
 		FT distance=FT(0);
-		typename SearchTraits::Construct_cartesian_const_iterator_d construct_it;
+		typename SearchTraits::Construct_cartesian_const_iterator_d construct_it=traits.construct_cartesian_const_iterator_d_object();
                 typename SearchTraits::Cartesian_const_iterator_d qit = construct_it(q),
 		  qe = construct_it(q,1);
 		for(unsigned int i = 0;qit != qe; i++, qit++){
