@@ -1,4 +1,4 @@
-// Copyright (c) 2002 Utrecht University (The Netherlands).
+// Copyright (c) 2002,2011 Utrecht University (The Netherlands).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Spatial_searching/include/CGAL/Fuzzy_sphere.h $
-// $Id: Fuzzy_sphere.h 28567 2006-02-16 14:30:13Z lsaboret $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Spatial_searching/include/CGAL/Fuzzy_sphere.h $
+// $Id: Fuzzy_sphere.h 64637 2011-07-06 11:11:58Z lrineau $
 // 
 //
 // Author(s)     : Hans Tangelder (<hanst@cs.uu.nl>)
@@ -26,7 +26,7 @@ namespace CGAL {
 
   template <class SearchTraits>
   class Fuzzy_sphere{
-
+    SearchTraits traits;
     public:
 
     typedef typename SearchTraits::FT FT;
@@ -36,21 +36,20 @@ namespace CGAL {
     Point_d c;
     FT r;
     FT eps;
-    unsigned int dim;
 
     public:
 
 
     	// default constructor
-    	Fuzzy_sphere() {}
+    	Fuzzy_sphere(const SearchTraits& traits_=SearchTraits()):traits(traits_) {}
 		
 
 	// constructor
-	Fuzzy_sphere(const Point_d& center, FT radius, FT epsilon=FT(0)) : 
-	c(center), r(radius), eps(epsilon), dim(c.dimension()) 
+	Fuzzy_sphere(const Point_d& center, FT radius, FT epsilon=FT(0),const SearchTraits& traits_=SearchTraits()) : 
+	traits(traits_),c(center), r(radius), eps(epsilon) 
 	{ 	// avoid problems if eps > r
 		if (eps>r) eps=r; 
-	} 
+	}
         	
         bool contains(const Point_d& p) const {
 		// test whether the squared distance 
@@ -58,12 +57,13 @@ namespace CGAL {
 		// is at most the squared_radius
 		FT squared_radius = r*r;
 		FT distance=FT(0);
-		typename SearchTraits::Construct_cartesian_const_iterator_d construct_it;
+		typename SearchTraits::Construct_cartesian_const_iterator_d construct_it=
+                  traits.construct_cartesian_const_iterator_d_object();
                 typename SearchTraits::Cartesian_const_iterator_d cit = construct_it(c),
-		                                                  pit = construct_it(p);
-		  
-		for (unsigned int i = 0; 
-		     (i < dim) && (distance <= squared_radius); ++i, ++cit, ++pit) {
+		                                                  pit = construct_it(p),
+                                                                  end = construct_it(c, 0);
+		for (; cit != end
+                       && (distance <= squared_radius); ++cit, ++pit) {
 		  distance += 
 			((*cit)-(*pit))*((*cit)-(*pit));
 		}
@@ -72,16 +72,17 @@ namespace CGAL {
         }
 
         
-	bool inner_range_intersects(const Kd_tree_rectangle<SearchTraits>& rectangle) const {                          
+	bool inner_range_intersects(const Kd_tree_rectangle<FT>& rectangle) const {                          
                 // test whether the interior of a sphere
 		// with radius (r-eps) intersects r, i.e.
                 // if the minimal distance of r to c is less than r-eps
 		FT distance = FT(0);
 		FT squared_radius = (r-eps)*(r-eps);
-		typename SearchTraits::Construct_cartesian_const_iterator_d construct_it;
-                typename SearchTraits::Cartesian_const_iterator_d cit = construct_it(c);
-
-		for (unsigned int i = 0; (i < dim) && (distance < squared_radius); ++i, ++cit) {
+		typename SearchTraits::Construct_cartesian_const_iterator_d construct_it=
+                  traits.construct_cartesian_const_iterator_d_object();
+                typename SearchTraits::Cartesian_const_iterator_d cit = construct_it(c),
+                                                                  end = construct_it(c, 0);
+		for (int i = 0; cit != end && (distance < squared_radius); ++cit, ++i) {
 			if ((*cit) < rectangle.min_coord(i))
 				distance += 
 				(rectangle.min_coord(i)-(*cit))*(rectangle.min_coord(i)-(*cit));
@@ -94,17 +95,18 @@ namespace CGAL {
 	}
 
 
-	bool outer_range_contains(const Kd_tree_rectangle<SearchTraits>& rectangle) const { 
+	bool outer_range_contains(const Kd_tree_rectangle<FT>& rectangle) const { 
         // test whether the interior of a sphere
 	// with radius (r+eps) is contained by r, i.e.
         // if the minimal distance of the boundary of r 
         // to c is less than r+eps                         
 	FT distance=FT(0);
 	FT squared_radius = (r+eps)*(r+eps);	
-	typename SearchTraits::Construct_cartesian_const_iterator_d construct_it;
-	typename SearchTraits::Cartesian_const_iterator_d cit = construct_it(c);
-	
-	for (unsigned int i = 0; (i < dim) && (distance < squared_radius) ; ++i, ++cit) {
+	typename SearchTraits::Construct_cartesian_const_iterator_d construct_it=
+          traits.construct_cartesian_const_iterator_d_object();
+	typename SearchTraits::Cartesian_const_iterator_d cit = construct_it(c),
+                                                          end = construct_it(c, 0);
+        for (int i = 0; cit != end && (distance < squared_radius) ; ++cit,++i) {
 		if ((*cit) <= (rectangle.min_coord(i)+rectangle.max_coord(i))/FT(2))
 			distance += 
 			(rectangle.max_coord(i)-(*cit))*(rectangle.max_coord(i)-(*cit));
