@@ -1,36 +1,36 @@
-// Copyright (c) 2007-2009 Inria Lorraine (France). All rights reserved.
-// 
+// Copyright (c) 2007-2010 Inria Lorraine (France). All rights reserved.
+//
 // This file is part of CGAL (www.cgal.org); you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public License as
 // published by the Free Software Foundation; version 2.1 of the License.
 // See the file LICENSE.LGPL distributed with CGAL.
-// 
+//
 // Licensees holding a valid commercial license may use this file in
 // accordance with the commercial license agreement provided with the software.
-// 
+//
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-// 
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Number_types/include/CGAL/GMP/Gmpfi_type.h $
-// $Id: Gmpfi_type.h 53963 2010-02-01 14:41:32Z penarand $
-// 
-// Author: Luis Pearanda <luis.penaranda@loria.fr>
+//
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Number_types/include/CGAL/GMP/Gmpfi_type.h $
+// $Id: Gmpfi_type.h 61900 2011-03-22 07:59:52Z penarand $
+//
+// Author: Luis Pearanda <luis.penaranda@gmx.com>
 
 #ifndef CGAL_GMPFI_TYPE_H
 #define CGAL_GMPFI_TYPE_H
 
 #include <CGAL/basic.h>
-#include <gmp.h>
+#include <CGAL/gmp.h>
 #include <mpfr.h>
 #include <CGAL/GMP/Gmpfr_type.h>
 #include <mpfi.h>
 #include <boost/operators.hpp>
-#include <CGAL/Handle_for.h>
 #include <CGAL/Uncertain.h>
 #ifdef CGAL_HAS_THREADS
 #  include <boost/thread/tss.hpp>
 #endif
 #include <limits>
+#include <algorithm>
 
 namespace CGAL{
 
@@ -71,33 +71,22 @@ Uncertain<bool> operator<(const Gmpfi&,const Gmpq&);
 Uncertain<bool> operator>(const Gmpfi&,const Gmpq&);
 Uncertain<bool> operator==(const Gmpfi&,const Gmpq&);
 
-struct Gmpfi_rep{
-        mpfi_t floating_point_interval;
-        bool clear_on_destruction;
-        Gmpfi_rep():clear_on_destruction(true){}
-        ~Gmpfi_rep(){
-                if(clear_on_destruction)
-                        mpfi_clear(floating_point_interval);
-        }
-};
-
 // the default precision of Gmpfi is the size of a double's mantissa
 #ifdef IEEE_DBL_MANT_DIG
-#  define _GMPFI_DEFAULT_PRECISION IEEE_DBL_MANT_DIG
+#  define CGAL_GMPFI_DEFAULT_PRECISION IEEE_DBL_MANT_DIG
 #else
-#  define _GMPFI_DEFAULT_PRECISION 53
+#  define CGAL_GMPFI_DEFAULT_PRECISION 53
 #endif
 
 // the default precision is a variable local to each thread in multithreaded
 // environments, or a global variable otherwise
 #ifdef CGAL_HAS_THREADS
-        boost::thread_specific_ptr<mp_prec_t> Gmpfi_default_precision_;
+        static boost::thread_specific_ptr<mp_prec_t> Gmpfi_default_precision_;
 #else
-        mp_prec_t Gmpfi_default_precision=_GMPFI_DEFAULT_PRECISION;
+        static mp_prec_t Gmpfi_default_precision=CGAL_GMPFI_DEFAULT_PRECISION;
 #endif
 
 class Gmpfi:
-        Handle_for<Gmpfi_rep>,
         boost::ordered_euclidian_ring_operators1<Gmpfi,
         boost::ordered_euclidian_ring_operators2<Gmpfi,Gmpfr,
         boost::ordered_euclidian_ring_operators2<Gmpfi,long,
@@ -109,7 +98,47 @@ class Gmpfi:
         boost::ordered_euclidian_ring_operators2<Gmpfi,Gmpq
         > > > > > > > > >
 {
-        typedef Handle_for<Gmpfi_rep>   Base;
+        private:
+
+        // The endpoints of the interval are represented by two objects of
+        // type Gmpfr. To apply MPFI functions to this interval, the
+        // pointers to the data in _left and _right are copied to the
+        // _interval structure using the function mpfi(). After the
+        // operation, the function gather_bounds should be called to put
+        // back the result of the operation in _left and _right.
+        Gmpfr _left,_right;
+        mutable __mpfi_struct _interval;
+
+        bool is_unique(){
+#ifdef CGAL_GMPFR_NO_REFCOUNT
+                return true;
+#else
+                return(_left.is_unique()&&_right.is_unique());
+#endif
+        }
+
+        // swaps the contents of this object and another one
+        void swap(Gmpfi &fi){
+                std::swap(*this,fi);
+        }
+
+        // after calling a library function that modifies the data in the
+        // structure _interval, this function has to be called in order to
+        // copy the data in _interval to _left and _right
+        void gather_bounds(){
+                mpfr_custom_init_set(
+                        _left.fr(),
+                        mpfr_custom_get_kind(&_interval.left),
+                        mpfr_custom_get_exp(&_interval.left),
+                        mpfr_get_prec(&_interval.left),
+                        mpfr_custom_get_mantissa(&_interval.left));
+                mpfr_custom_init_set(
+                        _right.fr(),
+                        mpfr_custom_get_kind(&_interval.right),
+                        mpfr_custom_get_exp(&_interval.right),
+                        mpfr_get_prec(&_interval.right),
+                        mpfr_custom_get_mantissa(&_interval.right));
+        }
 
         public:
 
@@ -117,116 +146,152 @@ class Gmpfi:
 
         // access
 
-        inline mpfi_srcptr mpfi()const{
-                return Ptr()->floating_point_interval;
+        mpfi_srcptr mpfi()const{
+                _interval.left=*_left.fr();
+                _interval.right=*_right.fr();
+                CGAL_assertion(mpfr_equal_p(_left.fr(),&_interval.left)!=0 &&
+                               mpfr_equal_p(_right.fr(),&_interval.right)!=0);
+                return &_interval;
         }
 
-        inline mpfr_srcptr left_mpfr()const{
-                return &(mpfi()->left);
+        mpfi_ptr mpfi(){
+                _interval.left=*_left.fr();
+                _interval.right=*_right.fr();
+                CGAL_assertion(mpfr_equal_p(_left.fr(),&_interval.left)!=0 &&
+                               mpfr_equal_p(_right.fr(),&_interval.right)!=0);
+                return &_interval;
         }
 
-        inline mpfr_srcptr right_mpfr()const{
-                return &(mpfi()->right);
+        mpfr_srcptr left_mpfr()const{
+                return _left.fr();
         }
 
-        inline mpfi_ptr mpfi(){
-                return ptr()->floating_point_interval;
+        mpfr_srcptr right_mpfr()const{
+                return _right.fr();
         }
 
-        inline Gmpfr inf()const{
-                return Gmpfr(left_mpfr());
+        Gmpfr inf()const{
+                return _left;
         }
 
-        inline Gmpfr sup()const{
-                return Gmpfr(right_mpfr());
-        }
-
-        inline
-        void dont_clear_on_destruction(){
-                ptr()->clear_on_destruction=false;
+        Gmpfr sup()const{
+                return _right;
         }
 
         // construction
 
-        Gmpfi(){
-                mpfi_init(mpfi());
-        }
+        Gmpfi(){}
+        ~Gmpfi(){}
 
-#define _GMPFI_CONSTRUCTOR_FROM_SCALAR(_type) \
+#define CGAL_GMPFI_CONSTRUCTOR_FROM_SCALAR(_type) \
         Gmpfi(const _type &t, \
               Gmpfi::Precision_type p=Gmpfi::get_default_precision()){ \
                 CGAL_assertion(p>=MPFR_PREC_MIN&&p<=MPFR_PREC_MAX); \
-                Gmpfr l(t,std::round_toward_neg_infinity,p), \
-                      r(t,std::round_toward_infinity,p); \
-                l.dont_clear_on_destruction(); \
-                r.dont_clear_on_destruction(); \
-                mpfi()->left=*(l.fr()); \
-                mpfi()->right=*(r.fr()); \
+                _left=Gmpfr(t,std::round_toward_neg_infinity,p); \
+                _right=Gmpfr(t,std::round_toward_infinity,p); \
+                CGAL_assertion(_left<=t&&_right>=t); \
         }
 
-_GMPFI_CONSTRUCTOR_FROM_SCALAR(long);
-_GMPFI_CONSTRUCTOR_FROM_SCALAR(unsigned long);
-_GMPFI_CONSTRUCTOR_FROM_SCALAR(int);
-_GMPFI_CONSTRUCTOR_FROM_SCALAR(double);
-_GMPFI_CONSTRUCTOR_FROM_SCALAR(long double);
-_GMPFI_CONSTRUCTOR_FROM_SCALAR(Gmpz);
-_GMPFI_CONSTRUCTOR_FROM_SCALAR(Gmpq);
+CGAL_GMPFI_CONSTRUCTOR_FROM_SCALAR(long);
+CGAL_GMPFI_CONSTRUCTOR_FROM_SCALAR(unsigned long);
+CGAL_GMPFI_CONSTRUCTOR_FROM_SCALAR(int);
+CGAL_GMPFI_CONSTRUCTOR_FROM_SCALAR(double);
+CGAL_GMPFI_CONSTRUCTOR_FROM_SCALAR(long double);
+CGAL_GMPFI_CONSTRUCTOR_FROM_SCALAR(Gmpz);
 
-        Gmpfi(mpfi_srcptr i,Gmpfi::Precision_type p=0){
-                if((p==0)||
-                   (p==mpfr_get_prec(&(i->left))
-                    &&p==mpfr_get_prec(&(i->right)))){
-                        mpfi()->left=i->left;
-                        mpfi()->right=i->right;
-                        dont_clear_on_destruction();
-                }else{
-                        CGAL_assertion(p>=MPFR_PREC_MIN&&p<=MPFR_PREC_MAX);
-                        mpfi_init2(mpfi(),p);
-                        mpfi_set(mpfi(),i);
-                }
+#undef CGAL_GMPFI_CONSTRUCTOR_FROM_SCALAR
+
+        Gmpfi(const Gmpq &q,
+              Gmpfi::Precision_type p=Gmpfi::get_default_precision()){
+                CGAL_assertion(p>=MPFR_PREC_MIN&&p<=MPFR_PREC_MAX);
+                _left=Gmpfr(0,p);
+                _right=Gmpfr(0,p);
+                mpfr_set_q(_left.fr(),q.mpq(),GMP_RNDD);
+                mpfr_set_q(_right.fr(),q.mpq(),GMP_RNDU);
+                CGAL_assertion(_left<=q&&_right>=q);
+        }
+
+        Gmpfi(mpfi_srcptr i){
+                _left=Gmpfr(&(i->left));
+                _right=Gmpfr(&(i->right));
+        }
+
+        Gmpfi(mpfi_srcptr i,Gmpfi::Precision_type p){
+                CGAL_assertion(p>=MPFR_PREC_MIN&&p<=MPFR_PREC_MAX);
+                _left=Gmpfr(&(i->left),std::round_toward_neg_infinity,p);
+                _right=Gmpfr(&(i->right),std::round_toward_infinity,p);
+                CGAL_assertion(mpfr_cmp(_left.fr(),&(i->left))<=0 &&
+                               mpfr_cmp(_right.fr(),&(i->right))>=0);
         }
 
         Gmpfi(const Gmpfr &f,
               Gmpfi::Precision_type p=Gmpfi::get_default_precision()){
                 CGAL_assertion(p>=MPFR_PREC_MIN&&p<=MPFR_PREC_MAX);
-                mpfi_init2(mpfi(),p);
-                mpfi_set_fr(mpfi(),f.fr());
+                _left=Gmpfr(f,std::round_toward_neg_infinity,p);
+                _right=Gmpfr(f,std::round_toward_infinity,p);
+                CGAL_assertion(_left<=f&&_right>=f);
         }
 
-        Gmpfi(std::pair<const Gmpfr,const Gmpfr> endpoints,
+        Gmpfi(const Gmpfr &l,
+              const Gmpfr &r,
               Gmpfi::Precision_type p=Gmpfi::get_default_precision()){
                 CGAL_assertion(p>=MPFR_PREC_MIN&&p<=MPFR_PREC_MAX);
-                mpfi_init2(mpfi(),p);
-                mpfi_interv_fr(
-                                mpfi(),
-                                endpoints.first.fr(),
-                                endpoints.second.fr());
+                _left=Gmpfr(l,std::round_toward_neg_infinity,p);
+                _right=Gmpfr(r,std::round_toward_infinity,p);
+                CGAL_assertion(_left<=l||(_left.is_nan()&&l.is_nan()));
+                CGAL_assertion(_right>=l||(_right.is_nan()&&r.is_nan()));
+        }
+
+        Gmpfi(std::pair<const Gmpfr,const Gmpfr> bounds,
+              Gmpfi::Precision_type p=Gmpfi::get_default_precision()){
+                CGAL_assertion(p>=MPFR_PREC_MIN&&p<=MPFR_PREC_MAX);
+                _left=Gmpfr(bounds.first,std::round_toward_neg_infinity,p);
+                _right=Gmpfr(bounds.second,std::round_toward_infinity,p);
+                CGAL_assertion(_left<=bounds.first||
+                               (_left.is_nan()&&bounds.first.is_nan()));
+                CGAL_assertion(_right>=bounds.second||
+                               (_right.is_nan()&&bounds.second.is_nan()));
         }
 
         template<class L,class R>
-        Gmpfi(std::pair<const L&,const R&> endpoints,
+        Gmpfi(std::pair<const L&,const R&> bounds,
               Gmpfi::Precision_type p=get_default_precision()){
                 CGAL_assertion(p>=MPFR_PREC_MIN&&p<=MPFR_PREC_MAX);
-                Gmpfr l(endpoints.first,std::round_toward_neg_infinity,p),
-                      r(endpoints.second,std::round_toward_infinity,p);
-                l.dont_clear_on_destruction();
-                r.dont_clear_on_destruction();
-                mpfi()->left=*(l.fr());
-                mpfi()->right=*(r.fr());
+                _left=Gmpfr(bounds.first,std::round_toward_neg_infinity,p);
+                _right=Gmpfr(bounds.second,std::round_toward_infinity,p);
+                CGAL_assertion(_left<=bounds.first&&_right>=bounds.second);
         }
 
-        // copy constructor
+        // copy assignment operator
+        Gmpfi& operator=(const Gmpfi &a){
+                _left=a.inf();
+                _right=a.sup();
+                CGAL_assertion(_left==a.inf()||
+                               (_left.is_nan()&&a.inf().is_nan()));
+                CGAL_assertion(_right==a.sup()||
+                               (_right.is_nan()&&a.sup().is_nan()));
+                return *this;
+        }
+
+        // copy constructor without precision
+        Gmpfi(const Gmpfi &a){
+                _left=a.inf();
+                _right=a.sup();
+                CGAL_assertion(_left==a.inf()||
+                               (_left.is_nan()&&a.inf().is_nan()));
+                CGAL_assertion(_right==a.sup()||
+                               (_right.is_nan()&&a.sup().is_nan()));
+        }
+
+        // copy constructor with precision
         Gmpfi(const Gmpfi &a,Gmpfi::Precision_type p){
                 CGAL_assertion(p>=MPFR_PREC_MIN&&p<=MPFR_PREC_MAX);
-                if(p==mpfr_get_prec(a.left_mpfr())&&
-                                p==mpfr_get_prec(a.right_mpfr())){
-                        Gmpfi temp(a);
-                        dont_clear_on_destruction();
-                        swap(temp);
-                }else{
-                        mpfi_init2(mpfi(),p);
-                        mpfi_set(mpfi(),a.mpfi());
-                }
+                _left=Gmpfr(a.inf(),std::round_toward_neg_infinity,p);
+                _right=Gmpfr(a.sup(),std::round_toward_infinity,p);
+                CGAL_assertion(_left<=a.inf()||
+                               (_left.is_nan()&&a.inf().is_nan()));
+                CGAL_assertion(_right>=a.sup()||
+                               (_right.is_nan()&&a.sup().is_nan()));
         }
 
         // default precision
@@ -234,8 +299,8 @@ _GMPFI_CONSTRUCTOR_FROM_SCALAR(Gmpq);
 #ifdef CGAL_HAS_THREADS
         static void init_precision_for_thread();
 #endif
-        static inline Gmpfi::Precision_type get_default_precision();
-        static inline Gmpfi::Precision_type set_default_precision(
+        static Gmpfi::Precision_type get_default_precision();
+        static Gmpfi::Precision_type set_default_precision(
                                                 Gmpfi::Precision_type prec);
 
         // precision of a single Gmpfi object
@@ -248,44 +313,46 @@ _GMPFI_CONSTRUCTOR_FROM_SCALAR(Gmpq);
         Gmpfi operator+()const;
         Gmpfi operator-()const;
 
-#define _GMPFI_DECLARE_OPERATORS(_type) \
+#define CGAL_GMPFI_DECLARE_OPERATORS(_type) \
         Gmpfi& operator+=(_type); \
         Gmpfi& operator-=(_type); \
         Gmpfi& operator*=(_type); \
         Gmpfi& operator/=(_type);
 
-        _GMPFI_DECLARE_OPERATORS(const Gmpfi&)
-        _GMPFI_DECLARE_OPERATORS(const Gmpfr&)
-        _GMPFI_DECLARE_OPERATORS(long)
-        _GMPFI_DECLARE_OPERATORS(unsigned long)
-        _GMPFI_DECLARE_OPERATORS(int)
-        _GMPFI_DECLARE_OPERATORS(const Gmpz&)
-        _GMPFI_DECLARE_OPERATORS(const Gmpq&)
+        CGAL_GMPFI_DECLARE_OPERATORS(const Gmpfi&)
+        CGAL_GMPFI_DECLARE_OPERATORS(const Gmpfr&)
+        CGAL_GMPFI_DECLARE_OPERATORS(long)
+        CGAL_GMPFI_DECLARE_OPERATORS(unsigned long)
+        CGAL_GMPFI_DECLARE_OPERATORS(int)
+        CGAL_GMPFI_DECLARE_OPERATORS(const Gmpz&)
+        CGAL_GMPFI_DECLARE_OPERATORS(const Gmpq&)
 
-#undef _GMPFI_DECLARE_OPERATORS
+#undef CGAL_GMPFI_DECLARE_OPERATORS
 
-#define _GMPFI_DECLARE_STATIC_FUNCTION(_f,_t1,_t2) \
+#define CGAL_GMPFI_DECLARE_STATIC_FUNCTION(_f,_t1,_t2) \
         static Gmpfi _f (_t1,_t2,Gmpfi::Precision_type=0);
 
-#define _GMPFI_DECLARE_STATIC_FUNCTIONS(_t1,_t2) \
-        _GMPFI_DECLARE_STATIC_FUNCTION(add,_t1,_t2) \
-        _GMPFI_DECLARE_STATIC_FUNCTION(sub,_t1,_t2) \
-        _GMPFI_DECLARE_STATIC_FUNCTION(mul,_t1,_t2) \
-        _GMPFI_DECLARE_STATIC_FUNCTION(div,_t1,_t2)
+#define CGAL_GMPFI_DECLARE_STATIC_FUNCTIONS(_t1,_t2) \
+        CGAL_GMPFI_DECLARE_STATIC_FUNCTION(add,_t1,_t2) \
+        CGAL_GMPFI_DECLARE_STATIC_FUNCTION(sub,_t1,_t2) \
+        CGAL_GMPFI_DECLARE_STATIC_FUNCTION(mul,_t1,_t2) \
+        CGAL_GMPFI_DECLARE_STATIC_FUNCTION(div,_t1,_t2)
 
-#define _GMPFI_DECLARE_TWO_WAY_STATIC_FUNCTIONS(_t) \
-        _GMPFI_DECLARE_STATIC_FUNCTIONS(const Gmpfi&,_t) \
-        _GMPFI_DECLARE_STATIC_FUNCTIONS(_t,const Gmpfi&)
+#define CGAL_GMPFI_DECLARE_TWO_WAY_STATIC_FUNCTIONS(_t) \
+        CGAL_GMPFI_DECLARE_STATIC_FUNCTIONS(const Gmpfi&,_t) \
+        CGAL_GMPFI_DECLARE_STATIC_FUNCTIONS(_t,const Gmpfi&)
 
-        _GMPFI_DECLARE_STATIC_FUNCTIONS(const Gmpfi&,const Gmpfi&)
-        _GMPFI_DECLARE_TWO_WAY_STATIC_FUNCTIONS(const Gmpfr&)
-        _GMPFI_DECLARE_TWO_WAY_STATIC_FUNCTIONS(long)
-        _GMPFI_DECLARE_TWO_WAY_STATIC_FUNCTIONS(unsigned long)
-        _GMPFI_DECLARE_TWO_WAY_STATIC_FUNCTIONS(int)
-        _GMPFI_DECLARE_TWO_WAY_STATIC_FUNCTIONS(const Gmpz&)
-        _GMPFI_DECLARE_TWO_WAY_STATIC_FUNCTIONS(const Gmpq&)
+        CGAL_GMPFI_DECLARE_STATIC_FUNCTIONS(const Gmpfi&,const Gmpfi&)
+        CGAL_GMPFI_DECLARE_TWO_WAY_STATIC_FUNCTIONS(const Gmpfr&)
+        CGAL_GMPFI_DECLARE_TWO_WAY_STATIC_FUNCTIONS(long)
+        CGAL_GMPFI_DECLARE_TWO_WAY_STATIC_FUNCTIONS(unsigned long)
+        CGAL_GMPFI_DECLARE_TWO_WAY_STATIC_FUNCTIONS(int)
+        CGAL_GMPFI_DECLARE_TWO_WAY_STATIC_FUNCTIONS(const Gmpz&)
+        CGAL_GMPFI_DECLARE_TWO_WAY_STATIC_FUNCTIONS(const Gmpq&)
 
-#undef _GMPFI_DECLARE_STATIC_FUNCTION
+#undef CGAL_GMPFI_DECLARE_STATIC_FUNCTION
+#undef CGAL_GMPFI_DECLARE_STATIC_FUNCTIONS
+#undef CGAL_GMPFI_DECLARE_TWO_WAY_STATIC_FUNCTIONS
 
         Gmpfi abs(Gmpfi::Precision_type=Gmpfi::get_default_precision())const;
         Gmpfi sqrt(Gmpfi::Precision_type=Gmpfi::get_default_precision())const;
@@ -334,10 +401,11 @@ _GMPFI_CONSTRUCTOR_FROM_SCALAR(Gmpq);
 
 // default precision
 #ifdef CGAL_HAS_THREADS
+inline
 void Gmpfi::init_precision_for_thread(){
         CGAL_precondition(Gmpfi_default_precision_.get()==NULL);
         Gmpfi_default_precision_.reset(
-                new mp_prec_t(_GMPFI_DEFAULT_PRECISION));
+                new mp_prec_t(CGAL_GMPFI_DEFAULT_PRECISION));
 }
 #endif
 
@@ -368,7 +436,9 @@ Gmpfi::Precision_type Gmpfi::set_default_precision(Gmpfi::Precision_type prec){
 
 inline
 Gmpfi::Precision_type Gmpfi::get_precision()const{
-        return mpfi_get_prec(mpfi());
+        return (_left.get_precision()>_right.get_precision()?
+                (Gmpfi::Precision_type)_left.get_precision():
+                (Gmpfi::Precision_type)_right.get_precision());
 }
 
 inline
@@ -386,165 +456,190 @@ Gmpfi Gmpfi::operator+()const{
 
 inline
 Gmpfi Gmpfi::operator-()const{
-        Gmpfi result(0,get_precision());
-        mpfi_neg(result.mpfi(),mpfi());
+        Gmpfi result (0, this->get_precision());
+        mpfi_neg (result.mpfi(), this->mpfi());
+        *(result._left.fr()) = result._interval.left;
+        *(result._right.fr()) = result._interval.right;
         return result;
 }
 
-// _GMPFI_BALANCE_ENDPOINTS checks if both endpoints of the interval have
+// CGAL_GMPFI_BALANCE_ENDPOINTS checks if both bounds of the interval have
 // the same precision. If not, it rounds the one with the smallest
 // precision.
-#define _GMPFI_BALANCE_ENDPOINTS \
-        if(mpfr_get_prec(left_mpfr())<mpfr_get_prec(right_mpfr())){\
-                mpfr_round_prec(&(mpfi()->left), \
-                                GMP_RNDD, \
-                                mpfr_get_prec(right_mpfr())); \
+#define CGAL_GMPFI_BALANCE_ENDPOINTS \
+        if(_left.get_precision()<_right.get_precision()){ \
+                _left=Gmpfr(_left,_right.get_precision()); \
         }else{ \
-                if(mpfr_get_prec(left_mpfr())>mpfr_get_prec(right_mpfr())){\
-                        mpfr_round_prec(&(mpfi()->right), \
-                                        GMP_RNDU, \
-                                        mpfr_get_prec(left_mpfr())); \
+                if(_right.get_precision()<_left.get_precision()){ \
+                        _right=Gmpfr(_right,_left.get_precision()); \
                 } \
-        }
+        }; \
+        CGAL_assertion_msg(_left.get_precision()==_right.get_precision(), \
+                           "error balancing bounds precision");
 
-// _GMPFI_OBJECT_BINARY_OPERATOR defines an overloaded binary operator of
-// the Gmpfi class, where the operated object belongs to another class,
+// CGAL_GMPFI_OBJECT_BINARY_OPERATOR defines an overloaded binary operator
+// of the Gmpfi class, where the operated object belongs to another class,
 // which represents a point (as opposition to an interval). The operation
-// will be performed using the biggest precision of the endpoints of this
-// Gmpfi object. That means that if endpoints have different precision, one
-// of them (the one with the biggest precision) will be rounded. This is
+// will be performed using the biggest precision of the bounds of this
+// Gmpfi object. That means that if bounds have different precision, one
+// of them (the one with the smallest precision) will be rounded. This is
 // not a problem when the object is not unique, since a new Gmpfi object
-// will be created with the endpoints having the correct precision.
-#define _GMPFI_OBJECT_BINARY_OPERATOR(_op,_class,_member,_fun) \
+// will be created with the bounds having the correct precision.
+#define CGAL_GMPFI_OBJECT_BINARY_OPERATOR(_op,_class,_member,_fun) \
         inline \
         Gmpfi& Gmpfi::_op(const _class &b){ \
-                if(unique()){ \
-                        _GMPFI_BALANCE_ENDPOINTS \
+                if(is_unique()){ \
+                        CGAL_GMPFI_BALANCE_ENDPOINTS \
                         _fun(mpfi(),mpfi(),b._member); \
+                        gather_bounds(); \
                 }else{ \
-                        Gmpfi result(0,get_precision()); \
-                        _fun(result.mpfi(),mpfi(),b._member); \
-                        swap(result); \
+                        Gmpfi result (0, this->get_precision()); \
+                        _fun (result.mpfi(), this->mpfi(), b._member); \
+                        *(result._left.fr()) = result._interval.left; \
+                        *(result._right.fr()) = result._interval.right; \
+                        this->swap (result); \
                 } \
                 return(*this); \
         }
 
-// _GMPFI_GMPFI_BINARY_OPERATOR defines an overloaded binary operator of
-// the Gmpfi class, where the operated object is also a Gmpfi object.
-// The operation will be performed using the biggest precision of the
-// endpoints of both intervals. The endpoints of target object will be
-// rounded accordingly before the operation.
-#define _GMPFI_GMPFI_BINARY_OPERATOR(_op,_fun) \
+// CGAL_GMPFI_GMPFI_BINARY_OPERATOR defines an overloaded binary operator
+// of the Gmpfi class, where both operands are Gmpfi objects.  The
+// operation will be performed using the biggest precision of the bounds
+// of both intervals. The bounds of target object will be rounded
+// accordingly before the operation.
+#define CGAL_GMPFI_GMPFI_BINARY_OPERATOR(_op,_fun) \
         inline \
         Gmpfi& Gmpfi::_op(const Gmpfi &fi){ \
-                if(unique()){ \
+                if(is_unique()){ \
                         if(get_precision()<fi.get_precision()){ \
-                                mpfi_round_prec(mpfi(),fi.get_precision()); \
+                                Gmpfi result (0, fi.get_precision()); \
+                                _fun(result.mpfi(), this->mpfi(), fi.mpfi()); \
+                                *(result._left.fr()) = result._interval.left; \
+                                *(result._right.fr())= result._interval.right;\
+                                this->swap (result); \
                         }else{ \
-                                _GMPFI_BALANCE_ENDPOINTS \
+                                CGAL_GMPFI_BALANCE_ENDPOINTS \
+                                _fun(mpfi(),mpfi(),fi.mpfi()); \
+                                gather_bounds(); \
                         } \
-                        _fun(mpfi(),mpfi(),fi.mpfi()); \
                 }else{ \
                         Gmpfi result(0, \
-                                     get_precision()<fi.get_precision()? \
-                                        fi.get_precision(): \
-                                        get_precision()); \
-                        _fun(result.mpfi(),mpfi(),fi.mpfi()); \
-                        swap(result); \
+                                     this->get_precision()<fi.get_precision()?\
+                                     fi.get_precision(): \
+                                     this->get_precision()); \
+                        _fun (result.mpfi(), this->mpfi(), fi.mpfi()); \
+                        *(result._left.fr()) = result._interval.left; \
+                        *(result._right.fr()) = result._interval.right; \
+                        this->swap (result); \
                 } \
                 return(*this); \
-        }
+  }
 
-// _GMPFI_TYPE_BINARY_OPERATOR defines an overloaded binary operator of
-// the Gmpfi class, where the operated belongs to a c++ type. Precision of
-// the operation is defined in the same manner that in
-// _GMPFI_OBJECT_BINARY_OPERATOR.
-#define _GMPFI_TYPE_BINARY_OPERATOR(_op,_type,_fun) \
+// CGAL_GMPFI_TYPE_BINARY_OPERATOR defines an overloaded binary operator of
+// the Gmpfi class, where the operated number belongs to a c++ type.
+// Precision of the operation is defined in the same manner that in
+// CGAL_GMPFI_OBJECT_BINARY_OPERATOR.
+#define CGAL_GMPFI_TYPE_BINARY_OPERATOR(_op,_type,_fun) \
         inline \
         Gmpfi& Gmpfi::_op(_type x){ \
-                if(unique()){ \
-                        _GMPFI_BALANCE_ENDPOINTS \
+                if(is_unique()){ \
+                        CGAL_GMPFI_BALANCE_ENDPOINTS \
                         _fun(mpfi(),mpfi(),x); \
+                        gather_bounds(); \
                 }else{ \
-                        Gmpfi result(0,get_precision()); \
-                        _fun(result.mpfi(),mpfi(),x); \
-                        swap(result); \
+                        Gmpfi result (0, this->get_precision()); \
+                        _fun (result.mpfi(), this->mpfi(), x); \
+                        *(result._left.fr()) = result._interval.left; \
+                        *(result._right.fr()) = result._interval.right; \
+                        this->swap (result); \
                 } \
                 return *this; \
         }
 
-_GMPFI_GMPFI_BINARY_OPERATOR(operator+=,mpfi_add)
-_GMPFI_GMPFI_BINARY_OPERATOR(operator-=,mpfi_sub)
-_GMPFI_GMPFI_BINARY_OPERATOR(operator*=,mpfi_mul)
-_GMPFI_GMPFI_BINARY_OPERATOR(operator/=,mpfi_div)
+CGAL_GMPFI_GMPFI_BINARY_OPERATOR(operator+=,mpfi_add)
+CGAL_GMPFI_GMPFI_BINARY_OPERATOR(operator-=,mpfi_sub)
+CGAL_GMPFI_GMPFI_BINARY_OPERATOR(operator*=,mpfi_mul)
+CGAL_GMPFI_GMPFI_BINARY_OPERATOR(operator/=,mpfi_div)
 
-_GMPFI_OBJECT_BINARY_OPERATOR(operator+=,Gmpfr,fr(),mpfi_add_fr)
-_GMPFI_OBJECT_BINARY_OPERATOR(operator-=,Gmpfr,fr(),mpfi_sub_fr)
-_GMPFI_OBJECT_BINARY_OPERATOR(operator*=,Gmpfr,fr(),mpfi_mul_fr)
-_GMPFI_OBJECT_BINARY_OPERATOR(operator/=,Gmpfr,fr(),mpfi_div_fr)
+CGAL_GMPFI_OBJECT_BINARY_OPERATOR(operator+=,Gmpfr,fr(),mpfi_add_fr)
+CGAL_GMPFI_OBJECT_BINARY_OPERATOR(operator-=,Gmpfr,fr(),mpfi_sub_fr)
+CGAL_GMPFI_OBJECT_BINARY_OPERATOR(operator*=,Gmpfr,fr(),mpfi_mul_fr)
+CGAL_GMPFI_OBJECT_BINARY_OPERATOR(operator/=,Gmpfr,fr(),mpfi_div_fr)
 
-_GMPFI_TYPE_BINARY_OPERATOR(operator+=,long,mpfi_add_si)
-_GMPFI_TYPE_BINARY_OPERATOR(operator-=,long,mpfi_sub_si)
-_GMPFI_TYPE_BINARY_OPERATOR(operator*=,long,mpfi_mul_si)
-_GMPFI_TYPE_BINARY_OPERATOR(operator/=,long,mpfi_div_si)
+CGAL_GMPFI_TYPE_BINARY_OPERATOR(operator+=,long,mpfi_add_si)
+CGAL_GMPFI_TYPE_BINARY_OPERATOR(operator-=,long,mpfi_sub_si)
+CGAL_GMPFI_TYPE_BINARY_OPERATOR(operator*=,long,mpfi_mul_si)
+CGAL_GMPFI_TYPE_BINARY_OPERATOR(operator/=,long,mpfi_div_si)
 
-_GMPFI_TYPE_BINARY_OPERATOR(operator+=,unsigned long,mpfi_add_ui)
-_GMPFI_TYPE_BINARY_OPERATOR(operator-=,unsigned long,mpfi_sub_ui)
-_GMPFI_TYPE_BINARY_OPERATOR(operator*=,unsigned long,mpfi_mul_ui)
-_GMPFI_TYPE_BINARY_OPERATOR(operator/=,unsigned long,mpfi_div_ui)
+CGAL_GMPFI_TYPE_BINARY_OPERATOR(operator+=,unsigned long,mpfi_add_ui)
+CGAL_GMPFI_TYPE_BINARY_OPERATOR(operator-=,unsigned long,mpfi_sub_ui)
+CGAL_GMPFI_TYPE_BINARY_OPERATOR(operator*=,unsigned long,mpfi_mul_ui)
+CGAL_GMPFI_TYPE_BINARY_OPERATOR(operator/=,unsigned long,mpfi_div_ui)
 
-_GMPFI_TYPE_BINARY_OPERATOR(operator+=,int,mpfi_add_si)
-_GMPFI_TYPE_BINARY_OPERATOR(operator-=,int,mpfi_sub_si)
-_GMPFI_TYPE_BINARY_OPERATOR(operator*=,int,mpfi_mul_si)
-_GMPFI_TYPE_BINARY_OPERATOR(operator/=,int,mpfi_div_si)
+CGAL_GMPFI_TYPE_BINARY_OPERATOR(operator+=,int,mpfi_add_si)
+CGAL_GMPFI_TYPE_BINARY_OPERATOR(operator-=,int,mpfi_sub_si)
+CGAL_GMPFI_TYPE_BINARY_OPERATOR(operator*=,int,mpfi_mul_si)
+CGAL_GMPFI_TYPE_BINARY_OPERATOR(operator/=,int,mpfi_div_si)
 
-_GMPFI_OBJECT_BINARY_OPERATOR(operator+=,Gmpz,mpz(),mpfi_add_z)
-_GMPFI_OBJECT_BINARY_OPERATOR(operator-=,Gmpz,mpz(),mpfi_sub_z)
-_GMPFI_OBJECT_BINARY_OPERATOR(operator*=,Gmpz,mpz(),mpfi_mul_z)
-_GMPFI_OBJECT_BINARY_OPERATOR(operator/=,Gmpz,mpz(),mpfi_div_z)
+CGAL_GMPFI_OBJECT_BINARY_OPERATOR(operator+=,Gmpz,mpz(),mpfi_add_z)
+CGAL_GMPFI_OBJECT_BINARY_OPERATOR(operator-=,Gmpz,mpz(),mpfi_sub_z)
+CGAL_GMPFI_OBJECT_BINARY_OPERATOR(operator*=,Gmpz,mpz(),mpfi_mul_z)
+CGAL_GMPFI_OBJECT_BINARY_OPERATOR(operator/=,Gmpz,mpz(),mpfi_div_z)
 
-_GMPFI_OBJECT_BINARY_OPERATOR(operator+=,Gmpq,mpq(),mpfi_add_q)
-_GMPFI_OBJECT_BINARY_OPERATOR(operator-=,Gmpq,mpq(),mpfi_sub_q)
-_GMPFI_OBJECT_BINARY_OPERATOR(operator*=,Gmpq,mpq(),mpfi_mul_q)
-_GMPFI_OBJECT_BINARY_OPERATOR(operator/=,Gmpq,mpq(),mpfi_div_q)
+CGAL_GMPFI_OBJECT_BINARY_OPERATOR(operator+=,Gmpq,mpq(),mpfi_add_q)
+CGAL_GMPFI_OBJECT_BINARY_OPERATOR(operator-=,Gmpq,mpq(),mpfi_sub_q)
+CGAL_GMPFI_OBJECT_BINARY_OPERATOR(operator*=,Gmpq,mpq(),mpfi_mul_q)
+CGAL_GMPFI_OBJECT_BINARY_OPERATOR(operator/=,Gmpq,mpq(),mpfi_div_q)
 
-#undef _GMPFI_GMPFI_BINARY_OPERATOR
-#undef _GMPFI_OBJECT_BINARY_OPERATOR
-#undef _GMPFI_TYPE_BINARY_OPERATOR
+#undef CGAL_GMPFI_BALANCE_ENDPOINTS
+#undef CGAL_GMPFI_GMPFI_BINARY_OPERATOR
+#undef CGAL_GMPFI_OBJECT_BINARY_OPERATOR
+#undef CGAL_GMPFI_TYPE_BINARY_OPERATOR
 
 // the static arithmetic functions are defined in a separate file
 #include <CGAL/GMP/Gmpfi_type_static.h>
 
-#define _GMPFI_ARITHMETIC_FUNCTION(_name,_fun) \
+#define CGAL_GMPFI_ARITHMETIC_FUNCTION(_name,_fun) \
         inline \
         Gmpfi Gmpfi::_name (Gmpfi::Precision_type p)const{ \
-                Gmpfi result(0,p); \
-                _fun(result.mpfi(),mpfi()); \
+                CGAL_assertion(p>=MPFR_PREC_MIN&&p<=MPFR_PREC_MAX); \
+                Gmpfi result (0, p); \
+                _fun (result.mpfi(), this->mpfi()); \
+                *(result._left.fr()) = result._interval.left; \
+                *(result._right.fr()) = result._interval.right; \
                 return result; \
         }
 
-_GMPFI_ARITHMETIC_FUNCTION(abs,mpfi_abs)
-_GMPFI_ARITHMETIC_FUNCTION(sqrt,mpfi_sqrt)
+CGAL_GMPFI_ARITHMETIC_FUNCTION(abs,mpfi_abs)
+CGAL_GMPFI_ARITHMETIC_FUNCTION(sqrt,mpfi_sqrt)
 
 inline
 Gmpfi Gmpfi::cbrt(Gmpfi::Precision_type p)const{
         // MPFI does not provide a cubic root function
-        Gmpfi result(0,p);
-        mpfr_cbrt(&(result.mpfi())->left,left_mpfr(),GMP_RNDD);
+        CGAL_assertion(p>=MPFR_PREC_MIN&&p<=MPFR_PREC_MAX);
+        Gmpfi result (0, p);
+        mpfr_cbrt(&(result.mpfi())->left, left_mpfr(), GMP_RNDD);
         mpfr_cbrt(&(result.mpfi())->right,right_mpfr(),GMP_RNDU);
+        *(result._left.fr()) = result._interval.left;
+        *(result._right.fr()) = result._interval.right;
         return result;
 }
 
 inline
 Gmpfi Gmpfi::kthroot(int k,Gmpfi::Precision_type p)const{
         // MPFI does not provide k-th root functions
-        Gmpfi result(0,p);
-        mpfr_root(&(result.mpfi())->left,left_mpfr(),k,GMP_RNDD);
+        CGAL_assertion(p>=MPFR_PREC_MIN&&p<=MPFR_PREC_MAX);
+        Gmpfi result (0, p);
+        mpfr_root(&(result.mpfi())->left, left_mpfr(), k,GMP_RNDD);
         mpfr_root(&(result.mpfi())->right,right_mpfr(),k,GMP_RNDU);
+        *(result._left.fr()) = result._interval.left;
+        *(result._right.fr()) = result._interval.right;
         return result;
 }
 
-_GMPFI_ARITHMETIC_FUNCTION(square,mpfi_sqr)
+CGAL_GMPFI_ARITHMETIC_FUNCTION(square,mpfi_sqr)
+
+#undef CGAL_GMPFI_ARITHMETIC_FUNCTION
 
 // comparison and query functions
 
@@ -602,10 +697,10 @@ bool Gmpfi::is_number()const{
 
 inline
 Uncertain<Sign> Gmpfi::sign()const{
-        int s_left=mpfr_sgn(left_mpfr());
-        if(s_left>0)
+        int leftsign=mpfr_sgn(left_mpfr());
+        if(leftsign>0)
                 return POSITIVE;
-        if(s_left==0){
+        if(leftsign==0){
                 if(mpfr_zero_p(right_mpfr())!=0)
                         return ZERO;
                 else
@@ -657,7 +752,7 @@ Uncertain<bool> Gmpfi::is_square(Gmpfi &y)const{
 inline
 Uncertain<bool> Gmpfi::divides(const Gmpfi &n,Gmpfi &c,Gmpfi::Precision_type p
                               )const{
-        if(mpfr_zero_p(&mpfi()->left)!=0 && mpfr_zero_p(&mpfi()->right)!=0)
+        if(mpfr_zero_p(left_mpfr())!=0 && mpfr_zero_p(right_mpfr())!=0)
                 return false;
         if(mpfi_has_zero(mpfi())!=0)
                 return Uncertain<bool>::indeterminate();
@@ -689,7 +784,7 @@ std::pair<double,double> Gmpfi::to_interval()const{
         double d_low=mpfr_get_d(left_mpfr(),GMP_RNDD);
         double d_upp=mpfr_get_d(right_mpfr(),GMP_RNDU);
         CGAL_assertion(std::numeric_limits<double>::has_infinity);
-        // if an endpoint is finite and its double is infinity, we overflow
+        // if a bound is finite and its double is infinity, we overflow
         if(mpfr_inf_p(left_mpfr())==0&&
                         d_low==std::numeric_limits<double>::infinity())
                 mpfr_set_underflow();
@@ -996,5 +1091,3 @@ Uncertain<Gmpfi> max BOOST_PREVENT_MACRO_SUBSTITUTION
 } // namespace CGAL
 
 #endif  // CGAL_GMPFI_TYPE_H
-
-// vim: tabstop=8: softtabstop=8: smarttab: shiftwidth=8: expandtab
