@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/HalfedgeDS/include/CGAL/HalfedgeDS_iterator_adaptor.h $
-// $Id: HalfedgeDS_iterator_adaptor.h 35787 2007-01-24 17:16:05Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/HalfedgeDS/include/CGAL/HalfedgeDS_iterator_adaptor.h $
+// $Id: HalfedgeDS_iterator_adaptor.h 56667 2010-06-09 07:37:13Z sloriot $
 // 
 //
 // Author(s)     : Lutz Kettner  <kettner@mpi-sb.mpg.de>
@@ -26,7 +26,7 @@
 
 #include <iterator>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 //  The iterator identity adaptor will be used for the HDS implementations
 //  that are based on STL (or other) container classes which do not
@@ -156,7 +156,7 @@ public:
     bool operator>=( const Self& i) const { return !(*this < i); }
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 // we don't need Koenig lookup here
 template < class D, class I>
