@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Spatial_sorting/include/CGAL/Hilbert_sort_base.h $
-// $Id: Hilbert_sort_base.h 51456 2009-08-24 17:10:04Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Spatial_sorting/include/CGAL/Hilbert_sort_base.h $
+// $Id: Hilbert_sort_base.h 63930 2011-06-07 08:20:54Z sloriot $
 //
 // Author(s)     : Christophe Delage
 
@@ -23,7 +23,7 @@
 #include <CGAL/basic.h>
 #include <algorithm>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 namespace internal {
 
@@ -40,6 +40,6 @@ namespace internal {
     }
 }
 
-CGAL_END_NAMESPACE
+} // namespace CGAL
 
 #endif//CGAL_HILBERT_SORT_BASE_H
