@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Homogeneous_kernel/include/CGAL/Homogeneous/distance_predicatesH3.h $
-// $Id: distance_predicatesH3.h 29102 2006-03-06 23:51:27Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Homogeneous_kernel/include/CGAL/Homogeneous/distance_predicatesH3.h $
+// $Id: distance_predicatesH3.h 56667 2010-06-09 07:37:13Z sloriot $
 // 
 //
 // Author(s)     : Stefan Schirra
@@ -25,7 +25,7 @@
 #ifndef CGAL_DISTANCE_PREDICATESH3_H
 #define CGAL_DISTANCE_PREDICATESH3_H
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template <class R>
 Comparison_result
@@ -328,6 +328,6 @@ has_smaller_signed_distance_to_plane(const PointH3<R>& p,
                                      const PointH3<R>& t)
 { return cmp_signed_dist_to_plane(p,q,r,s,t) == SMALLER; }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif //CGAL_DISTANCE_PREDICATESH3_H
