@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Kernel_d/include/CGAL/Homogeneous_d.h $
-// $Id: Homogeneous_d.h 51456 2009-08-24 17:10:04Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Kernel_d/include/CGAL/Homogeneous_d.h $
+// $Id: Homogeneous_d.h 63930 2011-06-07 08:20:54Z sloriot $
 // 
 //
 // Author(s)     : Michael Seel
@@ -47,7 +47,7 @@
 #include <CGAL/Kernel_d/simple_objects.h>
 #include <CGAL/Dimension.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template <class pRT, class pLA = Linear_algebraHd<pRT> >
 class Homogeneous_d 
@@ -236,6 +236,7 @@ public:
   { return Construct_aff_transformation_d(); }
 
   // function objects:
+  typedef Compute_coordinateHd<Self> Compute_coordinate_d;
   typedef Lift_to_paraboloidHd<Self> Lift_to_paraboloid_d;
   typedef Project_along_d_axisHd<Self> Project_along_d_axis_d;
   typedef MidpointHd<Self> Midpoint_d;
@@ -252,6 +253,8 @@ public:
   typedef Compare_lexicographicallyHd<Self> Compare_lexicographically_d;
   typedef Lt_from_compare<Self> Less_lexicographically_d;
   typedef Le_from_compare<Self> Less_or_equal_lexicographically_d;
+  typedef Less_coordinateHd<Self> Less_coordinate_d;
+  typedef Point_dimensionHd<Self> Point_dimension_d;
   typedef Eq_from_method<Self> Equal_d;
   typedef Center_of_sphereHd<Self> Center_of_sphere_d;
   typedef Contained_in_linear_hullHd<Self> Contained_in_linear_hull_d;
@@ -259,6 +262,12 @@ public:
   typedef Linearly_independentHd<Self> Linearly_independent_d;
   typedef Linear_baseHd<Self> Linear_base_d;
 
+  Compute_coordinate_d compute_coordinate_d_object() const
+  { return Compute_coordinate_d(); }
+  Point_dimension_d point_dimension_d_object() const
+  { return Point_dimension_d(); }
+  Less_coordinate_d less_coordinate_d_object() const
+  { return Less_coordinate_d(); }
   Lift_to_paraboloid_d lift_to_paraboloid_d_object() const
   { return Lift_to_paraboloid_d(); }
   Project_along_d_axis_d project_along_d_axis_d_object() const
@@ -396,7 +405,7 @@ public:
 }; // Homogeneous_d<R>
  
  
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #include <CGAL/Kernel_d/Point_d.h>
 #include <CGAL/Kernel_d/Vector_d.h>
