@@ -1,4 +1,4 @@
-// Copyright (c) 2005-2007  Tel-Aviv University (Israel).
+// Copyright (c) 2005,2006,2007,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Arrangement_on_surface_2/include/CGAL/IO/Arr_with_history_2_reader.h $
-// $Id: Arr_with_history_2_reader.h 40195 2007-09-05 09:51:34Z ophirset $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/IO/Arr_with_history_2_reader.h $
+// $Id: Arr_with_history_2_reader.h 64639 2011-07-06 11:41:06Z lrineau $
 // 
 //
 // Author(s)     : Ron Wein           <wein@post.tau.ac.il>
@@ -26,7 +26,7 @@
 #include <CGAL/IO/Arrangement_2_reader.h>
 #include <CGAL/Arrangement_2/Arr_with_history_accessor.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 /*! \class
  * An auxiliary class for reading an arrangement with history from an
@@ -128,6 +128,6 @@ protected:
    
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
