@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Qt_widget/include/CGAL/IO/Qt_widget.h $
-// $Id: Qt_widget.h 53026 2009-11-14 11:49:52Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Qt_widget/include/CGAL/IO/Qt_widget.h $
+// $Id: Qt_widget.h 63000 2011-04-15 09:12:06Z eric $
 // 
 //
 // Author(s)     : Laurent Rineau
@@ -39,7 +39,7 @@
 #include <qpixmap.h>
 #include <qprinter.h>
 
-#include <CGAL/auto_link/CGALQt.h>
+#include <CGAL/auto_link/CGALQt3.h>
 
 namespace CGAL {
 
@@ -598,7 +598,7 @@ Qt_widget& operator<<(Qt_widget& w, const Line_2<R>& l)
 
   if (dx==0 && dy==0) return w;
 
-  if (std::fabs(dx)>std::fabs(dy))
+  if (CGAL::abs(dx)>CGAL::abs(dy))
     {
       y1=p1d.y()+(x1-p1d.x())*dy/dx;
       y2=p1d.y()+(x2-p1d.x())*dy/dx;
@@ -640,7 +640,7 @@ Qt_widget& operator<<(Qt_widget& w, const Ray_2<R>& r)
 
   double x,y;
 
-  if (std::fabs(dx)>std::fabs(dy))
+  if (CGAL::abs(dx)>CGAL::abs(dy))
     {
       if (p1d.x()<p2d.x())
 	x = w.x_max();
