@@ -11,11 +11,11 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Apollonius_graph_2/include/CGAL/IO/Qt_widget_Hyperbola_2.h $
-// $Id: Qt_widget_Hyperbola_2.h 45459 2008-09-09 22:29:51Z lrineau $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Apollonius_graph_2/include/CGAL/IO/Qt_widget_Hyperbola_2.h $
+// $Id: Qt_widget_Hyperbola_2.h 63970 2011-06-08 06:31:19Z mkaravel $
 // 
 //
-// Author(s)     : Menelaos Karavelas <mkaravel@cse.nd.edu>
+// Author(s)     : Menelaos Karavelas <mkaravel@iacm.forth.gr>
 
 #ifndef CGAL_QT_WIDGET_HYPERBOLA_2_H
 #define CGAL_QT_WIDGET_HYPERBOLA_2_H
@@ -24,7 +24,7 @@
 #include <CGAL/Hyperbola_ray_2.h>
 #include <CGAL/IO/Qt_widget.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template< class Gt >
 inline
@@ -42,6 +42,6 @@ Qt_widget& operator<<(Qt_widget &s, Hyperbola_ray_2<Gt> &H)
   return s;
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_QT_WIDGET_HYPERBOLA_2_H
