@@ -1,4 +1,4 @@
-// Copyright (c) 2005  Tel-Aviv University (Israel).
+// Copyright (c) 2005,2006,2007,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,9 +11,9 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Arrangement_on_surface_2/include/CGAL/IO/Qt_widget_Polyline_2.h $
-// $Id: Qt_widget_Polyline_2.h 39957 2007-08-22 12:30:17Z efif $
-// $Date: 2007-08-22 14:30:17 +0200 (Wed, 22 Aug 2007) $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/IO/Qt_widget_Polyline_2.h $
+// $Id: Qt_widget_Polyline_2.h 64639 2011-07-06 11:41:06Z lrineau $
+// $Date: 2011-07-06 13:41:06 +0200 (Wed, 06 Jul 2011) $
 // 
 //
 // Author(s)     : Ron Wein  <wein@post.tau.ac.il>
@@ -25,7 +25,7 @@
 #include <CGAL/IO/Qt_widget.h>
 #include <CGAL/Arr_traits_2/Polyline_2.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 /*!
  * Export a polyline to a window stream 
@@ -37,6 +37,6 @@ Qt_widget & operator<<(Qt_widget & ws, const _Polyline_2<T_SegmentTraits> & cv)
   return ws;
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
