@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Convex_hull_2/include/CGAL/IO/Tee_for_output_iterator.h $
-// $Id: Tee_for_output_iterator.h 28567 2006-02-16 14:30:13Z lsaboret $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Convex_hull_2/include/CGAL/IO/Tee_for_output_iterator.h $
+// $Id: Tee_for_output_iterator.h 56667 2010-06-09 07:37:13Z sloriot $
 // 
 //
 // Author(s)     : Stefan Schirra
@@ -26,7 +26,7 @@
 #include <vector>
 #include <CGAL/Handle.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 template <class T> class _Tee_for_output_iterator_rep;
 
 template <class OutputIterator, class T>
@@ -99,6 +99,6 @@ public:
   std::vector<T> output_so_far;
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_IO_TEE_FOR_OUTPUT_ITERATOR_H
