@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Inventor/include/CGAL/IO/VRML_1_ostream.h $
-// $Id: VRML_1_ostream.h 35701 2007-01-10 19:09:41Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Inventor/include/CGAL/IO/VRML_1_ostream.h $
+// $Id: VRML_1_ostream.h 56667 2010-06-09 07:37:13Z sloriot $
 // 
 // Author(s)     : Andreas Fabri
 //                 Lutz Kettner <kettner@inf.ethz.ch>
@@ -37,7 +37,7 @@
 // base class Inventor_ostream_base, which is common for
 // both output streams.
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 class VRML_1_ostream : public Inventor_ostream_base {
 public:
@@ -57,7 +57,7 @@ private:
     }
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_IO_VRML_1_OSTREAM_H
 
@@ -65,7 +65,7 @@ CGAL_END_NAMESPACE
 #ifndef CGAL_IO_VRML_1_TETRAHEDRON_3
 #define CGAL_IO_VRML_1_TETRAHEDRON_3
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template <class R >
 VRML_1_ostream&
@@ -101,7 +101,7 @@ operator<<(VRML_1_ostream& os,
   return os;
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_IO_VRML_1_TETRAHEDRON_3
 #endif // CGAL_TETRAHEDRON_3_H
