@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/STL_Extension/include/CGAL/Iterator_identity.h $
-// $Id: Iterator_identity.h 46206 2008-10-11 20:21:08Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/STL_Extension/include/CGAL/Iterator_identity.h $
+// $Id: Iterator_identity.h 56667 2010-06-09 07:37:13Z sloriot $
 // 
 //
 // Author(s)     : Michael Hoffmann <hoffmann@inf.ethz.ch>
@@ -28,7 +28,7 @@
 
 #include <CGAL/circulator.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template < class I,
            class Ref  = typename std::iterator_traits<I>::reference,
@@ -141,6 +141,6 @@ Iterator_identity<I,Ref,Ptr,Val,Dist,Ctg>
 operator+( Dist n, Iterator_identity<I,Ref,Ptr,Val,Dist,Ctg> i)
 { return i += n; }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 #endif // CGAL_ITERATOR_IDENTITY_H //
 // EOF //
