@@ -1,4 +1,4 @@
-// Copyright (c) 2002 Utrecht University (The Netherlands).
+// Copyright (c) 2002,2011 Utrecht University (The Netherlands).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Spatial_searching/include/CGAL/K_neighbor_search.h $
-// $Id: K_neighbor_search.h 60167 2010-12-06 11:43:05Z lrineau $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Spatial_searching/include/CGAL/K_neighbor_search.h $
+// $Id: K_neighbor_search.h 64637 2011-07-06 11:11:58Z lrineau $
 // 
 //
 // Author(s)     : Hans Tangelder (<hanst@cs.uu.nl>)
@@ -25,7 +25,7 @@
 namespace CGAL {
 
 template <class SearchTraits, 
-          class Distance= Euclidean_distance<SearchTraits>,
+          class Distance= typename internal::Spatial_searching_default_distance<SearchTraits>::type,
           class Splitter= Sliding_midpoint<SearchTraits> ,
           class Tree= Kd_tree<SearchTraits, Splitter, Tag_true> >
 class K_neighbor_search: public internal::K_neighbor_search<SearchTraits,Distance,Splitter,Tree> {
@@ -48,17 +48,17 @@ private:
   using Base::branch;
 
   void 
-  compute_neighbors_general(typename Base::Node_handle N, const Kd_tree_rectangle<SearchTraits>& r) 
+  compute_neighbors_general(typename Base::Node_handle N, const Kd_tree_rectangle<FT>& r) 
   {
     if (!(N->is_leaf())) {
       this->number_of_internal_nodes_visited++;
       int new_cut_dim=N->cutting_dimension();
       FT  new_cut_val=N->cutting_value();
 
-      Kd_tree_rectangle<SearchTraits> r_lower(r);
+      Kd_tree_rectangle<FT> r_lower(r);
 
       // modifies also r_lower to lower half
-      Kd_tree_rectangle<SearchTraits> r_upper(r_lower);
+      Kd_tree_rectangle<FT> r_upper(r_lower);
       r_lower.split(r_upper, new_cut_dim, new_cut_val);
 
       FT distance_to_lower_half;
