@@ -1,4 +1,4 @@
-// Copyright (c) 2002 Utrecht University (The Netherlands).
+// Copyright (c) 2002,2011 Utrecht University (The Netherlands).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Spatial_searching/include/CGAL/Kd_tree_rectangle.h $
-// $Id: Kd_tree_rectangle.h 28567 2006-02-16 14:30:13Z lsaboret $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Spatial_searching/include/CGAL/Kd_tree_rectangle.h $
+// $Id: Kd_tree_rectangle.h 64637 2011-07-06 11:11:58Z lrineau $
 // 
 //
 // Author(s)     : Hans Tangelder (<hanst@cs.uu.nl>)
@@ -27,22 +27,22 @@
 
 namespace CGAL {
 
-  template <class SearchTraits, class P, class T>
+  template <class Construct_cartesian_const_iterator_d, class P, class T>
   struct set_bounds_from_pointer : public std::unary_function<P, void> {
     int dim;
     T *lower;
     T *upper;
+    Construct_cartesian_const_iterator_d construct_it;
     
-    set_bounds_from_pointer(int d, T *l, T *u) 
-      : dim(d), lower(l), upper(u) 
+    set_bounds_from_pointer(int d, T *l, T *u,Construct_cartesian_const_iterator_d construct_it_) 
+      : dim(d), lower(l), upper(u), construct_it(construct_it_)
     {}
 
     void 
     operator()(P p) 
     {
       T h;
-      typename SearchTraits::Construct_cartesian_const_iterator_d construct_it;
-      typename SearchTraits::Cartesian_const_iterator_d pit = construct_it(*p);
+      typename Construct_cartesian_const_iterator_d::result_type pit = construct_it(*p);
       for (int i = 0; i < dim; ++i, ++pit) {
 	h=(*pit);
 	if (h < lower[i]) lower[i] = h;
@@ -52,10 +52,10 @@ namespace CGAL {
   };
 
 
-  template <class SearchTraits> 
+  template <class FT_> 
   class Kd_tree_rectangle {
   public:
-    typedef typename SearchTraits::FT FT;
+    typedef FT_ FT;
     typedef FT T;
     
   private:
@@ -102,8 +102,8 @@ namespace CGAL {
     Kd_tree_rectangle(int d) 
       : dim(d), lower_(new FT[d]), upper_(new FT[d]), max_span_coord_(0)
     {
-      std::fill(lower_, lower_ + dim, 0);
-      std::fill(upper_, upper_ + dim, 0);
+      std::fill(lower_, lower_ + dim, FT(0));
+      std::fill(upper_, upper_ + dim, FT(0));
     }
 
     Kd_tree_rectangle() 
@@ -112,56 +112,41 @@ namespace CGAL {
     
     
     explicit 
-    Kd_tree_rectangle(const Kd_tree_rectangle<SearchTraits>& r) 
+    Kd_tree_rectangle(const Kd_tree_rectangle<FT>& r) 
       : dim(r.dim), lower_(new FT[dim]), upper_(new FT[dim]), 
 	max_span_coord_(r.max_span_coord_) 
     {
       std::copy(r.lower_, r.lower_+dim, lower_);
       std::copy(r.upper_, r.upper_+dim, upper_);
     }
-    
-    template <class PointPointerIter> // was PointIter
-    Kd_tree_rectangle(int d,  PointPointerIter begin,  PointPointerIter end)
-      : dim(d), lower_(new FT[d]), upper_(new FT[d]) 
+
+    template <class Construct_cartesian_const_iterator_d,class PointPointerIter>
+    void update_from_point_pointers(PointPointerIter begin, 
+                                    PointPointerIter end,
+                                    const Construct_cartesian_const_iterator_d& construct_it
+    ) 
     {
+      if (begin ==end)
+        return;
       // initialize with values of first point
-      typename SearchTraits::Construct_cartesian_const_iterator_d construct_it;
-      typename SearchTraits::Cartesian_const_iterator_d bit = construct_it(**begin);
+      typename Construct_cartesian_const_iterator_d::result_type bit = construct_it(**begin);
       
-      for (int i=0; i < dim; ++bit, ++i){
-	lower_[i]=(*bit); upper_[i]=lower_[i];
+      for (int i=0; i < dim; ++i, ++bit) {
+        lower_[i]= *bit; upper_[i]=lower_[i];
       }
       begin++;
       typedef typename std::iterator_traits<PointPointerIter>::value_type P;
-
-      std::for_each(begin, end, set_bounds_from_pointer<SearchTraits, P,T>(dim, lower_, upper_));
-      set_max_span();
-    }
-
-    template <class PointPointerIter>
-    void update_from_point_pointers(PointPointerIter begin, 
-                                    PointPointerIter end) 
-    {
-      if (begin ==end) { // no points
-	for (int i=0; i < dim; ++i) {
-	  lower_[i]= FT(1); upper_[i]= FT(-1);
-	}
-      } else {
-	// initialize with values of first point
-	typename SearchTraits::Construct_cartesian_const_iterator_d construct_it;
-	typename SearchTraits::Cartesian_const_iterator_d bit = construct_it(**begin);
-	
-	for (int i=0; i < dim; ++i, ++bit) {
-	  lower_[i]= *bit; upper_[i]=lower_[i];
-	}
-	begin++;
-	typedef typename std::iterator_traits<PointPointerIter>::value_type P;
-	std::for_each(begin, end,
-		      set_bounds_from_pointer<SearchTraits,P,T>(dim, lower_, upper_));
-      }
+      std::for_each(begin, end,set_bounds_from_pointer<Construct_cartesian_const_iterator_d,P,T>(dim, lower_, upper_,construct_it));
       set_max_span();
     }
     
+    template <class Construct_cartesian_const_iterator_d,class PointPointerIter> // was PointIter
+    Kd_tree_rectangle(int d,  PointPointerIter begin,  PointPointerIter end,const Construct_cartesian_const_iterator_d& construct_it)
+      : dim(d), lower_(new FT[d]), upper_(new FT[d]) 
+    {
+      update_from_point_pointers<Construct_cartesian_const_iterator_d>(begin,end,construct_it);
+    }
+
     inline int 
     max_span_coord() const 
     { 
@@ -236,9 +221,11 @@ namespace CGAL {
       return dim;
     }
 
+    const T* lower() const {return lower_;}
+    const T* upper() const {return upper_;}    
  
-    Kd_tree_rectangle<SearchTraits>& 
-    operator=(const Kd_tree_rectangle<SearchTraits>& r) 
+    Kd_tree_rectangle<FT>& 
+    operator=(const Kd_tree_rectangle<FT>& r) 
     {
       CGAL_assertion(dimension() == r.dimension());
       if (this != &r) {
@@ -253,9 +240,9 @@ namespace CGAL {
 
   }; // of class Kd_tree_rectangle
 
-  template <class SearchTraits>
+  template <class FT>
   std::ostream& 
-  operator<<(std::ostream& s, const Kd_tree_rectangle<SearchTraits>& r) 
+  operator<<(std::ostream& s, const Kd_tree_rectangle<FT>& r) 
   {
     return r.print(s);
   }
