@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Kernel_23/include/CGAL/Kernel/global_functions_2.h $
-// $Id: global_functions_2.h 51456 2009-08-24 17:10:04Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Kernel_23/include/CGAL/Kernel/global_functions_2.h $
+// $Id: global_functions_2.h 65553 2011-09-26 12:33:57Z lrineau $
 // 
 //
 // Author(s)     : Sylvain Pion
@@ -33,7 +33,7 @@
 #include <CGAL/Kernel/global_functions_internal_2.h>
 #include <CGAL/Kernel/mpl.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template < class K >
 typename K::Boolean
@@ -49,6 +49,15 @@ operator!=(const Point_2<K> &p, const Origin& o)
   return p != Point_2<K>(o);
 }
 
+template < class K >
+inline
+Angle
+angle(const Vector_2<K> &u,
+      const Vector_2<K> &v)
+{
+  return internal::angle(u, v, K());
+}
+
 template < class K >
 inline
 Angle
@@ -59,6 +68,17 @@ angle(const Point_2<K> &p,
   return internal::angle(p, q, r, K());
 }
 
+template < class K >
+inline
+Angle
+angle(const Point_2<K> &p,
+      const Point_2<K> &q,
+      const Point_2<K> &r,
+      const Point_2<K> &s)
+{
+  return internal::angle(p, q, r, s, K());
+}
+
 template < class K >
 inline
 typename K::Boolean
@@ -420,6 +440,14 @@ compare_xy(const Point_2<K> &p, const Point_2<K> &q)
   return internal::compare_xy(p, q, K());
 }
 
+template < class K >
+inline
+typename K::Comparison_result
+compare_lexicographically(const Point_2<K> &p, const Point_2<K> &q)
+{
+  return internal::compare_xy(p, q, K());
+}
+
 template < class K >
 inline
 typename K::Comparison_result
@@ -992,6 +1020,6 @@ y_equal(const Point_2<K> &p, const Point_2<K> &q)
   return internal::y_equal(p, q, K());
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif  // CGAL_KERNEL_GLOBAL_FUNCTIONS_2_H
