@@ -3,6 +3,7 @@
 // INRIA Sophia-Antipolis (France), Martin-Luther-University Halle-Wittenberg
 // (Germany), Max-Planck-Institute Saarbruecken (Germany), RISC Linz (Austria),
 // and Tel-Aviv University (Israel).  All rights reserved.
+// Copyright (c) 2010 GeometryFactory Sarl (France)
 //
 // This file is part of CGAL (www.cgal.org); you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public License as
@@ -15,8 +16,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Kernel_23/include/CGAL/Kernel/global_functions_internal_2.h $
-// $Id: global_functions_internal_2.h 51456 2009-08-24 17:10:04Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Kernel_23/include/CGAL/Kernel/global_functions_internal_2.h $
+// $Id: global_functions_internal_2.h 65553 2011-09-26 12:33:57Z lrineau $
 // 
 //
 // Author(s)     : Sylvain Pion
@@ -30,11 +31,24 @@
 // These functions are not documented for now, but could be as some point.
 
 #include <CGAL/basic.h>
+#include <boost/utility/enable_if.hpp>
+#include "boost/mpl/equal_to.hpp"
+#include <boost/mpl/int.hpp>
+#include <boost/mpl/integral_c.hpp>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 namespace internal {
 
+template < class K >
+inline
+typename K::Angle
+angle(const typename K::Vector_2 &u,
+      const typename K::Vector_2 &v, const K& k)
+{
+  return k.angle_2_object()(u, v);
+}
+
 template < class K >
 inline
 typename K::Angle
@@ -45,6 +59,17 @@ angle(const typename K::Point_2 &p,
   return k.angle_2_object()(p, q, r);
 }
 
+template < class K >
+inline
+typename K::Angle
+angle(const typename K::Point_2 &p,
+      const typename K::Point_2 &q,
+      const typename K::Point_2 &r,
+      const typename K::Point_2 &s, const K& k)
+{
+  return k.angle_2_object()(p, q, r, s);
+}
+
 template < class K >
 inline
 typename K::Boolean
@@ -253,6 +278,37 @@ compare_angle_with_x_axis(const typename K::Direction_2& d1,
   return k.compare_angle_with_x_axis_2_object()(d1, d2);
 }
 
+template <class K, class T1, class T2, class T3>
+inline
+typename boost::enable_if<
+  boost::mpl::equal_to<boost::mpl::integral_c<int, 
+                                              Ambient_dimension<T1>::type::value>,
+                       boost::mpl::integral_c<int, 2> >,
+  typename K::Comparison_result>
+::type
+compare_distance(const T1 &o1,
+                 const T2 &o2,
+                 const T3 &o3, const K& k)
+{
+  return k.compare_distance_2_object()(o1, o2, o3);
+}
+
+template <class K, class T1, class T2, class T3, class T4>
+inline
+typename boost::enable_if<
+  boost::mpl::equal_to<boost::mpl::integral_c<int, 
+                                              Ambient_dimension<T1>::type::value>,
+                       boost::mpl::integral_c<int, 2> >,
+  typename K::Comparison_result>
+::type
+compare_distance(const T1 &o1,
+                 const T2 &o2,
+                 const T3 &o3,
+                 const T4 &o4, const K& k)
+{
+  return k.compare_distance_2_object()(o1, o2, o3, o4);
+}
+
 template <class K >
 inline
 typename K::Comparison_result
@@ -873,6 +929,6 @@ y_equal(const typename K::Point_2 &p,
 
 } // namespace internal
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif  // CGAL_KERNEL_GLOBAL_FUNCTIONS_INTERNAL_2_H
