@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Kernel_d/include/CGAL/Kernel_d/PointHd.h $
-// $Id: PointHd.h 42940 2008-04-17 13:32:52Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Kernel_d/include/CGAL/Kernel_d/PointHd.h $
+// $Id: PointHd.h 56667 2010-06-09 07:37:13Z sloriot $
 // 
 // Author(s)     : Michael Seel
 
@@ -31,7 +31,7 @@
 #include <CGAL/Kernel_d/Aff_transformationHd.h>
 
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 #define PointHd PointHd2
 
 template <class RT, class LA> class PointHd;
@@ -289,7 +289,6 @@ coordinate access and conversions take constant time.  The space
 requirement for points is $O(|p.dimension()|)$.}*/
 
 #undef PointHd 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 #endif // CGAL_POINTHD_H 
 //----------------------- end of file ----------------------------------
-
