@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Kernel_d/include/CGAL/Kernel_d/function_objectsCd.h $
-// $Id: function_objectsCd.h 42940 2008-04-17 13:32:52Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Kernel_d/include/CGAL/Kernel_d/function_objectsCd.h $
+// $Id: function_objectsCd.h 63930 2011-06-07 08:20:54Z sloriot $
 // 
 //
 // Author(s)     : Michael Seel, Kurt Mehlhorn
@@ -34,7 +34,46 @@
 #define CGAL_KD_TRACEN(t) std::cerr << t << std::endl
 #define CGAL_KD_TRACEV(t) std::cerr << #t << " = " << (t) << std::endl
  
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
+
+template <typename K>
+class Compute_coordinateCd {
+  typedef typename K::FT             FT;
+  typedef typename K::Point_d        Point_d;
+  public:
+  typedef FT                         result_type;
+  result_type 
+    operator()(const Point_d& p, int i) const
+  {
+    return p.cartesian(i);
+  }
+};
+
+template <typename K>
+class Point_dimensionCd {
+  typedef typename K::FT             FT;
+  typedef typename K::Point_d        Point_d;
+  public:
+  typedef int                       result_type;
+  result_type 
+    operator()(const Point_d& p) const
+  {
+    return p.dimension();
+  }
+};
+
+template <typename K>
+class Less_coordinateCd {
+  typedef typename K::FT             FT;
+  typedef typename K::Point_d        Point_d;
+  public:
+  typedef bool                       result_type;
+  result_type 
+  operator()(const Point_d& p, const Point_d& q, int i) const
+  {
+    return p.cartesian(i)<q.cartesian(i);
+  }
+};
 
 template <class R>
 struct Lift_to_paraboloidCd {
@@ -149,7 +188,7 @@ template <class ForwardIterator, class OutputIterator>
 OutputIterator operator()(ForwardIterator first, ForwardIterator last, 
   const Point_d& p, OutputIterator result)
 { TUPLE_DIM_CHECK(first,last,Barycentric_coordinates_d);
-  int n = std::distance(first,last); 
+  //int n = std::distance(first,last); //unused variable
   int d = p.dimension();
   typename R::Affine_rank_d affine_rank;
   CGAL_assertion(affine_rank(first,last)==d);
@@ -183,7 +222,7 @@ typedef typename R::LA LA;
 template <class ForwardIterator>
 Orientation operator()(ForwardIterator first, ForwardIterator last)
 { TUPLE_DIM_CHECK(first,last,Orientation_d);
-  int d = std::distance(first,last); 
+  int d = static_cast<int>(std::distance(first,last)); 
   // range contains d points of dimension d-1
   CGAL_assertion_msg(first->dimension() == d-1,
   "Orientation_d: needs first->dimension() + 1 many points.");
@@ -210,7 +249,7 @@ Oriented_side operator()(ForwardIterator first, ForwardIterator last,
                          const Point_d& x)
 { 
   TUPLE_DIM_CHECK(first,last,Side_of_oriented_sphere_d);
-  int d = std::distance(first,last); // |A| contains |d| points
+  int d = static_cast<int>(std::distance(first,last)); // |A| contains |d| points
   CGAL_assertion_msg((d-1 == first->dimension()), 
   "Side_of_oriented_sphere_d: needs first->dimension()+1 many input points.");
   typename LA::Matrix M(d + 1); 
@@ -278,7 +317,7 @@ bool operator()(ForwardIterator first, ForwardIterator last,
                 const Point_d& p)
 {
   TUPLE_DIM_CHECK(first,last,Contained_in_simplex_d);
-  int k = std::distance(first,last); // |A| contains |k| points
+  int k = static_cast<int>(std::distance(first,last)); // |A| contains |k| points
   int d = first->dimension(); 
   CGAL_assertion_code(
     typename R::Affinely_independent_d check_independence; )
@@ -319,7 +358,7 @@ bool operator()(ForwardIterator first, ForwardIterator last,
                 const Point_d& p) 
 {
   TUPLE_DIM_CHECK(first,last,Contained_in_affine_hull_d);
-  int k = std::distance(first,last); // |A| contains |k| points
+  int k = static_cast<int>(std::distance(first,last)); // |A| contains |k| points
   int d = first->dimension(); 
   typename LA::Matrix M(d + 1,k); 
   typename LA::Vector b(d + 1); 
@@ -346,7 +385,7 @@ template <class ForwardIterator>
 int operator()(ForwardIterator first, ForwardIterator last) 
 {
   TUPLE_DIM_CHECK(first,last,Affine_rank_d);
-  int k = std::distance(first,last); // |A| contains |k| points
+  int k = static_cast<int>(std::distance(first,last)); // |A| contains |k| points
   if (k == 0) return -1;
   if (k == 1) return 0; 
   int d = first->dimension();
@@ -369,7 +408,7 @@ typedef typename R::LA LA;
 template <class ForwardIterator> 
 bool operator()(ForwardIterator first, ForwardIterator last) 
 { typename R::Affine_rank_d rank;
-  int n = std::distance(first,last);
+  int n = static_cast<int>(std::distance(first,last));
   return rank(first,last) == n-1;
 }
 };
@@ -393,7 +432,7 @@ template<class ForwardIterator>
 bool operator()(
   ForwardIterator first, ForwardIterator last, const Vector_d& x) 
 { TUPLE_DIM_CHECK(first,last,Contained_in_linear_hull_d);
-  int k = std::distance(first,last); // |A| contains |k| vectors
+  int k = static_cast<int>(std::distance(first,last)); // |A| contains |k| vectors
   int d = first->dimension();
   typename LA::Matrix M(d,k);
   typename LA::Vector b(d); 
@@ -412,7 +451,7 @@ typedef typename R::LA LA;
 template <class ForwardIterator>
 int operator()(ForwardIterator first, ForwardIterator last)
 { TUPLE_DIM_CHECK(first,last,linear_rank);
-  int k = std::distance(first,last); // k vectors
+  int k = static_cast<int>(std::distance(first,last)); // k vectors
   int d = first->dimension(); 
   typename LA::Matrix M(d,k);
   for (int i = 0; i < d  ; i++)
@@ -428,7 +467,7 @@ typedef typename R::LA LA;
 template <class ForwardIterator>
 bool operator()(ForwardIterator first, ForwardIterator last)
 { typename R::Linear_rank_d rank;
-  return rank(first,last) == std::distance(first,last);
+  return rank(first,last) == static_cast<int>(std::distance(first,last));
 }
 };
 
@@ -441,7 +480,7 @@ template <class ForwardIterator, class OutputIterator>
 OutputIterator operator()(ForwardIterator first, ForwardIterator last,
   OutputIterator result)
 { TUPLE_DIM_CHECK(first,last,linear_base);
-  int k = std::distance(first,last); // k vectors
+  int k = static_cast<int>(std::distance(first,last)); // k vectors
   int d = first->dimension();
   typename LA::Matrix M(d,k); 
   for (int j = 0; j < k; ++first, ++j)
@@ -461,6 +500,5 @@ OutputIterator operator()(ForwardIterator first, ForwardIterator last,
 
 
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 #endif //CGAL_FUNCTION_OBJECTSCD_H
-
