@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Kinetic_data_structures/include/CGAL/Kinetic/Regular_triangulation_3.h $
-// $Id: Regular_triangulation_3.h 40832 2007-11-08 00:27:20Z ameyer $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Kinetic_data_structures/include/CGAL/Kinetic/Regular_triangulation_3.h $
+// $Id: Regular_triangulation_3.h 59966 2010-11-29 12:32:22Z lrineau $
 // 
 //
 // Author(s)     : Daniel Russel <drussel@alumni.princeton.edu>
@@ -40,7 +40,7 @@
 #endif                          // initialize a member
 
 
-CGAL_KINETIC_BEGIN_INTERNAL_NAMESPACE
+namespace CGAL { namespace Kinetic { namespace internal {
 
 template <class KD>
 class Regular_3_pop_event: public Delaunay_event_base_3<KD, typename KD::Root_stack>
@@ -249,9 +249,9 @@ struct Regular_triangulation_3_types
 
 };
 
-CGAL_KINETIC_END_INTERNAL_NAMESPACE
+} } } //namespace CGAL::Kinetic::internal
 
-CGAL_KINETIC_BEGIN_NAMESPACE
+namespace CGAL { namespace Kinetic {
 
 /*!
   redundant_cells_ maps each cell with redundant points to the ids of the points in that cell
@@ -435,7 +435,7 @@ protected:
   typedef internal::Delaunay_triangulation_base_3<Base_traits, Delaunay_visitor> KDel;
 
   CGAL_KINETIC_DECLARE_LISTENERS(typename TraitsT::Simulator,
-				 typename Traits::Active_points_3_table);
+				 typename Traits::Active_points_3_table)
 
 public:
   
@@ -781,7 +781,6 @@ public:
 	     it != redundant_cells_.end(); ++it) {
 	  CGAL_LOG(Log::LOTS, "On init " << it->second 
 			   << " is redundant" << std::endl);
-	  typename Triangulation::Cell_handle h= it->first;
 	  CGAL_precondition(redundant_points_[it->second]==Event_key());
 	  handle_redundant(it->second, it->first);
 	}
@@ -855,7 +854,6 @@ protected:
 	  CGAL_assertion(vit->info() != Event_key() || !k.is_valid());
 	}
 	else {
-	  CGAL_assertion_code(Point_key k= vit->point());
 	  CGAL_assertion(vit->info() == Event_key());
 	}
 	CGAL_assertion(redundant_points_.find(vit->point())== redundant_points_.end());
@@ -891,13 +889,13 @@ protected:
 protected:
   //! also much check for vertex_events
   void flip(const typename Triangulation::Edge &edge) {
-    typename Triangulation::Facet f= kdel_.flip(edge);
+    kdel_.flip(edge);
 
     on_geometry_changed();
   }
 
   void flip(const typename KDel::Facet &flip_facet) {
-    typename Triangulation::Edge edge=  kdel_.flip(flip_facet);
+    kdel_.flip(flip_facet);
 
     on_geometry_changed();
   }
@@ -1205,7 +1203,7 @@ std::ostream &operator<<(std::ostream &out, const Regular_triangulation_3<Traits
 }
 
 
-CGAL_KINETIC_END_NAMESPACE
+} } //namespace CGAL::Kinetic
 
 #if defined(BOOST_MSVC)
 #  pragma warning(pop)
