@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Kinetic_data_structures/include/CGAL/Kinetic/internal/Kernel/Cartesian_moving_point_2.h $
-// $Id: Cartesian_moving_point_2.h 39777 2007-08-08 15:30:58Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Kinetic_data_structures/include/CGAL/Kinetic/internal/Kernel/Cartesian_moving_point_2.h $
+// $Id: Cartesian_moving_point_2.h 56668 2010-06-09 08:45:58Z sloriot $
 // 
 //
 // Author(s)     : Daniel Russel <drussel@alumni.princeton.edu>
@@ -24,7 +24,7 @@
 #include <iostream>
 #include <CGAL/Point_2.h>
 
-CGAL_KINETIC_BEGIN_INTERNAL_NAMESPACE;
+namespace CGAL { namespace Kinetic { namespace internal {
 
 template <class Coordinate_t>
 class Cartesian_moving_point_2
@@ -192,9 +192,9 @@ std::istream &operator>>(std::istream &in,
 }
 
 
-CGAL_KINETIC_END_INTERNAL_NAMESPACE
+} } } //namespace CGAL::Kinetic::internal
 
-CGAL_KINETIC_BEGIN_NAMESPACE
+namespace CGAL { namespace Kinetic {
 
 /*template <>
   template <class Coord, class SK>
@@ -212,5 +212,5 @@ CGAL_KINETIC_BEGIN_NAMESPACE
   arg.y()(P::time()));
   }
   };*/
-CGAL_KINETIC_END_NAMESPACE
+} } //namespace CGAL::Kinetic
 #endif
