@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Largest_empty_rect_2/include/CGAL/Largest_empty_iso_rectangle_2.h $
-// $Id: Largest_empty_iso_rectangle_2.h 41722 2008-01-20 21:28:50Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Largest_empty_rect_2/include/CGAL/Largest_empty_iso_rectangle_2.h $
+// $Id: Largest_empty_iso_rectangle_2.h 64639 2011-07-06 11:41:06Z lrineau $
 // 
 //
 // Author(s)     : Eli Packer (algorithm), Andreas Fabri (cgal conformance)
@@ -32,7 +32,7 @@
 #include <CGAL/Iterator_project.h>
 #include <CGAL/function_objects.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 /*!
   Largest_empty_iso_rectangle_2 is a class that implements the largest
@@ -548,21 +548,21 @@ private:
       --iter;
   }
 
-  void determine_first_two_iters(typename Point_data_set_of_y::iterator &iter1,
-				 typename Point_data_set_of_y::iterator &iter2,
-				 typename Point_data_set_of_y::iterator &iter3,
-				 bool &first_iter_is_right,
-				 bool &second_iter_is_right,
-				 bool &third_iter_is_right)
+  void determine_first_two_iters(typename Point_data_set_of_y::iterator& iter1,
+				 typename Point_data_set_of_y::iterator& iter2,
+				 typename Point_data_set_of_y::iterator& iter3,
+				 bool& first_iter_is_right,
+				 bool& second_iter_is_right,
+				 bool& third_iter_is_right)
   {
-    if(first_iter_is_right) {
-      if(second_iter_is_right) {
+    if (first_iter_is_right) {
+      if (second_iter_is_right) {
         iter1 = iter2;
         iter2 = iter3;
         first_iter_is_right = second_iter_is_right;
         second_iter_is_right = third_iter_is_right;
       } else {
-        if(third_iter_is_right) {
+        if (third_iter_is_right) {
           iter1 = iter2;
           iter2 = iter3;
           first_iter_is_right = second_iter_is_right;
@@ -573,8 +573,8 @@ private:
         }
       }
     } else {
-      if(second_iter_is_right) {
-        if(third_iter_is_right) {
+      if (second_iter_is_right) {
+        if (third_iter_is_right) {
           iter2 = iter3;
           second_iter_is_right = third_iter_is_right;  
         } else {
@@ -1180,8 +1180,14 @@ template<class T>
 void 
 Largest_empty_iso_rectangle_2<T>::phase_3()
 {
-  bool first_iter_is_right = true, second_iter_is_right = true; // init for compiler warning
-  bool third_iter_is_right, first_exist,second_exist,third_exist;
+  // init for compiler warning
+  bool first_iter_is_right(true);
+  bool second_iter_is_right(true);
+  bool third_iter_is_right(true);
+  bool first_exist(true);
+  bool second_exist(true);
+  bool third_exist(true);
+  
   typename Point_data_set_of_y::iterator iter, last_iter = y_sorted.end();
   typename Point_data_set_of_y::iterator iter1, iter2, iter3, 
                                 right_iter, left_iter, last = last_iter;
@@ -1415,6 +1421,6 @@ Largest_empty_iso_rectangle_2<T>::clear()
 
 
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_LARGEST_EMPTY_ISO_RECTANGLE_2_H
