@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Number_types/include/CGAL/Lazy_exact_nt.h $
-// $Id: Lazy_exact_nt.h 53026 2009-11-14 11:49:52Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Number_types/include/CGAL/Lazy_exact_nt.h $
+// $Id: Lazy_exact_nt.h 63778 2011-05-31 13:03:27Z sloriot $
 //
 //
 // Author(s)     : Sylvain Pion
@@ -39,7 +39,7 @@
 #include <CGAL/Profile_counter.h>
 #include <CGAL/Lazy.h>
 
-// #include <CGAL/Root_of_traits.h> // TODO
+#include <CGAL/Sqrt_extension_fwd.h>
 
 /*
  * This file contains the definition of the number type Lazy_exact_nt<ET>,
@@ -87,7 +87,7 @@
  * - .rafine_approx()   ??
  */
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template <class NT> class Lazy_exact_nt;
 
@@ -117,7 +117,7 @@ struct Lazy_exact_Int_Cst : public Lazy_exact_nt_rep<ET>
   Lazy_exact_Int_Cst (int i)
       : Lazy_exact_nt_rep<ET>(double(i)) {}
 
-  void update_exact()  { this->et = new ET((int)this->approx().inf()); }
+  void update_exact() const { this->et = new ET((int)this->approx().inf()); }
 };
 
 // double constant
@@ -127,7 +127,7 @@ struct Lazy_exact_Cst : public Lazy_exact_nt_rep<ET>
   Lazy_exact_Cst (double d)
       : Lazy_exact_nt_rep<ET>(d) {}
 
-  void update_exact()  { this->et = new ET(this->approx().inf()); }
+  void update_exact() const { this->et = new ET(this->approx().inf()); }
 };
 
 // Exact constant
@@ -140,14 +140,14 @@ struct Lazy_exact_Ex_Cst : public Lazy_exact_nt_rep<ET>
     this->et = new ET(e);
   }
 
-  void update_exact()  { CGAL_error(); }
+  void update_exact() const { CGAL_error(); }
 };
 
 // Construction from a Lazy_exact_nt<ET1> (which keeps the lazyness).
 template <typename ET, typename ET1>
 class Lazy_lazy_exact_Cst : public Lazy_exact_nt_rep<ET>
 {
-  Lazy_exact_nt<ET1> l;
+  mutable Lazy_exact_nt<ET1> l;
 
 public:
 
@@ -157,14 +157,14 @@ public:
     this->set_depth(l.depth() + 1);
   }
 
-  void update_exact()
+  void update_exact() const
   {
     this->et = new ET(l.exact());
-    this->approx() = l.approx();
+    this->at = l.approx();
     prune_dag();
   }
 
-  void prune_dag() { l = Lazy_exact_nt<ET1>(); }
+  void prune_dag() const { l = Lazy_exact_nt<ET1>(); }
 };
 
 
@@ -175,7 +175,7 @@ public:
 template <typename ET>
 struct Lazy_exact_unary : public Lazy_exact_nt_rep<ET>
 {
-  Lazy_exact_nt<ET> op1;
+  mutable Lazy_exact_nt<ET> op1;
 
   Lazy_exact_unary (const Interval_nt<false> &i, const Lazy_exact_nt<ET> &a)
       : Lazy_exact_nt_rep<ET>(i), op1(a)
@@ -183,7 +183,7 @@ struct Lazy_exact_unary : public Lazy_exact_nt_rep<ET>
     this->set_depth(op1.depth() + 1);
   }
 
-  void prune_dag() { op1 = Lazy_exact_nt<ET>(); }
+  void prune_dag() const { op1 = Lazy_exact_nt<ET>(); }
 
 #ifdef CGAL_LAZY_KERNEL_DEBUG
   void
@@ -202,8 +202,8 @@ struct Lazy_exact_unary : public Lazy_exact_nt_rep<ET>
 template <typename ET, typename ET1 = ET, typename ET2 = ET>
 struct Lazy_exact_binary : public Lazy_exact_nt_rep<ET>
 {
-  Lazy_exact_nt<ET1> op1;
-  Lazy_exact_nt<ET2> op2;
+  mutable Lazy_exact_nt<ET1> op1;
+  mutable Lazy_exact_nt<ET2> op2;
 
   Lazy_exact_binary (const Interval_nt<false> &i,
 		     const Lazy_exact_nt<ET1> &a, const Lazy_exact_nt<ET2> &b)
@@ -212,7 +212,7 @@ struct Lazy_exact_binary : public Lazy_exact_nt_rep<ET>
     this->set_depth((std::max)(op1.depth(), op2.depth()) + 1);
   }
 
-  void prune_dag()
+  void prune_dag() const
   {
     op1 = Lazy_exact_nt<ET1>();
     op2 = Lazy_exact_nt<ET2>();
@@ -245,11 +245,11 @@ struct NAME : public Lazy_exact_unary<ET>                                \
   NAME (const Lazy_exact_nt<ET> &a)                                      \
       : Lazy_exact_unary<ET>((P(), OP(a.approx())), a) {}                \
                                                                          \
-  void update_exact()                                                    \
+  void update_exact() const                                              \
   {                                                                      \
     this->et = new ET(OP(this->op1.exact()));                            \
     if (!this->approx().is_point())                                      \
-      this->approx() = CGAL_NTS to_interval(*(this->et));                \
+      this->at = CGAL_NTS to_interval(*(this->et));                      \
     this->prune_dag();                                                   \
    }                                                                     \
 };
@@ -268,11 +268,11 @@ struct NAME : public Lazy_exact_binary<ET, ET1, ET2>                     \
   NAME (const Lazy_exact_nt<ET1> &a, const Lazy_exact_nt<ET2> &b)        \
     : Lazy_exact_binary<ET, ET1, ET2>((P(), a.approx() OP b.approx()), a, b) {} \
                                                                          \
-  void update_exact()                                                    \
+  void update_exact() const                                              \
   {                                                                      \
     this->et = new ET(this->op1.exact() OP this->op2.exact());           \
     if (!this->approx().is_point())                                      \
-      this->approx() = CGAL_NTS to_interval(*(this->et));                \
+      this->at = CGAL_NTS to_interval(*(this->et));                      \
     this->prune_dag();                                                   \
    }                                                                     \
 };
@@ -287,12 +287,13 @@ template <typename ET>
 struct Lazy_exact_Min : public Lazy_exact_binary<ET>
 {
   Lazy_exact_Min (const Lazy_exact_nt<ET> &a, const Lazy_exact_nt<ET> &b)
-    : Lazy_exact_binary<ET>((min)(a.approx(), b.approx()), a, b) {}
+    : Lazy_exact_binary<ET>((CGAL::min)(a.approx(), b.approx()), a, b) {}
 
-  void update_exact()
+  void update_exact() const
   {
-    this->et = new ET((min)(this->op1.exact(), this->op2.exact()));
-    if (!this->approx().is_point()) this->approx() = CGAL_NTS to_interval(*(this->et));
+    this->et = new ET((CGAL::min)(this->op1.exact(), this->op2.exact()));
+    if (!this->approx().is_point()) 
+      this->at = CGAL_NTS to_interval(*(this->et));
     this->prune_dag();
   }
 };
@@ -302,12 +303,13 @@ template <typename ET>
 struct Lazy_exact_Max : public Lazy_exact_binary<ET>
 {
   Lazy_exact_Max (const Lazy_exact_nt<ET> &a, const Lazy_exact_nt<ET> &b)
-    : Lazy_exact_binary<ET>((max)(a.approx(), b.approx()), a, b) {}
+    : Lazy_exact_binary<ET>((CGAL::max)(a.approx(), b.approx()), a, b) {}
 
-  void update_exact()
+  void update_exact() const
   {
-    this->et = new ET((max)(this->op1.exact(), this->op2.exact()));
-    if (!this->approx().is_point()) this->approx() = CGAL_NTS to_interval(*(this->et));
+    this->et = new ET((CGAL::max)(this->op1.exact(), this->op2.exact()));
+    if (!this->approx().is_point()) 
+      this->at = CGAL_NTS to_interval(*(this->et));
     this->prune_dag();
   }
 };
@@ -352,7 +354,13 @@ public :
     : Base(new Lazy_exact_Ex_Cst<ET>(e)){}
 
   template <class ET1>
-  Lazy_exact_nt (const Lazy_exact_nt<ET1> &x)
+  Lazy_exact_nt (const Lazy_exact_nt<ET1> &x,
+      typename boost::enable_if<is_implicit_convertible<ET1,ET>,int>::type=0)
+    : Base(new Lazy_lazy_exact_Cst<ET, ET1>(x)){}
+
+  template <class ET1>
+  explicit Lazy_exact_nt (const Lazy_exact_nt<ET1> &x,
+  typename boost::disable_if<is_implicit_convertible<ET1,ET>,int>::type=0)
     : Base(new Lazy_lazy_exact_Cst<ET, ET1>(x)){}
 
   Self operator+ () const
@@ -853,6 +861,21 @@ struct Div_selector< NT, Null_functor > {
   typedef Null_functor Div;
 };
 
+template< class NT, class Functor >
+struct Inverse_selector {
+  struct Inverse  {
+    typedef NT result_type;
+    NT operator()( const NT& x ) const {
+      return NT( 1 ) / x ;
+    }
+  };
+};
+
+template< class NT >
+struct Inverse_selector< NT, Null_functor > {
+  typedef Null_functor Inverse;
+};
+
 template< class NT, class Functor >
 struct Mod_selector {
   struct Mod : public std::binary_function<NT, NT, NT > {
@@ -961,6 +984,9 @@ public:
 
     typedef typename INTERN_LAZY_EXACT_NT::Div_mod_selector
     <Lazy_exact_nt<ET>, typename AST_ET::Div_mod > ::Div_mod Div_mod;
+    
+    typedef typename INTERN_LAZY_EXACT_NT::Inverse_selector
+    <Lazy_exact_nt<ET>, typename AST_ET::Inverse > ::Inverse Inverse;    
 };
 
 
@@ -1100,6 +1126,7 @@ public:
 
 
 CGAL_DEFINE_COERCION_TRAITS_FOR_SELF_TEM(Lazy_exact_nt<ET>, class ET)
+CGAL_DEFINE_COERCION_TRAITS_FROM_TO_TEM(ET,Lazy_exact_nt<ET>,class ET)
 
 template<class ET1, class ET2 >
 struct Coercion_traits< Lazy_exact_nt<ET1>, Lazy_exact_nt<ET2> >
@@ -1204,8 +1231,15 @@ struct Min <Lazy_exact_nt<ET> >
 
     Lazy_exact_nt<ET> operator()( const Lazy_exact_nt<ET>& x, const Lazy_exact_nt<ET>& y) const
     {
-        CGAL_PROFILER(std::string("calls to    : ") + std::string(CGAL_PRETTY_FUNCTION));
-        return new Lazy_exact_Min<ET>(x, y);
+      if (x.identical(y)){
+        return x;
+      }
+      Uncertain<bool> res = x.approx() < y.approx();
+      if(is_certain(res)){
+        return res.make_certain() ? x : y;
+      }
+      CGAL_PROFILER(std::string("calls to    : ") + std::string(CGAL_PRETTY_FUNCTION));
+      return new Lazy_exact_Min<ET>(x, y);
     }
 };
 
@@ -1215,6 +1249,13 @@ struct Max <Lazy_exact_nt<ET> >
 
     Lazy_exact_nt<ET> operator()( const Lazy_exact_nt<ET>& x, const Lazy_exact_nt<ET>& y) const
     {
+      if (x.identical(y)){
+        return x;
+      }
+      Uncertain<bool> res = x.approx() > y.approx();
+      if(is_certain(res)){
+        return  res.make_certain() ? x : y;
+      }
         CGAL_PROFILER(std::string("calls to    : ") + std::string(CGAL_PRETTY_FUNCTION));
         return new Lazy_exact_Max<ET>(x, y);
     }
@@ -1265,6 +1306,7 @@ struct NT_converter < Lazy_exact_nt<ET>, ET >
   { return a.exact(); }
 };
 
+namespace internal {
 // Returns true if the value is representable by a double and to_double()
 // would return it.  False means "don't know" (the exact number type is not
 // queried).
@@ -1273,95 +1315,11 @@ inline bool
 fit_in_double(const Lazy_exact_nt<ET>& l, double& r)
 { return fit_in_double(l.approx(), r); }
 
+} // namespace internal
 
-// We create a type of new node in Lazy_exact_nt's DAG
-// for the make_root_of_2() operation.
-
-template <typename ET >
-struct Lazy_exact_ro2
-  : public Lazy_exact_nt_rep< typename Root_of_traits<ET>::RootOf_2 >
-{
-    typedef typename Root_of_traits<ET>::RootOf_2   RO2;
-    typedef Lazy_exact_nt_rep<RO2>                  Base;
-    typedef typename Base::AT::Protector            P;
-
-
-    mutable Lazy_exact_nt<ET> op1, op2, op3;
-    bool smaller;
-    bool old_rep;//if the rep=true then representation with polynomial coeff, else alpha, beta, gamma
-
-
-    Lazy_exact_ro2 (const Lazy_exact_nt<ET> &a,
-                    const Lazy_exact_nt<ET> &b,
-                    const Lazy_exact_nt<ET> &c, bool s)
-      : Base((P(), make_root_of_2(a.approx(), b.approx(), c.approx(), s))),
-        op1(a), op2(b), op3(c), smaller(s), old_rep(true) {}
-
-    Lazy_exact_ro2 (const Lazy_exact_nt<ET> &a,
-                    const Lazy_exact_nt<ET> &b,
-                    const Lazy_exact_nt<ET> &c)
-      : Base((P(), make_root_of_2(a.approx(), b.approx(), c.approx()))),
-        op1(a), op2(b), op3(c), smaller(true), old_rep(false) {}
-
-    void update_exact()
-    {
-        if (old_rep)
-          this->et = new RO2(make_root_of_2(op1.exact(), op2.exact(),
-                                            op3.exact(), smaller));
-        else
-          this->et = new RO2(make_root_of_2(op1.exact(), op2.exact(),
-                                            op3.exact()));
-        if (!this->approx().is_point())
-            this->at = to_interval(*(this->et));
-        this->prune_dag();
-
-    }
-
-    void prune_dag() const
-    {
-        op1 = op2 = op3 = Lazy_exact_nt<ET>();
-    }
-};
-
-template <typename NT >
-struct Root_of_traits< Lazy_exact_nt < NT > >
-{
-private:
-    typedef Root_of_traits<NT> T;
-public:
-    typedef Root_of_traits< Lazy_exact_nt < NT > > Base;
-    typedef Lazy_exact_nt< typename T::RootOf_1 > RootOf_1;
-    typedef Lazy_exact_nt< typename T::RootOf_2 > RootOf_2;
-    typedef RootOf_2 Root_of_2;
-    typedef RootOf_1 Root_of_1;
-    struct Make_root_of_2{
-        typedef RootOf_2 result_type;
-        Root_of_2
-        operator()(const Lazy_exact_nt<NT>& a, const Lazy_exact_nt<NT>& b, const Lazy_exact_nt<NT>& c) const{
-            return new Lazy_exact_ro2<NT>(a, b, c);
-        };
-        RootOf_2
-        operator()(const Lazy_exact_nt<NT>& a, const Lazy_exact_nt<NT>& b, const Lazy_exact_nt<NT>& c, bool smaller) const{
-          return new Lazy_exact_ro2<NT>(a, b, c, smaller);
-        };
-    };
-
-};
-
-
-//these two functions for test suite requirement
-template < typename RT >
-typename CGAL::Root_of_traits<CGAL::Lazy_exact_nt<RT> >::RootOf_2 make_sqrt(const CGAL::Lazy_exact_nt< RT> & r)
-{
-  typedef Lazy_exact_nt< RT> TT;
-  CGAL_assertion(r >= 0);
-  if(CGAL_NTS is_zero(r)) return make_root_of_2((TT) 1,(TT) 0,(TT) 0);
-  return make_root_of_2((TT) 1,(TT) 0,-r,false);
-}
-
-template < typename RT >
+template <class NT_,class ROOT_, class ACDE_TAG_, class FP_TAG>
 void
-print(std::ostream &os, const CGAL::Lazy_exact_nt< Root_of_2<RT> > &r)
+print(std::ostream &os, const CGAL::Lazy_exact_nt< Sqrt_extension<NT_,ROOT_,ACDE_TAG_,FP_TAG> > &r)
 {
   print(os,r.exact());
 }
@@ -1410,6 +1368,6 @@ class Modular_traits<Lazy_exact_nt<ET> >
 #undef CGAL_int
 #undef CGAL_To_interval
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_LAZY_EXACT_NT_H
