@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Minkowski_sum_2/include/CGAL/Minkowski_sum_2/Minkowski_sum_conv_2.h $
-// $Id: Minkowski_sum_conv_2.h 45567 2008-09-16 06:57:00Z ophirset $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Minkowski_sum_2/include/CGAL/Minkowski_sum_2/Minkowski_sum_conv_2.h $
+// $Id: Minkowski_sum_conv_2.h 64639 2011-07-06 11:41:06Z lrineau $
 //
 // Author(s)     : Ron Wein   <wein@post.tau.ac.il>
 
@@ -24,7 +24,7 @@
 #include <CGAL/Minkowski_sum_2/Arr_labeled_traits_2.h>
 #include <CGAL/Minkowski_sum_2/Union_of_segment_cycles_2.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 /*! \class
  * A class for computing the Minkowski sum of two simple polygons based on the
@@ -110,7 +110,7 @@ private:
 
   // Traits-related types:
   typedef Arr_segment_traits_2<Kernel>                    Segment_traits_2;
-  typedef Arr_labeled_traits_2<Segment_traits_2>          Traits_2; 
+  typedef Arr_labeled_traits_2<Segment_traits_2>          Traits_2;
 
   typedef typename Segment_traits_2::X_monotone_curve_2   Segment_2;
   typedef typename Traits_2::X_monotone_curve_2           Labeled_segment_2;
@@ -197,7 +197,7 @@ public:
     std::vector<Direction_2>  dirs2 (n2);
     Vertex_circulator         prev2, curr2, next2;
     Vertex_ref                bottom_left;
-    bool                      is_convex2 = true;
+    // bool                      is_convex2 = true;
     std::list<Vertex_ref>     reflex_vertices;
     unsigned int              k2;
     
@@ -223,7 +223,7 @@ public:
       if (f_orientation (*prev2, *curr2, *next2) == RIGHT_TURN)
       {
         // We found a reflex vertex.
-        is_convex2 = false;
+        // is_convex2 = false;
         reflex_vertices.push_back (Vertex_ref (curr2, k2));
       }
 
@@ -521,7 +521,7 @@ private:
     } while (k1 != first1 || k2 != first2); 
 
     CGAL_assertion (f_equal (curr_pt, first_pt));
-
+    
     // Before moving un-necessary sub-cycles from the segment list, make sure
     // the list contains no "cyclic" sub-cylces. We do that by making sure that
     // the first and last segments of the list correspond to traversals of
@@ -670,16 +670,14 @@ private:
     if (reduced_cycle)
     {
       seg_index = 0;
-      for (curr = cycle.begin(); curr != cycle.end(); ++curr, ++seg_index)
-        cycle.back().label().set_index (seg_index);
+      for (curr = cycle.begin(); curr != cycle.end(); ++curr)
+        curr->label().set_index (seg_index++);
     }
-
     cycle.back().label().set_flag (true);
     return;
   }
 };
 
-
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
