@@ -11,15 +11,16 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.3-branch/Nef_2/include/CGAL/Nef_2/geninfo.h $
-// $Id: geninfo.h 28567 2006-02-16 14:30:13Z lsaboret $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Nef_2/include/CGAL/Nef_2/geninfo.h $
+// $Id: geninfo.h 61485 2011-03-02 18:52:57Z sloriot $
 // 
 //
 // Author(s)     : Michael Seel <seel@mpi-sb.mpg.de>
 
-#ifndef GENINFO_H
-#define GENINFO_H
+#ifndef CGAL_NEF_2_GENINFO_H
+#define CGAL_NEF_2_GENINFO_H
 
+#include <CGAL/config.h>
 #include <memory>
 
 /*{\Moptions outfile=geninfo.man}*/
@@ -41,10 +42,7 @@ misuse memory problems occur.}*/
 
 /*{\Moperations 2 1}*/
 
-#ifdef __BORLANDC__
-#pragma option -w-rch -w-eff -w-ccc
-#endif
-
+  #ifdef CGAL_USE_FORMER_GENINFO
   static void create(GenPtr& p) 
   /*{\Mstatic create a slot for an object of type |T| referenced 
     via |p|.}*/
@@ -75,6 +73,16 @@ misuse memory problems occur.}*/
     if (sizeof(T) >  sizeof(GenPtr)) delete (T*) p;
     p=0;
   }
+  #else //CGAL_USE_FORMER_GENINFO
+  static void create(GenPtr& p)  { p = (GenPtr) new T; }
+  static T& access(GenPtr& p)  { return *(T*)p;  }
+  static const T& const_access(const GenPtr& p) 
+  { return *(const T*)p;   }
+  static void clear(GenPtr& p){ 
+    delete (T*) p;
+    p=0;
+  }
+  #endif  //CGAL_USE_FORMER_GENINFO
 
 };
 
@@ -103,5 +111,3 @@ which is used to compile the code and thus the scheme enables platform
 independent programming.}*/
 
 #endif //GENINFO_H
-
-
