@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Nef_3/include/CGAL/Nef_3/SNC_simplify.h $
-// $Id: SNC_simplify.h 50723 2009-07-20 13:46:03Z hachenb $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Nef_3/include/CGAL/Nef_3/SNC_simplify.h $
+// $Id: SNC_simplify.h 63706 2011-05-27 11:26:40Z sloriot $
 //
 //
 // Author(s)     : Peter Hachenberger <hachenberger@mpi-sb.mpg.de>
@@ -29,7 +29,7 @@
 #define CGAL_NEF_DEBUG 41
 #include <CGAL/Nef_2/debug.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template<typename SNC_structure>
 class SNC_simplify_base : public SNC_decorator<SNC_structure> {
@@ -292,32 +292,6 @@ class SNC_simplify_base : public SNC_decorator<SNC_structure> {
     return simplified;
   }
 
-  bool vertex_on_facet_simplification() {
-    simplified = false;
-
-    Vertex_iterator v = (*this->sncp()).vertices_begin();
-    while( v != (*this->sncp()).vertices_end()) {
-      Vertex_iterator v_next(v);
-      ++v_next;
-      simplify_redundant_vertex_on_facet(v);
-      v = v_next;
-    }
-    return simplified;
-  }
-
-  bool vertex_on_edge_simplification() {
-    simplified = false;
-
-    Vertex_iterator v = (*this->sncp()).vertices_begin();
-    while( v != (*this->sncp()).vertices_end()) {
-      Vertex_iterator v_next(v);
-      ++v_next;
-      simplify_redundant_vertex_on_edge(v);
-      v = v_next;
-    }
-    return simplified;
-  }
-
   bool vertex_simplification(bool snc_computed = true) {
     simplified = false;
 
@@ -616,7 +590,22 @@ class SNC_simplify_base : public SNC_decorator<SNC_structure> {
     SHalfloop_handle sl;
     CGAL_forall_shalfloops(sl, *this->sncp()) {
       SM_decorator SD(&*sl->incident_sface()->center_vertex());
-      SD.store_sm_boundary_object( sl, sl->incident_sface());
+      //I added the following 'if' because even if the map has been cleared, when merging edges
+      //if one sloop is created and the vertex not simplified, then the map is updated.
+      //In the example below, the edge e is removed and a sloop is create on the sphere map
+      //of a vertex v. But since three edges are still incident to v, v is not simplified. 
+      //There is one point where the distance between two non-edge-adjacent facets is 0.
+      //
+      //      |               |
+      // |    |  \  |  / |    |
+      // |    /   \ | /  |    /
+      // |   /     \|/   |   /
+      // |  /      /     |  /
+      // | /      / e    | /
+      // |/______/_______|/
+      //   
+      if (!SD.map()->is_sm_boundary_object(sl)) 
+        SD.store_sm_boundary_object( sl, sl->incident_sface());
     }
   }
 
@@ -723,6 +712,8 @@ class SNC_simplify<SNC_indexed_items, SNC_structure>
   typedef typename SNC_structure::SHalfedge_around_facet_circulator 
                                   SHalfedge_around_facet_circulator;
 
+  using Base::is_part_of_edge;
+
  public:
   SNC_simplify(SNC_structure& sncs) : Base(sncs) {}
 
@@ -773,5 +764,5 @@ class SNC_simplify<SNC_indexed_items, SNC_structure>
   }
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 #endif // CGAL_SNC_STRUCTURE_H
