@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Nef_S2/include/CGAL/Nef_S2/SM_point_locator.h $
-// $Id: SM_point_locator.h 45448 2008-09-09 16:03:25Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Nef_S2/include/CGAL/Nef_S2/SM_point_locator.h $
+// $Id: SM_point_locator.h 63822 2011-06-01 13:47:17Z sloriot $
 // 
 //
 // Author(s)     : Michael Seel <seel@mpi-sb.mpg.de>
@@ -30,7 +30,7 @@
 #include <CGAL/Nef_2/debug.h>
 
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 /*{\Moptions print_title=yes }*/ 
 
@@ -94,6 +94,7 @@ public:
   typedef typename Decorator_traits::SHalfloop_handle     SHalfloop_handle;   
   typedef typename Decorator_traits::SFace_handle         SFace_handle;     
 
+
   typedef typename Decorator_traits::SVertex_iterator     SVertex_iterator;
   typedef typename Decorator_traits::SHalfedge_iterator   SHalfedge_iterator;
   typedef typename Decorator_traits::SHalfloop_iterator   SHalfloop_iterator;
@@ -104,6 +105,10 @@ public:
   typedef typename Decorator_traits::SHalfedge_around_sface_circulator
                                      SHalfedge_around_sface_circulator;
 
+  using Base::cyclic_adj_succ;
+  using Base::is_isolated;
+  using Base::first_out_edge;
+
   Sphere_segment segment(SHalfedge_handle e) const
   { return Sphere_segment(e->source()->point(), e->twin()->source()->point(), e->circle()); }
 
@@ -314,6 +319,7 @@ public:
     return Object_handle(); // never reached!
   }
 
+#if 0 //THIS CODE DOES NOT SEEM TO BE USED
   template <typename Object_predicate>
   Object_handle ray_shoot(const Sphere_point& p, 
 			  const Sphere_direction& d,
@@ -330,22 +336,21 @@ public:
   { 
     Sphere_circle c(d.circle());
     Sphere_segment s;
-    bool s_init(false);
     Object_handle h = locate(p);
     SVertex_handle v; 
     SHalfedge_handle e; 
     SHalfloop_handle l; 
     SFace_handle f;
-    if ( CGAL::assign(v,h) && M(v) ||
-         CGAL::assign(e,h) && M(e) ||
-	 CGAL::assign(l,h) && M(l) ||
-         CGAL::assign(f,h) && M(f) ) return h;
+    if ( ( CGAL::assign(v,h) && M(v) ) ||
+         ( CGAL::assign(e,h) && M(e) ) ||
+         ( CGAL::assign(l,h) && M(l) ) ||
+         ( CGAL::assign(f,h) && M(f) ) ) return h;
     h = Object_handle(); 
     CGAL_NEF_TRACEN("not contained");
 #if 0
     HASEN: s am anfang circle, ab wann segment ?
 	   wo loop ?
-
+    bool s_init(false);
     CGAL_forall_svertices (v,*this) {
       Point pv = v->point();
       if ( !(s_init && s.has_on(pv) ||
@@ -399,7 +404,8 @@ public:
     CGAL_error_msg("not yet correct");
     return h;
   }
-
+#endif
+  
   Object_handle ray_shoot(const Sphere_point& p, 
 			  const Sphere_circle& c,
 			  Sphere_point& ip,
@@ -457,8 +463,9 @@ public:
     CGAL_forall_sedges(ei,*this) {
       Sphere_segment se = segment(ei);
       CGAL_NEF_TRACEN("ray_shoot " << s_init);
-      if(s_init)
+      if(s_init) {
 	CGAL_NEF_TRACEN("  " << s.source() << "->" << s.target() << " | " << s.sphere_circle() << " is long " << s.is_long());
+      }
       CGAL_NEF_TRACEN("  " << se.source() << "->" << se.target() << " | " << se.sphere_circle() << " is long " << se.is_long());
 
       // TODO: start-end point of s on se or c
@@ -650,8 +657,5 @@ marks_of_halfspheres(Mark& lower, Mark& upper, int axis) {
   }
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 #endif // CGAL_SM_POINT_LOCATOR_H
-
-
-
