@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Optimisation_basic/include/CGAL/Optimisation/Access_coordinates_begin_d.h $
-// $Id: Access_coordinates_begin_d.h 46260 2008-10-14 08:04:25Z afabri $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Optimisation_basic/include/CGAL/Optimisation/Access_coordinates_begin_d.h $
+// $Id: Access_coordinates_begin_d.h 56667 2010-06-09 07:37:13Z sloriot $
 // 
 //
 // Author(s)     : Sven Schoenherr <sven@inf.ethz.ch>
@@ -25,7 +25,7 @@
 #define CGAL_OPTIMISATION_ACCESS_COORDINATES_BEGIN_D_H
 
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 class Cartesian_tag;
 class Homogeneous_tag;
@@ -74,7 +74,7 @@ public:
     }
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_OPTIMISATION_ACCESS_COORDINATES_BEGIN_D_H
 
