@@ -1,4 +1,4 @@
-// Copyright (c) 2002 Utrecht University (The Netherlands).
+// Copyright (c) 2002,2011 Utrecht University (The Netherlands).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Spatial_searching/include/CGAL/Orthogonal_incremental_neighbor_search.h $
-// $Id: Orthogonal_incremental_neighbor_search.h 36334 2007-02-15 21:24:48Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Spatial_searching/include/CGAL/Orthogonal_incremental_neighbor_search.h $
+// $Id: Orthogonal_incremental_neighbor_search.h 64637 2011-07-06 11:11:58Z lrineau $
 // 
 //
 // Author(s)     : Hans Tangelder (<hanst@cs.uu.nl>)
@@ -30,7 +30,7 @@
 namespace CGAL {
 
   template <class SearchTraits, 
-            class Distance_= Euclidean_distance<SearchTraits>,
+            class Distance_= typename internal::Spatial_searching_default_distance<SearchTraits>::type,
             class Splitter_ = Sliding_midpoint<SearchTraits>,
             class Tree_= Kd_tree<SearchTraits, Splitter_, Tag_true> >
   class Orthogonal_incremental_neighbor_search {
@@ -50,10 +50,17 @@ namespace CGAL {
     typedef std::vector<Node_with_distance*> Node_with_distance_vector;
     typedef std::vector<Point_with_transformed_distance*> Point_with_transformed_distance_vector;
 
-
+    template<class T>
+    struct Object_wrapper
+    {   
+      T object;
+      Object_wrapper(const T& t):object(t){}
+      const T& operator* () const { return object; }
+      const T* operator-> () const { return &object; }
+    };
 
     class Iterator_implementation {
-
+      SearchTraits traits;
     public:
 
       int number_of_neighbours_computed;
@@ -69,8 +76,6 @@ namespace CGAL {
 
       Query_item query_point;
 
-      int total_item_number;
-
       FT distance_to_root;
 
       bool search_nearest_neighbour;
@@ -127,17 +132,19 @@ namespace CGAL {
     
 
       // constructor
-      Iterator_implementation(Tree& tree, Query_item& q, const Distance& tr,
+      Iterator_implementation(Tree& tree,const Query_item& q, const Distance& tr,
 			      FT Eps=FT(0.0), bool search_nearest=true)
-	: number_of_neighbours_computed(0), number_of_internal_nodes_visited(0), 
+	: traits(tree.traits()),number_of_neighbours_computed(0), number_of_internal_nodes_visited(0), 
 	number_of_leaf_nodes_visited(0), number_of_items_visited(0),
 	Orthogonal_distance_instance(tr), multiplication_factor(Orthogonal_distance_instance.transformed_distance(FT(1.0)+Eps)), 
-	query_point(q), total_item_number(tree.size()), search_nearest_neighbour(search_nearest), 
+	query_point(q), search_nearest_neighbour(search_nearest), 
 	PriorityQueue(Priority_higher(search_nearest)), Item_PriorityQueue(Distance_smaller(search_nearest)),
 	reference_count(1)
 	  
 	  
       {
+        if (tree.empty()) return;
+        
         // if (search_nearest) 
 	distance_to_root=
 	  Orthogonal_distance_instance.min_distance_to_rectangle(q,
@@ -172,10 +179,10 @@ namespace CGAL {
       }
 
       // postfix operator
-      Point_with_transformed_distance 
+      Object_wrapper<Point_with_transformed_distance>
       operator++(int) 
       {
-        Point_with_transformed_distance result = *(Item_PriorityQueue.top());
+        Object_wrapper<Point_with_transformed_distance> result( *(Item_PriorityQueue.top()) );
         ++*this;
         return result;
       }
@@ -200,12 +207,12 @@ namespace CGAL {
       //destructor
       ~Iterator_implementation() 
       {
-	while (PriorityQueue.size()>0) {
+	while (!PriorityQueue.empty()) {
 	  Node_with_distance* The_top=PriorityQueue.top();
 	  PriorityQueue.pop();
 	  delete The_top;
 	}
-	while (Item_PriorityQueue.size()>0) {
+	while (!Item_PriorityQueue.empty()) {
 	  Point_with_transformed_distance* The_top=Item_PriorityQueue.top();
 	  Item_PriorityQueue.pop();
 	  delete The_top;
@@ -235,7 +242,7 @@ namespace CGAL {
 	    next_neighbour_found=
 	      (rd < multiplication_factor*Item_PriorityQueue.top()->second);
         }
-	typename SearchTraits::Construct_cartesian_const_iterator_d construct_it;
+	typename SearchTraits::Construct_cartesian_const_iterator_d construct_it=traits.construct_cartesian_const_iterator_d_object();
 	typename SearchTraits::Cartesian_const_iterator_d query_point_it = construct_it(query_point);
         // otherwise browse the tree further
         while ((!next_neighbour_found) && (!PriorityQueue.empty())) {
@@ -344,7 +351,7 @@ namespace CGAL {
 
     // constructor
     Orthogonal_incremental_neighbor_search(Tree& tree,  
-					   Query_item& q, FT Eps = FT(0.0), 
+					   const Query_item& q, FT Eps = FT(0.0), 
 					   bool search_nearest=true, const Distance& tr=Distance()) 
       : start(tree,q,tr,Eps,search_nearest),
         past_the_end()
@@ -376,7 +383,7 @@ namespace CGAL {
 
     public:
 
-      typedef std::forward_iterator_tag iterator_category;
+      typedef std::input_iterator_tag iterator_category;
       typedef Point_with_transformed_distance       value_type;
       typedef Point_with_transformed_distance*      pointer;
       typedef const Point_with_transformed_distance&      reference;
@@ -402,7 +409,7 @@ namespace CGAL {
       }
 
       // constructor
-      iterator(Tree& tree, Query_item& q, const Distance& tr=Distance(), FT eps=FT(0.0), 
+      iterator(Tree& tree,const Query_item& q, const Distance& tr=Distance(), FT eps=FT(0.0), 
 	       bool search_nearest=true)
 	: Ptr_implementation(new Iterator_implementation(tree, q, tr, eps, search_nearest))
 	{}
@@ -414,11 +421,31 @@ namespace CGAL {
         if (Ptr_implementation != 0) Ptr_implementation->reference_count++;
       }
 
+      iterator& operator=(const iterator& Iter)
+      {
+        if (Ptr_implementation != Iter.Ptr_implementation){
+          if (Ptr_implementation != 0 && --(Ptr_implementation->reference_count)==0) {
+              delete Ptr_implementation;
+          }
+          Ptr_implementation = Iter.Ptr_implementation;
+          if (Ptr_implementation != 0) Ptr_implementation->reference_count++;
+        }
+        return *this;
+      }      
+      
+      
       const Point_with_transformed_distance& 
       operator* () const 
       {
 	return *(*Ptr_implementation);
       }
+      
+      // -> operator
+      const Point_with_transformed_distance*
+      operator-> () const 
+      {
+	return &*(*Ptr_implementation);
+      }
 
       // prefix operator
       iterator& 
@@ -429,12 +456,10 @@ namespace CGAL {
       }
 
       // postfix operator
-      iterator 
+      Object_wrapper<Point_with_transformed_distance>
       operator++(int) 
       {
-	iterator tmp(*this);
-	++(*this);
-	return tmp;
+	return (*Ptr_implementation)++;
       }
 
 
