@@ -11,11 +11,11 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Apollonius_graph_2/include/CGAL/Parabola_2.h $
-// $Id: Parabola_2.h 42811 2008-04-09 13:35:34Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Apollonius_graph_2/include/CGAL/Parabola_2.h $
+// $Id: Parabola_2.h 63970 2011-06-08 06:31:19Z mkaravel $
 // 
 //
-// Author(s)     : Menelaos Karavelas <mkaravel@cse.nd.edu>
+// Author(s)     : Menelaos Karavelas <mkaravel@iacm.forth.gr>
 
 
 
@@ -25,7 +25,7 @@
 #include <CGAL/determinant.h>
 
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 
 template < class Gt >
@@ -263,7 +263,7 @@ public:
   {
     Point_2 q(CGAL::to_double(p.x()), CGAL::to_double(p.y()));
 
-    FT d = distance(q, c) - fabs(distance(q, l));
+    FT d = distance(q, c) - CGAL::abs(distance(q, l));
     if ( d < 0 )  return ON_NEGATIVE_SIDE;
     if ( d > 0 )  return ON_POSITIVE_SIDE;
     return ON_ORIENTED_BOUNDARY;
@@ -329,6 +329,6 @@ Stream& operator<<(Stream& s, const Parabola_2<Gt> &P)
 
 
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_PARABOLA_2_H
