@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Intersections_2/include/CGAL/Point_2_Iso_rectangle_2_intersection.h $
-// $Id: Point_2_Iso_rectangle_2_intersection.h 51456 2009-08-24 17:10:04Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Intersections_2/include/CGAL/Point_2_Iso_rectangle_2_intersection.h $
+// $Id: Point_2_Iso_rectangle_2_intersection.h 56667 2010-06-09 07:37:13Z sloriot $
 // 
 //
 // Author(s)     : Geert-Jan Giezeman
@@ -29,7 +29,7 @@
 #include <CGAL/Point_2.h>
 #include <CGAL/Object.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 namespace internal {
 
@@ -121,6 +121,6 @@ intersection(const Point_2<K> &pt,
   return Intersect()(pt, iso);
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
