@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Surface_reconstruction_points_3/include/CGAL/Poisson_reconstruction_function.h $
-// $Id: Poisson_reconstruction_function.h 52585 2009-10-16 08:50:48Z stayeb $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Surface_reconstruction_points_3/include/CGAL/Poisson_reconstruction_function.h $
+// $Id: Poisson_reconstruction_function.h 63231 2011-04-29 15:50:56Z lrineau $
 //
 // Author(s)     : Laurent Saboret, Pierre Alliez
 
@@ -38,7 +38,7 @@
 
 #include <boost/shared_ptr.hpp>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 
 /// Given a set of 3D points with oriented normals sampled on the boundary of a 3D solid,
@@ -195,7 +195,7 @@ public:
   /// - solving for operator() at each vertex of the triangulation with a sparse linear solver,
   /// - and shifting and orienting operator() such that it is 0 at all input points and negative inside the inferred surface.
   ///
-  /// @heading Parameters:
+  /// @commentheading Template parameters:
   /// @param SparseLinearAlgebraTraits_d Symmetric definite positive sparse linear solver.
   /// The default solver is TAUCS Multifrontal Supernodal Cholesky Factorization.
   ///
@@ -262,11 +262,10 @@ public:
   {
     m_hint = m_tr->locate(p,m_hint);
 
-    if(m_hint == NULL)
-      return 1e38;
-
-    if(m_tr->is_infinite(m_hint))
-      return 1e38;
+    if(m_tr->is_infinite(m_hint)) {
+      int i = m_hint->index(m_tr->infinite_vertex());
+      return m_hint->vertex((i+1)&3)->f();
+    }
 
     FT a,b,c,d;
     barycentric_coordinates(p,m_hint,a,b,c,d);
@@ -309,7 +308,7 @@ private:
   /// Poisson reconstruction.
   /// Returns false on error.
   ///
-  /// @heading Parameters:
+  /// @commentheading Template parameters:
   /// @param SparseLinearAlgebraTraits_d Symmetric definite positive sparse linear solver.
   template <class SparseLinearAlgebraTraits_d>
   bool solve_poisson(
@@ -342,14 +341,15 @@ private:
     typename SparseLinearAlgebraTraits_d::Matrix A(nb_variables); // matrix is symmetric definite positive
     typename SparseLinearAlgebraTraits_d::Vector X(nb_variables), B(nb_variables);
 
-    Finite_vertices_iterator v;
-    for(v = m_tr->finite_vertices_begin();
-        v != m_tr->finite_vertices_end();
-        v++)
+    Finite_vertices_iterator v, e;
+    for(v = m_tr->finite_vertices_begin(),
+        e = m_tr->finite_vertices_end();
+        v != e;
+        ++v)
     {
       if(!v->constrained())
       {
-        B[v->index()] = div_normalized(v); // rhs -> divergent
+        B[v->index()] = div(v); // rhs -> divergent
         assemble_poisson_row<SparseLinearAlgebraTraits_d>(A,v,B,lambda);
       }
     }
@@ -385,7 +385,7 @@ private:
 
     // copy function's values to vertices
     unsigned int index = 0;
-    for (v = m_tr->finite_vertices_begin(); v != m_tr->finite_vertices_end(); v++)
+    for (v = m_tr->finite_vertices_begin(), e = m_tr->finite_vertices_end(); v!= e; ++v)
       if(!v->constrained())
         v->f() = X[index++];
 
@@ -420,9 +420,10 @@ private:
   FT median_value_at_input_vertices() const
   {
     std::deque<FT> values;
-    Finite_vertices_iterator v;
-    for(v = m_tr->finite_vertices_begin();
-        v != m_tr->finite_vertices_end();
+    Finite_vertices_iterator v, e;
+    for(v = m_tr->finite_vertices_begin(),
+        e= m_tr->finite_vertices_end();
+        v != e; 
         v++)
       if(v->type() == Triangulation::INPUT)
         values.push_back(v->f());
@@ -453,19 +454,20 @@ private:
     const Point& pd = cell->vertex(3)->point();
 
     FT v = volume(pa,pb,pc,pd);
-    a = std::fabs(volume(pb,pc,pd,p) / v);
-    b = std::fabs(volume(pa,pc,pd,p) / v);
-    c = std::fabs(volume(pb,pa,pd,p) / v);
-    d = std::fabs(volume(pb,pc,pa,p) / v);
+    a = CGAL::abs(volume(pb,pc,pd,p) / v);
+    b = CGAL::abs(volume(pa,pc,pd,p) / v);
+    c = CGAL::abs(volume(pb,pa,pd,p) / v);
+    d = CGAL::abs(volume(pb,pc,pa,p) / v);
   }
 
   FT find_sink()
   {
     m_sink = CGAL::ORIGIN;
     FT min_f = 1e38;
-    Finite_vertices_iterator v;
-    for(v = m_tr->finite_vertices_begin();
-        v != m_tr->finite_vertices_end();
+    Finite_vertices_iterator v, e;
+    for(v = m_tr->finite_vertices_begin(),
+        e= m_tr->finite_vertices_end();
+        v != e;
         v++)
     {
       if(v->f() < min_f)
@@ -479,18 +481,20 @@ private:
 
   void shift_f(const FT shift)
   {
-    Finite_vertices_iterator v;
-    for(v = m_tr->finite_vertices_begin();
-        v != m_tr->finite_vertices_end();
+    Finite_vertices_iterator v, e;
+    for(v = m_tr->finite_vertices_begin(),
+        e = m_tr->finite_vertices_end();
+        v!= e;
         v++)
       v->f() += shift;
   }
 
   void flip_f()
   {
-    Finite_vertices_iterator v;
-    for(v = m_tr->finite_vertices_begin();
-        v != m_tr->finite_vertices_end();
+    Finite_vertices_iterator v, e;
+    for(v = m_tr->finite_vertices_begin(),
+          e = m_tr->finite_vertices_end();
+        v != e;
         v++)
       v->f() = -v->f();
   }
@@ -499,7 +503,8 @@ private:
   {
     // TODO: return NULL if none and assert
     std::vector<Vertex_handle> vertices;
-    m_tr->incident_vertices(m_tr->infinite_vertex(),std::back_inserter(vertices));
+    vertices.reserve(32);
+    m_tr->adjacent_vertices(m_tr->infinite_vertex(),std::back_inserter(vertices));
     typename std::vector<Vertex_handle>::iterator it = vertices.begin();
     return *it;
   }
@@ -511,16 +516,15 @@ private:
     v->f() = value;
   }
 
-  // divergent
-  FT div_normalized(Vertex_handle v)
+  // divergent 
+  FT div(Vertex_handle v)
   {
     std::vector<Cell_handle> cells;
+    cells.reserve(32);
     m_tr->incident_cells(v,std::back_inserter(cells));
     if(cells.size() == 0)
       return 0.0;
 
-    FT length = 100000;
-    int counter = 0;
     FT div = 0.0;
     typename std::vector<Cell_handle>::iterator it;
     for(it = cells.begin(); it != cells.end(); it++)
@@ -538,25 +542,11 @@ private:
 
       // compute n'
       int index = cell->index(v);
-      const Point& x = cell->vertex(index)->point();
       const Point& a = cell->vertex((index+1)%4)->point();
       const Point& b = cell->vertex((index+2)%4)->point();
       const Point& c = cell->vertex((index+3)%4)->point();
       Vector nn = (index%2==0) ? CGAL::cross_product(b-a,c-a) : CGAL::cross_product(c-a,b-a);
-      nn = nn / std::sqrt(nn*nn); // normalize
-      Vector p = a - x;
-      Vector q = b - x;
-      Vector r = c - x;
-      FT p_n = std::sqrt(p*p);
-      FT q_n = std::sqrt(q*q);
-      FT r_n = std::sqrt(r*r);
-      FT solid_angle = p*(CGAL::cross_product(q,r));
-      solid_angle = std::abs(solid_angle * 1.0 / (p_n*q_n*r_n + (p*q)*r_n + (q*r)*p_n + (r*p)*q_n));
-      Triangle face(a,b,c);
-      FT area = std::sqrt(face.squared_area());
-      length = std::sqrt((x-a)*(x-a)) + std::sqrt((x-b)*(x-b)) + std::sqrt((x-c)*(x-c));
-      counter++;
-      div += n * nn * area * 3 / length ;
+      div += n * nn;
     }
     return div;
   }
@@ -618,7 +608,7 @@ private:
     // sum up areas
     FT area = 0.0;
     const Point& a = voronoi_points[0];
-    unsigned int nb_triangles = voronoi_points.size() - 2;
+    unsigned int nb_triangles = voronoi_points.size() - 1;
     for(unsigned int i=1;i<nb_triangles;i++)
     {
       const Point& b = voronoi_points[i];
@@ -673,8 +663,8 @@ private:
         Point ck = CGAL::circumcenter(pi,pj,pk);
         Point cl = CGAL::circumcenter(pi,pj,pl);
 
-        Triangle mcck(m,m,ck);
-        Triangle mccl(m,m,cl);
+        Triangle mcck(m,c,ck);
+        Triangle mccl(m,c,cl);
 
         area += std::sqrt(mcck.squared_area());
         area += std::sqrt(mccl.squared_area());
@@ -713,7 +703,7 @@ private:
 
   /// Assemble vi's row of the linear system A*X=B
   ///
-  /// @heading Parameters:
+  /// @commentheading Template parameters:
   /// @param SparseLinearAlgebraTraits_d Symmetric definite positive sparse linear solver.
   template <class SparseLinearAlgebraTraits_d>
   void assemble_poisson_row(typename SparseLinearAlgebraTraits_d::Matrix& A,
@@ -722,19 +712,27 @@ private:
                             double lambda)
   {
     // for each vertex vj neighbor of vi
-    std::vector<Vertex_handle> vertices;
-    m_tr->incident_vertices(vi,std::back_inserter(vertices));
+    std::vector<Edge> edges;
+    m_tr->incident_edges(vi,std::back_inserter(edges));
+
     double diagonal = 0.0;
-    for(typename std::vector<Vertex_handle>::iterator it = vertices.begin();
-        it != vertices.end();
+
+  for(typename std::vector<Edge>::iterator it = edges.begin();
+        it != edges.end();
         it++)
     {
-      Vertex_handle vj = *it;
+      Vertex_handle vj = it->first->vertex(it->third);
+      if(vj == vi){
+        vj = it->first->vertex(it->second);
+      }
       if(m_tr->is_infinite(vj))
         continue;
 
       // get corresponding edge
-      Edge edge = sorted_edge(vi,vj);
+      Edge edge( it->first, it->first->index(vi), it->first->index(vj));
+      if(vi->index() < vj->index()){
+        std::swap(edge.second,  edge.third);
+      }
 
       double cij = cotan_geometric(edge);
       if(vj->constrained())
@@ -744,28 +742,14 @@ private:
 
       diagonal += cij;
     }
-
     // diagonal coefficient
     if (vi->type() == Triangulation::INPUT)
       A.set_coef(vi->index(),vi->index(), diagonal + lambda, true /*new*/) ;
     else
       A.set_coef(vi->index(),vi->index(), diagonal, true /*new*/);
+
   }
 
-  Edge sorted_edge(Vertex_handle vi,
-                   Vertex_handle vj)
-  {
-    int i1 = 0;
-    int i2 = 0;
-    Cell_handle cell = NULL;
-    bool success;
-    if(vi->index() > vj->index())
-      success = m_tr->is_edge(vi,vj,cell,i1,i2);
-    else
-      success = m_tr->is_edge(vj,vi,cell,i1,i2);
-    CGAL_surface_reconstruction_points_assertion(success);
-    return Edge(cell,i1,i2);
-  }
 
   /// Computes enlarged geometric bounding sphere of the embedded triangulation.
   Sphere enlarged_bounding_sphere(FT ratio) const
@@ -777,6 +761,6 @@ private:
 }; // end of Poisson_reconstruction_function
 
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_POISSON_RECONSTRUCTION_FUNCTION_H
