@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Kinetic_data_structures/include/CGAL/Polynomial/internal/Kernel/Sign_at.h $
-// $Id: Sign_at.h 35777 2007-01-23 17:02:20Z drussel $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Kinetic_data_structures/include/CGAL/Polynomial/internal/Kernel/Sign_at.h $
+// $Id: Sign_at.h 57833 2010-08-06 11:08:29Z afabri $
 // 
 //
 // Author(s)     : Daniel Russel <drussel@alumni.princeton.edu>
@@ -26,7 +26,7 @@
 #include <CGAL/Polynomial/polynomial_converters.h>
 #include <CGAL/Polynomial/internal/Rational/Sign_at_rational.h>
 
-CGAL_POLYNOMIAL_BEGIN_INTERNAL_NAMESPACE
+namespace CGAL { namespace POLYNOMIAL { namespace internal {
 template <class Root, class K>
 class Sign_at
 {
@@ -35,7 +35,7 @@ class Sign_at
 public:
   Sign_at(K k=K()): k_(k) {
   }
-  Sign_at(){}
+
   typedef typename K::Root argument_type;
   typedef CGAL::Sign result_type;
 
@@ -95,5 +95,5 @@ public:
 
 };
 
-CGAL_POLYNOMIAL_END_INTERNAL_NAMESPACE
+} } } //namespace CGAL::POLYNOMIAL::internal
 #endif
