@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/QP_solver/include/CGAL/QP_solver/functors.h $
-// $Id: functors.h 46451 2008-10-23 14:31:10Z gaertner $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/QP_solver/include/CGAL/QP_solver/functors.h $
+// $Id: functors.h 58951 2010-09-29 21:05:51Z ybrise $
 // 
 //
 // Author(s)     : Sven Schoenherr 
@@ -28,7 +28,7 @@
 #include <functional>
 #include <iterator>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 // ==================
 // class declarations
@@ -239,7 +239,9 @@ class Map_with_default {
   // public types
 public:
   typedef typename Map::mapped_type       mapped_type;
-  typedef typename Map::difference_type   difference_type;
+  //typedef typename Map::difference_type   difference_type;
+  typedef typename Map::size_type         size_type;
+  typedef typename Map::key_type          key_type;
   typedef mapped_type                     result_type;
   // data members
 private:
@@ -257,7 +259,7 @@ public:
   {}
   
   // operator()
-  const mapped_type& operator() (difference_type n) const {
+  const mapped_type& operator() (key_type n) const {
     CGAL_qpe_precondition (map != 0);
     typename Map::const_iterator i = map->find (n);
     if (i != map->end())
@@ -267,7 +269,7 @@ public:
   }
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_QP_SOLVER_FUNCTORS_H
 
