@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/GraphicsView/include/CGAL/Qt/CircularArcGraphicsItem.h $
-// $Id: CircularArcGraphicsItem.h 45725 2008-09-24 13:24:24Z lrineau $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/GraphicsView/include/CGAL/Qt/CircularArcGraphicsItem.h $
+// $Id: CircularArcGraphicsItem.h 64637 2011-07-06 11:11:58Z lrineau $
 // 
 //
 // Author(s)     : Andreas Fabri <Andreas.Fabri@geometryfactory.com>
@@ -87,6 +87,7 @@ protected:
   QRectF bounding_rect;
 
   QPen edges_pen;
+  QPen vertices_pen;
 
   Circular_arc_2 arc_;
 };
@@ -122,8 +123,8 @@ CircularArcGraphicsItem<CK>::boundingRect() const
 template <typename CK>
 void 
 CircularArcGraphicsItem<CK>::paint(QPainter *painter, 
-                                    const QStyleOptionGraphicsItem *option,
-                                    QWidget * widget)
+                                    const QStyleOptionGraphicsItem * /*option*/,
+                                    QWidget * /*widget*/)
 {
   painter->setPen(this->edgesPen());
   painterostream = PainterOstream<CK>(painter);
