@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Algebraic_foundations/include/CGAL/Rational_traits.h $
-// $Id: Rational_traits.h 51456 2009-08-24 17:10:04Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Algebraic_foundations/include/CGAL/Rational_traits.h $
+// $Id: Rational_traits.h 61559 2011-03-08 10:27:31Z glisse $
 //
 //
 // Author(s)     : Michael Hemmer    <hemmer@mpi-inf.mpg.de>
@@ -28,8 +28,10 @@
 
 #include <CGAL/number_type_basic.h>
 #include <CGAL/Fraction_traits.h>
+#include <CGAL/is_convertible.h>
+#include <boost/utility/enable_if.hpp>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 namespace internal{
 
@@ -68,10 +70,13 @@ public:
         return den; 
     }
     
-    Rational make_rational(const RT & n, const RT & d) const
+    template<class N,class D>
+    Rational make_rational(const N& n, const D& d,typename boost::enable_if_c<is_implicit_convertible<N,RT>::value&&is_implicit_convertible<D,RT>::value,int>::type=0) const
     { return Compose()(n,d); } 
-    Rational make_rational(const Rational & n, const Rational & d) const
-    { return n/d; } 
+
+    template<class N,class D>
+    Rational make_rational(const N& n, const D& d,typename boost::enable_if_c<!is_implicit_convertible<N,RT>::value||!is_implicit_convertible<D,RT>::value,int>::type=0) const
+    { return n/d; } // Assume that n or d is already a fraction
 };
 }// namespace internal
 
@@ -87,8 +92,7 @@ typename Fraction_traits<T>::Denominator_type
 >::value >
 {};
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_RATIONAL_TRAITS_H
 // EOF
-
