@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Triangulation_2/include/CGAL/Regular_triangulation_2.h $
-// $Id: Regular_triangulation_2.h 53845 2010-01-27 16:43:40Z lrineau $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Triangulation_2/include/CGAL/Regular_triangulation_2.h $
+// $Id: Regular_triangulation_2.h 63930 2011-06-07 08:20:54Z sloriot $
 // 
 //
 // Author(s)     : Frederic Fichel, Mariette Yvinec, Julia Floetotto
@@ -25,7 +25,17 @@
 #include <CGAL/Regular_triangulation_vertex_base_2.h>
 #include <CGAL/utility.h>
 
-CGAL_BEGIN_NAMESPACE 
+#include <boost/bind.hpp>
+
+#ifndef CGAL_TRIANGULATION_2_DONT_INSERT_RANGE_OF_POINTS_WITH_INFO
+#include <CGAL/Spatial_sort_traits_adapter_2.h>
+#include <CGAL/internal/info_check.h>
+
+#include <boost/iterator/zip_iterator.hpp>
+#include <boost/mpl/and.hpp>
+#endif //CGAL_TRIANGULATION_2_DONT_INSERT_RANGE_OF_POINTS_WITH_INFO
+
+namespace CGAL { 
 
 template < typename K_ >
 struct Weighted_point_mapper_2 
@@ -91,6 +101,16 @@ public:
   using Base::EDGE;
   using Base::OUTSIDE_CONVEX_HULL;
   using Base::orientation;
+  using Base::locate;
+  using Base::incident_faces;
+  using Base::is_infinite;
+  using Base::degree;
+  using Base::delete_vertex;
+  using Base::incident_vertices;
+  using Base::make_hole;
+  using Base::mirror_index;
+  using Base::show_vertex;
+  using Base::test_dim_down;
 #endif
 
 private:
@@ -192,14 +212,14 @@ public:
   Oriented_side power_test(const Weighted_point &p,
 			   const Weighted_point &q,
 			   const Weighted_point &r,
-			   const Weighted_point &s) const;
+			   const Weighted_point &s, bool perturb) const;
   Oriented_side power_test(const Weighted_point &p,
 			   const Weighted_point &q,
 			   const Weighted_point &r) const;
   Oriented_side power_test(const Weighted_point &p,
 			   const Weighted_point &r) const;
   Oriented_side power_test(const Face_handle &f, 
-			   const Weighted_point &p) const;
+			   const Weighted_point &p, bool perturb=false) const;
   Oriented_side power_test(const Face_handle& f, int i,
 			   const Weighted_point &p) const;
  
@@ -325,11 +345,30 @@ private:
 
 
 public:
+#ifndef CGAL_TRIANGULATION_2_DONT_INSERT_RANGE_OF_POINTS_WITH_INFO
   template < class InputIterator >
-  int
+  std::ptrdiff_t
+  insert( InputIterator first, InputIterator last,
+          typename boost::enable_if<
+            boost::mpl::or_<
+              boost::is_same<
+                  typename std::iterator_traits<InputIterator>::value_type,
+                  Weighted_point
+              >,
+              boost::is_same<
+                  typename std::iterator_traits<InputIterator>::value_type,
+                  Bare_point
+              >
+            >
+          >::type* = NULL  
+  )
+#else  
+  template < class InputIterator >
+  std::ptrdiff_t
   insert(InputIterator first, InputIterator last)
+#endif //CGAL_TRIANGULATION_2_DONT_INSERT_RANGE_OF_POINTS_WITH_INFO
   {
-      int n = number_of_vertices();
+      size_type n = number_of_vertices();
 
       std::vector<Weighted_point> points (first, last);
       spatial_sort (points.begin(), points.end(), geom_traits());
@@ -343,6 +382,92 @@ public:
       return number_of_vertices() - n;
   }
 
+#ifndef CGAL_TRIANGULATION_2_DONT_INSERT_RANGE_OF_POINTS_WITH_INFO
+private:
+  //top stands for tuple-or-pair
+  template <class Info>
+  const Weighted_point& top_get_first(const std::pair<Weighted_point,Info>& pair) const { return pair.first; }
+  template <class Info>
+  const Info& top_get_second(const std::pair<Weighted_point,Info>& pair) const { return pair.second; }
+  template <class Info>
+  const Weighted_point& top_get_first(const boost::tuple<Weighted_point,Info>& tuple) const { return boost::get<0>(tuple); }
+  template <class Info>
+  const Info& top_get_second(const boost::tuple<Weighted_point,Info>& tuple) const { return boost::get<1>(tuple); }
+
+  template <class Tuple_or_pair,class InputIterator>
+  std::ptrdiff_t insert_with_info(InputIterator first,InputIterator last)
+  {
+    int n = number_of_vertices();
+    std::vector<std::ptrdiff_t> indices;
+    std::vector<Weighted_point> points;
+    std::vector<typename Triangulation_data_structure::Vertex::Info> infos;
+    std::ptrdiff_t index=0;
+    for (InputIterator it=first;it!=last;++it){
+      Tuple_or_pair pair = *it;
+      points.push_back( top_get_first(pair) );
+      infos.push_back ( top_get_second(pair) );
+      indices.push_back(index++);
+    }
+
+    typedef Spatial_sort_traits_adapter_2<Geom_traits,Weighted_point*> Search_traits;
+    
+    spatial_sort(indices.begin(),indices.end(),Search_traits(&(points[0]),geom_traits()));    
+
+    Face_handle hint;
+    Vertex_handle v_hint;
+    for (typename std::vector<std::ptrdiff_t>::const_iterator
+      it = indices.begin(), end = indices.end();
+      it != end; ++it)
+    {
+      v_hint = insert (points[*it], hint);
+      
+      if (v_hint!=Vertex_handle()){
+        v_hint->info()=infos[*it];
+        hint=v_hint->face();
+      }
+    }
+
+    return number_of_vertices() - n;
+  }
+  
+public:
+
+  template < class InputIterator >
+  std::ptrdiff_t
+  insert( InputIterator first,
+          InputIterator last,
+          typename boost::enable_if<
+            boost::mpl::or_<
+              boost::is_same<
+                typename std::iterator_traits<InputIterator>::value_type,
+                std::pair<Weighted_point,typename internal::Info_check<typename Triangulation_data_structure::Vertex>::type>
+              >,
+              boost::is_same<
+                typename std::iterator_traits<InputIterator>::value_type,
+                std::pair<Bare_point,typename internal::Info_check<typename Triangulation_data_structure::Vertex>::type>
+              >
+            >
+          >::type* = NULL
+  )
+  {return insert_with_info< std::pair<Weighted_point,typename internal::Info_check<typename Triangulation_data_structure::Vertex>::type> >(first,last);}
+  
+  template <class  InputIterator_1,class InputIterator_2>
+  std::ptrdiff_t
+  insert( boost::zip_iterator< boost::tuple<InputIterator_1,InputIterator_2> > first,
+          boost::zip_iterator< boost::tuple<InputIterator_1,InputIterator_2> > last,
+          typename boost::enable_if<
+            boost::mpl::and_<
+              boost::mpl::or_<
+                typename boost::is_same< typename std::iterator_traits<InputIterator_1>::value_type, Weighted_point >,
+                typename boost::is_same< typename std::iterator_traits<InputIterator_1>::value_type, Bare_point >
+              >,
+              typename boost::is_same< typename std::iterator_traits<InputIterator_2>::value_type, typename internal::Info_check<typename Triangulation_data_structure::Vertex>::type >
+            >
+          >::type* =NULL
+  )
+  {return insert_with_info< boost::tuple<Weighted_point,typename internal::Info_check<typename Triangulation_data_structure::Vertex>::type> >(first,last);}
+#endif //CGAL_TRIANGULATION_2_DONT_INSERT_RANGE_OF_POINTS_WITH_INFO  
+  
   template < class Stream>
   Stream& draw_dual(Stream & ps) const
     {
@@ -615,7 +740,7 @@ operator=(const Self &tr)
 template < class Gt, class Tds >
 Oriented_side
 Regular_triangulation_2<Gt,Tds>::
-power_test(const Face_handle &f, const Weighted_point &p) const
+power_test(const Face_handle &f, const Weighted_point &p, bool perturb) const
 {
   // p is supposed to be a finite point
   // if f is a finite face, 
@@ -627,7 +752,7 @@ power_test(const Face_handle &f, const Weighted_point &p) const
   if ( ! f->has_vertex(infinite_vertex(), i) )
     return power_test(f->vertex(0)->point(),
 		      f->vertex(1)->point(),
-		      f->vertex(2)->point(),p);
+		      f->vertex(2)->point(),p, perturb);
 
   Orientation o = orientation(f->vertex(ccw(i))->point(),
 			      f->vertex( cw(i))->point(),
@@ -662,12 +787,52 @@ template < class Gt, class Tds >
 inline
 Oriented_side
 Regular_triangulation_2<Gt,Tds>::
-power_test(const Weighted_point &p,
-	   const Weighted_point &q,
-	   const Weighted_point &r,
-	   const Weighted_point &s) const
+power_test(const Weighted_point &p0,
+	   const Weighted_point &p1,
+	   const Weighted_point &p2,
+	   const Weighted_point &p,
+           bool perturb) const
 {
-  return geom_traits().power_test_2_object()(p,q,r,s);
+    CGAL_triangulation_precondition( orientation(p0, p1, p2) == POSITIVE );
+
+    using namespace boost;
+
+    Oriented_side os = geom_traits().power_test_2_object()(p0, p1, p2, p);
+
+    if ( (os != ON_ORIENTED_BOUNDARY) || (! perturb))
+        return os;
+
+    // We are now in a degenerate case => we do a symbolic perturbation.
+
+    // We sort the points lexicographically.
+    const Weighted_point * points[4] = {&p0, &p1, &p2, &p};
+    std::sort(points, points + 4,
+              boost::bind(&Self::compare_xy, this,
+                          boost::bind(Dereference<Weighted_point>(), _1),
+                          boost::bind(Dereference<Weighted_point>(), _2)) == SMALLER);
+
+
+
+
+
+    // We successively look whether the leading monomial, then 2nd monomial
+    // of the determinant has non null coefficient.
+    // 2 iterations are enough (cf paper)
+    for (int i=3; i>1; --i) {
+        if (points[i] == &p)
+            return ON_NEGATIVE_SIDE; // since p0 p1 p2 are non collinear
+                                     // and positively oriented
+	Orientation o;
+        if (points[i] == &p2 && (o = orientation(p0,p1,p)) != COLLINEAR )
+            return o;
+        if (points[i] == &p1 && (o = orientation(p0,p,p2)) != COLLINEAR )
+            return o;
+        if (points[i] == &p0 && (o = orientation(p,p1,p2)) != COLLINEAR )
+            return o;
+    }
+
+    CGAL_triangulation_assertion(false);
+    return ON_NEGATIVE_SIDE;
 }
 
 template < class Gt, class Tds >
@@ -1090,7 +1255,7 @@ insert(const Weighted_point &p, Locate_type lt, Face_handle loc, int li)
         {
             CGAL_precondition (dimension() >= 1);
             Oriented_side os = dimension() == 1 ? power_test (loc, li, p) :
-                                                  power_test (loc, p);
+                                                  power_test (loc, p, true);
 
             if (os < 0) {
                 if (is_infinite (loc)) loc = loc->neighbor (li);
@@ -1103,7 +1268,7 @@ insert(const Weighted_point &p, Locate_type lt, Face_handle loc, int li)
     case Base::FACE:
         {
             CGAL_precondition (dimension() >= 2);
-            if (power_test (loc, p) < 0) {
+            if (power_test (loc, p, true) < 0) {
                 return hide_new_vertex(loc,p);
             }
             v = insert_in_face (p, loc);
@@ -1514,7 +1679,7 @@ fill_hole_regular(std::list<Edge> & first_hole)
 		      p2=p;
 		      cut_after=hit;
 		    }
-		  else if (power_test(p0,p1,p2,p) == 
+		  else if (power_test(p0,p1,p2,p,true) == 
 			   ON_POSITIVE_SIDE)
 		    {
 		      v2=vv;
@@ -1824,7 +1989,7 @@ stack_flip(Vertex_handle v, Faces_around_stack &faces_around)
   // now dimension() == 2
   //test the regularity of edge (f,i)
   //if( power_test(n, v->point()) == ON_NEGATIVE_SIDE)
-  if( power_test(n, v->point()) != ON_POSITIVE_SIDE)
+  if( power_test(n, v->point(), true) != ON_POSITIVE_SIDE)
     return;
     
   if(is_infinite(f,i))
@@ -1957,7 +2122,7 @@ stack_flip_dim1(Face_handle f, int i, Faces_around_stack &faces_around)
   n->neighbor(1-in)->set_neighbor(n->neighbor(1-in)->index(n), f);
   (f->vertex_list()).splice(f->vertex_list().begin(),n->vertex_list());
   set_face(f->vertex_list(),f);
-  delete_face(n);
+  this->delete_face(n);
   hide_vertex(f,va);
   faces_around.push_front(f);
   return;
@@ -2073,6 +2238,6 @@ nearest_power_vertex(const Bare_point& p) const
 }
 
 
-CGAL_END_NAMESPACE 
+} //namespace CGAL 
 
 #endif // CGAL_REGULAR_TRIANGULATION_2_H
