@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Number_types/include/CGAL/Root_of_traits.h $
-// $Id: Root_of_traits.h 51456 2009-08-24 17:10:04Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Number_types/include/CGAL/Root_of_traits.h $
+// $Id: Root_of_traits.h 63998 2011-06-09 06:27:38Z sloriot $
 //
 //
 // Author(s)     : Sylvain Pion, Monique Teillaud, Athanasios Kakargias, Michael Hemmer
@@ -22,37 +22,102 @@
 #define CGAL_ROOT_OF_TRAITS_H
 
 #include <CGAL/number_type_basic.h>
-#include <CGAL/Root_of_2.h>
+#include <CGAL/Arithmetic_kernel.h>
+#include <CGAL/Sqrt_extension.h>
 #include <CGAL/Quotient.h>
+#include <boost/mpl/has_xxx.hpp>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
+
+template < typename NT >
+struct Root_of_traits;
+
+template < class NT >
+inline
+typename Root_of_traits< NT >::Root_of_2
+make_root_of_2(const NT &a, const NT &b, const NT &c)
+{
+    typename Root_of_traits<NT>::Make_root_of_2 make_root_of_2;
+    return make_root_of_2(a,b,c);
+}
+
+
+template < class NT >
+inline
+typename Root_of_traits< NT >::Root_of_2
+make_root_of_2(const NT &a, const NT &b, const NT &c,const bool smaller)
+{
+    typename Root_of_traits<NT>::Make_root_of_2 make_root_of_2;
+    return make_root_of_2(a,b,c,smaller);
+}
+
+template < class NT >
+inline 
+typename Root_of_traits< NT >::Root_of_2
+make_sqrt(const NT &a)
+{
+  typename Root_of_traits<NT>::Make_sqrt make_sqrt;
+  return make_sqrt(a);
+}
 
 namespace internal {
 
+BOOST_MPL_HAS_XXX_TRAIT_NAMED_DEF(Has_typedef_Arithmetic_kernel,Arithmetic_kernel,false)  
+
+template <class NT,bool has_AK=Has_typedef_Arithmetic_kernel<Get_arithmetic_kernel<NT> >::value>
+struct Get_rational_type{
+  typedef Quotient<NT> type;
+};
+
+template <class NT>
+struct Get_rational_type<NT,true>{
+  typedef typename Get_arithmetic_kernel<NT>::Arithmetic_kernel::Rational type;
+};
+
+  
+//Default or not a field.
+//If no specialization of Get_arithmetic_kernel is available, a field type compatible with NT 
+//is made using CGAL::Quotient
 template < typename NT, class Algebraic_category>
 struct Root_of_traits_helper{
-    typedef Quotient<NT> Root_of_1;
-    typedef CGAL::Root_of_2<NT> Root_of_2;
+//    typedef Quotient<NT> Root_of_1;
+    typedef typename Get_rational_type<NT>::type Root_of_1;
+    typedef CGAL::Sqrt_extension<Root_of_1,Root_of_1,::CGAL::Tag_true,::CGAL::Tag_true>             Root_of_2;
+//    typedef CGAL::Root_of_2<NT> Root_of_2;
     struct Make_root_of_2{
         typedef Root_of_2 result_type;
-        Root_of_2 operator()(const NT& a, const NT& b, const NT& c){
+        Root_of_2 operator()(const NT& a, const NT& b, const NT& c) const {
             return Root_of_2(a,b,c);
         }
-        Root_of_2 operator()(const NT& a, const NT& b, const NT& c, bool s){
+        Root_of_2 operator()(const NT& a, const NT& b, const NT& c, bool s) const {
             return Root_of_2(a,b,c,s);
         }
         Root_of_2 operator()(const Root_of_1& a,
                              const Root_of_1& b,
-                             const Root_of_1& c){
+                             const Root_of_1& c) const {
             return Root_of_2(a,b,c);
         }
         Root_of_2 operator()(const Root_of_1& a,
                              const Root_of_1& b,
                              const Root_of_1& c,
-                             bool s){
+                             bool s) const {
             return Root_of_2(a,b,c,s);
         }
     };
+  
+  
+private:
+  typedef CGAL::Algebraic_structure_traits<Root_of_2> AST;
+public:
+  typedef typename AST::Square  Square; 
+  typedef typename AST::Inverse Inverse;
+  
+  struct Make_sqrt {
+    typedef Root_of_2 result_type;
+    Root_of_2 operator()(const NT& x) const {
+      return Root_of_2(x,true);
+    }
+  };
 };
 
 template < typename FT>
@@ -62,21 +127,25 @@ struct Root_of_traits_helper < FT, Field_tag >
 private:
     typedef Fraction_traits<FT> FrT;
     // Field must be a Type (Decomposable)
-    BOOST_STATIC_ASSERT((FrT::Is_fraction::value));
+    // We have the typedef as VC10 fails with 
+    // static_assert(FrT::Is_fraction::value)
+    typedef typename FrT::Is_fraction ISF;
+    BOOST_STATIC_ASSERT((ISF::value));
+
 
     typedef typename FrT::Numerator_type      RT;
     typedef typename FrT::Decompose Decompose;
 public:
-    typedef CGAL::Root_of_2< RT >  Root_of_2;
+    typedef CGAL::Sqrt_extension<Root_of_1,Root_of_1,::CGAL::Tag_true,::CGAL::Tag_true>             Root_of_2;
 
     struct Make_root_of_2{
         typedef Root_of_2 result_type;
         Root_of_2
-        operator()(const FT& a, const FT& b, const FT& c){
+        operator()(const FT& a, const FT& b, const FT& c) const {
             return Root_of_2(a,b,c);
         }
         Root_of_2
-        operator()(const FT& a, const FT& b, const FT& c, bool smaller){
+        operator()(const FT& a, const FT& b, const FT& c, bool smaller) const {
             Decompose decompose;
             RT a_num,b_num,c_num;
             RT a_den,b_den,c_den; // Denomiantor same as RT
@@ -92,6 +161,19 @@ public:
             return make_root_of_2(a_,b_,c_,smaller);
         }
     };
+
+private:
+  typedef CGAL::Algebraic_structure_traits<Root_of_2> AST;
+public:
+  typedef typename AST::Square  Square; 
+  typedef typename AST::Inverse Inverse;
+  
+  struct Make_sqrt{
+    typedef Root_of_2 result_type;
+    Root_of_2 operator()(const FT& x) const {
+      return Root_of_2( FT(0),FT(1),x);
+    }
+  };
 };
 
 template < typename NT >
@@ -103,7 +185,7 @@ struct Root_of_traits_helper < NT, Field_with_sqrt_tag >
     struct Make_root_of_2{
         typedef NT result_type;
         // just a copy, not sure about the semantic of smaller
-        NT operator()(const NT& a, const NT& b, const NT& c, bool smaller){
+        NT operator()(const NT& a, const NT& b, const NT& c, bool smaller) const {
             // former make_root_of_2_sqrt()
             CGAL_assertion( a != 0 );
             NT discriminant = CGAL_NTS square(b) - a*c*4;
@@ -114,10 +196,23 @@ struct Root_of_traits_helper < NT, Field_with_sqrt_tag >
             return (d-b)/(a*2);
         }
         // it's so easy
-        NT operator()(const NT& a, const NT& b, const NT& c){
+        NT operator()(const NT& a, const NT& b, const NT& c) const {
             return a + b * CGAL_NTS sqrt(c) ;
         }
     };
+
+private:
+  typedef CGAL::Algebraic_structure_traits<Root_of_2> AST;
+public:
+  typedef typename AST::Square  Square; 
+  typedef typename AST::Inverse Inverse;
+  
+  struct Make_sqrt{
+    typedef Root_of_2 result_type;
+    Root_of_2 operator()(const NT& x) const {
+      return CGAL::sqrt(x);
+    }
+  };
 };
 
 template < typename NT >
@@ -153,7 +248,7 @@ struct Root_of_traits<Interval_nt<B> >{
   struct Make_root_of_2{
     typedef Interval_nt<B> result_type;
     // just a copy, not sure about the semantic of smaller
-    Interval_nt<B> operator()(const Interval_nt<B>& a, const Interval_nt<B>& b, const Interval_nt<B>& c, bool smaller){
+    Interval_nt<B> operator()(const Interval_nt<B>& a, const Interval_nt<B>& b, const Interval_nt<B>& c, bool smaller) const {
         // former make_root_of_2_sqrt()
         if (CGAL::possibly(a==0))
           return Interval_nt<B>::largest();
@@ -165,31 +260,15 @@ struct Root_of_traits<Interval_nt<B> >{
         return (d-b)/(a*2);
     }
     // it's so easy
-    Interval_nt<B> operator()(const Interval_nt<B>& a, const Interval_nt<B>& b, const Interval_nt<B>& c){
+    Interval_nt<B> operator()(const Interval_nt<B>& a, const Interval_nt<B>& b, const Interval_nt<B>& c) const {
         return a + b * CGAL_NTS sqrt(c) ;
     }
   };
 };
 
-template < class NT >
-inline
-typename Root_of_traits< NT >::Root_of_2
-make_root_of_2(const NT &a, const NT &b, const NT &c)
-{
-    typename Root_of_traits<NT>::Make_root_of_2 make_root_of_2;
-    return make_root_of_2(a,b,c);
-}
 
+} //namespace CGAL
 
-template < class NT >
-inline
-typename Root_of_traits< NT >::Root_of_2
-make_root_of_2(const NT &a, const NT &b, const NT &c,const bool smaller)
-{
-    typename Root_of_traits<NT>::Make_root_of_2 make_root_of_2;
-    return make_root_of_2(a,b,c,smaller);
-}
-
-CGAL_END_NAMESPACE
+#include <CGAL/Root_of_traits_specializations.h>
 
 #endif // CGAL_ROOT_OF_TRAITS_H
