@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Segment_Delaunay_graph_2/include/CGAL/Segment_Delaunay_graph_2/Voronoi_vertex_ring_C2.h $
-// $Id: Voronoi_vertex_ring_C2.h 42809 2008-04-09 13:09:17Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Segment_Delaunay_graph_2/include/CGAL/Segment_Delaunay_graph_2/Voronoi_vertex_ring_C2.h $
+// $Id: Voronoi_vertex_ring_C2.h 63778 2011-05-31 13:03:27Z sloriot $
 // 
 //
 // Author(s)     : Menelaos Karavelas <mkaravel@cse.nd.edu>
@@ -29,9 +29,9 @@
 #include <CGAL/Segment_Delaunay_graph_2/Are_same_segments_C2.h>
 
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
-CGAL_SEGMENT_DELAUNAY_GRAPH_2_BEGIN_NAMESPACE
+namespace SegmentDelaunayGraph_2 {
 
 
 template<class K>
@@ -65,6 +65,11 @@ public:
   typedef typename Base::Oriented_side       Oriented_side;
   typedef typename Base::Sign                Sign;
 
+  using Base::compute_supporting_line;
+  using Base::oriented_side_of_line;
+  using Base::opposite_line;
+  using Base::to_ft;
+
 private:
   typedef Are_same_points_C2<K>     Are_same_points_2;
   typedef Are_same_segments_C2<K>   Are_same_segments_2;
@@ -712,7 +717,7 @@ private:
   Orientation
   orientation(const Line_2& l, Type) const
   {
-    Sqrt_1 Zero(RT(0), RT(0), ux.a().c());
+    Sqrt_1 Zero(RT(0), RT(0), ux.a().root());
 
     Sqrt_1 a = l.a() + Zero;
     Sqrt_1 b = l.b() + Zero;
@@ -832,7 +837,7 @@ private:
     CGAL_precondition( st.is_point() );
     Point_2 t = st.point();
 
-    Sqrt_1 Zero(RT(0), RT(0), ux.a().c());
+    Sqrt_1 Zero(RT(0), RT(0), ux.a().root());
 
     Point_2 pref = p_ref().point();
 
@@ -863,7 +868,7 @@ private:
 
     Point_2 t = st.point();
 
-    Sqrt_1 Zero(RT(0), RT(0), ux.a().c());
+    Sqrt_1 Zero(RT(0), RT(0), ux.a().root());
 
     RT a1, b1, c1;
     compute_supporting_line(p_.supporting_site(), a1, b1, c1);
@@ -972,7 +977,7 @@ private:
   Oriented_side
   oriented_side(const Line_2& l, const Point_2& p, Type) const
   {
-    Sqrt_1 Zero(RT(0), RT(0), ux.a().c());
+    Sqrt_1 Zero(RT(0), RT(0), ux.a().root());
     Sqrt_1 px = p.x() + Zero;
     Sqrt_1 py = p.y() + Zero;
 
@@ -1031,7 +1036,7 @@ private:
 
   Sign incircle(const Line_2& l, PSS_Type) const
   {
-    Sqrt_1 Zero(RT(0), RT(0), ux.a().c());
+    Sqrt_1 Zero(RT(0), RT(0), ux.a().root());
 
     Point_2 pref = p_ref().point();
 
@@ -1057,7 +1062,7 @@ private:
 
   Sign incircle(const Line_2& l, SSS_Type) const
   {
-    Sqrt_1 Zero(RT(0), RT(0), ux.a().c());
+    Sqrt_1 Zero(RT(0), RT(0), ux.a().root());
 
     RT a1, b1, c1;
     compute_supporting_line(p_.supporting_site(), a1, b1, c1);
@@ -1514,9 +1519,9 @@ private:
 };
 
 
-CGAL_SEGMENT_DELAUNAY_GRAPH_2_END_NAMESPACE
+} //namespace SegmentDelaunayGraph_2
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 
 #endif // CGAL_SEGMENT_DELAUNAY_GRAPH_2_VORONOI_VERTEX_RING_C2_H
