@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Segment_Delaunay_graph_2/include/CGAL/Segment_Delaunay_graph_simple_site_2.h $
-// $Id: Segment_Delaunay_graph_simple_site_2.h 46222 2008-10-13 09:56:02Z afabri $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Segment_Delaunay_graph_2/include/CGAL/Segment_Delaunay_graph_simple_site_2.h $
+// $Id: Segment_Delaunay_graph_simple_site_2.h 56667 2010-06-09 07:37:13Z sloriot $
 // 
 //
 // Author(s)     : Menelaos Karavelas <mkaravel@cse.nd.edu>
@@ -29,7 +29,7 @@
 
 #include <CGAL/Segment_Delaunay_graph_2/Constructions_C2.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
   /** A Site is either a point or a segment or a point defined as the
       intersection of two non-parallel segments (if defined)
@@ -263,6 +263,6 @@ operator<<(Stream& str, Segment_Delaunay_graph_simple_site_2<R>& t)
 }
 
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_SEGMENT_DELAUNAY_GRAPH_SIMPLE_SITE_H
