@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Number_types/include/CGAL/Sqrt_extension/Sqrt_extension_type.h $
-// $Id: Sqrt_extension_type.h 52628 2009-10-20 08:59:26Z lrineau $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Number_types/include/CGAL/Sqrt_extension/Sqrt_extension_type.h $
+// $Id: Sqrt_extension_type.h 64473 2011-06-29 12:41:42Z sloriot $
 //
 //
 // Author(s)     : Michael Hemmer   <hemmer@mpi-inf.mpg.de>
@@ -36,20 +36,18 @@
 
 #include <CGAL/number_type_basic.h>
 #include <boost/operators.hpp>
-
-//#define SQRT_EXT_USE_FILTER 1
-#ifdef SQRT_EXT_USE_FILTER
-  #include <CGAL/Interval_arithmetic.h> 
-#endif
-
+#include <CGAL/Interval_arithmetic.h> 
+#include <CGAL/Sqrt_extension_fwd.h>
+#include <boost/optional.hpp>
+#include <boost/type_traits/is_same.hpp>
 
 #define CGAL_int(T)    typename First_if_different<int,    T>::Type
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
-template <class NT_,class ROOT_> class Sqrt_extension;
-template<class NT, class ROOT>
-void output_maple(std::ostream&, const Sqrt_extension<NT,ROOT>&);
+
+template<class NT, class ROOT, class ACDE_TAG, class FP_TAG >
+void output_maple(std::ostream&, const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>&);
 
 /*! \ingroup CGAL_Sqrt_extension
 \brief represents an extension of a number type by one square root.
@@ -77,16 +75,48 @@ Note that the extension of an UFDomain or EuclideanRing is just an
 IntegralDomain, since the extension in general destroys the unique
 factorization property.
 */
-template <class NT_,class ROOT_>
-class Sqrt_extension : 
-    boost::ordered_field_operators1< Sqrt_extension<NT_,ROOT_>,
-    boost::ordered_field_operators2< Sqrt_extension<NT_,ROOT_>, NT_ ,
-    boost::ordered_field_operators2< Sqrt_extension<NT_,ROOT_>, CGAL_int(NT_)
+
+namespace internal {
+template <class Tag>
+class Interval_optional_caching;
+
+//empty class
+template <>
+class Interval_optional_caching< ::CGAL::Tag_false >
+{
+protected:
+  void invalidate_interval() {}
+  bool is_cached() const {return false;}
+  std::pair<double,double> cached_value() const {return std::pair<double,double>();}
+  void update_cached_value(const std::pair<double,double>&) const {}
+};
+  
+ 
+template <>
+class Interval_optional_caching< ::CGAL::Tag_true >
+{
+protected:
+  typedef boost::optional< std::pair<double,double> > Cached_interval;
+  mutable Cached_interval interval_;
+  void invalidate_interval() {interval_=Cached_interval();}  
+  bool is_cached() const {return (interval_?true:false);}
+  std::pair<double,double> cached_value() const {return *interval_;}
+  void update_cached_value(const std::pair<double,double>& i) const {interval_=i;}
+};
+
+} //namespace internal
+
+template <class NT_,class ROOT_, class ACDE_TAG_, class FP_TAG>
+class Sqrt_extension : public internal::Interval_optional_caching<FP_TAG>,
+    boost::ordered_field_operators1< Sqrt_extension<NT_,ROOT_,ACDE_TAG_,FP_TAG>,
+    boost::ordered_field_operators2< Sqrt_extension<NT_,ROOT_,ACDE_TAG_,FP_TAG>, NT_ ,
+    boost::ordered_field_operators2< Sqrt_extension<NT_,ROOT_,ACDE_TAG_,FP_TAG>, CGAL_int(NT_)
 > > >{
 public:
     typedef NT_ NT;
     typedef ROOT_ ROOT;
-    typedef Sqrt_extension<NT,ROOT> Self;
+    typedef ACDE_TAG_ ACDE_TAG; 
+    typedef Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG> Self;
 private:
     NT a0_;
     NT a1_;
@@ -109,6 +139,10 @@ public:
     Sqrt_extension(const NT& i)
         : a0_(NT(i)), a1_(NT(0)), root_(ROOT(0)), is_extended_(false) {}
 
+    //non-documented: used for Make_sqrt
+    Sqrt_extension(const ROOT& root,bool)
+          :a0_(NT(0)), a1_(NT(1)), root_(root), is_extended_(true) {}
+          
     /*!\brief Explicit constructor of Sqrt_extension, from any type NTX.
      * \pre NT must constructible from NTX */
     template <class NTX>
@@ -116,7 +150,7 @@ public:
         : a0_(NT(i)), a1_(NT(0)), root_(ROOT(0)), is_extended_(false) {}
 
     /*! \brief copy constructor  */
-    Sqrt_extension(const Sqrt_extension<NT,ROOT>& x)
+    Sqrt_extension(const Self& x)
         : a0_(x.a0()),
           a1_(x.a1()),
           root_(x.root()),
@@ -143,33 +177,84 @@ public:
         : a0_(a0),
           a1_(a1),
           root_(root),
-          is_extended_(true){
-        CGAL_precondition( !CGAL_NTS is_zero(root));
+          is_extended_( true ){
+      CGAL_precondition( ACDE_TAG_::value || !CGAL_NTS is_zero(root) ); //if ACDE_TAG_ is Tag_true, we allow root to be 0
     }
 
+    /*! \brief Constructor of Sqrt_extension, from
+     *  \c polynomial. The bool
+     *  \pre NT must constructible from (NTX,NTX)
+     *  \pre ROOT must constructible from (NTX,NTX)
+     */    
+  template <class NTX>
+  explicit Sqrt_extension(const NTX& a, const NTX& b, const NTX& c, const bool is_smaller,
+    typename boost::enable_if< boost::mpl::and_<
+      boost::is_same< typename Fraction_traits<NT>::Numerator_type,NTX >,
+      boost::is_same< typename Fraction_traits<ROOT>::Numerator_type,NTX >
+    > >::type* = 0  )
+  {
+    typename Fraction_traits<NT>::Compose compose_nt;
+    if ( a != 0 ) {
+      a0_ = compose_nt(-b,2*a);
+      root_ = CGAL_NTS square(a0_) - ROOT(c,a);
+      if(CGAL_NTS is_zero(root_)) {
+	is_extended_ = false;
+      } else {
+	a1_ = (is_smaller ? -1 : 1);
+	is_extended_ = true;
+      }
+    }
+    else {
+      CGAL_assertion( b != 0 );
+      is_extended_ = false;
+      a0_ = compose_nt(-c,b);
+      a1_ = 0;
+      root_ = 0;
+    }
+  }
+
+  
+  Self conjugate() const
+  {
+    if(!is_extended_) return *this;
+    return Self(a0_,-a1_,root_);
+  }
+
     //! Access operator for a0_, \c const
     inline const NT& a0() const { return a0_; }
+    inline const NT& alpha() const { return a0_; } //for backward compatibility
     //! Access operator for a0_
     NT&        a0()       { return a0_; }
+    NT&        alpha()       { return a0_; } //for backward compatibility
     //! Access operator for a1_, \c const
     inline const NT& a1() const { return a1_; }
+    inline const NT& beta() const { return a1_; }  //for backward compatibility
     //! Access operator for a1_
     NT&        a1()       { return a1_; }
+    NT&        beta()       { return a1_; }  //for backward compatibility
     //! Access operator for root_, \c const
-    inline const ROOT& root() const { return root_; }
+    inline const ROOT& root() const { return root_; }  
+    inline const ROOT& gamma() const { return root_; }  //for backward compatibility
     //! Access operator for is_extended_, \c const
     inline const bool& is_extended() const { return is_extended_; }
+    inline bool is_rational() const {
+      CGAL_precondition( (boost::is_same<NT,ROOT>::value) || !"NT and ROOT should be identical and rational");
+      return !is_extended_;} //for backward compatibility
+    
+    //!check if the number is an extension (test the values) and update the internal flag
+    inline bool check_if_is_extended() {
+      if(CGAL_NTS is_zero(a1_) || CGAL_NTS is_zero(root_)) 
+        is_extended_ = false;
+      return is_extended_;
+    }
+    
     //! Access operator for root_
     //ROOT& root() { return root_; }
 
     // TODO: add to documentation
-    static void check_roots(const Self& a, const Self b ) {
-        if(a.is_extended() && b.is_extended()){
-            if (a.root() != b.root()){
-                //CGAL_error_msg("Interoperation of incompatible algebraic extensions");
-                throw std::range_error("Interoperation of incompatible algebraic extensions");
-            }
-        }
+    static void check_roots(const Self& a, const Self& b ) {
+      if(a.is_extended() && b.is_extended())
+        CGAL_precondition (a.root() == b.root());
     }
 
     // output_maple function for EXACUS compatibility
@@ -178,19 +263,27 @@ public:
         CGAL::output_maple( os, *this );
     }
 
-    std::pair<double, double> to_interval() const{
-   
-    if (! is_extended_)
-        return CGAL_NTS to_interval(a0_);
-    
-    const CGAL::Interval_nt<true>&  a0_int = CGAL_NTS to_interval(a0_);
-    const CGAL::Interval_nt<true>&  a1_int = CGAL_NTS to_interval(a1_);
-    const CGAL::Interval_nt<true>&  root_int = CGAL_NTS to_interval(root_);
-    const CGAL::Interval_nt<true>&  x_int = 
-        a0_int + (a1_int * CGAL::sqrt(root_int));
+    std::pair<double, double> compute_to_interval() const
+    {
+      if (! is_extended_)
+          return CGAL_NTS to_interval(a0_);
+      CGAL::Interval_nt<false>::Protector p;
+      const CGAL::Interval_nt<false>&  a0_int = CGAL_NTS to_interval(a0_);
+      const CGAL::Interval_nt<false>&  a1_int = CGAL_NTS to_interval(a1_);
+      const CGAL::Interval_nt<false>&  root_int = CGAL_NTS to_interval(root_);
+      const CGAL::Interval_nt<false>&  x_int = 
+          a0_int + (a1_int * CGAL::sqrt(root_int));
 
-    return (std::make_pair (x_int.inf(), x_int.sup()));
-}
+      std::pair<double, double> res(x_int.inf(), x_int.sup());
+      this->update_cached_value(res);
+      return res;
+    }
+    
+    std::pair<double,double> to_interval() const
+    {
+      std::pair<double,double> ret=this->is_cached()?this->cached_value():compute_to_interval();
+      return ret;
+    }    
 
     //! propagates the simplify command to the members of xx
     void simplify(){
@@ -231,14 +324,14 @@ public:
         if (! is_extended_)
             return CGAL_NTS sign(a0());
 
-#ifdef SQRT_EXT_USE_FILTER
-        const std::pair<double, double>&  x_in = this->to_interval(); 
+        if (FP_TAG::value){
+          const std::pair<double, double>&  x_in = this->to_interval(); 
 
-        if (x_in.first > 0)
-          return (CGAL::POSITIVE);
-        else if (x_in.second < 0)
-          return (CGAL::NEGATIVE);
-#endif
+          if (x_in.first > 0)
+            return (CGAL::POSITIVE);
+          else if (x_in.second < 0)
+            return (CGAL::NEGATIVE);
+        }
 
         return (this->sign_());
     }
@@ -278,9 +371,12 @@ public:
     }
 
     Self& operator += (const Self& p) {
+      this->invalidate_interval();
         if(is_extended_){
             if (p.is_extended_){
+                #ifndef NDEBUG
                 Self::check_roots(*this, p);
+                #endif
                 return *this = Self (a0_+p.a0_, a1_+p.a1_, root_);
             }else{
                 return *this = Self (a0_+p.a0_, a1_, root_);
@@ -294,10 +390,12 @@ public:
     }
 
     Self& operator -= (const Self& p) {
-
+      this->invalidate_interval();
         if(is_extended_){
             if (p.is_extended_){
+                #ifndef NDEBUG
                 Self::check_roots(*this, p);
+                #endif
                 return *this = Self (a0_-p.a0_, a1_-p.a1_, root_);
             }else{
                 return *this = Self (a0_-p.a0_, a1_, root_);
@@ -310,10 +408,13 @@ public:
         }
     }
       
-    Self& operator *= (const Self& p){        
+    Self& operator *= (const Self& p){   
+      this->invalidate_interval();
         if(is_extended_){
             if (p.is_extended_){
+                #ifndef NDEBUG
                 Self::check_roots(*this, p);
+                #endif
                 return *this = Self (
                         a0_*p.a0_+a1_*p.a1_*Root_nt_cast()(root_),  
                         a0_*p.a1_+a1_*p.a0_,
@@ -329,6 +430,7 @@ public:
         }   
     }
     Self& operator /= (const Self& p) {
+      this->invalidate_interval();
 
         CGAL_assertion( ! CGAL_NTS is_zero(p) );
         typename CGAL::Algebraic_structure_traits<NT>::Integral_division idiv;
@@ -357,19 +459,23 @@ public:
 // SPECIALIZE_MEMBERS NT
 
     Self& operator += (const NT& num) {
+      this->invalidate_interval();
         a0() += NT(num);
         return *this;
     }
     Self& operator -= (const NT& num) {
+      this->invalidate_interval();
         a0() -= NT(num);
         return *this;
     }
     Self& operator *= (const NT& num) {
+      this->invalidate_interval();
         a0() *= NT(num);
         a1() *= NT(num);
         return *this;
     }
     Self& operator /= (const NT& num) {
+      this->invalidate_interval();
         CGAL_assertion(! CGAL_NTS is_zero(num));
         a0() /= NT(num);
         a1() /= NT(num);
@@ -377,19 +483,23 @@ public:
     }
 
    Self& operator += (CGAL_int(NT) num) {
+      this->invalidate_interval();
         a0() += NT(num);
         return *this;
     }
     Self& operator -= (CGAL_int(NT) num) {
+      this->invalidate_interval();
         a0() -= NT(num);
         return *this;
     }
     Self& operator *= (CGAL_int(NT) num) {
+      this->invalidate_interval();
         a0() *= NT(num);
         a1() *= NT(num);
         return *this;
     }
     Self& operator /= (CGAL_int(NT) num) {
+      this->invalidate_interval();
         CGAL_assertion(! CGAL_NTS is_zero(num));
         a0() /= NT(num);
         a1() /= NT(num);
@@ -409,15 +519,15 @@ compare (const NT& num) const {
     if (! is_extended_)
         return (CGAL::compare (a0_, num));
 
-#ifdef SQRT_EXT_USE_FILTER
-    const std::pair<double, double>&  x_in = this->to_interval(); 
-    const std::pair<double, double>&  y_in = CGAL::to_interval (num); 
-    
-    if (x_in.second < y_in.first)
-      return (SMALLER);
-    else if (x_in.first > y_in.second)
-      return (LARGER);
-#endif
+    if (FP_TAG::value){
+      const std::pair<double, double>&  x_in = this->to_interval(); 
+      const std::pair<double, double>&  y_in = CGAL::to_interval (num); 
+      
+      if (x_in.second < y_in.first)
+        return (SMALLER);
+      else if (x_in.first > y_in.second)
+        return (LARGER);
+    }
 
     return ((Self(a0_ - num, a1_, root_)).sign_());
 }
@@ -426,7 +536,7 @@ compare (const NT& num) const {
 // However, the default is, that the the numbers are defined over the same
 // extension. 
 CGAL::Comparison_result
-compare(const Self& y, bool in_same_extension = true ) const
+  compare(const Self& y, bool in_same_extension = !ACDE_TAG::value ) const
 {
     if (! is_extended_)
         return (CGAL::opposite (y.compare (a0_)));
@@ -436,15 +546,16 @@ compare(const Self& y, bool in_same_extension = true ) const
     if (in_same_extension)
         return ((*this) - y).sign();
 
-#ifdef SQRT_EXT_USE_FILTER
-    const std::pair<double, double>&  x_in = this->to_interval(); 
-    const std::pair<double, double>&  y_in = y.to_interval(); 
-    
-    if (x_in.second < y_in.first)
-      return (SMALLER);
-    else if (x_in.first > y_in.second)
-      return (LARGER);
-#endif
+    if (FP_TAG::value)
+    {
+      const std::pair<double, double>&  x_in = this->to_interval(); 
+      const std::pair<double, double>&  y_in = y.to_interval(); 
+      
+      if (x_in.second < y_in.first)
+        return (SMALLER);
+      else if (x_in.first > y_in.second)
+        return (LARGER);
+    }
 
   // Perform the exact comparison:
   // Note that the comparison of (a1 + b1*sqrt(c1)) and (a2 + b2*sqrt(c2))
@@ -541,95 +652,130 @@ compare(const Self& y, bool in_same_extension = true ) const
 }
 };
 
-// UNARY 
-template <class NT,class ROOT> Sqrt_extension<NT,ROOT>
-operator + (const Sqrt_extension<NT,ROOT>& p) { return p; }
+/*!
+ * Compute the square of a one-root number.
+ */
+template <class NT,class ROOT,class ACDE_TAG,class FP_TAG>
+Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG> square (const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>& x)
+{
+  if (!x.is_extended())
+    return Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG> (x.alpha() * x.alpha());
 
-template <class NT,class ROOT> Sqrt_extension<NT,ROOT>
-operator - (const Sqrt_extension<NT,ROOT>& p){
+  // Use the equation:
+  //
+  //   (a + b*sqrt(c))^2 = (a^2 + b^2*c) + 2ab*sqrt(c)
+  //
+  return (Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG> (x.alpha()*x.alpha() + x.beta()*x.beta() * NT(x.gamma()),
+                                2 * x.alpha() * x.beta(),
+                                x.gamma()));
+}
+
+// UNARY 
+template <class NT,class ROOT,class ACDE_TAG,class FP_TAG> Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>
+  operator + (const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>& p) { return p; }
+
+template <class NT,class ROOT,class ACDE_TAG,class FP_TAG> Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>
+operator - (const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>& p){
     if(p.is_extended())
-        return  Sqrt_extension<NT,ROOT>(-p.a0(),-p.a1(),p.root());
+      return  Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>(-p.a0(),-p.a1(),p.root());
     else
-        return  Sqrt_extension<NT,ROOT>(-p.a0());
+      return  Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>(-p.a0());
 }
 
 
 // BINARY 
-template <class NT,class ROOT> bool
-operator == (const Sqrt_extension<NT,ROOT>& p1, const Sqrt_extension<NT,ROOT>& p2)
-{ return (p1-p2).is_zero() ; }
-template <class NT,class ROOT> bool
-operator < (const Sqrt_extension<NT,ROOT>& p1, const Sqrt_extension<NT,ROOT>& p2)
+template <class NT,class ROOT,class FP_TAG> bool
+operator == (const Sqrt_extension<NT,ROOT,Tag_false,FP_TAG>& p1, const Sqrt_extension<NT,ROOT,Tag_false,FP_TAG>& p2)
+{ return (p1-p2).is_zero(); }
+template <class NT,class ROOT,class FP_TAG> bool
+operator == (const Sqrt_extension<NT,ROOT,Tag_true,FP_TAG>& p1, const Sqrt_extension<NT,ROOT,Tag_true,FP_TAG>& p2)
+{ return ( p1.compare(p2) == CGAL::ZERO ); }
+template <class NT,class ROOT,class ACDE_TAG,class FP_TAG> bool
+operator < (const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>& p1, const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>& p2)
 { return ( p1.compare(p2) == CGAL::SMALLER ); }
 
 
 // NT
 // righthand side
-template <class NT,class ROOT>   bool operator ==
-(const Sqrt_extension<NT,ROOT>& p, const NT& num)
+template <class NT,class ROOT,class ACDE_TAG,class FP_TAG>   bool operator ==
+(const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>& p, const NT& num)
 { return (p-num).is_zero();}
-template <class NT,class ROOT>    bool operator <
-(const Sqrt_extension<NT,ROOT>& p, const NT& num)
+template <class NT,class ROOT,class ACDE_TAG,class FP_TAG>    bool operator <
+(const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>& p, const NT& num)
 { return ( p.compare(num) == CGAL::SMALLER ); }
-template <class NT,class ROOT>    bool operator >
-(const Sqrt_extension<NT,ROOT>& p, const NT& num)
+template <class NT,class ROOT,class ACDE_TAG,class FP_TAG>    bool operator >
+(const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>& p, const NT& num)
 { return ( p.compare(num) == CGAL::LARGER ); }
 
 // lefthand side
-template <class NT,class ROOT> bool operator ==
-(const NT& num, const Sqrt_extension<NT,ROOT>& p)
+template <class NT,class ROOT,class ACDE_TAG,class FP_TAG> bool operator ==
+(const NT& num, const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>& p)
 { return  ( p == num );}
-template <class NT,class ROOT>  bool operator <
-(const NT& num, const Sqrt_extension<NT,ROOT>& p)
+template <class NT,class ROOT,class ACDE_TAG,class FP_TAG>  bool operator <
+(const NT& num, const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>& p)
 { return ( p.compare(num) == CGAL::LARGER ); }
-template <class NT,class ROOT>  bool operator >
-(const NT& num, const Sqrt_extension<NT,ROOT>& p)
+template <class NT,class ROOT,class ACDE_TAG,class FP_TAG>  bool operator >
+(const NT& num, const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>& p)
 { return ( p.compare(num) == CGAL::SMALLER ); }
 
 
 //CGAL_int(NT)
-template <class NT,class ROOT>    bool operator ==
-(const Sqrt_extension<NT,ROOT>& p, CGAL_int(NT) num)
+template <class NT,class ROOT,class ACDE_TAG,class FP_TAG>    bool operator ==
+(const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>& p, CGAL_int(NT) num)
 { return (p-num).is_zero();}
-template <class NT,class ROOT>    bool operator <
-(const Sqrt_extension<NT,ROOT>& p, CGAL_int(NT) num)
+template <class NT,class ROOT,class ACDE_TAG,class FP_TAG>    bool operator <
+(const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>& p, CGAL_int(NT) num)
 { return ( p.compare(num) == CGAL::SMALLER ); }
-template <class NT,class ROOT>    bool operator >
-(const Sqrt_extension<NT,ROOT>& p, CGAL_int(NT) num)
+template <class NT,class ROOT,class ACDE_TAG,class FP_TAG>    bool operator >
+(const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>& p, CGAL_int(NT) num)
 { return ( p.compare(num) == CGAL::LARGER ); }
 
-template <class NT,class ROOT> bool operator ==
-(CGAL_int(NT) num, const Sqrt_extension<NT,ROOT>& p)
+template <class NT,class ROOT,class ACDE_TAG,class FP_TAG> bool operator ==
+(CGAL_int(NT) num, const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>& p)
 { return  ( p == num );}
-template <class NT,class ROOT>  bool operator <
-(CGAL_int(NT) num, const Sqrt_extension<NT,ROOT>& p)
+template <class NT,class ROOT,class ACDE_TAG,class FP_TAG>  bool operator <
+(CGAL_int(NT) num, const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>& p)
 { return ( p.compare(num) == CGAL::LARGER ); }
-template <class NT,class ROOT>  bool operator >
-(CGAL_int(NT) num, const Sqrt_extension<NT,ROOT>& p)
+template <class NT,class ROOT,class ACDE_TAG,class FP_TAG>  bool operator >
+(CGAL_int(NT) num, const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>& p)
 { return ( p.compare(num) == CGAL::SMALLER ); }
 
-template<typename NT, typename ROOT> inline 
-Sqrt_extension<NT,ROOT> min BOOST_PREVENT_MACRO_SUBSTITUTION(
-const Sqrt_extension<NT,ROOT> & x,
-const Sqrt_extension<NT,ROOT> & y){
+template<class NT, class ROOT,class ACDE_TAG,class FP_TAG> inline 
+Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG> min BOOST_PREVENT_MACRO_SUBSTITUTION(
+const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG> & x,
+const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG> & y){
   return (std::min)(x,y);
 }
-template<typename NT, typename ROOT> inline 
-Sqrt_extension<NT,ROOT> max BOOST_PREVENT_MACRO_SUBSTITUTION(
-const Sqrt_extension<NT,ROOT> & x,
-const Sqrt_extension<NT,ROOT> & y){
+template<class NT, class ROOT,class ACDE_TAG,class FP_TAG> inline 
+Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG> max BOOST_PREVENT_MACRO_SUBSTITUTION(
+const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG> & x,
+const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG> & y){
   return (std::max)(x,y);
 }
 
-template <class NT, class ROOT> inline 
+template <class NT, class ROOT,class ACDE_TAG,class FP_TAG> inline 
 CGAL::Comparison_result compare (
-    const Sqrt_extension<NT,ROOT>& x, 
-    const Sqrt_extension<NT,ROOT>& y,
-    bool in_same_extension = true ){
+    const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>& x, 
+    const Sqrt_extension<NT,ROOT,ACDE_TAG,FP_TAG>& y,
+    bool in_same_extension = !ACDE_TAG::value ){
   return x.compare(y,in_same_extension);
 }
 
-CGAL_END_NAMESPACE
+
+template <class NT_,class ROOT_, class ACDE_TAG_, class FP_TAG>
+void
+print(std::ostream &os, const Sqrt_extension<NT_,ROOT_,ACDE_TAG_,FP_TAG> &r)
+{
+  if(!r.is_extended()) {
+    os << "(" << r.a0() << ")";
+  } else {
+    os << "(" << r.a0() << " + " << r.a1() <<
+          "*sqrt(" << r.root() << ")"<< ")";
+  }
+}
+
+
+} //namespace CGAL
 
 #undef CGAL_int
 
