@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Surface_mesher/include/CGAL/Surface_mesher/Implicit_surface_oracle_3.h $
-// $Id: Implicit_surface_oracle_3.h 47824 2009-01-26 15:22:57Z lrineau $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Surface_mesher/include/CGAL/Surface_mesher/Implicit_surface_oracle_3.h $
+// $Id: Implicit_surface_oracle_3.h 64637 2011-07-06 11:11:58Z lrineau $
 //
 //
 // Author(s)     : Steve OUDOT, Laurent RINEAU
@@ -25,6 +25,7 @@
 #include <CGAL/point_generators_3.h>
 #include <CGAL/Surface_mesher/Sphere_oracle_3.h>
 #include <CGAL/Real_embeddable_traits.h>
+#include <CGAL/Surface_mesher/Profile_counter.h>
 
 #include <boost/mpl/has_xxx.hpp>
 
@@ -49,7 +50,7 @@ namespace CGAL {
 #ifdef  BOOST_MPL_CFG_NO_HAS_XXX
 #  error "BOOST_MPL_HAS_XXX_TRAIT_DEF is needed!"
 #else
-   BOOST_MPL_HAS_XXX_TRAIT_NAMED_DEF(has_set_on_surface, Set_on_surface_tag, true);
+   BOOST_MPL_HAS_XXX_TRAIT_NAMED_DEF(has_set_on_surface, Set_on_surface_tag, true)
 #endif
 
   namespace Surface_mesher {
@@ -303,7 +304,7 @@ namespace CGAL {
         }
         else
           return Object();
-      }; // end operator()(Surface_3, Line_3)
+      } // end operator()(Surface_3, Line_3)
 
       // debug function
       std::string debug_point(const Surface_3& surface,
