@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Intersections_3/include/CGAL/Triangle_3_Line_3_do_intersect.h $
-// $Id: Triangle_3_Line_3_do_intersect.h 53116 2009-11-20 12:36:02Z stayeb $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Intersections_3/include/CGAL/Triangle_3_Line_3_do_intersect.h $
+// $Id: Triangle_3_Line_3_do_intersect.h 56667 2010-06-09 07:37:13Z sloriot $
 // 
 //
 // Author(s)     : Philippe Guigue
@@ -21,7 +21,7 @@
 #ifndef CGAL_TRIANGLE_3_LINE_3_DO_INTERSECT_H
 #define CGAL_TRIANGLE_3_LINE_3_DO_INTERSECT_H
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 namespace internal {
 
@@ -134,6 +134,6 @@ inline bool do_intersect(const Line_3<K> &l,
 }
 */
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif //CGAL_TRIANGLE_3_LINE_3_DO_INTERSECT_H
