@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Voronoi_diagram_2/include/CGAL/Voronoi_diagram_2.h $
-// $Id: Voronoi_diagram_2.h 46258 2008-10-14 07:47:16Z afabri $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Voronoi_diagram_2/include/CGAL/Voronoi_diagram_2.h $
+// $Id: Voronoi_diagram_2.h 64637 2011-07-06 11:11:58Z lrineau $
 // 
 //
 // Author(s)     : Menelaos Karavelas <mkaravel@iacm.forth.gr>
@@ -46,7 +46,7 @@
 
 #include <boost/variant.hpp>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 //=========================================================================
 //=========================================================================
@@ -746,6 +746,7 @@ public:
   // insert is not really supported...
   inline Face_handle insert(const Site_2& t, const Tag_false&) {
     INSERT_IS_NOT_SUPPORTED(t);
+    return Face_handle();
   }
 
  public:
@@ -821,6 +822,6 @@ std::istream& operator>>(std::istream& is,
 }
 
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_VORONOI_DIAGRAM_2_H
