@@ -1,4 +1,4 @@
-// Copyright (c) 2002 Utrecht University (The Netherlands).
+// Copyright (c) 2002,2011 Utrecht University (The Netherlands).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Spatial_searching/include/CGAL/Weighted_Minkowski_distance.h $
-// $Id: Weighted_Minkowski_distance.h 36920 2007-03-08 10:05:31Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Spatial_searching/include/CGAL/Weighted_Minkowski_distance.h $
+// $Id: Weighted_Minkowski_distance.h 64637 2011-07-06 11:11:58Z lrineau $
 // 
 //
 // Author(s)     : Hans Tangelder (<hanst@cs.uu.nl>)
@@ -30,7 +30,7 @@ namespace CGAL {
 
   template <class SearchTraits>
   class Weighted_Minkowski_distance {
-
+    SearchTraits traits;
     public:
 
     typedef typename SearchTraits::Point_d Point_d;
@@ -49,12 +49,12 @@ namespace CGAL {
 
 
     // default constructor
-    Weighted_Minkowski_distance()
-      : power(2) 
+    Weighted_Minkowski_distance(const SearchTraits& traits_=SearchTraits())
+      : traits(traits_),power(2) 
     {}
 
-    Weighted_Minkowski_distance(const int d) 
-      : power(2), the_weights(d)
+    Weighted_Minkowski_distance(const int d,const SearchTraits& traits_=SearchTraits()) 
+      : traits(traits_),power(2), the_weights(d)
     {
       for (unsigned int i = 0; i < d; ++i) the_weights[i]=FT(1);
     }
@@ -63,8 +63,9 @@ namespace CGAL {
     
 
     Weighted_Minkowski_distance (FT pow, int dim,
-				 const Weight_vector& weights) 
-      : power(pow)
+				 const Weight_vector& weights,
+                                 const SearchTraits& traits_=SearchTraits()) 
+      : traits(traits_),power(pow)
     {
       CGAL_assertion(power >= FT(0));
       CGAL_assertion(dim==weights.size());
@@ -76,8 +77,9 @@ namespace CGAL {
 
     template <class InputIterator>
     Weighted_Minkowski_distance (FT pow, int dim,
-				 InputIterator begin, InputIterator end) 
-      : power(pow)
+				 InputIterator begin, InputIterator end,
+                                 const SearchTraits& traits_=SearchTraits()) 
+      : traits(traits_),power(pow)
     {
       CGAL_assertion(power >= FT(0));
       the_weights.resize(dim);
@@ -96,19 +98,20 @@ namespace CGAL {
     transformed_distance(const Query_item& q, const Point_d& p) 
     {
       FT distance = FT(0);
-      typename SearchTraits::Construct_cartesian_const_iterator_d construct_it;
+      typename SearchTraits::Construct_cartesian_const_iterator_d construct_it=
+        traits.construct_cartesian_const_iterator_d_object();
       Coord_iterator qit = construct_it(q),
 	             qe = construct_it(q,1), 
 	             pit = construct_it(p);
       if (power == FT(0)) {
 	for (unsigned int i = 0; qit != qe; ++qit, ++i)
-	  if (the_weights[i] * std::fabs((*qit) - (*pit)) > distance)
-	    distance = the_weights[i] * std::fabs((*qit)-(*pit));
+	  if (the_weights[i] * CGAL::abs((*qit) - (*pit)) > distance)
+	    distance = the_weights[i] * CGAL::abs((*qit)-(*pit));
       }
       else
 	for (unsigned int i = 0; qit != qe; ++qit, ++i)
 	  distance += 
-	    the_weights[i] * std::pow(std::fabs((*qit)-(*pit)),power);
+	    the_weights[i] * std::pow(CGAL::abs((*qit)-(*pit)),power);
       return distance;
     }
     
@@ -116,10 +119,11 @@ namespace CGAL {
     inline 
     FT 
     min_distance_to_rectangle(const Query_item& q,
-			      const Kd_tree_rectangle<SearchTraits>& r) const 
+			      const Kd_tree_rectangle<FT>& r) const 
     {
       FT distance = FT(0);
-      typename SearchTraits::Construct_cartesian_const_iterator_d construct_it;
+      typename SearchTraits::Construct_cartesian_const_iterator_d construct_it=
+        traits.construct_cartesian_const_iterator_d_object();
       Coord_iterator qit = construct_it(q), qe = construct_it(q,1);
       if (power == FT(0))
 	{
@@ -151,9 +155,10 @@ namespace CGAL {
     inline 
     FT
     max_distance_to_rectangle(const Query_item& q,
-			      const Kd_tree_rectangle<SearchTraits>& r) const {
+			      const Kd_tree_rectangle<FT>& r) const {
       FT distance=FT(0);
-      typename SearchTraits::Construct_cartesian_const_iterator_d construct_it;
+      typename SearchTraits::Construct_cartesian_const_iterator_d construct_it=
+        traits.construct_cartesian_const_iterator_d_object();
       Coord_iterator qit = construct_it(q), qe = construct_it(q,1);
       if (power == FT(0))
 	{
@@ -192,16 +197,16 @@ namespace CGAL {
       FT new_dist;
       if (power == FT(0))
 	{
-	  if (the_weights[cutting_dimension]*std::fabs(new_off) 
+	  if (the_weights[cutting_dimension]*CGAL::abs(new_off) 
 	      > dist) 
 	    new_dist= 
-	      the_weights[cutting_dimension]*std::fabs(new_off);
+	      the_weights[cutting_dimension]*CGAL::abs(new_off);
 	  else new_dist=dist;
 	}
       else
 	{
 	  new_dist = dist + the_weights[cutting_dimension] * 
-	    (std::pow(std::fabs(new_off),power)-std::pow(std::fabs(old_off),power));
+	    (std::pow(CGAL::abs(new_off),power)-std::pow(CGAL::abs(old_off),power));
 	}
       return new_dist;
     }
