@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Point_set_processing_3/include/CGAL/compute_average_spacing.h $
-// $Id: compute_average_spacing.h 52628 2009-10-20 08:59:26Z lrineau $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Point_set_processing_3/include/CGAL/compute_average_spacing.h $
+// $Id: compute_average_spacing.h 63388 2011-05-06 10:24:08Z lrineau $
 //
 // Author(s) : Pierre Alliez and Laurent Saboret
 
@@ -27,7 +27,7 @@
 #include <iterator>
 #include <list>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 
 // ----------------------------------------------------------------------------
@@ -117,7 +117,7 @@ compute_average_spacing(
   InputIterator beyond, ///< past-the-end iterator over the input points.
   PointPMap point_pmap, ///< property map InputIterator -> Point_3
   unsigned int k, ///< number of neighbors.
-  const Kernel& kernel) ///< geometric traits.
+  const Kernel& /*kernel*/) ///< geometric traits.
 {
   // basic geometric types
   typedef typename Kernel::Point_3 Point;
@@ -136,12 +136,10 @@ compute_average_spacing(
   // precondition: at least 2 nearest neighbors
   CGAL_point_set_processing_precondition(k >= 2);
 
-  InputIterator it;
-
   // Instanciate a KD-tree search.
   // Note: We have to convert each input iterator to Point_3.
   std::vector<Point> kd_tree_points; 
-  for(it = first; it != beyond; it++)
+  for(InputIterator it = first; it != beyond; it++)
   {
       Point point = get(point_pmap, it);
       kd_tree_points.push_back(point);
@@ -152,7 +150,7 @@ compute_average_spacing(
   // vectors (already normalized)
   FT sum_spacings = (FT)0.0;
   unsigned int nb_points = 0;
-  for(it = first; it != beyond; it++)
+  for(InputIterator it = first; it != beyond; it++)
   {
     sum_spacings += internal::compute_average_spacing<Kernel,Tree>(get(point_pmap,it),tree,k);
     nb_points++;
@@ -201,7 +199,7 @@ compute_average_spacing(
 /// @endcond
 
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_AVERAGE_SPACING_3_H
 
