@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Kernel_d/include/CGAL/constructions_d.h $
-// $Id: constructions_d.h 28567 2006-02-16 14:30:13Z lsaboret $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Kernel_d/include/CGAL/constructions_d.h $
+// $Id: constructions_d.h 59745 2010-11-17 10:25:51Z lrineau $
 // 
 //
 // Author(s)     : Michael Seel
@@ -24,7 +24,9 @@
 #ifndef CGAL_CONSTRUCTIONS_D_H
 #define CGAL_CONSTRUCTIONS_D_H
 
-CGAL_BEGIN_NAMESPACE
+#include <CGAL/Kernel_d/Point_d.h>
+
+namespace CGAL {
 
 /*{\Moptions outfile=constructions_d.man}*/
 
@@ -76,6 +78,5 @@ in |result|. The returned iterator marks the end of the output.
 }
 
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 #endif // CGAL_CONSTRUCTIONS_D_H
-
