@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Convex_hull_2/include/CGAL/convex_hull_2.h $
-// $Id: convex_hull_2.h 41433 2008-01-03 19:02:00Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Convex_hull_2/include/CGAL/convex_hull_2.h $
+// $Id: convex_hull_2.h 56667 2010-06-09 07:37:13Z sloriot $
 // 
 //
 // Author(s)     : Stefan Schirra
@@ -26,7 +26,7 @@
 #include <CGAL/ch_bykat.h>
 #include <iterator> 
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template <class InputIterator, class OutputIterator, class Traits>
 inline
@@ -188,6 +188,6 @@ upper_hull_points_2(ForwardIterator first, ForwardIterator last,
     return upper_hull_points_2(first, last, result, Kernel());
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_CONVEX_HULL_2_H
