@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Convex_hull_2/include/CGAL/convex_hull_constructive_traits_2.h $
-// $Id: convex_hull_constructive_traits_2.h 51456 2009-08-24 17:10:04Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Convex_hull_2/include/CGAL/convex_hull_constructive_traits_2.h $
+// $Id: convex_hull_constructive_traits_2.h 56667 2010-06-09 07:37:13Z sloriot $
 // 
 //
 // Author(s)     : Stefan Schirra
@@ -26,7 +26,7 @@
 
 #include <CGAL/ch_function_objects_2.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 template <class K_>
 class Convex_hull_constructive_traits_2 : public K_
 {
@@ -75,7 +75,6 @@ class convex_hull_constructive_traits_2 :
 {
 };
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_CONVEX_HULL_CONSTRUCTIVE_TRAITS_2_H
-
