@@ -1,4 +1,4 @@
-// Copyright (c) 2001  Max-Planck-Institute Saarbruecken (Germany).
+// Copyright (c) 2001,2011  Max-Planck-Institute Saarbruecken (Germany).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Convex_hull_3/include/CGAL/convex_hull_incremental_3.h $
-// $Id: convex_hull_incremental_3.h 31432 2006-06-05 11:07:27Z wein $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Convex_hull_3/include/CGAL/convex_hull_incremental_3.h $
+// $Id: convex_hull_incremental_3.h 64637 2011-07-06 11:11:58Z lrineau $
 // 
 //
 // Author(s)     : Stefan Schirra <Stefan.Schirra@mpi-sb.mpg.de>
@@ -26,7 +26,7 @@
 #include <CGAL/Convex_hull_d_to_polyhedron_3.h>
 #include <CGAL/Convex_hull_2/ch_assertions.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template <class InputIterator, class Polyhedron>
 void
@@ -41,9 +41,10 @@ convex_hull_incremental_3(InputIterator first, InputIterator beyond,
   ChullType CH(3);
   for ( ; first != beyond ; ++first)  CH.insert(*first);
   if ( test_correctness ) CGAL_ch_assertion(CH.is_valid());
+  P.clear();
   CGAL::convex_hull_d_to_polyhedron_3(CH,P);
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_CONVEX_HULL_INCREMENTAL_3_H
