@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Number_types/include/CGAL/double.h $
-// $Id: double.h 44911 2008-08-12 13:09:51Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Number_types/include/CGAL/double.h $
+// $Id: double.h 62108 2011-04-01 14:01:17Z afabri $
 //
 //
 // Author(s)     : Geert-Jan Giezeman, Michael Hemmer
@@ -31,6 +31,9 @@
 #include <math.h> // for nextafter
 #include <limits>
 
+#ifdef CGAL_USE_SSE2_FABS
+#include <CGAL/sse2.h>
+#endif
 
 #ifdef _MSC_VER
 #include <cfloat>
@@ -40,7 +43,7 @@
 #  include <CGAL/IEEE_754_unions.h>
 #endif
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 #ifdef CGAL_CFG_IEEE_754_BUG
 
@@ -119,17 +122,41 @@ template <> class Algebraic_structure_traits< double >
 
 };
 
+
+  
+#ifdef CGAL_USE_SSE2_FABS   
+inline double sse2fabs(double a)
+{
+  static CGAL_ALIGN_16 const union{
+    __int64 i[2];
+    __m128d m;
+  } absMask = {0x7fffffffffffffff, 0x7fffffffffffffff};
+	  
+  __m128d temp = _mm_set1_pd(a);
+  
+  temp = _mm_and_pd(temp, absMask.m);
+  _mm_store_sd(&a, temp);
+  return a;
+}
+
+#endif
+
 template <> class Real_embeddable_traits< double >
   : public INTERN_RET::Real_embeddable_traits_base< double , CGAL::Tag_true> {
   public:
 
+
 // GCC is faster with std::fabs().
-#ifdef __GNUG__
+#if defined(__GNUG__) || defined(CGAL_MSVC_USE_STD_FABS) || defined(CGAL_USE_SSE2_FABS)
     class Abs
       : public std::unary_function< Type, Type > {
       public:
         Type operator()( const Type& x ) const {
+#ifdef CGAL_USE_SSE2_FABS
+          return sse2fabs(x);
+#else         
           return std::fabs( x );
+#endif
         }
     };
 #endif
@@ -189,6 +216,6 @@ split_numerator_denominator(double d)
   return std::make_pair(num, den);
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_DOUBLE_H
