@@ -1,4 +1,4 @@
-// Copyright (c) 2005  Tel-Aviv University (Israel).
+// Copyright (c) 2007,2009,2010,2011 Tel-Aviv University (Israel).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Arrangement_on_surface_2/include/CGAL/graph_traits_Arrangement_2.h $
-// $Id: graph_traits_Arrangement_2.h 50780 2009-07-23 12:15:34Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Arrangement_on_surface_2/include/CGAL/graph_traits_Arrangement_2.h $
+// $Id: graph_traits_Arrangement_2.h 64639 2011-07-06 11:41:06Z lrineau $
 // 
 //
 // Author(s)     : Ron Wein <wein@post.tau.ac.il>
@@ -293,7 +293,7 @@ public:
     if (v->is_isolated())
       return out_edge_iterator();
 
-    return out_edge_iterator (v->incident_halfedges(), true, 0, v->degree());
+    return out_edge_iterator (v->incident_halfedges(), true, 0, static_cast<int>(v->degree()));
   }
 
   out_edge_iterator out_edges_end (vertex_descriptor v)
@@ -301,7 +301,7 @@ public:
     if (v->is_isolated())
       return out_edge_iterator ();
 
-    const int  deg = v->degree();
+    const int  deg = static_cast<int>(v->degree());
     return out_edge_iterator (v->incident_halfedges(), true, deg, deg);
   }
 
@@ -349,9 +349,9 @@ public:
   {}
 };
 
-}; // namespace boost
+} // namespace boost
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 // Functions required by the IncidenceGraph concept:
 // -------------------------------------------------
@@ -600,6 +600,6 @@ edges (const CGAL::Arrangement_on_surface_2<GeomTraits, TopTraits>& arr)
   return std::make_pair (gt_arr.edges_begin(), gt_arr.edges_end());
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif
