@@ -15,18 +15,27 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Intersections_2/include/CGAL/intersection_2_3.h $
-// $Id: intersection_2_3.h 46250 2008-10-13 20:35:32Z pmachado $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Intersections_2/include/CGAL/intersection_2_1.h $
+// $Id: intersection_2_1.h 28567 2006-02-16 14:30:13Z lsaboret $
 // 
 //
 // Author(s)     : Geert-Jan Giezeman
 
 
 
-#ifndef CGAL_INTERSECTION_2_3_H
-#define CGAL_INTERSECTION_2_3_H
+#ifndef CGAL_INTERSECTION_2_1_H
+#define CGAL_INTERSECTION_2_1_H
 
-#include <CGAL/Circle_2_Circle_2_intersection.h>
-#include <CGAL/Circle_2_Line_2_intersection.h>
+#include <CGAL/Line_2_Line_2_intersection.h>
+#include <CGAL/Segment_2_Line_2_intersection.h>
+#include <CGAL/Segment_2_Segment_2_intersection.h>
+#include <CGAL/Ray_2_Line_2_intersection.h>
+#include <CGAL/Ray_2_Segment_2_intersection.h>
+#include <CGAL/Ray_2_Ray_2_intersection.h>
+#include <CGAL/Point_2_Line_2_intersection.h>
+#include <CGAL/Point_2_Ray_2_intersection.h>
+#include <CGAL/Point_2_Segment_2_intersection.h>
+#include <CGAL/Point_2_Point_2_intersection.h>
+#include <CGAL/Point_2_Triangle_2_intersection.h>
 
 #endif
