@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Number_types/include/CGAL/leda_integer.h $
-// $Id: leda_integer.h 46989 2008-11-23 14:08:51Z afabri $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Number_types/include/CGAL/leda_integer.h $
+// $Id: leda_integer.h 63778 2011-05-31 13:03:27Z sloriot $
 //
 //
 // Author(s)     : Andreas Fabri, Michael Hemmer
@@ -45,7 +45,8 @@
 #include <CGAL/Residue.h>
 #include <CGAL/Modular_traits.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
+
 
 template <> class Algebraic_structure_traits< leda_integer >
   : public Algebraic_structure_traits_base< leda_integer,
@@ -266,7 +267,7 @@ public:
 };
 
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 // Unary + is missing for leda::integer
 namespace leda {
