@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Number_types/include/CGAL/long_long.h $
-// $Id: long_long.h 44789 2008-08-05 13:42:15Z hemmer $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Number_types/include/CGAL/long_long.h $
+// $Id: long_long.h 64106 2011-06-14 15:52:53Z pmoeller $
 //
 //
 // Author(s)     : Stefan Schirra, Michael Hemmer
@@ -30,7 +30,7 @@
 
 #include <CGAL/number_type_basic.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template<> class Algebraic_structure_traits< long long int >
   : public Algebraic_structure_traits_base< long long int,
@@ -77,16 +77,7 @@ template <> class Real_embeddable_traits< long long int >
     };
 };
 
-#if (defined(__sparc__) || defined(__sparc) || defined(sparc)) || \
-    (defined(__i386__)  || defined(__i386)  || defined(i386)) || \
-    (defined(__ppc__)   || defined(__ppc)   || defined(ppc)) || \
-    (defined(__powerpc__) || defined(__powerpc) || defined(powerpc))
-typedef  long long int           Integer64;
-typedef  unsigned long long int  UInteger64;
-#define CGAL_HAS_INTEGER64
-#endif
-
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #include <CGAL/Interval_nt.h>
 
