@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Skin_surface_3/include/CGAL/make_union_of_balls_3.h $
-// $Id: make_union_of_balls_3.h 52628 2009-10-20 08:59:26Z lrineau $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Skin_surface_3/include/CGAL/make_union_of_balls_3.h $
+// $Id: make_union_of_balls_3.h 60662 2011-01-09 11:47:58Z nicokruithof $
 // 
 //
 // Author(s)     : Nico Kruithof <Nico@cs.rug.nl>
@@ -20,7 +20,6 @@
 #ifndef CGAL_MAKE_UNION_OF_BALLS_MESH_3_H
 #define CGAL_MAKE_UNION_OF_BALLS_MESH_3_H
 
-#include <CGAL/Exact_predicates_inexact_constructions_kernel.h>
 #include <CGAL/Skin_surface_traits_3.h>
 #include <CGAL/Union_of_balls_3.h>
 #include <CGAL/mesh_union_of_balls_3.h>
@@ -28,7 +27,7 @@
 
 #include <CGAL/make_union_of_balls_3.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template <class WP_iterator,
 	  class Polyhedron_3>
@@ -36,7 +35,9 @@ void make_union_of_balls_mesh_3(Polyhedron_3 &p,
 			      WP_iterator begin, WP_iterator end, 
 			      int nSubdivisions=0)
 {
-  typedef Exact_predicates_inexact_constructions_kernel K;
+  typedef typename WP_iterator::value_type              Weighted_point;
+  typedef typename Kernel_traits<Weighted_point>::Kernel K;
+
   typedef Skin_surface_traits_3<K>                      Traits;
   typedef Union_of_balls_3<Traits>                      Union_of_balls;
   
@@ -49,6 +50,6 @@ void make_union_of_balls_mesh_3(Polyhedron_3 &p,
 
 
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_MAKE_UNION_OF_BALLS_MESH_3_H
