@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Surface_reconstruction_points_3/include/CGAL/poisson_refine_triangulation.h $
-// $Id: poisson_refine_triangulation.h 52585 2009-10-16 08:50:48Z stayeb $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Surface_reconstruction_points_3/include/CGAL/poisson_refine_triangulation.h $
+// $Id: poisson_refine_triangulation.h 57924 2010-08-10 13:22:20Z afabri $
 //
 // Author(s)     : Laurent RINEAU, Laurent Saboret
 
@@ -26,8 +26,9 @@
 #include <CGAL/Poisson_mesh_cell_criteria_3.h>
 #include <CGAL/Memory_sizer.h>
 #include <CGAL/surface_reconstruction_points_assertions.h>
+#include <CGAL/Surface_mesh_traits_generator_3.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 
 /// Utility class for poisson_refine_triangulation():
@@ -53,6 +54,7 @@ public:
   using Base::triangulation_ref_impl;
   using Base::oracle;
   using Base::surface;
+  using Base::should_be_refined;
 
   typedef typename Tr::Geom_traits Geom_traits;
   typedef typename Tr::Vertex_handle Vertex_handle;
@@ -95,8 +97,9 @@ public:
 
   void scan_triangulation_impl()
   {
-    for(typename Tr::Finite_cells_iterator cit = triangulation_ref_impl().finite_cells_begin();
-        cit != triangulation_ref_impl().finite_cells_end();
+    for(typename Tr::Finite_cells_iterator cit = triangulation_ref_impl().finite_cells_begin(),
+        eit = triangulation_ref_impl().finite_cells_end();
+        cit != eit;
         ++cit)
       test_if_cell_is_bad(cit);
   }
@@ -116,7 +119,7 @@ public:
     typedef std::vector<Cell_handle> Cells;
     typedef typename Cells::iterator Cell_iterator;
     Cells incident_cells;
-
+    incident_cells.reserve(32);
     triangulation_ref_impl().incident_cells(v, std::back_inserter(incident_cells));
 
     for(Cell_iterator cit = incident_cells.begin();
@@ -249,6 +252,6 @@ unsigned int poisson_refine_triangulation(
 }
 
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_POISSON_REFINE_TRIANGULATION_H
