@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Cartesian_kernel/include/CGAL/predicates/kernel_ftC2.h $
-// $Id: kernel_ftC2.h 44908 2008-08-12 12:43:20Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/Cartesian_kernel/include/CGAL/predicates/kernel_ftC2.h $
+// $Id: kernel_ftC2.h 65553 2011-09-26 12:33:57Z lrineau $
 // 
 //
 // Author(s)     : Herve Bronnimann (Herve.Bronnimann@sophia.inria.fr)
@@ -30,7 +30,7 @@
 #include <CGAL/predicates/sign_of_determinant.h>
 #include <CGAL/constructions/kernel_ftC2.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template < class FT >
 inline
@@ -186,6 +186,14 @@ compare_y_at_xC2(const FT &l1a, const FT &l1b, const FT &l1c,
                                         h1a*num+h1c*den, h1b);
 }
 
+// forward-declaration of orientationC2, used in compare_y_at_xC2
+template < class FT >
+inline
+typename Same_uncertainty_nt<Orientation, FT>::type
+orientationC2(const FT &px, const FT &py,
+              const FT &qx, const FT &qy,
+              const FT &rx, const FT &ry);
+
 template < class FT >
 CGAL_KERNEL_LARGE_INLINE
 typename Compare<FT>::result_type
@@ -412,6 +420,15 @@ orientationC2(const FT &ux, const FT &uy, const FT &vx, const FT &vy)
   return sign_of_determinant(ux, uy, vx, vy);
 }
 
+template < class FT >
+inline
+typename Same_uncertainty_nt<Angle, FT>::type
+angleC2(const FT &ux, const FT &uy,
+        const FT &vx, const FT &vy)
+{
+  return enum_cast<Angle>(CGAL_NTS sign(ux*vx + uy*vy));
+}
+
 template < class FT >
 inline
 typename Same_uncertainty_nt<Angle, FT>::type
@@ -422,6 +439,17 @@ angleC2(const FT &px, const FT &py,
   return enum_cast<Angle>(CGAL_NTS sign((px-qx)*(rx-qx)+(py-qy)*(ry-qy)));
 }
 
+template < class FT >
+inline
+typename Same_uncertainty_nt<Angle, FT>::type
+angleC2(const FT &px, const FT &py,
+        const FT &qx, const FT &qy,
+        const FT &rx, const FT &ry,
+        const FT &sx, const FT &sy)
+{
+  return enum_cast<Angle>(CGAL_NTS sign((px-qx)*(rx-sx)+(py-qy)*(ry-sy)));
+}
+
 template < class FT >
 CGAL_KERNEL_MEDIUM_INLINE
 typename Equal_to<FT>::result_type
@@ -606,6 +634,6 @@ side_of_oriented_lineC2(const FT &a, const FT &b, const FT &c,
   return CGAL_NTS sign(a*x+b*y+c);
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif  // CGAL_PREDICATES_KERNEL_FTC2_H
