@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Interpolation/include/CGAL/predicates/predicates_for_voronoi_intersection_cartesian_2_3.h $
-// $Id: predicates_for_voronoi_intersection_cartesian_2_3.h 42806 2008-04-09 12:35:10Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Interpolation/include/CGAL/predicates/predicates_for_voronoi_intersection_cartesian_2_3.h $
+// $Id: predicates_for_voronoi_intersection_cartesian_2_3.h 56667 2010-06-09 07:37:13Z sloriot $
 // 
 //
 // Author(s)     : Julia Floetotto
@@ -20,7 +20,7 @@
 #ifndef CGAL_PREDICATES_FOR_VORONOI_INTERSECTION_CARTESIAN_2_3_H
 #define CGAL_PREDICATES_FOR_VORONOI_INTERSECTION_CARTESIAN_2_3_H
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 template < class RT>
 Oriented_side
@@ -146,6 +146,6 @@ side_of_plane_centered_sphereC3(const RT &ax, const RT &ay, const RT &az,
 						   rx-px, ry-py,rz-pz);
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_PREDICATES_FOR_VORONOI_INTERSECTION_CARTESIAN_2_3_H
