@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/STL_Extension/include/CGAL/tags.h $
-// $Id: tags.h 36014 2007-02-02 08:37:35Z hemmer $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/STL_Extension/include/CGAL/tags.h $
+// $Id: tags.h 63225 2011-04-29 14:32:31Z sloriot $
 // 
 //
 // Author(s)     : Stefan Schirra
@@ -26,8 +26,9 @@
 #define CGAL_TAGS_H
 
 #include <CGAL/IO/io_tags.h>
+#include <boost/config.hpp>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 struct Void {};
 
@@ -48,8 +49,10 @@ inline bool check_tag( Tag_false) {return false;}
 struct Null_tag {};
 
 struct Null_functor {
+  #if defined(BOOST_MSVC) //temporary fix for VC
   typedef Null_tag result_type;
   typedef Null_tag second_argument_type; 
+  #endif
 };
 
 
@@ -80,6 +83,6 @@ inline
 void
 assert_equal_types( const T&, const T&) {}
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 
 #endif // CGAL_TAGS_H
