@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Intersections_2/src/CGAL/Bbox_2_intersections.cpp $
-// $Id: Bbox_2_intersections.cpp 31166 2006-05-17 16:30:56Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Intersections_2/src/CGAL/Bbox_2_intersections.cpp $
+// $Id: Bbox_2_intersections.cpp 56667 2010-06-09 07:37:13Z sloriot $
 // 
 //
 // Author(s)     : Geert-Jan Giezeman
@@ -28,7 +28,7 @@
 typedef CGAL::Simple_cartesian<double> Rcart;
 
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 class Bbox_2_Line_2_pair_impl
 {
@@ -363,4 +363,4 @@ bool do_intersect_ray_2(
     return pair.intersection_type() != Bbox_2_Ray_2_pair::NO_INTERSECTION;
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
