@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Stream_support/src/CGAL/File_writer_wavefront.cpp $
-// $Id: File_writer_wavefront.cpp 35787 2007-01-24 17:16:05Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Stream_support/src/CGAL/File_writer_wavefront.cpp $
+// $Id: File_writer_wavefront.cpp 56667 2010-06-09 07:37:13Z sloriot $
 // 
 //
 // Author(s)     : Lutz Kettner  <kettner@mpi-sb.mpg.de>
@@ -25,7 +25,7 @@
 #include <iostream>
 #include <CGAL/IO/File_writer_wavefront.h>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 void
 File_writer_wavefront::
@@ -45,5 +45,5 @@ write_header( std::ostream& o,
     out() << "# ------------------------------------------\n\n";
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
 // EOF //
