@@ -15,16 +15,17 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Random_numbers/src/CGAL/Random.cpp $
-// $Id: Random.cpp 47078 2008-11-27 15:32:38Z lrineau $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/Random_numbers/src/CGAL/Random.cpp $
+// $Id: Random.cpp 58582 2010-09-09 09:52:00Z afabri $
 // 
 //
 // Author(s)     : Sven Schnherr <sven@inf.ethz.ch>
 
 #include <CGAL/Random.h>
 #include <ctime>
+#include <sstream>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 // Class implementation (continued)
 // ================================
@@ -32,7 +33,7 @@ CGAL_BEGIN_NAMESPACE
 // constructors
 Random::
 Random( )
-    : rand_max_plus_1( RAND_MAX+1.0), val(0)
+    :  val(0)
 {
     // get system's time
     std::time_t s;
@@ -40,16 +41,16 @@ Random( )
     seed = (unsigned int)s;
 
     // initialize random numbers generator
-    std::srand( seed);
+    rng.seed(static_cast<boost::int32_t>(seed));
     random_value = get_int(0, 1<<15);
 }
 
 Random::
-Random( unsigned int  seed_)
-    : rand_max_plus_1( RAND_MAX+1.0), val(0), seed(seed_)
+Random( unsigned int  seed)
+    : val(0), seed(seed)
 {
     // initialize random numbers generator
-    std::srand( seed);
+    rng.seed(static_cast<boost::int32_t>(seed));
     random_value = get_int(0, 1<<15);
 }
 
@@ -64,18 +65,23 @@ Random::get_seed () const
 void 
 Random::save_state( Random::State& state) const
 {
-  state = Random::State(random_value, val);
+  std::ostringstream os;
+  os << rng;
+  state = Random::State(os.str(),random_value, val, seed);
 }
 
 void 
 Random::restore_state( const Random::State& state)
 {
-  random_value = state.first;
-  val = state.second;
+  std::istringstream is(state.rng);
+  is >> rng;
+  random_value = state.random_value;
+  val = state.val;
+  seed = state.seed;
 }
 
 // Global variables
 // ================
 Random  default_random;
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
