@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/STL_Extension/src/CGAL/assertions.cpp $
-// $Id: assertions.cpp 58595 2010-09-10 09:51:25Z glisse $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-3.9-branch/STL_Extension/src/CGAL/assertions.cpp $
+// $Id: assertions.cpp 65393 2011-09-14 13:38:48Z lrineau $
 // 
 //
 // Author(s)     : Geert-Jan Giezeman and Sven Schnherr
@@ -49,7 +49,7 @@ _standard_error_handler(
         int         line,
         const char* msg )
 {
-#if defined(__GNUG__) && !defined(__clang__)
+#if defined(__GNUG__) && !defined(__llvm__)
     // After g++ 3.4, std::terminate defaults to printing to std::cerr itself.
     if (_error_behaviour == THROW_EXCEPTION)
         return;
@@ -73,7 +73,7 @@ _standard_warning_handler( const char *,
                           int         line,
                           const char* msg )
 {
-#if defined(__GNUG__) && !defined(__clang__)
+#if defined(__GNUG__) && !defined(__llvm__)
     // After g++ 3.4, std::terminate defaults to printing to std::cerr itself.
     if (_warning_behaviour == THROW_EXCEPTION)
         return;
