@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/iostream/src/CGAL/io.cpp $
-// $Id: io.cpp 40831 2007-11-07 23:11:19Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/trunk/iostream/src/CGAL/io.cpp $
+// $Id: io.cpp 56667 2010-06-09 07:37:13Z sloriot $
 // 
 //
 // Author(s)     : Andreas Fabri
@@ -28,7 +28,7 @@
 #include <sstream>
 #include <string>
 
-CGAL_BEGIN_NAMESPACE
+namespace CGAL {
 
 int IO::mode = std::ios::xalloc();
 
@@ -121,4 +121,4 @@ swallow(std::istream &is, const std::string& s ) {
     }
 }
 
-CGAL_END_NAMESPACE
+} //namespace CGAL
